Class: OpenAI::Models::Admin::Organization::AuditLogListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/admin/organization/audit_log_list_params.rb,
sig/openai/models/admin/organization/audit_log_list_params.rbs

Overview

See Also:

  • OpenAI::Resources::Admin::Organization::AuditLogs#list

Defined Under Namespace

Modules: EventType Classes: EffectiveAt

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(gt: nil, gte: nil, lt: nil, lte: nil) ⇒ Object

Parameters:

  • actor_emails —

    Return only events performed by users with these emails.

  • actor_ids —

    Return only events performed by these actors. Can be a user ID, a service account ID, or an api key tracking ID.

  • after —

    A cursor for use in pagination. after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include after=obj_foo in order to fetch the next page of the list.

  • before —

    A cursor for use in pagination. before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_foo, your subsequent call can include before=obj_foo in order to fetch the previous page of the list.

  • effective_at —

    Return only events whose effective_at (Unix seconds) is in this range.

  • event_types —

    Return only events with a type in one of these values. For example, project.created. For all options, see the documentation for the audit log object.

  • limit —

    A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20.

  • project_ids —

    Return only events for these projects.

  • resource_ids —

    Return only events performed on these targets. For example, a project ID updated. For ChatGPT connector role events, use the workspace connector resource ID shown in details.id, such as <workspace_id>__<connector_id>.

  • tenant_only —

    Return only tenant-scoped events associated with this organization. Required for tenant-scoped events such as role.bound_to_resource and role.unbound_from_resource. When true, all supplied event types must be tenant-scoped.



# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 166

Instance Attribute Details

#actor_emails ⇒ ::Array[String]?

Return only events performed by users with these emails.

Returns:

  • (::Array[String], nil)


16
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 16

optional :actor_emails, OpenAI::Internal::Type::ArrayOf[String]

#actor_ids ⇒ ::Array[String]?

Return only events performed by these actors. Can be a user ID, a service account ID, or an api key tracking ID.

Returns:

  • (::Array[String], nil)


23
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 23

optional :actor_ids, OpenAI::Internal::Type::ArrayOf[String]

#after ⇒ String?

A cursor for use in pagination. after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include after=obj_foo in order to fetch the next page of the list.

Returns:

  • (String, nil)


32
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 32

optional :after, String

#before ⇒ String?

A cursor for use in pagination. before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_foo, your subsequent call can include before=obj_foo in order to fetch the previous page of the list.

Returns:

  • (String, nil)


41
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 41

optional :before, String

#effective_at ⇒ OpenAI::Admin::Organization::AuditLogListParams::EffectiveAt?

Return only events whose effective_at (Unix seconds) is in this range.

Returns:

  • (OpenAI::Admin::Organization::AuditLogListParams::EffectiveAt, nil)


47
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 47

optional :effective_at, -> { OpenAI::Admin::Organization::AuditLogListParams::EffectiveAt }

#event_types ⇒ ::Array[OpenAI::Models::Admin::Organization::AuditLogListParams::event_type]?

Return only events with a type in one of these values. For example, project.created. For all options, see the documentation for the audit log object.

Returns:

  • (::Array[OpenAI::Models::Admin::Organization::AuditLogListParams::event_type], nil)


55
56
57
58
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 55

optional(
  :event_types,
  -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Admin::Organization::AuditLogListParams::EventType] }
)

#limit ⇒ Integer?

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20.

Returns:

  • (Integer, nil)


65
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 65

optional :limit, Integer

#project_ids ⇒ ::Array[String]?

Return only events for these projects.

Returns:

  • (::Array[String], nil)


71
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 71

optional :project_ids, OpenAI::Internal::Type::ArrayOf[String]

#resource_ids ⇒ ::Array[String]?

Return only events performed on these targets. For example, a project ID updated. For ChatGPT connector role events, use the workspace connector resource ID shown in details.id, such as <workspace_id>__<connector_id>.

Returns:

  • (::Array[String], nil)


79
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 79

optional :resource_ids, OpenAI::Internal::Type::ArrayOf[String]

#tenant_only ⇒ Boolean?

Return only tenant-scoped events associated with this organization. Required for tenant-scoped events such as role.bound_to_resource and role.unbound_from_resource. When true, all supplied event types must be tenant-scoped.

Returns:



88
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 88

optional :tenant_only, OpenAI::Internal::Type::Boolean

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


167
# File 'sig/openai/models/admin/organization/audit_log_list_params.rbs', line 167

def to_hash: -> {