Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/admin/organization/audit_log_list_response.rb,
sig/openai/models/admin/organization/audit_log_list_response.rbs

Overview

See Also:

  • OpenAI::Models::Admin::Organization::AuditLogListResponse#actor

Defined Under Namespace

Modules: Type Classes: APIKey, Session

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, email: nil) ⇒ Object

The user who performed the audit logged action.

Parameters:

  • id (String) (defaults to: nil)

    The user id.

  • email (String) (defaults to: nil)

    The user email.



# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 800

Instance Attribute Details

#api_keyOpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::APIKey?

The API Key used to perform the audit logged action.



786
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 786

optional :api_key, -> { OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::APIKey }

#sessionOpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::Session?

The session in which the audit logged action was performed.



792
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 792

optional :session, -> { OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::Session }

#typeSymbol, ...

The type of actor. Is either session or api_key.



798
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 798

optional :type, enum: -> { OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::Type }

Instance Method Details

#to_hash{

Returns:

  • ({)


865
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 865

def to_hash: -> {