Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::APIKey
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::APIKey
- Defined in:
- lib/openai/models/admin/organization/audit_log_list_response.rb,
sig/openai/models/admin/organization/audit_log_list_response.rbs
Overview
Defined Under Namespace
Modules: Type Classes: ServiceAccount, User
Instance Attribute Summary collapse
-
#id ⇒ String?
The tracking id of the API key.
-
#service_account ⇒ OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::APIKey::ServiceAccount?
The service account that performed the audit logged action.
-
#type ⇒ Symbol, ...
The type of API key.
-
#user ⇒ OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::APIKey::User?
The user who performed the audit logged action.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil) ⇒ Object
constructor
The service account that performed the audit logged action.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil) ⇒ Object
The service account that performed the audit logged action.
|
|
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 927
|
Instance Attribute Details
#id ⇒ String?
The tracking id of the API key.
901 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 901 optional :id, String |
#service_account ⇒ OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::APIKey::ServiceAccount?
The service account that performed the audit logged action.
907 908 909 910 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 907 optional( :service_account, -> { OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::APIKey::ServiceAccount } ) |
#type ⇒ Symbol, ...
The type of API key. Can be either user or service_account.
916 917 918 919 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 916 optional( :type, enum: -> { OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::APIKey::Type } ) |
#user ⇒ OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::APIKey::User?
The user who performed the audit logged action.
925 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 925 optional :user, -> { OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::APIKey::User } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 961
|
Instance Method Details
#to_hash ⇒ {
911 |
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 911
def to_hash: -> {
|