Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::Session
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::Session
- Defined in:
- lib/openai/models/admin/organization/audit_log_list_response.rb
Overview
Defined Under Namespace
Classes: User
Instance Attribute Summary collapse
-
#ip_address ⇒ String?
The IP address from which the action was performed.
-
#user ⇒ OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::Session::User?
The user who performed the audit logged action.
Instance Method Summary collapse
-
#initialize(ip_address: nil, user: nil) ⇒ Object
constructor
The session in which the audit logged action was performed.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ip_address: nil, user: nil) ⇒ Object
The session in which the audit logged action was performed.
|
|
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 718
|
Instance Attribute Details
#ip_address ⇒ String?
The IP address from which the action was performed.
710 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 710 optional :ip_address, String |
#user ⇒ OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::Session::User?
The user who performed the audit logged action.
716 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 716 optional :user, -> { OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::Session::User } |