Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::CheckpointPermissionCreated::Data

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/admin/organization/audit_log_list_response.rb,
sig/openai/models/admin/organization/audit_log_list_response.rbs

Overview

See Also:

  • OpenAI::Models::Admin::Organization::AuditLogListResponse::CheckpointPermissionCreated#data

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • fine_tuned_model_checkpoint —

    The ID of the fine-tuned model checkpoint.

  • project_id —

    The ID of the project that the checkpoint permission was created for.



1699
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 1699

def initialize: (

Instance Attribute Details

#fine_tuned_model_checkpoint ⇒ String?

The ID of the fine-tuned model checkpoint.

Returns:

  • (String, nil)


1442
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1442

optional :fine_tuned_model_checkpoint, String

#project_id ⇒ String?

The ID of the project that the checkpoint permission was created for.

Returns:

  • (String, nil)


1448
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1448

optional :project_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


1704
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 1704

def to_hash: -> {