Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::OrganizationUpdated::ChangesRequested
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::AuditLogListResponse::OrganizationUpdated::ChangesRequested
- Defined in:
- lib/openai/models/admin/organization/audit_log_list_response.rb,
sig/openai/models/admin/organization/audit_log_list_response.rbs
Overview
Instance Attribute Summary collapse
-
#api_call_logging ⇒ String?
How your organization logs data from supported API calls.
-
#api_call_logging_project_ids ⇒ String?
The list of project ids if api_call_logging is set to
enabled_for_selected_projects. -
#description ⇒ String?
The organization description.
-
#name ⇒ String?
The organization name.
-
#threads_ui_visibility ⇒ String?
Visibility of the threads page which shows messages created with the Assistants API and Playground.
-
#title ⇒ String?
The organization title.
-
#usage_dashboard_visibility ⇒ String?
Visibility of the usage dashboard which shows activity and costs for your organization.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1740 |
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 1740
def initialize: (
|
Instance Attribute Details
#api_call_logging ⇒ String?
How your organization logs data from supported API calls. One of disabled,
enabled_per_call, enabled_for_all_projects, or
enabled_for_selected_projects
1662 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1662 optional :api_call_logging, String |
#api_call_logging_project_ids ⇒ String?
The list of project ids if api_call_logging is set to
enabled_for_selected_projects
1669 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1669 optional :api_call_logging_project_ids, String |
#description ⇒ String?
The organization description.
1675 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1675 optional :description, String |
#name ⇒ String?
The organization name.
1681 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1681 optional :name, String |
#threads_ui_visibility ⇒ String?
Visibility of the threads page which shows messages created with the Assistants
API and Playground. One of ANY_ROLE, OWNERS, or NONE.
1688 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1688 optional :threads_ui_visibility, String |
#title ⇒ String?
The organization title.
1694 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1694 optional :title, String |
#usage_dashboard_visibility ⇒ String?
Visibility of the usage dashboard which shows activity and costs for your
organization. One of ANY_ROLE or OWNERS.
1701 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1701 optional :usage_dashboard_visibility, String |
Instance Method Details
#to_hash ⇒ {
1750 |
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 1750
def to_hash: -> {
|