Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::ProjectCreated::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::AuditLogListResponse::ProjectCreated::Data
- Defined in:
- lib/openai/models/admin/organization/audit_log_list_response.rb,
sig/openai/models/admin/organization/audit_log_list_response.rbs
Overview
Instance Attribute Summary collapse
-
#name ⇒ String?
The project name.
-
#title ⇒ String?
The title of the project as seen on the dashboard.
Instance Method Summary collapse
-
#initialize ⇒ Data
constructor
A new instance of Data.
- #to_hash ⇒ { name: String, title: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Data
Returns a new instance of Data.
1658 |
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 1658
def initialize: (?name: String, ?title: String) -> void
|
Instance Attribute Details
#name ⇒ String?
The project name.
1685 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1685 optional :name, String |
#title ⇒ String?
The title of the project as seen on the dashboard.
1691 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1691 optional :title, String |
Instance Method Details
#to_hash ⇒ { name: String, title: String }
1660 |
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 1660
def to_hash: -> { name: String, title: String }
|