Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleBoundToResource

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/admin/organization/audit_log_list_response.rb,
sig/openai/models/admin/organization/audit_log_list_response.rbs

Overview

See Also:

  • OpenAI::Models::Admin::Organization::AuditLogListResponse#role_bound_to_resource

Defined Under Namespace

Modules: Source

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, connector_id: nil, connector_name: nil, enabled: nil, permissions: nil, resource_id: nil, resource_type: nil, role_id: nil, source: nil, workspace_id: nil) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleBoundToResource for more details.

The details for events with this type.

Parameters:

  • id (String) (defaults to: nil)

    The ID of the resource the role was bound to. ChatGPT workspace connector resour

  • connector_id (String) (defaults to: nil)

    The connector ID for a ChatGPT workspace connector resource.

  • connector_name (String) (defaults to: nil)

    The connector display name for a ChatGPT workspace connector resource, or the co

  • enabled (Boolean) (defaults to: nil)

    Whether the connector is enabled for the role.

  • permissions (Array<String>) (defaults to: nil)

    The permissions granted to the role for the resource.

  • resource_id (String) (defaults to: nil)

    The ID of the resource the role was bound to.

  • resource_type (String) (defaults to: nil)

    The type of resource the role was bound to.

  • role_id (String) (defaults to: nil)

    The ID of the role that was bound to the resource.

  • source (Symbol, OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleBoundToResource::Source) (defaults to: nil)

    The connector role mutation path that produced the event.

  • workspace_id (String) (defaults to: nil)

    The workspace ID for a ChatGPT workspace connector resource.



# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2085

Instance Attribute Details

#connector_idString?

The connector ID for a ChatGPT workspace connector resource.

Parameters:

  • (String)

Returns:

  • (String, nil)


2033
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2033

optional :connector_id, String

#connector_nameString?

The connector display name for a ChatGPT workspace connector resource, or the connector ID when the display name could not be resolved.

Parameters:

  • (String)

Returns:

  • (String, nil)


2040
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2040

optional :connector_name, String

#enabledBoolean?

Whether the connector is enabled for the role.

Parameters:

Returns:



2046
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2046

optional :enabled, OpenAI::Internal::Type::Boolean

#idString?

The ID of the resource the role was bound to. ChatGPT workspace connector resources use <workspace_id>__<connector_id>.

Parameters:

  • (String)

Returns:

  • (String, nil)


2027
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2027

optional :id, String

#permissionsArray<String>?

The permissions granted to the role for the resource.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


2052
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2052

optional :permissions, OpenAI::Internal::Type::ArrayOf[String]

#resource_idString?

The ID of the resource the role was bound to.

Parameters:

  • (String)

Returns:

  • (String, nil)


2058
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2058

optional :resource_id, String

#resource_typeString?

The type of resource the role was bound to.

Parameters:

  • (String)

Returns:

  • (String, nil)


2064
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2064

optional :resource_type, String

#role_idString?

The ID of the role that was bound to the resource.

Parameters:

  • (String)

Returns:

  • (String, nil)


2070
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2070

optional :role_id, String

#sourceSymbol, ...

The connector role mutation path that produced the event.



2076
2077
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2076

optional :source,
enum: -> { OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleBoundToResource::Source }

#workspace_idString?

The workspace ID for a ChatGPT workspace connector resource.

Parameters:

  • (String)

Returns:

  • (String, nil)


2083
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2083

optional :workspace_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


2142
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 2142

def to_hash: -> {