Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleUnboundFromResource

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/admin/organization/audit_log_list_response.rb,
sig/openai/models/admin/organization/audit_log_list_response.rbs

Overview

See Also:

  • OpenAI::Models::Admin::Organization::AuditLogListResponse#role_unbound_from_resource

Defined Under Namespace

Modules: Source

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, connector_id: nil, connector_name: nil, enabled: nil, permissions: nil, resource_id: nil, resource_type: nil, role_id: nil, source: nil, workspace_id: nil) ⇒ Object

Parameters:

  • id (defaults to: nil) —

    The ID of the resource the role was unbound from. ChatGPT workspace connector resources use <workspace_id>__<connector_id>.

  • connector_id (defaults to: nil) —

    The connector ID for a ChatGPT workspace connector resource.

  • connector_name (defaults to: nil) —

    The connector display name for a ChatGPT workspace connector resource, or the connector ID when the display name could not be resolved.

  • enabled (defaults to: nil) —

    Whether the connector is enabled for the role.

  • permissions (defaults to: nil) —

    The permissions remaining for the role after the change.

  • resource_id (defaults to: nil) —

    The ID of the resource the role was unbound from.

  • resource_type (defaults to: nil) —

    The type of resource the role was unbound from.

  • role_id (defaults to: nil) —

    The ID of the role that was unbound from the resource.

  • source (defaults to: nil) —

    The connector role mutation path that produced the event.

  • workspace_id (defaults to: nil) —

    The workspace ID for a ChatGPT workspace connector resource.



# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2708

Instance Attribute Details

#connector_id ⇒ String?

The connector ID for a ChatGPT workspace connector resource.

Returns:

  • (String, nil)


2654
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2654

optional :connector_id, String

#connector_name ⇒ String?

The connector display name for a ChatGPT workspace connector resource, or the connector ID when the display name could not be resolved.

Returns:

  • (String, nil)


2661
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2661

optional :connector_name, String

#enabled ⇒ Boolean?

Whether the connector is enabled for the role.

Returns:



2667
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2667

optional :enabled, OpenAI::Internal::Type::Boolean

#id ⇒ String?

The ID of the resource the role was unbound from. ChatGPT workspace connector resources use <workspace_id>__<connector_id>.

Returns:

  • (String, nil)


2648
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2648

optional :id, String

#permissions ⇒ ::Array[String]?

The permissions remaining for the role after the change.

Returns:

  • (::Array[String], nil)


2673
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2673

optional :permissions, OpenAI::Internal::Type::ArrayOf[String]

#resource_id ⇒ String?

The ID of the resource the role was unbound from.

Returns:

  • (String, nil)


2679
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2679

optional :resource_id, String

#resource_type ⇒ String?

The type of resource the role was unbound from.

Returns:

  • (String, nil)


2685
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2685

optional :resource_type, String

#role_id ⇒ String?

The ID of the role that was unbound from the resource.

Returns:

  • (String, nil)


2691
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2691

optional :role_id, String

#source ⇒ OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleUnboundFromResource::source?

The connector role mutation path that produced the event.

Returns:

  • (OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleUnboundFromResource::source, nil)


2697
2698
2699
2700
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2697

optional(
  :source,
  enum: -> { OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleUnboundFromResource::Source }
)

#workspace_id ⇒ String?

The workspace ID for a ChatGPT workspace connector resource.

Returns:

  • (String, nil)


2706
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2706

optional :workspace_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


3257
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 3257

def to_hash: -> {