Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::WorkloadIdentityProviderMappingUpdated

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/admin/organization/audit_log_list_response.rb,
sig/openai/models/admin/organization/audit_log_list_response.rbs

Overview

See Also:

  • OpenAI::Models::Admin::Organization::AuditLogListResponse#workload_identity_provider_mapping_updated

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • id —

    The workload identity provider mapping ID.

  • changes_requested —

    The payload used to update the workload identity provider mapping.

  • identity_provider_id —

    The workload identity provider ID.



3816
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 3816

def initialize: (

Instance Attribute Details

#changes_requested ⇒ top?

The payload used to update the workload identity provider mapping.

Returns:

  • (top, nil)


3168
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 3168

optional :changes_requested, OpenAI::Internal::Type::Unknown

#id ⇒ String?

The workload identity provider mapping ID.

Returns:

  • (String, nil)


3162
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 3162

optional :id, String

#identity_provider_id ⇒ String?

The workload identity provider ID.

Returns:

  • (String, nil)


3174
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 3174

optional :identity_provider_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


3822
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 3822

def to_hash: -> {