Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::WorkloadIdentityProviderUpdated

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/admin/organization/audit_log_list_response.rb,
sig/openai/models/admin/organization/audit_log_list_response.rbs

Overview

See Also:

  • OpenAI::Models::Admin::Organization::AuditLogListResponse#workload_identity_provider_updated

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, changes_requested: nil) ⇒ WorkloadIdentityProviderUpdated

Returns a new instance of WorkloadIdentityProviderUpdated.

Parameters:

  • id (defaults to: nil) —

    The workload identity provider ID.

  • changes_requested (defaults to: nil) —

    The payload used to update the workload identity provider.

  • id: (String) (defaults to: nil)
  • changes_requested: (top) (defaults to: nil)


# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 3251

Instance Attribute Details

#changes_requested ⇒ top?

The payload used to update the workload identity provider.

Returns:

  • (top, nil)


3249
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 3249

optional :changes_requested, OpenAI::Internal::Type::Unknown

#id ⇒ String?

The workload identity provider ID.

Returns:

  • (String, nil)


3243
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 3243

optional :id, String

Instance Method Details

#to_hash ⇒ { ?id: String, ?changes_requested: top }

Returns:

  • ({ ?id: String, ?changes_requested: top })


3900
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 3900

def to_hash: -> { ?id: String, ?changes_requested: top }