Class: OpenAI::Models::Admin::Organization::CertificateRetrieveParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::CertificateRetrieveParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/admin/organization/certificate_retrieve_params.rb
Overview
Defined Under Namespace
Modules: Include
Instance Attribute Summary collapse
- #certificate_id ⇒ String
-
#include ⇒ Array<Symbol, OpenAI::Models::Admin::Organization::CertificateRetrieveParams::Include>?
A list of additional fields to include in the response.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#certificate_id ⇒ String
15 |
# File 'lib/openai/models/admin/organization/certificate_retrieve_params.rb', line 15 required :certificate_id, String |
#include ⇒ Array<Symbol, OpenAI::Models::Admin::Organization::CertificateRetrieveParams::Include>?
A list of additional fields to include in the response. Currently the only supported value is ‘content` to fetch the PEM content of the certificate.
22 23 |
# File 'lib/openai/models/admin/organization/certificate_retrieve_params.rb', line 22 optional :include, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Admin::Organization::CertificateRetrieveParams::Include] } |