Class: OpenAI::Models::Admin::Organization::Groups::UserCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/admin/organization/groups/user_create_response.rb,
sig/openai/models/admin/organization/groups/user_create_response.rbs

Overview

See Also:

  • OpenAI::Resources::Admin::Organization::Groups::Users#create

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(group_id:, user_id:, object: :"group.user") ⇒ Object

Parameters:

  • group_id —

    Identifier of the group the user was added to.

  • user_id —

    Identifier of the user that was added.

  • object (defaults to: :"group.user") —

    Always group.user.



# File 'lib/openai/models/admin/organization/groups/user_create_response.rb', line 28

Instance Attribute Details

#group_id ⇒ String

Identifier of the group the user was added to.

Returns:

  • (String)


14
# File 'lib/openai/models/admin/organization/groups/user_create_response.rb', line 14

required :group_id, String

#object ⇒ :"group.user"

Always group.user.

Returns:

  • (:"group.user")


20
# File 'lib/openai/models/admin/organization/groups/user_create_response.rb', line 20

required :object, const: :"group.user"

#user_id ⇒ String

Identifier of the user that was added.

Returns:

  • (String)


26
# File 'lib/openai/models/admin/organization/groups/user_create_response.rb', line 26

required :user_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


31
# File 'sig/openai/models/admin/organization/groups/user_create_response.rbs', line 31

def to_hash: -> {