Class: OpenAI::Models::Admin::Organization::Groups::UserListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/admin/organization/groups/user_list_params.rb

Overview

Defined Under Namespace

Modules: Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(group_id:, after: nil, limit: nil, order: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::Groups::UserListParams for more details.

Parameters:

  • group_id (String)
  • after (String) (defaults to: nil)

    A cursor for use in pagination. Provide the ID of the last user from the previou

  • limit (Integer) (defaults to: nil)

    A limit on the number of users to be returned. Limit can range between 0 and 100

  • order (Symbol, OpenAI::Models::Admin::Organization::Groups::UserListParams::Order) (defaults to: nil)

    Specifies the sort order of users in the list.

  • request_options (OpenAI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/openai/models/admin/organization/groups/user_list_params.rb', line 38

Instance Attribute Details

#afterString?

A cursor for use in pagination. Provide the ID of the last user from the previous list response to retrieve the next page.

Returns:

  • (String, nil)


23
# File 'lib/openai/models/admin/organization/groups/user_list_params.rb', line 23

optional :after, String

#group_idString

Returns:

  • (String)


16
# File 'lib/openai/models/admin/organization/groups/user_list_params.rb', line 16

required :group_id, String

#limitInteger?

A limit on the number of users to be returned. Limit can range between 0 and 1000, and the default is 100.

Returns:

  • (Integer, nil)


30
# File 'lib/openai/models/admin/organization/groups/user_list_params.rb', line 30

optional :limit, Integer

#orderSymbol, ...

Specifies the sort order of users in the list.



36
# File 'lib/openai/models/admin/organization/groups/user_list_params.rb', line 36

optional :order, enum: -> { OpenAI::Admin::Organization::Groups::UserListParams::Order }