Class: OpenAI::Models::Admin::Organization::Groups::UserRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::Groups::UserRetrieveResponse
- Defined in:
- lib/openai/models/admin/organization/groups/user_retrieve_response.rb
Overview
Defined Under Namespace
Modules: UserType
Instance Attribute Summary collapse
-
#email ⇒ String?
Email address of the user, or ‘null` for users without an email.
-
#id ⇒ String
Identifier for the user.
-
#is_service_account ⇒ Boolean?
Whether the user is a service account.
-
#name ⇒ String
Display name of the user.
-
#picture ⇒ String?
URL of the user’s profile picture, if available.
-
#user_type ⇒ Symbol, OpenAI::Models::Admin::Organization::Groups::UserRetrieveResponse::UserType
The type of user.
Instance Method Summary collapse
-
#initialize(id:, email:, is_service_account:, name:, picture:, user_type:) ⇒ Object
constructor
Details about a user returned from an organization group membership lookup.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, email:, is_service_account:, name:, picture:, user_type:) ⇒ Object
Details about a user returned from an organization group membership lookup.
|
|
# File 'lib/openai/models/admin/organization/groups/user_retrieve_response.rb', line 47
|
Instance Attribute Details
#email ⇒ String?
Email address of the user, or ‘null` for users without an email.
20 |
# File 'lib/openai/models/admin/organization/groups/user_retrieve_response.rb', line 20 required :email, String, nil?: true |
#id ⇒ String
Identifier for the user.
14 |
# File 'lib/openai/models/admin/organization/groups/user_retrieve_response.rb', line 14 required :id, String |
#is_service_account ⇒ Boolean?
Whether the user is a service account.
26 |
# File 'lib/openai/models/admin/organization/groups/user_retrieve_response.rb', line 26 required :is_service_account, OpenAI::Internal::Type::Boolean, nil?: true |
#name ⇒ String
Display name of the user.
32 |
# File 'lib/openai/models/admin/organization/groups/user_retrieve_response.rb', line 32 required :name, String |
#picture ⇒ String?
URL of the user’s profile picture, if available.
38 |
# File 'lib/openai/models/admin/organization/groups/user_retrieve_response.rb', line 38 required :picture, String, nil?: true |
#user_type ⇒ Symbol, OpenAI::Models::Admin::Organization::Groups::UserRetrieveResponse::UserType
The type of user.
44 45 |
# File 'lib/openai/models/admin/organization/groups/user_retrieve_response.rb', line 44 required :user_type, enum: -> { OpenAI::Models::Admin::Organization::Groups::UserRetrieveResponse::UserType } |