Class: OpenAI::Models::Admin::Organization::InviteCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/admin/organization/invite_create_params.rb,
sig/openai/models/admin/organization/invite_create_params.rbs

Overview

See Also:

  • OpenAI::Resources::Admin::Organization::Invites#create

Defined Under Namespace

Modules: Role Classes: Project

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(email:, role:, projects: nil, request_options: {}) ⇒ Object

Parameters:

  • email —

    Send an email to this address

  • role —

    owner or reader

  • projects (defaults to: nil) —

    An array of projects to which membership is granted at the same time the org invite is accepted. If omitted, the user will be invited to the default project for compatibility with legacy behavior. If empty list is passed, the user will not be invited to any projects, including the default one.



# File 'lib/openai/models/admin/organization/invite_create_params.rb', line 36

Instance Attribute Details

#email ⇒ String

Send an email to this address

Returns:

  • (String)


16
# File 'lib/openai/models/admin/organization/invite_create_params.rb', line 16

required :email, String

#projects ⇒ ::Array[OpenAI::Admin::Organization::InviteCreateParams::Project]?

An array of projects to which membership is granted at the same time the org invite is accepted. If omitted, the user will be invited to the default project for compatibility with legacy behavior. If empty list is passed, the user will not be invited to any projects, including the default one.

Returns:

  • (::Array[OpenAI::Admin::Organization::InviteCreateParams::Project], nil)


31
32
33
34
# File 'lib/openai/models/admin/organization/invite_create_params.rb', line 31

optional(
  :projects,
  -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Admin::Organization::InviteCreateParams::Project] }
)

#role ⇒ OpenAI::Models::Admin::Organization::InviteCreateParams::role

owner or reader

Returns:

  • (OpenAI::Models::Admin::Organization::InviteCreateParams::role)


22
# File 'lib/openai/models/admin/organization/invite_create_params.rb', line 22

required :role, enum: -> { OpenAI::Admin::Organization::InviteCreateParams::Role }

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/admin/organization/invite_create_params.rb', line 58

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


53
# File 'sig/openai/models/admin/organization/invite_create_params.rbs', line 53

def to_hash: -> {