Class: OpenAI::Models::Admin::Organization::OrganizationUser

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/admin/organization/organization_user.rb,
sig/openai/models/admin/organization/organization_user.rbs

Overview

See Also:

  • OpenAI::Resources::Admin::Organization::Users#retrieve

Defined Under Namespace

Classes: Projects, User

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, name: nil, role: nil) ⇒ Object

Parameters:

  • id (defaults to: nil)

    The identifier, which can be referenced in API endpoints

  • added_at

    The Unix timestamp (in seconds) of when the user was added.

  • api_key_last_used_at

    The Unix timestamp (in seconds) of the user's last API key usage.

  • created

    The Unix timestamp (in seconds) of when the user was created.

  • developer_persona

    The developer persona metadata for the user.

  • email

    The email address of the user

  • is_default

    Whether this is the organization's default user.

  • is_scale_tier_authorized_purchaser

    Whether the user is an authorized purchaser for Scale Tier.

  • is_scim_managed

    Whether the user is managed through SCIM.

  • is_service_account

    Whether the user is a service account.

  • name (defaults to: nil)

    The name of the user

  • projects

    Projects associated with the user, if included.

  • role (defaults to: nil)

    owner or reader

  • technical_level

    The technical level metadata for the user.

  • user

    Nested user details.

  • object

    The object type, which is always organization.user



# File 'lib/openai/models/admin/organization/organization_user.rb', line 105

Instance Attribute Details

#added_atInteger

The Unix timestamp (in seconds) of when the user was added.

Returns:

  • (Integer)


19
# File 'lib/openai/models/admin/organization/organization_user.rb', line 19

required :added_at, Integer

#api_key_last_used_atInteger?

The Unix timestamp (in seconds) of the user's last API key usage.

Returns:

  • (Integer, nil)


31
# File 'lib/openai/models/admin/organization/organization_user.rb', line 31

optional :api_key_last_used_at, Integer, nil?: true

#createdInteger?

The Unix timestamp (in seconds) of when the user was created.

Returns:

  • (Integer, nil)


37
# File 'lib/openai/models/admin/organization/organization_user.rb', line 37

optional :created, Integer

#developer_personaString?

The developer persona metadata for the user.

Returns:

  • (String, nil)


43
# File 'lib/openai/models/admin/organization/organization_user.rb', line 43

optional :developer_persona, String, nil?: true

#emailString?

The email address of the user

Returns:

  • (String, nil)


49
# File 'lib/openai/models/admin/organization/organization_user.rb', line 49

optional :email, String, nil?: true

#idString

The identifier, which can be referenced in API endpoints

Returns:

  • (String)


13
# File 'lib/openai/models/admin/organization/organization_user.rb', line 13

required :id, String

#is_defaultBoolean?

Whether this is the organization's default user.

Returns:



55
# File 'lib/openai/models/admin/organization/organization_user.rb', line 55

optional :is_default, OpenAI::Internal::Type::Boolean

#is_scale_tier_authorized_purchaserBoolean?

Whether the user is an authorized purchaser for Scale Tier.

Returns:



61
# File 'lib/openai/models/admin/organization/organization_user.rb', line 61

optional :is_scale_tier_authorized_purchaser, OpenAI::Internal::Type::Boolean, nil?: true

#is_scim_managedBoolean?

Whether the user is managed through SCIM.

Returns:



67
# File 'lib/openai/models/admin/organization/organization_user.rb', line 67

optional :is_scim_managed, OpenAI::Internal::Type::Boolean

#is_service_accountBoolean?

Whether the user is a service account.

Returns:



73
# File 'lib/openai/models/admin/organization/organization_user.rb', line 73

optional :is_service_account, OpenAI::Internal::Type::Boolean

#nameString?

The name of the user

Returns:

  • (String, nil)


79
# File 'lib/openai/models/admin/organization/organization_user.rb', line 79

optional :name, String, nil?: true

#object:"organization.user"

The object type, which is always organization.user

Returns:

  • (:"organization.user")


25
# File 'lib/openai/models/admin/organization/organization_user.rb', line 25

required :object, const: :"organization.user"

#projectsOpenAI::Admin::Organization::OrganizationUser::Projects?

Projects associated with the user, if included.

Returns:

  • (OpenAI::Admin::Organization::OrganizationUser::Projects, nil)


85
# File 'lib/openai/models/admin/organization/organization_user.rb', line 85

optional :projects, -> { OpenAI::Admin::Organization::OrganizationUser::Projects }, nil?: true

#roleString?

owner or reader

Returns:

  • (String, nil)


91
# File 'lib/openai/models/admin/organization/organization_user.rb', line 91

optional :role, String, nil?: true

#technical_levelString?

The technical level metadata for the user.

Returns:

  • (String, nil)


97
# File 'lib/openai/models/admin/organization/organization_user.rb', line 97

optional :technical_level, String, nil?: true

#userOpenAI::Admin::Organization::OrganizationUser::User?

Nested user details.

Returns:

  • (OpenAI::Admin::Organization::OrganizationUser::User, nil)


103
# File 'lib/openai/models/admin/organization/organization_user.rb', line 103

optional :user, -> { OpenAI::Admin::Organization::OrganizationUser::User }

Instance Method Details

#to_hash{

Returns:

  • ({)


144
# File 'sig/openai/models/admin/organization/organization_user.rbs', line 144

def to_hash: -> {