Class: OpenAI::Models::Admin::Organization::ProjectCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::ProjectCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/admin/organization/project_create_params.rb,
sig/openai/models/admin/organization/project_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#external_key_id ⇒ String?
External key ID to associate with the project.
- #geography ⇒ String? deprecated Deprecated.
-
#name ⇒ String
The friendly name of the project, this name appears in reports.
-
#residency ⇒ Symbol, ...
Create the project with the specified residency configuration.
Attributes included from Internal::Type::RequestParameters
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(name:, external_key_id: nil, geography: nil, residency: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ProjectCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, external_key_id: nil, geography: nil, residency: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::ProjectCreateParams for more details.
|
|
# File 'lib/openai/models/admin/organization/project_create_params.rb', line 46
|
Instance Attribute Details
#external_key_id ⇒ String?
External key ID to associate with the project.
22 |
# File 'lib/openai/models/admin/organization/project_create_params.rb', line 22 optional :external_key_id, String, nil?: true |
#geography ⇒ String?
Create the project with the specified data residency region. Your organization
must have access to Data residency functionality in order to use. See
data residency controls
to review the functionality and limitations of setting this field. Deprecated:
use residency instead. Do not provide both geography and residency.
34 |
# File 'lib/openai/models/admin/organization/project_create_params.rb', line 34 optional :geography, String, nil?: true |
#name ⇒ String
The friendly name of the project, this name appears in reports.
16 |
# File 'lib/openai/models/admin/organization/project_create_params.rb', line 16 required :name, String |
#residency ⇒ Symbol, ...
Create the project with the specified residency configuration. Your organization must have access to the requested residency configuration in order to use it. See data residency controls to review the functionality and limitations of setting this field.
44 |
# File 'lib/openai/models/admin/organization/project_create_params.rb', line 44 optional :residency, enum: -> { OpenAI::Admin::Organization::ProjectResidency }, nil?: true |
Instance Method Details
#to_hash ⇒ {
34 |
# File 'sig/openai/models/admin/organization/project_create_params.rbs', line 34
def to_hash: -> {
|