Class: OpenAI::Models::Admin::Organization::ProjectUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::ProjectUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/admin/organization/project_update_params.rb
Overview
Instance Attribute Summary collapse
-
#external_key_id ⇒ String?
External key ID to associate with the project.
-
#geography ⇒ String?
Geography for the project.
-
#name ⇒ String?
The updated name of the project, this name appears in reports.
- #project_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(project_id:, external_key_id: nil, geography: nil, name: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(project_id:, external_key_id: nil, geography: nil, name: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/openai/models/admin/organization/project_update_params.rb', line 35
|
Instance Attribute Details
#external_key_id ⇒ String?
External key ID to associate with the project.
21 |
# File 'lib/openai/models/admin/organization/project_update_params.rb', line 21 optional :external_key_id, String, nil?: true |
#geography ⇒ String?
Geography for the project.
27 |
# File 'lib/openai/models/admin/organization/project_update_params.rb', line 27 optional :geography, String, nil?: true |
#name ⇒ String?
The updated name of the project, this name appears in reports.
33 |
# File 'lib/openai/models/admin/organization/project_update_params.rb', line 33 optional :name, String, nil?: true |
#project_id ⇒ String
15 |
# File 'lib/openai/models/admin/organization/project_update_params.rb', line 15 required :project_id, String |