Class: OpenAI::Models::Admin::Organization::Projects::APIKeyListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/admin/organization/projects/api_key_list_params.rb,
sig/openai/models/admin/organization/projects/api_key_list_params.rbs

Overview

See Also:

  • OpenAI::Resources::Admin::Organization::Projects::APIKeys#list

Defined Under Namespace

Modules: OwnerProjectAccess

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(project_id:, after: nil, limit: nil, owner_project_access: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::Projects::APIKeyListParams for more details.

Parameters:

  • project_id (String)
  • after (String) (defaults to: nil)

    A cursor for use in pagination. after is an object ID that defines your place

  • limit (Integer) (defaults to: nil)

    A limit on the number of objects to be returned. Limit can range between 1 and 1

  • owner_project_access (Symbol, OpenAI::Models::Admin::Organization::Projects::APIKeyListParams::OwnerProjectAccess) (defaults to: nil)

    Filter API keys by whether the owner currently has effective access to the proje

  • request_options (OpenAI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/openai/models/admin/organization/projects/api_key_list_params.rb', line 45

Instance Attribute Details

#afterString?

A cursor for use in pagination. after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include after=obj_foo in order to fetch the next page of the list.

Parameters:

  • (String)

Returns:

  • (String, nil)


25
# File 'lib/openai/models/admin/organization/projects/api_key_list_params.rb', line 25

optional :after, String

#limitInteger?

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


32
# File 'lib/openai/models/admin/organization/projects/api_key_list_params.rb', line 32

optional :limit, Integer

#owner_project_accessSymbol, ...

Filter API keys by whether the owner currently has effective access to the project. Use active for owners with access, inactive for owners without access, or any for all enabled project API keys. If omitted, the endpoint applies its existing membership-based visibility rules, which may exclude some enabled keys.



42
43
# File 'lib/openai/models/admin/organization/projects/api_key_list_params.rb', line 42

optional :owner_project_access,
enum: -> { OpenAI::Admin::Organization::Projects::APIKeyListParams::OwnerProjectAccess }

#project_idString

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/openai/models/admin/organization/projects/api_key_list_params.rb', line 16

required :project_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


43
# File 'sig/openai/models/admin/organization/projects/api_key_list_params.rbs', line 43

def to_hash: -> {