Module: OpenAI::Models::Admin::Organization::Projects::APIKeyListParams::OwnerProjectAccess
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/admin/organization/projects/api_key_list_params.rb,
sig/openai/models/admin/organization/projects/api_key_list_params.rbs
Overview
Filter API keys by whether the owner currently has effective access to the
project. Use active for owners with access, inactive for owners without
access, or any for all enabled project API keys. If omitted, the endpoint
applies its existing membership-based visibility rules, which may exclude some
enabled keys.
Constant Summary collapse
- ACTIVE =
:active- INACTIVE =
:inactive- ANY =
:any
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/admin/organization/projects/api_key_list_params.rb', line 72
|
Instance Method Details
#self?.values ⇒ ::Array[OpenAI::Models::Admin::Organization::Projects::APIKeyListParams::owner_project_access]
60 |
# File 'sig/openai/models/admin/organization/projects/api_key_list_params.rbs', line 60
def self?.values: -> ::Array[OpenAI::Models::Admin::Organization::Projects::APIKeyListParams::owner_project_access]
|