Class: OpenAI::Models::Admin::Organization::Projects::CertificateListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/admin/organization/projects/certificate_list_response.rb,
sig/openai/models/admin/organization/projects/certificate_list_response.rbs

Overview

See Also:

  • OpenAI::Resources::Admin::Organization::Projects::Certificates#list

Defined Under Namespace

Classes: CertificateDetails

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, active:, certificate_details:, created_at:, name:, object: :"organization.project.certificate") ⇒ Object

Parameters:

  • id —

    The identifier, which can be referenced in API endpoints

  • active —

    Whether the certificate is currently active at the project level.

  • created_at —

    The Unix timestamp (in seconds) of when the certificate was uploaded.

  • name —

    The name of the certificate.

  • object (defaults to: :"organization.project.certificate") —

    The object type, which is always organization.project.certificate.



# File 'lib/openai/models/admin/organization/projects/certificate_list_response.rb', line 48

Instance Attribute Details

#active ⇒ Boolean

Whether the certificate is currently active at the project level.

Returns:



20
# File 'lib/openai/models/admin/organization/projects/certificate_list_response.rb', line 20

required :active, OpenAI::Internal::Type::Boolean

#certificate_details ⇒ OpenAI::Models::Admin::Organization::Projects::CertificateListResponse::CertificateDetails



25
26
27
28
# File 'lib/openai/models/admin/organization/projects/certificate_list_response.rb', line 25

required(
  :certificate_details,
  -> { OpenAI::Models::Admin::Organization::Projects::CertificateListResponse::CertificateDetails }
)

#created_at ⇒ Integer

The Unix timestamp (in seconds) of when the certificate was uploaded.

Returns:

  • (Integer)


34
# File 'lib/openai/models/admin/organization/projects/certificate_list_response.rb', line 34

required :created_at, Integer

#id ⇒ String

The identifier, which can be referenced in API endpoints

Returns:

  • (String)


14
# File 'lib/openai/models/admin/organization/projects/certificate_list_response.rb', line 14

required :id, String

#name ⇒ String?

The name of the certificate.

Returns:

  • (String, nil)


40
# File 'lib/openai/models/admin/organization/projects/certificate_list_response.rb', line 40

required :name, String, nil?: true

#object ⇒ :"organization.project.certificate"

The object type, which is always organization.project.certificate.

Returns:

  • (:"organization.project.certificate")


46
# File 'lib/openai/models/admin/organization/projects/certificate_list_response.rb', line 46

required :object, const: :"organization.project.certificate"

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


53
# File 'sig/openai/models/admin/organization/projects/certificate_list_response.rbs', line 53

def to_hash: -> {