Class: OpenAI::Models::Admin::Organization::Projects::Groups::RoleCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/admin/organization/projects/groups/role_create_response.rb,
sig/openai/models/admin/organization/projects/groups/role_create_response.rbs

Overview

See Also:

  • OpenAI::Resources::Admin::Organization::Projects::Groups::Roles#create

Defined Under Namespace

Classes: Group

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(group:, role:, object: :"group.role") ⇒ Object

Parameters:

  • group

    Summary information about a group returned in role assignment responses.

  • role

    Details about a role that can be assigned through the public Roles API.

  • object (defaults to: :"group.role")

    Always group.role.



# File 'lib/openai/models/admin/organization/projects/groups/role_create_response.rb', line 29

Instance Attribute Details

#groupOpenAI::Models::Admin::Organization::Projects::Groups::RoleCreateResponse::Group

Summary information about a group returned in role assignment responses.



15
# File 'lib/openai/models/admin/organization/projects/groups/role_create_response.rb', line 15

required :group, -> { OpenAI::Models::Admin::Organization::Projects::Groups::RoleCreateResponse::Group }

#object:"group.role"

Always group.role.

Returns:



21
# File 'lib/openai/models/admin/organization/projects/groups/role_create_response.rb', line 21

required :object, const: :"group.role"

#roleOpenAI::Admin::Organization::Role

Details about a role that can be assigned through the public Roles API.

Returns:

  • (OpenAI::Admin::Organization::Role)


27
# File 'lib/openai/models/admin/organization/projects/groups/role_create_response.rb', line 27

required :role, -> { OpenAI::Admin::Organization::Role }

Instance Method Details

#to_hash{

Returns:

  • ({)


36
# File 'sig/openai/models/admin/organization/projects/groups/role_create_response.rbs', line 36

def to_hash: -> {