Class: OpenAI::Models::Admin::Organization::Projects::Groups::RoleCreateResponse::Group
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::Projects::Groups::RoleCreateResponse::Group
- Defined in:
- lib/openai/models/admin/organization/projects/groups/role_create_response.rb
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ Integer
Unix timestamp (in seconds) when the group was created.
-
#id ⇒ String
Identifier for the group.
-
#name ⇒ String
Display name of the group.
-
#object ⇒ Symbol, :group
Always ‘group`.
-
#scim_managed ⇒ Boolean
Whether the group is managed through SCIM.
Instance Method Summary collapse
-
#initialize(id:, created_at:, name:, scim_managed:, object: :group) ⇒ Object
constructor
Summary information about a group returned in role assignment responses.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, name:, scim_managed:, object: :group) ⇒ Object
Summary information about a group returned in role assignment responses.
|
|
# File 'lib/openai/models/admin/organization/projects/groups/role_create_response.rb', line 70
|
Instance Attribute Details
#created_at ⇒ Integer
Unix timestamp (in seconds) when the group was created.
50 |
# File 'lib/openai/models/admin/organization/projects/groups/role_create_response.rb', line 50 required :created_at, Integer |
#id ⇒ String
Identifier for the group.
44 |
# File 'lib/openai/models/admin/organization/projects/groups/role_create_response.rb', line 44 required :id, String |
#name ⇒ String
Display name of the group.
56 |
# File 'lib/openai/models/admin/organization/projects/groups/role_create_response.rb', line 56 required :name, String |
#object ⇒ Symbol, :group
Always ‘group`.
62 |
# File 'lib/openai/models/admin/organization/projects/groups/role_create_response.rb', line 62 required :object, const: :group |