Class: OpenAI::Models::Admin::Organization::Projects::HostedToolPermissionUpdateParams::WebSearch

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/admin/organization/projects/hosted_tool_permission_update_params.rb,
sig/openai/models/admin/organization/projects/hosted_tool_permission_update_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(enabled:) ⇒ WebSearch

The web search permission update.

Parameters:

  • enabled (Boolean)

    Whether to enable the hosted tool for the project.

  • enabled: (Boolean)


# File 'lib/openai/models/admin/organization/projects/hosted_tool_permission_update_params.rb', line 140

Instance Attribute Details

#enabledBoolean

Whether to enable the hosted tool for the project.

Parameters:

Returns:



138
# File 'lib/openai/models/admin/organization/projects/hosted_tool_permission_update_params.rb', line 138

required :enabled, OpenAI::Internal::Type::Boolean

Instance Method Details

#to_hash{ enabled: bool }

Returns:

  • ({ enabled: bool })


100
# File 'sig/openai/models/admin/organization/projects/hosted_tool_permission_update_params.rbs', line 100

def to_hash: -> { enabled: bool }