Class: OpenAI::Models::Admin::Organization::Projects::ProjectGroup
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::Projects::ProjectGroup
- Defined in:
- lib/openai/models/admin/organization/projects/project_group.rb
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ Integer
Unix timestamp (in seconds) when the group was granted project access.
-
#group_id ⇒ String
Identifier of the group that has access to the project.
-
#group_name ⇒ String
Display name of the group.
-
#group_type ⇒ String
The type of the group.
-
#object ⇒ Symbol, :"project.group"
Always ‘project.group`.
-
#project_id ⇒ String
Identifier of the project.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#created_at ⇒ Integer
Unix timestamp (in seconds) when the group was granted project access.
14 |
# File 'lib/openai/models/admin/organization/projects/project_group.rb', line 14 required :created_at, Integer |
#group_id ⇒ String
Identifier of the group that has access to the project.
20 |
# File 'lib/openai/models/admin/organization/projects/project_group.rb', line 20 required :group_id, String |
#group_name ⇒ String
Display name of the group.
26 |
# File 'lib/openai/models/admin/organization/projects/project_group.rb', line 26 required :group_name, String |
#group_type ⇒ String
The type of the group.
32 |
# File 'lib/openai/models/admin/organization/projects/project_group.rb', line 32 required :group_type, String |
#object ⇒ Symbol, :"project.group"
Always ‘project.group`.
38 |
# File 'lib/openai/models/admin/organization/projects/project_group.rb', line 38 required :object, const: :"project.group" |
#project_id ⇒ String
Identifier of the project.
44 |
# File 'lib/openai/models/admin/organization/projects/project_group.rb', line 44 required :project_id, String |