Class: OpenAI::Models::Admin::Organization::Projects::ProjectSpendLimit::Enforcement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::Projects::ProjectSpendLimit::Enforcement
- Defined in:
- lib/openai/models/admin/organization/projects/project_spend_limit.rb,
sig/openai/models/admin/organization/projects/project_spend_limit.rbs
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#status ⇒ String, ...
Whether the hard spend limit is currently enforcing.
Instance Method Summary collapse
-
#initialize(status:) ⇒ Object
constructor
The current enforcement state of the hard spend limit.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(status:) ⇒ Object
The current enforcement state of the hard spend limit.
|
|
# File 'lib/openai/models/admin/organization/projects/project_spend_limit.rb', line 91
|
Instance Attribute Details
#status ⇒ String, ...
Whether the hard spend limit is currently enforcing.
88 89 |
# File 'lib/openai/models/admin/organization/projects/project_spend_limit.rb', line 88 required :status, union: -> { OpenAI::Admin::Organization::Projects::ProjectSpendLimit::Enforcement::Status } |
Instance Method Details
#to_hash ⇒ {
66 |
# File 'sig/openai/models/admin/organization/projects/project_spend_limit.rbs', line 66
def to_hash: -> {
|