Class: OpenAI::Models::Admin::Organization::Projects::RateLimitListRateLimitsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::Projects::RateLimitListRateLimitsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/admin/organization/projects/rate_limit_list_rate_limits_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
A cursor for use in pagination.
-
#before ⇒ String?
A cursor for use in pagination.
-
#limit ⇒ Integer?
A limit on the number of objects to be returned.
- #project_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(project_id:, after: nil, before: nil, limit: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see RateLimitListRateLimitsParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(project_id:, after: nil, before: nil, limit: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::Projects::RateLimitListRateLimitsParams for more details.
|
|
# File 'lib/openai/models/admin/organization/projects/rate_limit_list_rate_limits_params.rb', line 42
|
Instance Attribute Details
#after ⇒ String?
A cursor for use in pagination. ‘after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include after=obj_foo in order to fetch the next page of the list.
25 |
# File 'lib/openai/models/admin/organization/projects/rate_limit_list_rate_limits_params.rb', line 25 optional :after, String |
#before ⇒ String?
A cursor for use in pagination. ‘before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, beginning with obj_foo, your subsequent call can include before=obj_foo in order to fetch the previous page of the list.
34 |
# File 'lib/openai/models/admin/organization/projects/rate_limit_list_rate_limits_params.rb', line 34 optional :before, String |
#limit ⇒ Integer?
A limit on the number of objects to be returned. The default is 100.
40 |
# File 'lib/openai/models/admin/organization/projects/rate_limit_list_rate_limits_params.rb', line 40 optional :limit, Integer |
#project_id ⇒ String
16 |
# File 'lib/openai/models/admin/organization/projects/rate_limit_list_rate_limits_params.rb', line 16 required :project_id, String |