Class: OpenAI::Models::Admin::Organization::Projects::RoleListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/admin/organization/projects/role_list_params.rb

Overview

Defined Under Namespace

Modules: Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(project_id:, after: nil, limit: nil, order: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::Projects::RoleListParams for more details.

Parameters:

  • project_id (String)
  • after (String) (defaults to: nil)

    Cursor for pagination. Provide the value from the previous response’s ‘next` fie

  • limit (Integer) (defaults to: nil)

    A limit on the number of roles to return. Defaults to 1000.

  • order (Symbol, OpenAI::Models::Admin::Organization::Projects::RoleListParams::Order) (defaults to: nil)

    Sort order for the returned roles.

  • request_options (OpenAI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/openai/models/admin/organization/projects/role_list_params.rb', line 37

Instance Attribute Details

#afterString?

Cursor for pagination. Provide the value from the previous response’s ‘next` field to continue listing roles.

Returns:

  • (String, nil)


23
# File 'lib/openai/models/admin/organization/projects/role_list_params.rb', line 23

optional :after, String

#limitInteger?

A limit on the number of roles to return. Defaults to 1000.

Returns:

  • (Integer, nil)


29
# File 'lib/openai/models/admin/organization/projects/role_list_params.rb', line 29

optional :limit, Integer

#orderSymbol, ...

Sort order for the returned roles.



35
# File 'lib/openai/models/admin/organization/projects/role_list_params.rb', line 35

optional :order, enum: -> { OpenAI::Admin::Organization::Projects::RoleListParams::Order }

#project_idString

Returns:

  • (String)


16
# File 'lib/openai/models/admin/organization/projects/role_list_params.rb', line 16

required :project_id, String