Class: OpenAI::Models::Admin::Organization::Projects::SpendAlertListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/admin/organization/projects/spend_alert_list_params.rb,
sig/openai/models/admin/organization/projects/spend_alert_list_params.rbs

Overview

See Also:

  • OpenAI::Resources::Admin::Organization::Projects::SpendAlerts#list

Defined Under Namespace

Modules: Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(project_id:, after: nil, before: nil, limit: nil, order: nil, request_options: {}) ⇒ Object

Parameters:

  • after (defaults to: nil) —

    Cursor for pagination. Provide the ID of the last spend alert from the previous response to fetch the next page.

  • before (defaults to: nil) —

    Cursor for pagination. Provide the ID of the first spend alert from the previous response to fetch the previous page.

  • limit (defaults to: nil) —

    A limit on the number of spend alerts to return. Defaults to 20.

  • order (defaults to: nil) —

    Sort order for the returned spend alerts.



# File 'lib/openai/models/admin/organization/projects/spend_alert_list_params.rb', line 44

Instance Attribute Details

#after ⇒ String?

Cursor for pagination. Provide the ID of the last spend alert from the previous response to fetch the next page.

Returns:

  • (String, nil)


23
# File 'lib/openai/models/admin/organization/projects/spend_alert_list_params.rb', line 23

optional :after, String

#before ⇒ String?

Cursor for pagination. Provide the ID of the first spend alert from the previous response to fetch the previous page.

Returns:

  • (String, nil)


30
# File 'lib/openai/models/admin/organization/projects/spend_alert_list_params.rb', line 30

optional :before, String

#limit ⇒ Integer?

A limit on the number of spend alerts to return. Defaults to 20.

Returns:

  • (Integer, nil)


36
# File 'lib/openai/models/admin/organization/projects/spend_alert_list_params.rb', line 36

optional :limit, Integer

#order ⇒ OpenAI::Models::Admin::Organization::Projects::SpendAlertListParams::order?

Sort order for the returned spend alerts.

Returns:

  • (OpenAI::Models::Admin::Organization::Projects::SpendAlertListParams::order, nil)


42
# File 'lib/openai/models/admin/organization/projects/spend_alert_list_params.rb', line 42

optional :order, enum: -> { OpenAI::Admin::Organization::Projects::SpendAlertListParams::Order }

#project_id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/openai/models/admin/organization/projects/spend_alert_list_params.rb', line 16

required :project_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


71
# File 'sig/openai/models/admin/organization/projects/spend_alert_list_params.rbs', line 71

def to_hash: -> {