Class: OpenAI::Models::Admin::Organization::Projects::SpendAlertUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::Projects::SpendAlertUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/admin/organization/projects/spend_alert_update_params.rb
Overview
Defined Under Namespace
Modules: Currency, Interval Classes: NotificationChannel
Instance Attribute Summary collapse
- #alert_id ⇒ String
-
#currency ⇒ Symbol, OpenAI::Models::Admin::Organization::Projects::SpendAlertUpdateParams::Currency
The currency for the threshold amount.
-
#interval ⇒ Symbol, OpenAI::Models::Admin::Organization::Projects::SpendAlertUpdateParams::Interval
The time interval for evaluating spend against the threshold.
-
#notification_channel ⇒ OpenAI::Models::Admin::Organization::Projects::SpendAlertUpdateParams::NotificationChannel
Email notification settings for a spend alert.
- #project_id ⇒ String
-
#threshold_amount ⇒ Integer
The alert threshold amount, in cents.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(project_id:, alert_id:, currency:, interval:, notification_channel:, threshold_amount:, request_options: {}) ⇒ Object
|
|
# File 'lib/openai/models/admin/organization/projects/spend_alert_update_params.rb', line 48
|
Instance Attribute Details
#alert_id ⇒ String
21 |
# File 'lib/openai/models/admin/organization/projects/spend_alert_update_params.rb', line 21 required :alert_id, String |
#currency ⇒ Symbol, OpenAI::Models::Admin::Organization::Projects::SpendAlertUpdateParams::Currency
The currency for the threshold amount.
27 |
# File 'lib/openai/models/admin/organization/projects/spend_alert_update_params.rb', line 27 required :currency, enum: -> { OpenAI::Admin::Organization::Projects::SpendAlertUpdateParams::Currency } |
#interval ⇒ Symbol, OpenAI::Models::Admin::Organization::Projects::SpendAlertUpdateParams::Interval
The time interval for evaluating spend against the threshold.
33 |
# File 'lib/openai/models/admin/organization/projects/spend_alert_update_params.rb', line 33 required :interval, enum: -> { OpenAI::Admin::Organization::Projects::SpendAlertUpdateParams::Interval } |
#notification_channel ⇒ OpenAI::Models::Admin::Organization::Projects::SpendAlertUpdateParams::NotificationChannel
Email notification settings for a spend alert.
39 40 |
# File 'lib/openai/models/admin/organization/projects/spend_alert_update_params.rb', line 39 required :notification_channel, -> { OpenAI::Admin::Organization::Projects::SpendAlertUpdateParams::NotificationChannel } |
#project_id ⇒ String
16 |
# File 'lib/openai/models/admin/organization/projects/spend_alert_update_params.rb', line 16 required :project_id, String |
#threshold_amount ⇒ Integer
The alert threshold amount, in cents.
46 |
# File 'lib/openai/models/admin/organization/projects/spend_alert_update_params.rb', line 46 required :threshold_amount, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/admin/organization/projects/spend_alert_update_params.rb', line 69
|