Class: OpenAI::Models::Admin::Organization::Projects::Users::RoleCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::Projects::Users::RoleCreateResponse
- Defined in:
- lib/openai/models/admin/organization/projects/users/role_create_response.rb
Overview
Instance Attribute Summary collapse
-
#object ⇒ Symbol, :"user.role"
Always ‘user.role`.
-
#role ⇒ OpenAI::Models::Admin::Organization::Role
Details about a role that can be assigned through the public Roles API.
-
#user ⇒ OpenAI::Models::Admin::Organization::OrganizationUser
Represents an individual ‘user` within an organization.
Instance Method Summary collapse
-
#initialize(role:, user:, object: :"user.role") ⇒ Object
constructor
Role assignment linking a user to a role.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(role:, user:, object: :"user.role") ⇒ Object
Role assignment linking a user to a role.
|
|
# File 'lib/openai/models/admin/organization/projects/users/role_create_response.rb', line 29
|
Instance Attribute Details
#object ⇒ Symbol, :"user.role"
Always ‘user.role`.
15 |
# File 'lib/openai/models/admin/organization/projects/users/role_create_response.rb', line 15 required :object, const: :"user.role" |
#role ⇒ OpenAI::Models::Admin::Organization::Role
Details about a role that can be assigned through the public Roles API.
21 |
# File 'lib/openai/models/admin/organization/projects/users/role_create_response.rb', line 21 required :role, -> { OpenAI::Admin::Organization::Role } |
#user ⇒ OpenAI::Models::Admin::Organization::OrganizationUser
Represents an individual ‘user` within an organization.
27 |
# File 'lib/openai/models/admin/organization/projects/users/role_create_response.rb', line 27 required :user, -> { OpenAI::Admin::Organization::OrganizationUser } |