Class: OpenAI::Models::Admin::Organization::SpendLimitUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/admin/organization/spend_limit_update_params.rb,
sig/openai/models/admin/organization/spend_limit_update_params.rbs

Overview

See Also:

  • OpenAI::Resources::Admin::Organization::SpendLimit#update

Defined Under Namespace

Modules: Currency, Interval

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(currency:, interval:, threshold_amount:, request_options: {}) ⇒ Object

Parameters:

  • currency —

    The currency for the threshold amount. Currently, only USD is supported.

  • interval —

    The time interval for evaluating spend against the threshold. Currently, only month is supported.

  • threshold_amount —

    The hard spend limit amount, in cents.



# File 'lib/openai/models/admin/organization/spend_limit_update_params.rb', line 31

Instance Attribute Details

#currency ⇒ OpenAI::Models::Admin::Organization::SpendLimitUpdateParams::currency

The currency for the threshold amount. Currently, only USD is supported.

Returns:

  • (OpenAI::Models::Admin::Organization::SpendLimitUpdateParams::currency)


16
# File 'lib/openai/models/admin/organization/spend_limit_update_params.rb', line 16

required :currency, enum: -> { OpenAI::Admin::Organization::SpendLimitUpdateParams::Currency }

#interval ⇒ OpenAI::Models::Admin::Organization::SpendLimitUpdateParams::interval

The time interval for evaluating spend against the threshold. Currently, only month is supported.

Returns:

  • (OpenAI::Models::Admin::Organization::SpendLimitUpdateParams::interval)


23
# File 'lib/openai/models/admin/organization/spend_limit_update_params.rb', line 23

required :interval, enum: -> { OpenAI::Admin::Organization::SpendLimitUpdateParams::Interval }

#threshold_amount ⇒ Integer

The hard spend limit amount, in cents.

Returns:

  • (Integer)


29
# File 'lib/openai/models/admin/organization/spend_limit_update_params.rb', line 29

required :threshold_amount, Integer

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/admin/organization/spend_limit_update_params.rb', line 50

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


41
# File 'sig/openai/models/admin/organization/spend_limit_update_params.rbs', line 41

def to_hash: -> {