Class: OpenAI::Models::Admin::Organization::UsageAudioSpeechesResponse::Data::Result::OrganizationUsageCompletionsResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::UsageAudioSpeechesResponse::Data::Result::OrganizationUsageCompletionsResult
- Defined in:
- lib/openai/models/admin/organization/usage_audio_speeches_response.rb
Instance Attribute Summary collapse
-
#api_key_id ⇒ String?
When ‘group_by=api_key_id`, this field provides the API key ID of the grouped usage result.
-
#batch ⇒ Boolean?
When ‘group_by=batch`, this field tells whether the grouped usage result is batch or not.
-
#input_audio_tokens ⇒ Integer?
The aggregated number of audio input tokens used, including cached tokens.
-
#input_cached_tokens ⇒ Integer?
The aggregated number of text input tokens that has been cached from previous requests.
-
#input_tokens ⇒ Integer
The aggregated number of text input tokens used, including cached tokens.
-
#model ⇒ String?
When ‘group_by=model`, this field provides the model name of the grouped usage result.
-
#num_model_requests ⇒ Integer
The count of requests made to the model.
- #object ⇒ Symbol, :"organization.usage.completions.result"
-
#output_audio_tokens ⇒ Integer?
The aggregated number of audio output tokens used.
-
#output_tokens ⇒ Integer
The aggregated number of text output tokens used.
-
#project_id ⇒ String?
When ‘group_by=project_id`, this field provides the project ID of the grouped usage result.
-
#service_tier ⇒ String?
When ‘group_by=service_tier`, this field provides the service tier of the grouped usage result.
-
#user_id ⇒ String?
When ‘group_by=user_id`, this field provides the user ID of the grouped usage result.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#api_key_id ⇒ String?
When ‘group_by=api_key_id`, this field provides the API key ID of the grouped usage result.
137 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 137 optional :api_key_id, String, nil?: true |
#batch ⇒ Boolean?
When ‘group_by=batch`, this field tells whether the grouped usage result is batch or not.
144 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 144 optional :batch, OpenAI::Internal::Type::Boolean, nil?: true |
#input_audio_tokens ⇒ Integer?
The aggregated number of audio input tokens used, including cached tokens.
150 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 150 optional :input_audio_tokens, Integer |
#input_cached_tokens ⇒ Integer?
The aggregated number of text input tokens that has been cached from previous requests. For customers subscribe to scale tier, this includes scale tier tokens.
158 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 158 optional :input_cached_tokens, Integer |
#input_tokens ⇒ Integer
The aggregated number of text input tokens used, including cached tokens. For customers subscribe to scale tier, this includes scale tier tokens.
112 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 112 required :input_tokens, Integer |
#model ⇒ String?
When ‘group_by=model`, this field provides the model name of the grouped usage result.
165 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 165 optional :model, String, nil?: true |
#num_model_requests ⇒ Integer
The count of requests made to the model.
118 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 118 required :num_model_requests, Integer |
#object ⇒ Symbol, :"organization.usage.completions.result"
123 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 123 required :object, const: :"organization.usage.completions.result" |
#output_audio_tokens ⇒ Integer?
The aggregated number of audio output tokens used.
171 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 171 optional :output_audio_tokens, Integer |
#output_tokens ⇒ Integer
The aggregated number of text output tokens used. For customers subscribe to scale tier, this includes scale tier tokens.
130 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 130 required :output_tokens, Integer |
#project_id ⇒ String?
When ‘group_by=project_id`, this field provides the project ID of the grouped usage result.
178 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 178 optional :project_id, String, nil?: true |
#service_tier ⇒ String?
When ‘group_by=service_tier`, this field provides the service tier of the grouped usage result.
185 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 185 optional :service_tier, String, nil?: true |
#user_id ⇒ String?
When ‘group_by=user_id`, this field provides the user ID of the grouped usage result.
192 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 192 optional :user_id, String, nil?: true |