Class: OpenAI::Models::Admin::Organization::UsageAudioSpeechesResponse::Data::Result::OrganizationUsageImagesResult

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/admin/organization/usage_audio_speeches_response.rb,
sig/openai/models/admin/organization/usage_audio_speeches_response.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Parameters:

  • images

    The number of images processed.

  • num_model_requests

    The count of requests made to the model.

  • api_key_id

    When group_by=api_key_id, this field provides the API key ID of the grouped usage result.

  • model

    When group_by=model, this field provides the model name of the grouped usage result.

  • project_id

    When group_by=project_id, this field provides the project ID of the grouped usage result.

  • size

    When group_by=size, this field provides the image size of the grouped usage result.

  • source

    When group_by=source, this field provides the source of the grouped usage result, possible values are image.generation, image.edit, image.variation.

  • user_id

    When group_by=user_id, this field provides the user ID of the grouped usage result.



547
# File 'sig/openai/models/admin/organization/usage_audio_speeches_response.rbs', line 547

def initialize: (

Instance Attribute Details

#api_key_idString?

When group_by=api_key_id, this field provides the API key ID of the grouped usage result.

Returns:

  • (String, nil)


566
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 566

optional :api_key_id, String, nil?: true

#imagesInteger

The number of images processed.

Returns:

  • (Integer)


548
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 548

required :images, Integer

#modelString?

When group_by=model, this field provides the model name of the grouped usage result.

Returns:

  • (String, nil)


573
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 573

optional :model, String, nil?: true

#num_model_requestsInteger

The count of requests made to the model.

Returns:

  • (Integer)


554
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 554

required :num_model_requests, Integer

#objectSymbol, :"organization.usage.images.result"

Parameters:

  • value (:"organization.usage.images.result")

Returns:

  • (Symbol, :"organization.usage.images.result")


559
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 559

required :object, const: :"organization.usage.images.result"

#project_idString?

When group_by=project_id, this field provides the project ID of the grouped usage result.

Returns:

  • (String, nil)


580
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 580

optional :project_id, String, nil?: true

#sizeString?

When group_by=size, this field provides the image size of the grouped usage result.

Returns:

  • (String, nil)


587
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 587

optional :size, String, nil?: true

#sourceString?

When group_by=source, this field provides the source of the grouped usage result, possible values are image.generation, image.edit, image.variation.

Returns:

  • (String, nil)


594
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 594

optional :source, String, nil?: true

#user_idString?

When group_by=user_id, this field provides the user ID of the grouped usage result.

Returns:

  • (String, nil)


601
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 601

optional :user_id, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


559
# File 'sig/openai/models/admin/organization/usage_audio_speeches_response.rbs', line 559

def to_hash: -> {