Class: OpenAI::Models::Admin::Organization::UsageAudioTranscriptionsResponse::Data::Result::OrganizationCostsResult

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb,
sig/openai/models/admin/organization/usage_audio_transcriptions_response.rbs

Defined Under Namespace

Classes: Amount

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount: nil, api_key_id: nil, line_item: nil, project_id: nil, quantity: nil, quantity_unit: nil, object: :"organization.costs.result") ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::UsageAudioTranscriptionsResponse::Data::Result::OrganizationCostsResult for more details.

The aggregated costs details of the specific time bucket.

Parameters:

  • amount (OpenAI::Models::Admin::Organization::UsageAudioTranscriptionsResponse::Data::Result::OrganizationCostsResult::Amount) (defaults to: nil)

    The monetary value in its associated currency.

  • api_key_id (String, nil) (defaults to: nil)

    When group_by=api_key_id, this field provides the API Key ID of the grouped co

  • line_item (String, nil) (defaults to: nil)

    When group_by=line_item, this field provides the line item of the grouped cost

  • project_id (String, nil) (defaults to: nil)

    When group_by=project_id, this field provides the project ID of the grouped co

  • quantity (Float, nil) (defaults to: nil)

    When group_by=line_item, this field provides the quantity of the grouped costs

  • quantity_unit (String, Symbol, OpenAI::Models::Admin::Organization::CostQuantityUnit, nil) (defaults to: nil)

    The unit of the quantity value. If no single supported unit applies to the res

  • object (Symbol, :"organization.costs.result") (defaults to: :"organization.costs.result")


# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 987

Instance Attribute Details

#amountOpenAI::Models::Admin::Organization::UsageAudioTranscriptionsResponse::Data::Result::OrganizationCostsResult::Amount?

The monetary value in its associated currency.



939
940
941
942
943
944
# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 939

optional(
  :amount,
  -> {
    OpenAI::Models::Admin::Organization::UsageAudioTranscriptionsResponse::Data::Result::OrganizationCostsResult::Amount
  }
)

#api_key_idString?

When group_by=api_key_id, this field provides the API Key ID of the grouped costs result.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


951
# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 951

optional :api_key_id, String, nil?: true

#line_itemString?

When group_by=line_item, this field provides the line item of the grouped costs result.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


958
# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 958

optional :line_item, String, nil?: true

#objectSymbol, :"organization.costs.result"

Parameters:

  • value (:"organization.costs.result")

Returns:

  • (Symbol, :"organization.costs.result")


933
# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 933

required :object, const: :"organization.costs.result"

#project_idString?

When group_by=project_id, this field provides the project ID of the grouped costs result.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


965
# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 965

optional :project_id, String, nil?: true

#quantityFloat?

When group_by=line_item, this field provides the quantity of the grouped costs result.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


972
# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 972

optional :quantity, Float, nil?: true

#quantity_unitString, ...

The unit of the quantity value. If no single supported unit applies to the result, this field is null.

Parameters:

  • value (OpenAI::Models::Admin::Organization::cost_quantity_unit, nil)

Returns:



979
980
981
982
983
984
985
# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 979

optional(
  :quantity_unit,
  union: -> {
    OpenAI::Admin::Organization::CostQuantityUnit
  },
  nil?: true
)

Instance Method Details

#to_hash{

Returns:

  • ({)


662
# File 'sig/openai/models/admin/organization/usage_audio_transcriptions_response.rbs', line 662

def to_hash: -> {