Class: OpenAI::Models::Admin::Organization::UsageAudioTranscriptionsResponse::Data::Result::OrganizationUsageWebSearchesResult

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from OpenAI::Internal::Type::BaseModel

Instance Attribute Details

#api_key_idString?

When ‘group_by=api_key_id`, this field provides the API key ID of the grouped usage result.

Returns:

  • (String, nil)


744
# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 744

optional :api_key_id, String, nil?: true

#context_levelString?

When ‘group_by=context_level`, this field provides the search context size of the grouped usage result.

Returns:

  • (String, nil)


751
# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 751

optional :context_level, String, nil?: true

#modelString?

When ‘group_by=model`, this field provides the model name of the grouped usage result.

Returns:

  • (String, nil)


758
# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 758

optional :model, String, nil?: true

#num_model_requestsInteger

The count of model requests.

Returns:

  • (Integer)


726
# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 726

required :num_model_requests, Integer

#num_requestsInteger

The count of web search calls.

Returns:

  • (Integer)


732
# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 732

required :num_requests, Integer

#objectSymbol, :"organization.usage.web_searches.result"

Returns:

  • (Symbol, :"organization.usage.web_searches.result")


737
# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 737

required :object, const: :"organization.usage.web_searches.result"

#project_idString?

When ‘group_by=project_id`, this field provides the project ID of the grouped usage result.

Returns:

  • (String, nil)


765
# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 765

optional :project_id, String, nil?: true

#user_idString?

When ‘group_by=user_id`, this field provides the user ID of the grouped usage result.

Returns:

  • (String, nil)


772
# File 'lib/openai/models/admin/organization/usage_audio_transcriptions_response.rb', line 772

optional :user_id, String, nil?: true