Class: OpenAI::Models::Admin::Organization::UsageCodeInterpreterSessionsResponse::Data::Result::OrganizationUsageAudioSpeechesResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::UsageCodeInterpreterSessionsResponse::Data::Result::OrganizationUsageAudioSpeechesResult
- Defined in:
- lib/openai/models/admin/organization/usage_code_interpreter_sessions_response.rb,
sig/openai/models/admin/organization/usage_code_interpreter_sessions_response.rbs
Instance Attribute Summary collapse
-
#api_key_id ⇒ String?
When
group_by=api_key_id, this field provides the API key ID of the grouped usage result. -
#characters ⇒ Integer
The number of characters processed.
-
#model ⇒ String?
When
group_by=model, this field provides the model name of the grouped usage result. -
#num_model_requests ⇒ Integer
The count of requests made to the model.
- #object ⇒ Symbol, :"organization.usage.audio_speeches.result"
-
#project_id ⇒ String?
When
group_by=project_id, this field provides the project ID of the grouped usage result. -
#user_id ⇒ String?
When
group_by=user_id, this field provides the user ID of the grouped usage result.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
343 |
# File 'sig/openai/models/admin/organization/usage_code_interpreter_sessions_response.rbs', line 343
def initialize: (
|
Instance Attribute Details
#api_key_id ⇒ String?
When group_by=api_key_id, this field provides the API key ID of the grouped
usage result.
481 |
# File 'lib/openai/models/admin/organization/usage_code_interpreter_sessions_response.rb', line 481 optional :api_key_id, String, nil?: true |
#characters ⇒ Integer
The number of characters processed.
463 |
# File 'lib/openai/models/admin/organization/usage_code_interpreter_sessions_response.rb', line 463 required :characters, Integer |
#model ⇒ String?
When group_by=model, this field provides the model name of the grouped usage
result.
488 |
# File 'lib/openai/models/admin/organization/usage_code_interpreter_sessions_response.rb', line 488 optional :model, String, nil?: true |
#num_model_requests ⇒ Integer
The count of requests made to the model.
469 |
# File 'lib/openai/models/admin/organization/usage_code_interpreter_sessions_response.rb', line 469 required :num_model_requests, Integer |
#object ⇒ Symbol, :"organization.usage.audio_speeches.result"
474 |
# File 'lib/openai/models/admin/organization/usage_code_interpreter_sessions_response.rb', line 474 required :object, const: :"organization.usage.audio_speeches.result" |
#project_id ⇒ String?
When group_by=project_id, this field provides the project ID of the grouped
usage result.
495 |
# File 'lib/openai/models/admin/organization/usage_code_interpreter_sessions_response.rb', line 495 optional :project_id, String, nil?: true |
#user_id ⇒ String?
When group_by=user_id, this field provides the user ID of the grouped usage
result.
502 |
# File 'lib/openai/models/admin/organization/usage_code_interpreter_sessions_response.rb', line 502 optional :user_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
353 |
# File 'sig/openai/models/admin/organization/usage_code_interpreter_sessions_response.rbs', line 353
def to_hash: -> {
|