Class: OpenAI::Models::Admin::Organization::UsageCompletionsResponse::Data::Result::OrganizationUsageImagesResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::UsageCompletionsResponse::Data::Result::OrganizationUsageImagesResult
- Defined in:
- lib/openai/models/admin/organization/usage_completions_response.rb
Instance Attribute Summary collapse
-
#api_key_id ⇒ String?
When ‘group_by=api_key_id`, this field provides the API key ID of the grouped usage result.
-
#images ⇒ Integer
The number of images processed.
-
#model ⇒ String?
When ‘group_by=model`, this field provides the model name of the grouped usage result.
-
#num_model_requests ⇒ Integer
The count of requests made to the model.
- #object ⇒ Symbol, :"organization.usage.images.result"
-
#project_id ⇒ String?
When ‘group_by=project_id`, this field provides the project ID of the grouped usage result.
-
#size ⇒ String?
When ‘group_by=size`, this field provides the image size of the grouped usage result.
-
#source ⇒ String?
When ‘group_by=source`, this field provides the source of the grouped usage result, possible values are `image.generation`, `image.edit`, `image.variation`.
-
#user_id ⇒ String?
When ‘group_by=user_id`, this field provides the user ID of the grouped usage result.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#api_key_id ⇒ String?
When ‘group_by=api_key_id`, this field provides the API key ID of the grouped usage result.
387 |
# File 'lib/openai/models/admin/organization/usage_completions_response.rb', line 387 optional :api_key_id, String, nil?: true |
#images ⇒ Integer
The number of images processed.
369 |
# File 'lib/openai/models/admin/organization/usage_completions_response.rb', line 369 required :images, Integer |
#model ⇒ String?
When ‘group_by=model`, this field provides the model name of the grouped usage result.
394 |
# File 'lib/openai/models/admin/organization/usage_completions_response.rb', line 394 optional :model, String, nil?: true |
#num_model_requests ⇒ Integer
The count of requests made to the model.
375 |
# File 'lib/openai/models/admin/organization/usage_completions_response.rb', line 375 required :num_model_requests, Integer |
#object ⇒ Symbol, :"organization.usage.images.result"
380 |
# File 'lib/openai/models/admin/organization/usage_completions_response.rb', line 380 required :object, const: :"organization.usage.images.result" |
#project_id ⇒ String?
When ‘group_by=project_id`, this field provides the project ID of the grouped usage result.
401 |
# File 'lib/openai/models/admin/organization/usage_completions_response.rb', line 401 optional :project_id, String, nil?: true |
#size ⇒ String?
When ‘group_by=size`, this field provides the image size of the grouped usage result.
408 |
# File 'lib/openai/models/admin/organization/usage_completions_response.rb', line 408 optional :size, String, nil?: true |
#source ⇒ String?
When ‘group_by=source`, this field provides the source of the grouped usage result, possible values are `image.generation`, `image.edit`, `image.variation`.
415 |
# File 'lib/openai/models/admin/organization/usage_completions_response.rb', line 415 optional :source, String, nil?: true |
#user_id ⇒ String?
When ‘group_by=user_id`, this field provides the user ID of the grouped usage result.
422 |
# File 'lib/openai/models/admin/organization/usage_completions_response.rb', line 422 optional :user_id, String, nil?: true |