Class: OpenAI::Models::Admin::Organization::UsageCostsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/admin/organization/usage_costs_params.rb,
sig/openai/models/admin/organization/usage_costs_params.rbs

Overview

See Also:

  • OpenAI::Resources::Admin::Organization::Usage#costs

Defined Under Namespace

Modules: BucketWidth, GroupBy

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(start_time:, api_key_ids: nil, bucket_width: nil, end_time: nil, group_by: nil, limit: nil, line_items: nil, page: nil, project_ids: nil, request_options: {}) ⇒ Object

Parameters:

  • start_time —

    Start time (Unix seconds) of the query time range, inclusive.

  • api_key_ids (defaults to: nil) —

    Return only costs for these API keys.

  • bucket_width (defaults to: nil) —

    Width of each time bucket in response. Currently only 1d is supported, default to 1d.

  • end_time (defaults to: nil) —

    End time (Unix seconds) of the query time range, exclusive.

  • group_by (defaults to: nil) —

    Group the costs by the specified fields. Support fields include project_id, line_item, api_key_id and any combination of them.

  • limit (defaults to: nil) —

    A limit on the number of buckets to be returned. Limit can range between 1 and 180, and the default is 7.

  • line_items (defaults to: nil) —

    Return only costs for these exact line item names. Each value must match the complete line_item value, for example gpt-6-astra, input_tokens.

  • page (defaults to: nil) —

    A cursor for use in pagination. Corresponding to the next_page field from the previous response.

  • project_ids (defaults to: nil) —

    Return only costs for these projects.



# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 74

Instance Attribute Details

#api_key_ids ⇒ ::Array[String]?

Return only costs for these API keys.

Returns:

  • (::Array[String], nil)


22
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 22

optional :api_key_ids, OpenAI::Internal::Type::ArrayOf[String]

#bucket_width ⇒ OpenAI::Models::Admin::Organization::UsageCostsParams::bucket_width?

Width of each time bucket in response. Currently only 1d is supported, default to 1d.

Returns:

  • (OpenAI::Models::Admin::Organization::UsageCostsParams::bucket_width, nil)


29
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 29

optional :bucket_width, enum: -> { OpenAI::Admin::Organization::UsageCostsParams::BucketWidth }

#end_time ⇒ Integer?

End time (Unix seconds) of the query time range, exclusive.

Returns:

  • (Integer, nil)


35
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 35

optional :end_time, Integer

#group_by ⇒ ::Array[OpenAI::Models::Admin::Organization::UsageCostsParams::group_by]?

Group the costs by the specified fields. Support fields include project_id, line_item, api_key_id and any combination of them.

Returns:

  • (::Array[OpenAI::Models::Admin::Organization::UsageCostsParams::group_by], nil)


42
43
44
45
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 42

optional(
  :group_by,
  -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Admin::Organization::UsageCostsParams::GroupBy] }
)

#limit ⇒ Integer?

A limit on the number of buckets to be returned. Limit can range between 1 and 180, and the default is 7.

Returns:

  • (Integer, nil)


52
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 52

optional :limit, Integer

#line_items ⇒ ::Array[String]?

Return only costs for these exact line item names. Each value must match the complete line_item value, for example gpt-6-astra, input_tokens.

Returns:

  • (::Array[String], nil)


59
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 59

optional :line_items, OpenAI::Internal::Type::ArrayOf[String]

#page ⇒ String?

A cursor for use in pagination. Corresponding to the next_page field from the previous response.

Returns:

  • (String, nil)


66
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 66

optional :page, String

#project_ids ⇒ ::Array[String]?

Return only costs for these projects.

Returns:

  • (::Array[String], nil)


72
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 72

optional :project_ids, OpenAI::Internal::Type::ArrayOf[String]

#start_time ⇒ Integer

Start time (Unix seconds) of the query time range, inclusive.

Returns:

  • (Integer)


16
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 16

required :start_time, Integer

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 116

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


124
# File 'sig/openai/models/admin/organization/usage_costs_params.rbs', line 124

def to_hash: -> {