Class: OpenAI::Models::Admin::Organization::UsageCostsResponse::Data::Result::OrganizationCostsResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::UsageCostsResponse::Data::Result::OrganizationCostsResult
- Defined in:
- lib/openai/models/admin/organization/usage_costs_response.rb,
sig/openai/models/admin/organization/usage_costs_response.rbs
Defined Under Namespace
Classes: Amount
Instance Attribute Summary collapse
-
#amount ⇒ OpenAI::Models::Admin::Organization::UsageCostsResponse::Data::Result::OrganizationCostsResult::Amount?
The monetary value in its associated currency.
-
#api_key_id ⇒ String?
When
group_by=api_key_id, this field provides the API Key ID of the grouped costs result. -
#line_item ⇒ String?
When
group_by=line_item, this field provides the line item of the grouped costs result. - #object ⇒ Symbol, :"organization.costs.result"
-
#project_id ⇒ String?
When
group_by=project_id, this field provides the project ID of the grouped costs result. -
#quantity ⇒ Float?
When
group_by=line_item, this field provides the quantity of the grouped costs result. -
#quantity_unit ⇒ String, ...
The unit of the
quantityvalue.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(amount: nil, api_key_id: nil, line_item: nil, project_id: nil, quantity: nil, quantity_unit: nil, object: :"organization.costs.result") ⇒ Object
constructor
Some parameter documentations has been truncated, see OrganizationCostsResult for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount: nil, api_key_id: nil, line_item: nil, project_id: nil, quantity: nil, quantity_unit: nil, object: :"organization.costs.result") ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::UsageCostsResponse::Data::Result::OrganizationCostsResult for more details.
The aggregated costs details of the specific time bucket.
|
|
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 981
|
Instance Attribute Details
#amount ⇒ OpenAI::Models::Admin::Organization::UsageCostsResponse::Data::Result::OrganizationCostsResult::Amount?
The monetary value in its associated currency.
933 934 935 936 937 938 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 933 optional( :amount, -> { OpenAI::Models::Admin::Organization::UsageCostsResponse::Data::Result::OrganizationCostsResult::Amount } ) |
#api_key_id ⇒ String?
When group_by=api_key_id, this field provides the API Key ID of the grouped
costs result.
945 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 945 optional :api_key_id, String, nil?: true |
#line_item ⇒ String?
When group_by=line_item, this field provides the line item of the grouped
costs result.
952 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 952 optional :line_item, String, nil?: true |
#object ⇒ Symbol, :"organization.costs.result"
927 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 927 required :object, const: :"organization.costs.result" |
#project_id ⇒ String?
When group_by=project_id, this field provides the project ID of the grouped
costs result.
959 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 959 optional :project_id, String, nil?: true |
#quantity ⇒ Float?
When group_by=line_item, this field provides the quantity of the grouped costs
result.
966 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 966 optional :quantity, Float, nil?: true |
#quantity_unit ⇒ String, ...
The unit of the quantity value. If no single supported unit applies to the
result, this field is null.
973 974 975 976 977 978 979 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 973 optional( :quantity_unit, union: -> { OpenAI::Admin::Organization::CostQuantityUnit }, nil?: true ) |
Instance Method Details
#to_hash ⇒ {
662 |
# File 'sig/openai/models/admin/organization/usage_costs_response.rbs', line 662
def to_hash: -> {
|