Class: OpenAI::Models::Admin::Organization::UsageCostsResponse::Data::Result::OrganizationUsageAudioSpeechesResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::UsageCostsResponse::Data::Result::OrganizationUsageAudioSpeechesResult
- Defined in:
- lib/openai/models/admin/organization/usage_costs_response.rb
Instance Attribute Summary collapse
-
#api_key_id ⇒ String?
When ‘group_by=api_key_id`, this field provides the API key ID of the grouped usage result.
-
#characters ⇒ Integer
The number of characters processed.
-
#model ⇒ String?
When ‘group_by=model`, this field provides the model name of the grouped usage result.
-
#num_model_requests ⇒ Integer
The count of requests made to the model.
- #object ⇒ Symbol, :"organization.usage.audio_speeches.result"
-
#project_id ⇒ String?
When ‘group_by=project_id`, this field provides the project ID of the grouped usage result.
-
#user_id ⇒ String?
When ‘group_by=user_id`, this field provides the user ID of the grouped usage result.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#api_key_id ⇒ String?
When ‘group_by=api_key_id`, this field provides the API key ID of the grouped usage result.
473 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 473 optional :api_key_id, String, nil?: true |
#characters ⇒ Integer
The number of characters processed.
455 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 455 required :characters, Integer |
#model ⇒ String?
When ‘group_by=model`, this field provides the model name of the grouped usage result.
480 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 480 optional :model, String, nil?: true |
#num_model_requests ⇒ Integer
The count of requests made to the model.
461 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 461 required :num_model_requests, Integer |
#object ⇒ Symbol, :"organization.usage.audio_speeches.result"
466 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 466 required :object, const: :"organization.usage.audio_speeches.result" |
#project_id ⇒ String?
When ‘group_by=project_id`, this field provides the project ID of the grouped usage result.
487 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 487 optional :project_id, String, nil?: true |
#user_id ⇒ String?
When ‘group_by=user_id`, this field provides the user ID of the grouped usage result.
494 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 494 optional :user_id, String, nil?: true |