Class: OpenAI::Models::Admin::Organization::UsageCostsResponse::Data::Result::OrganizationUsageAudioTranscriptionsResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::UsageCostsResponse::Data::Result::OrganizationUsageAudioTranscriptionsResult
- Defined in:
- lib/openai/models/admin/organization/usage_costs_response.rb
Instance Attribute Summary collapse
-
#api_key_id ⇒ String?
When ‘group_by=api_key_id`, this field provides the API key ID of the grouped usage result.
-
#model ⇒ String?
When ‘group_by=model`, this field provides the model name of the grouped usage result.
-
#num_model_requests ⇒ Integer
The count of requests made to the model.
- #object ⇒ Symbol, :"organization.usage.audio_transcriptions.result"
-
#project_id ⇒ String?
When ‘group_by=project_id`, this field provides the project ID of the grouped usage result.
-
#seconds ⇒ Integer
The number of seconds processed.
-
#user_id ⇒ String?
When ‘group_by=user_id`, this field provides the user ID of the grouped usage result.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#api_key_id ⇒ String?
When ‘group_by=api_key_id`, this field provides the API key ID of the grouped usage result.
541 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 541 optional :api_key_id, String, nil?: true |
#model ⇒ String?
When ‘group_by=model`, this field provides the model name of the grouped usage result.
548 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 548 optional :model, String, nil?: true |
#num_model_requests ⇒ Integer
The count of requests made to the model.
523 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 523 required :num_model_requests, Integer |
#object ⇒ Symbol, :"organization.usage.audio_transcriptions.result"
528 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 528 required :object, const: :"organization.usage.audio_transcriptions.result" |
#project_id ⇒ String?
When ‘group_by=project_id`, this field provides the project ID of the grouped usage result.
555 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 555 optional :project_id, String, nil?: true |
#seconds ⇒ Integer
The number of seconds processed.
534 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 534 required :seconds, Integer |
#user_id ⇒ String?
When ‘group_by=user_id`, this field provides the user ID of the grouped usage result.
562 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 562 optional :user_id, String, nil?: true |