Class: OpenAI::Models::Admin::Organization::UsageEmbeddingsResponse::Data::Result::OrganizationUsageWebSearchesResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::UsageEmbeddingsResponse::Data::Result::OrganizationUsageWebSearchesResult
- Defined in:
- lib/openai/models/admin/organization/usage_embeddings_response.rb,
sig/openai/models/admin/organization/usage_embeddings_response.rbs
Instance Attribute Summary collapse
-
#api_key_id ⇒ String?
When
group_by=api_key_id, this field provides the API key ID of the grouped usage result. -
#context_level ⇒ String?
When
group_by=context_level, this field provides the search context size of the grouped usage result. -
#model ⇒ String?
When
group_by=model, this field provides the model name of the grouped usage result. -
#num_model_requests ⇒ Integer
The count of model requests.
-
#num_requests ⇒ Integer
The count of web search calls.
- #object ⇒ Symbol, :"organization.usage.web_searches.result"
-
#project_id ⇒ String?
When
group_by=project_id, this field provides the project ID of the grouped usage result. -
#user_id ⇒ String?
When
group_by=user_id, this field provides the user ID of the grouped usage result.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
599 |
# File 'sig/openai/models/admin/organization/usage_embeddings_response.rbs', line 599
def initialize: (
|
Instance Attribute Details
#api_key_id ⇒ String?
When group_by=api_key_id, this field provides the API key ID of the grouped
usage result.
871 |
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 871 optional :api_key_id, String, nil?: true |
#context_level ⇒ String?
When group_by=context_level, this field provides the search context size of
the grouped usage result.
878 |
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 878 optional :context_level, String, nil?: true |
#model ⇒ String?
When group_by=model, this field provides the model name of the grouped usage
result.
885 |
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 885 optional :model, String, nil?: true |
#num_model_requests ⇒ Integer
The count of model requests.
853 |
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 853 required :num_model_requests, Integer |
#num_requests ⇒ Integer
The count of web search calls.
859 |
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 859 required :num_requests, Integer |
#object ⇒ Symbol, :"organization.usage.web_searches.result"
864 |
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 864 required :object, const: :"organization.usage.web_searches.result" |
#project_id ⇒ String?
When group_by=project_id, this field provides the project ID of the grouped
usage result.
892 |
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 892 optional :project_id, String, nil?: true |
#user_id ⇒ String?
When group_by=user_id, this field provides the user ID of the grouped usage
result.
899 |
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 899 optional :user_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
610 |
# File 'sig/openai/models/admin/organization/usage_embeddings_response.rbs', line 610
def to_hash: -> {
|