Class: OpenAI::Models::Admin::Organization::UsageImagesResponse::Data::Result::OrganizationUsageAudioTranscriptionsResult

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/admin/organization/usage_images_response.rb,
sig/openai/models/admin/organization/usage_images_response.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • num_model_requests —

    The count of requests made to the model.

  • seconds —

    The number of seconds processed.

  • api_key_id —

    When group_by=api_key_id, this field provides the API key ID of the grouped usage result.

  • model —

    When group_by=model, this field provides the model name of the grouped usage result.

  • project_id —

    When group_by=project_id, this field provides the project ID of the grouped usage result.

  • user_id —

    When group_by=user_id, this field provides the user ID of the grouped usage result.



697
# File 'sig/openai/models/admin/organization/usage_images_response.rbs', line 697

def initialize: (

Instance Attribute Details

#api_key_id ⇒ String?

When group_by=api_key_id, this field provides the API key ID of the grouped usage result.

Returns:

  • (String, nil)


732
# File 'lib/openai/models/admin/organization/usage_images_response.rb', line 732

optional :api_key_id, String, nil?: true

#model ⇒ String?

When group_by=model, this field provides the model name of the grouped usage result.

Returns:

  • (String, nil)


739
# File 'lib/openai/models/admin/organization/usage_images_response.rb', line 739

optional :model, String, nil?: true

#num_model_requests ⇒ Integer

The count of requests made to the model.

Returns:

  • (Integer)


714
# File 'lib/openai/models/admin/organization/usage_images_response.rb', line 714

required :num_model_requests, Integer

#object ⇒ Symbol, :"organization.usage.audio_transcriptions.result"

Parameters:

  • value (:"organization.usage.audio_transcriptions.result")

Returns:

  • (Symbol, :"organization.usage.audio_transcriptions.result")


719
# File 'lib/openai/models/admin/organization/usage_images_response.rb', line 719

required :object, const: :"organization.usage.audio_transcriptions.result"

#project_id ⇒ String?

When group_by=project_id, this field provides the project ID of the grouped usage result.

Returns:

  • (String, nil)


746
# File 'lib/openai/models/admin/organization/usage_images_response.rb', line 746

optional :project_id, String, nil?: true

#seconds ⇒ Integer

The number of seconds processed.

Returns:

  • (Integer)


725
# File 'lib/openai/models/admin/organization/usage_images_response.rb', line 725

required :seconds, Integer

#user_id ⇒ String?

When group_by=user_id, this field provides the user ID of the grouped usage result.

Returns:

  • (String, nil)


753
# File 'lib/openai/models/admin/organization/usage_images_response.rb', line 753

optional :user_id, String, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


707
# File 'sig/openai/models/admin/organization/usage_images_response.rbs', line 707

def to_hash: -> {