Class: OpenAI::Models::Admin::Organization::UsageModerationsResponse::Data::Result::OrganizationUsageImagesResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::UsageModerationsResponse::Data::Result::OrganizationUsageImagesResult
- Defined in:
- lib/openai/models/admin/organization/usage_moderations_response.rb,
sig/openai/models/admin/organization/usage_moderations_response.rbs
Instance Attribute Summary collapse
-
#api_key_id ⇒ String?
When
group_by=api_key_id, this field provides the API key ID of the grouped usage result. -
#images ⇒ Integer
The number of images processed.
-
#model ⇒ String?
When
group_by=model, this field provides the model name of the grouped usage result. -
#num_model_requests ⇒ Integer
The count of requests made to the model.
- #object ⇒ Symbol, :"organization.usage.images.result"
-
#project_id ⇒ String?
When
group_by=project_id, this field provides the project ID of the grouped usage result. -
#size ⇒ String?
When
group_by=size, this field provides the image size of the grouped usage result. -
#source ⇒ String?
When
group_by=source, this field provides the source of the grouped usage result, possible values areimage.generation,image.edit,image.variation. -
#user_id ⇒ String?
When
group_by=user_id, this field provides the user ID of the grouped usage result.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
355 |
# File 'sig/openai/models/admin/organization/usage_moderations_response.rbs', line 355
def initialize: (
|
Instance Attribute Details
#api_key_id ⇒ String?
When group_by=api_key_id, this field provides the API key ID of the grouped
usage result.
470 |
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 470 optional :api_key_id, String, nil?: true |
#images ⇒ Integer
The number of images processed.
452 |
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 452 required :images, Integer |
#model ⇒ String?
When group_by=model, this field provides the model name of the grouped usage
result.
477 |
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 477 optional :model, String, nil?: true |
#num_model_requests ⇒ Integer
The count of requests made to the model.
458 |
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 458 required :num_model_requests, Integer |
#object ⇒ Symbol, :"organization.usage.images.result"
463 |
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 463 required :object, const: :"organization.usage.images.result" |
#project_id ⇒ String?
When group_by=project_id, this field provides the project ID of the grouped
usage result.
484 |
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 484 optional :project_id, String, nil?: true |
#size ⇒ String?
When group_by=size, this field provides the image size of the grouped usage
result.
491 |
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 491 optional :size, String, nil?: true |
#source ⇒ String?
When group_by=source, this field provides the source of the grouped usage
result, possible values are image.generation, image.edit, image.variation.
498 |
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 498 optional :source, String, nil?: true |
#user_id ⇒ String?
When group_by=user_id, this field provides the user ID of the grouped usage
result.
505 |
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 505 optional :user_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
367 |
# File 'sig/openai/models/admin/organization/usage_moderations_response.rbs', line 367
def to_hash: -> {
|