Class: OpenAI::Models::Admin::Organization::UsageModerationsResponse::Data::Result::OrganizationUsageWebSearchesResult

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/admin/organization/usage_moderations_response.rb,
sig/openai/models/admin/organization/usage_moderations_response.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • num_model_requests —

    The count of model requests.

  • num_requests —

    The count of web search calls.

  • api_key_id —

    When group_by=api_key_id, this field provides the API key ID of the grouped usage result.

  • context_level —

    When group_by=context_level, this field provides the search context size of the grouped usage result.

  • model —

    When group_by=model, this field provides the model name of the grouped usage result.

  • project_id —

    When group_by=project_id, this field provides the project ID of the grouped usage result.

  • user_id —

    When group_by=user_id, this field provides the user ID of the grouped usage result.



913
# File 'sig/openai/models/admin/organization/usage_moderations_response.rbs', line 913

def initialize: (

Instance Attribute Details

#api_key_id ⇒ String?

When group_by=api_key_id, this field provides the API key ID of the grouped usage result.

Returns:

  • (String, nil)


938
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 938

optional :api_key_id, String, nil?: true

#context_level ⇒ String?

When group_by=context_level, this field provides the search context size of the grouped usage result.

Returns:

  • (String, nil)


945
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 945

optional :context_level, String, nil?: true

#model ⇒ String?

When group_by=model, this field provides the model name of the grouped usage result.

Returns:

  • (String, nil)


952
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 952

optional :model, String, nil?: true

#num_model_requests ⇒ Integer

The count of model requests.

Returns:

  • (Integer)


920
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 920

required :num_model_requests, Integer

#num_requests ⇒ Integer

The count of web search calls.

Returns:

  • (Integer)


926
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 926

required :num_requests, Integer

#object ⇒ Symbol, :"organization.usage.web_searches.result"

Parameters:

  • value (:"organization.usage.web_searches.result")

Returns:

  • (Symbol, :"organization.usage.web_searches.result")


931
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 931

required :object, const: :"organization.usage.web_searches.result"

#project_id ⇒ String?

When group_by=project_id, this field provides the project ID of the grouped usage result.

Returns:

  • (String, nil)


959
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 959

optional :project_id, String, nil?: true

#user_id ⇒ String?

When group_by=user_id, this field provides the user ID of the grouped usage result.

Returns:

  • (String, nil)


966
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 966

optional :user_id, String, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


924
# File 'sig/openai/models/admin/organization/usage_moderations_response.rbs', line 924

def to_hash: -> {