Class: OpenAI::Models::Admin::Organization::UsageVectorStoresResponse::Data::Result::OrganizationUsageEmbeddingsResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::UsageVectorStoresResponse::Data::Result::OrganizationUsageEmbeddingsResult
- Defined in:
- lib/openai/models/admin/organization/usage_vector_stores_response.rb,
sig/openai/models/admin/organization/usage_vector_stores_response.rbs
Instance Attribute Summary collapse
-
#api_key_id ⇒ String?
When
group_by=api_key_id, this field provides the API key ID of the grouped usage result. -
#input_tokens ⇒ Integer
The aggregated number of input tokens used.
-
#model ⇒ String?
When
group_by=model, this field provides the model name of the grouped usage result. -
#num_model_requests ⇒ Integer
The count of requests made to the model.
- #object ⇒ Symbol, :"organization.usage.embeddings.result"
-
#project_id ⇒ String?
When
group_by=project_id, this field provides the project ID of the grouped usage result. -
#user_id ⇒ String?
When
group_by=user_id, this field provides the user ID of the grouped usage result.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
192 |
# File 'sig/openai/models/admin/organization/usage_vector_stores_response.rbs', line 192
def initialize: (
|
Instance Attribute Details
#api_key_id ⇒ String?
When group_by=api_key_id, this field provides the API key ID of the grouped
usage result.
259 |
# File 'lib/openai/models/admin/organization/usage_vector_stores_response.rb', line 259 optional :api_key_id, String, nil?: true |
#input_tokens ⇒ Integer
The aggregated number of input tokens used.
241 |
# File 'lib/openai/models/admin/organization/usage_vector_stores_response.rb', line 241 required :input_tokens, Integer |
#model ⇒ String?
When group_by=model, this field provides the model name of the grouped usage
result.
266 |
# File 'lib/openai/models/admin/organization/usage_vector_stores_response.rb', line 266 optional :model, String, nil?: true |
#num_model_requests ⇒ Integer
The count of requests made to the model.
247 |
# File 'lib/openai/models/admin/organization/usage_vector_stores_response.rb', line 247 required :num_model_requests, Integer |
#object ⇒ Symbol, :"organization.usage.embeddings.result"
252 |
# File 'lib/openai/models/admin/organization/usage_vector_stores_response.rb', line 252 required :object, const: :"organization.usage.embeddings.result" |
#project_id ⇒ String?
When group_by=project_id, this field provides the project ID of the grouped
usage result.
273 |
# File 'lib/openai/models/admin/organization/usage_vector_stores_response.rb', line 273 optional :project_id, String, nil?: true |
#user_id ⇒ String?
When group_by=user_id, this field provides the user ID of the grouped usage
result.
280 |
# File 'lib/openai/models/admin/organization/usage_vector_stores_response.rb', line 280 optional :user_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
202 |
# File 'sig/openai/models/admin/organization/usage_vector_stores_response.rbs', line 202
def to_hash: -> {
|