Class: OpenAI::Models::Admin::Organization::UsageWebSearchCallsResponse::Data::Result::OrganizationUsageAudioTranscriptionsResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::UsageWebSearchCallsResponse::Data::Result::OrganizationUsageAudioTranscriptionsResult
- Defined in:
- lib/openai/models/admin/organization/usage_web_search_calls_response.rb,
sig/openai/models/admin/organization/usage_web_search_calls_response.rbs
Instance Attribute Summary collapse
-
#api_key_id ⇒ String?
When
group_by=api_key_id, this field provides the API key ID of the grouped usage result. -
#model ⇒ String?
When
group_by=model, this field provides the model name of the grouped usage result. -
#num_model_requests ⇒ Integer
The count of requests made to the model.
- #object ⇒ Symbol, :"organization.usage.audio_transcriptions.result"
-
#project_id ⇒ String?
When
group_by=project_id, this field provides the project ID of the grouped usage result. -
#seconds ⇒ Integer
The number of seconds processed.
-
#user_id ⇒ String?
When
group_by=user_id, this field provides the user ID of the grouped usage result.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
390 |
# File 'sig/openai/models/admin/organization/usage_web_search_calls_response.rbs', line 390
def initialize: (
|
Instance Attribute Details
#api_key_id ⇒ String?
When group_by=api_key_id, this field provides the API key ID of the grouped
usage result.
549 |
# File 'lib/openai/models/admin/organization/usage_web_search_calls_response.rb', line 549 optional :api_key_id, String, nil?: true |
#model ⇒ String?
When group_by=model, this field provides the model name of the grouped usage
result.
556 |
# File 'lib/openai/models/admin/organization/usage_web_search_calls_response.rb', line 556 optional :model, String, nil?: true |
#num_model_requests ⇒ Integer
The count of requests made to the model.
531 |
# File 'lib/openai/models/admin/organization/usage_web_search_calls_response.rb', line 531 required :num_model_requests, Integer |
#object ⇒ Symbol, :"organization.usage.audio_transcriptions.result"
536 |
# File 'lib/openai/models/admin/organization/usage_web_search_calls_response.rb', line 536 required :object, const: :"organization.usage.audio_transcriptions.result" |
#project_id ⇒ String?
When group_by=project_id, this field provides the project ID of the grouped
usage result.
563 |
# File 'lib/openai/models/admin/organization/usage_web_search_calls_response.rb', line 563 optional :project_id, String, nil?: true |
#seconds ⇒ Integer
The number of seconds processed.
542 |
# File 'lib/openai/models/admin/organization/usage_web_search_calls_response.rb', line 542 required :seconds, Integer |
#user_id ⇒ String?
When group_by=user_id, this field provides the user ID of the grouped usage
result.
570 |
# File 'lib/openai/models/admin/organization/usage_web_search_calls_response.rb', line 570 optional :user_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
400 |
# File 'sig/openai/models/admin/organization/usage_web_search_calls_response.rbs', line 400
def to_hash: -> {
|