Class: OpenAI::Models::Audio::TranscriptionTextDeltaEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Audio::TranscriptionTextDeltaEvent
- Defined in:
- lib/openai/models/audio/transcription_text_delta_event.rb,
sig/openai/models/audio/transcription_text_delta_event.rbs
Defined Under Namespace
Classes: Logprob
Instance Attribute Summary collapse
-
#delta ⇒ String
The text delta that was additionally transcribed.
-
#logprobs ⇒ Array<OpenAI::Models::Audio::TranscriptionTextDeltaEvent::Logprob>?
The log probabilities of the delta.
-
#segment_id ⇒ String?
Identifier of the diarized segment that this delta belongs to.
-
#type ⇒ Symbol, :"transcript.text.delta"
The type of the event.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
27 |
# File 'sig/openai/models/audio/transcription_text_delta_event.rbs', line 27
def initialize: (
|
Instance Attribute Details
#delta ⇒ String
The text delta that was additionally transcribed.
11 |
# File 'lib/openai/models/audio/transcription_text_delta_event.rb', line 11 required :delta, String |
#logprobs ⇒ Array<OpenAI::Models::Audio::TranscriptionTextDeltaEvent::Logprob>?
The log probabilities of the delta. Only included if you
create a transcription
with the include[] parameter set to logprobs.
25 26 |
# File 'lib/openai/models/audio/transcription_text_delta_event.rb', line 25 optional :logprobs, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Audio::TranscriptionTextDeltaEvent::Logprob] } |
#segment_id ⇒ String?
Identifier of the diarized segment that this delta belongs to. Only present when
using gpt-4o-transcribe-diarize.
33 |
# File 'lib/openai/models/audio/transcription_text_delta_event.rb', line 33 optional :segment_id, String |
#type ⇒ Symbol, :"transcript.text.delta"
The type of the event. Always transcript.text.delta.
17 |
# File 'lib/openai/models/audio/transcription_text_delta_event.rb', line 17 required :type, const: :"transcript.text.delta" |
Instance Method Details
#to_hash ⇒ {
34 |
# File 'sig/openai/models/audio/transcription_text_delta_event.rbs', line 34
def to_hash: -> {
|