Class: OpenAI::Models::Audio::TranscriptionTextDoneEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/audio/transcription_text_done_event.rb,
sig/openai/models/audio/transcription_text_done_event.rbs

Defined Under Namespace

Classes: Logprob, Usage

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token: nil, bytes: nil, logprob: nil) ⇒ Object

Parameters:

  • text —

    The text that was transcribed.

  • languages —

    The languages detected in the audio. Returned by gpt-transcribe. An empty array indicates that no language could be reliably detected.

  • logprobs —

    The log probabilities of the individual tokens in the transcription. Only included if you create a transcription with the include[] parameter set to logprobs.

  • usage —

    Usage statistics for models billed by token usage.

  • type —

    The type of the event. Always transcript.text.done.



# File 'lib/openai/models/audio/transcription_text_done_event.rb', line 87

Instance Attribute Details

#languages ⇒ ::Array[OpenAI::Audio::TranscriptionLanguage]?

The languages detected in the audio. Returned by gpt-transcribe. An empty array indicates that no language could be reliably detected.

Returns:

  • (::Array[OpenAI::Audio::TranscriptionLanguage], nil)


24
# File 'lib/openai/models/audio/transcription_text_done_event.rb', line 24

optional :languages, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Audio::TranscriptionLanguage] }

#logprobs ⇒ ::Array[OpenAI::Audio::TranscriptionTextDoneEvent::Logprob]?

The log probabilities of the individual tokens in the transcription. Only included if you create a transcription with the include[] parameter set to logprobs.

Returns:

  • (::Array[OpenAI::Audio::TranscriptionTextDoneEvent::Logprob], nil)


33
34
35
36
# File 'lib/openai/models/audio/transcription_text_done_event.rb', line 33

optional(
  :logprobs,
  -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Audio::TranscriptionTextDoneEvent::Logprob] }
)

#text ⇒ String

The text that was transcribed.

Returns:

  • (String)


11
# File 'lib/openai/models/audio/transcription_text_done_event.rb', line 11

required :text, String

#type ⇒ :"transcript.text.done"

The type of the event. Always transcript.text.done.

Returns:

  • (:"transcript.text.done")


17
# File 'lib/openai/models/audio/transcription_text_done_event.rb', line 17

required :type, const: :"transcript.text.done"

#usage ⇒ OpenAI::Audio::TranscriptionTextDoneEvent::Usage?

Usage statistics for models billed by token usage.

Returns:

  • (OpenAI::Audio::TranscriptionTextDoneEvent::Usage, nil)


42
# File 'lib/openai/models/audio/transcription_text_done_event.rb', line 42

optional :usage, -> { OpenAI::Audio::TranscriptionTextDoneEvent::Usage }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


74
# File 'sig/openai/models/audio/transcription_text_done_event.rbs', line 74

def to_hash: -> {