Class: OpenAI::Models::Audio::TranscriptionTextDoneEvent::Logprob

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/audio/transcription_text_done_event.rb,
sig/openai/models/audio/transcription_text_done_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(text:, languages: nil, logprobs: nil, usage: nil, type: :"transcript.text.done") ⇒ Object

Parameters:

  • token —

    The token that was used to generate the log probability.

  • bytes —

    The bytes that were used to generate the log probability.

  • logprob —

    The log probability of the token.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/openai/models/audio/transcription_text_done_event.rb', line 68

class Logprob < OpenAI::Internal::Type::BaseModel
  # @!attribute token
  #   The token that was used to generate the log probability.
  #
  #   @return [String, nil]
  optional :token, String

  # @!attribute bytes
  #   The bytes that were used to generate the log probability.
  #
  #   @return [Array<Integer>, nil]
  optional :bytes, OpenAI::Internal::Type::ArrayOf[Integer]

  # @!attribute logprob
  #   The log probability of the token.
  #
  #   @return [Float, nil]
  optional :logprob, Float

  # @!method initialize(token: nil, bytes: nil, logprob: nil)
  #   @param token [String]
  #     The token that was used to generate the log probability.
  #
  #   @param bytes [Array<Integer>]
  #     The bytes that were used to generate the log probability.
  #
  #   @param logprob [Float]
  #     The log probability of the token.
end

Instance Attribute Details

#bytes ⇒ ::Array[Integer]?

The bytes that were used to generate the log probability.

Returns:

  • (::Array[Integer], nil)


79
# File 'lib/openai/models/audio/transcription_text_done_event.rb', line 79

optional :bytes, OpenAI::Internal::Type::ArrayOf[Integer]

#logprob ⇒ Float?

The log probability of the token.

Returns:

  • (Float, nil)


85
# File 'lib/openai/models/audio/transcription_text_done_event.rb', line 85

optional :logprob, Float

#token ⇒ String?

The token that was used to generate the log probability.

Returns:

  • (String, nil)


73
# File 'lib/openai/models/audio/transcription_text_done_event.rb', line 73

optional :token, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


116
# File 'sig/openai/models/audio/transcription_text_done_event.rbs', line 116

def to_hash: -> {