Module: OpenAI::Models::AudioResponseFormat
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/audio_response_format.rb
Overview
The format of the output, in one of these options: json, text, srt, verbose_json, vtt, or diarized_json. For gpt-4o-transcribe and gpt-4o-mini-transcribe, the only supported format is json. For gpt-4o-transcribe-diarize, the supported formats are json, text, and diarized_json, with diarized_json required to receive speaker annotations.
Constant Summary collapse
- JSON =
:json- TEXT =
:text- SRT =
:srt- VERBOSE_JSON =
:verbose_json- VTT =
:vtt- DIARIZED_JSON =
:diarized_json
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/audio_response_format.rb', line 20
|