Module: OpenAI::Models::BatchCreateParams::Endpoint

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/batch_create_params.rb

Overview

The endpoint to be used for all requests in the batch. Currently /v1/responses, /v1/chat/completions, /v1/embeddings, /v1/completions, /v1/moderations, /v1/images/generations, and /v1/images/edits are supported. Note that /v1/embeddings batches are also restricted to a maximum of 50,000 embedding inputs across all requests in the batch.

Constant Summary collapse

V1_RESPONSES =
:"/v1/responses"
V1_CHAT_COMPLETIONS =
:"/v1/chat/completions"
V1_EMBEDDINGS =
:"/v1/embeddings"
V1_COMPLETIONS =
:"/v1/completions"
V1_MODERATIONS =
:"/v1/moderations"
V1_IMAGES_GENERATIONS =
:"/v1/images/generations"
V1_IMAGES_EDITS =
:"/v1/images/edits"

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info