Class: OpenAI::Models::Beta::Agent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Agent
- Defined in:
- lib/openai/models/beta/agent.rb,
sig/openai/models/beta/agent.rbs
Overview
Defined Under Namespace
Modules: ServiceTier
Instance Attribute Summary collapse
-
#created_at ⇒ Integer
The Unix timestamp, in seconds, when the agent was created.
-
#id ⇒ String
The ID of the reusable agent.
-
#instructions ⇒ String?
Custom instructions appended to the agent's default base instructions.
-
#metadata ⇒ Hash{Symbol=>String}
Custom string key-value pairs attached to the agent.
-
#model ⇒ String
The requested model name used for inference.
-
#multi_agent ⇒ OpenAI::Models::Beta::MultiAgentConfig
The resolved configuration for creating and coordinating subagents.
-
#name ⇒ String?
A human-readable name for the agent, or null if it is unnamed.
-
#object ⇒ Symbol, :agent
The object type.
-
#reasoning ⇒ OpenAI::Models::Beta::AgentReasoning
The resolved reasoning configuration, including the model default for an omitted effort.
-
#service_tier ⇒ Symbol, OpenAI::Models::Beta::Agent::ServiceTier
The resolved service-tier policy used for model requests.
-
#text ⇒ OpenAI::Models::Beta::AgentText
The resolved configuration for text generated by the agent.
-
#tools ⇒ Array<OpenAI::Models::Beta::PersistedAgentTool::Function, OpenAI::Models::Beta::PersistedAgentTool::ToolSearch, OpenAI::Models::Beta::PersistedAgentTool::ProgrammaticToolCalling, OpenAI::Models::Beta::PersistedAgentTool::Mcp, OpenAI::Models::Beta::PersistedAgentTool::WebSearch>
Tools available to the agent.
-
#updated_at ⇒ Integer
The Unix timestamp, in seconds, when the agent was last updated.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(id:, created_at:, instructions:, metadata:, model:, multi_agent:, name:, reasoning:, service_tier:, text:, tools:, updated_at:, object: :agent) ⇒ Object
constructor
A reusable agent scoped to the caller's project.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, instructions:, metadata:, model:, multi_agent:, name:, reasoning:, service_tier:, text:, tools:, updated_at:, object: :agent) ⇒ Object
A reusable agent scoped to the caller's project.
|
|
# File 'lib/openai/models/beta/agent.rb', line 87
|
Instance Attribute Details
#created_at ⇒ Integer
The Unix timestamp, in seconds, when the agent was created.
18 |
# File 'lib/openai/models/beta/agent.rb', line 18 required :created_at, Integer |
#id ⇒ String
The ID of the reusable agent.
12 |
# File 'lib/openai/models/beta/agent.rb', line 12 required :id, String |
#instructions ⇒ String?
Custom instructions appended to the agent's default base instructions.
24 |
# File 'lib/openai/models/beta/agent.rb', line 24 required :instructions, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String}
Custom string key-value pairs attached to the agent.
30 |
# File 'lib/openai/models/beta/agent.rb', line 30 required :metadata, OpenAI::Internal::Type::HashOf[String] |
#model ⇒ String
The requested model name used for inference.
36 |
# File 'lib/openai/models/beta/agent.rb', line 36 required :model, String |
#multi_agent ⇒ OpenAI::Models::Beta::MultiAgentConfig
The resolved configuration for creating and coordinating subagents.
42 |
# File 'lib/openai/models/beta/agent.rb', line 42 required :multi_agent, -> { OpenAI::Beta::MultiAgentConfig } |
#name ⇒ String?
A human-readable name for the agent, or null if it is unnamed.
48 |
# File 'lib/openai/models/beta/agent.rb', line 48 required :name, String, nil?: true |
#object ⇒ Symbol, :agent
The object type. Always agent.
54 |
# File 'lib/openai/models/beta/agent.rb', line 54 required :object, const: :agent |
#reasoning ⇒ OpenAI::Models::Beta::AgentReasoning
The resolved reasoning configuration, including the model default for an omitted effort.
61 |
# File 'lib/openai/models/beta/agent.rb', line 61 required :reasoning, -> { OpenAI::Beta::AgentReasoning } |
#service_tier ⇒ Symbol, OpenAI::Models::Beta::Agent::ServiceTier
The resolved service-tier policy used for model requests.
67 |
# File 'lib/openai/models/beta/agent.rb', line 67 required :service_tier, enum: -> { OpenAI::Beta::Agent::ServiceTier } |
#text ⇒ OpenAI::Models::Beta::AgentText
The resolved configuration for text generated by the agent.
73 |
# File 'lib/openai/models/beta/agent.rb', line 73 required :text, -> { OpenAI::Beta::AgentText } |
#tools ⇒ Array<OpenAI::Models::Beta::PersistedAgentTool::Function, OpenAI::Models::Beta::PersistedAgentTool::ToolSearch, OpenAI::Models::Beta::PersistedAgentTool::ProgrammaticToolCalling, OpenAI::Models::Beta::PersistedAgentTool::Mcp, OpenAI::Models::Beta::PersistedAgentTool::WebSearch>
Tools available to the agent.
79 |
# File 'lib/openai/models/beta/agent.rb', line 79 required :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::PersistedAgentTool] } |
#updated_at ⇒ Integer
The Unix timestamp, in seconds, when the agent was last updated.
85 |
# File 'lib/openai/models/beta/agent.rb', line 85 required :updated_at, Integer |
Instance Method Details
#to_hash ⇒ {
64 |
# File 'sig/openai/models/beta/agent.rbs', line 64 def to_hash: -> { |