Class: OpenAI::Models::Beta::AgentBrowserAuthenticationSubmitParam

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agent_browser_authentication_submit_param.rb,
sig/openai/models/beta/agent_browser_authentication_submit_param.rbs

Defined Under Namespace

Classes: Field

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



29
# File 'sig/openai/models/beta/agent_browser_authentication_submit_param.rbs', line 29

def initialize: (

Instance Attribute Details

#action ⇒ Symbol, :submit



10
# File 'lib/openai/models/beta/agent_browser_authentication_submit_param.rb', line 10

required :action, const: :submit

#fields ⇒ ::Array[OpenAI::Beta::AgentBrowserAuthenticationSubmitParam::Field]

Values for up to six active fields in the required action. The submitted field-value mapping and selected option must fit within 120 KiB of JSON.



17
18
19
20
# File 'lib/openai/models/beta/agent_browser_authentication_submit_param.rb', line 17

required(
  :fields,
  -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::AgentBrowserAuthenticationSubmitParam::Field] }
)

#selected_option ⇒ String?

The chosen method. Required when the required action contains options.



31
# File 'lib/openai/models/beta/agent_browser_authentication_submit_param.rb', line 31

optional :selected_option, String, nil?: true

#type ⇒ Symbol, :browser_authentication



25
# File 'lib/openai/models/beta/agent_browser_authentication_submit_param.rb', line 25

required :type, const: :browser_authentication

Instance Method Details

#to_hash ⇒ {



36
# File 'sig/openai/models/beta/agent_browser_authentication_submit_param.rbs', line 36

def to_hash: -> {