Class: OpenAI::Models::Beta::AgentOutputItem::ComputerUseApprovalRequest::Request::Option
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::AgentOutputItem::ComputerUseApprovalRequest::Request::Option
- Defined in:
- lib/openai/models/beta/agent_output_item.rb,
sig/openai/models/beta/agent_output_item.rbs
Instance Attribute Summary collapse
-
#field_ids ⇒ ::Array[String]
IDs from the registered fields that this method accepts.
-
#id ⇒ String
The option ID to submit as selected_option.
-
#label ⇒ String
The method label to display.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, field_ids:, label:) ⇒ Object
|
|
# File 'lib/openai/models/beta/agent_output_item.rb', line 308
|
Instance Attribute Details
#field_ids ⇒ ::Array[String]
IDs from the registered fields that this method accepts.
300 |
# File 'lib/openai/models/beta/agent_output_item.rb', line 300 required :field_ids, OpenAI::Internal::Type::ArrayOf[String] |
#id ⇒ String
The option ID to submit as selected_option.
294 |
# File 'lib/openai/models/beta/agent_output_item.rb', line 294 required :id, String |
#label ⇒ String
The method label to display.
306 |
# File 'lib/openai/models/beta/agent_output_item.rb', line 306 required :label, String |
Instance Method Details
#to_hash ⇒ {
266 |
# File 'sig/openai/models/beta/agent_output_item.rbs', line 266 def to_hash: -> { |