Class: OpenAI::Models::Beta::AgentSession::Agent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::AgentSession::Agent
- Defined in:
- lib/openai/models/beta/agent_session.rb,
sig/openai/models/beta/agent_session.rbs
Overview
Defined Under Namespace
Modules: ServiceTier
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of the agent.
-
#instructions ⇒ String?
Custom instructions appended to the agent's default base instructions.
-
#model ⇒ String
The model used by the agent.
-
#multi_agent ⇒ OpenAI::Models::Beta::MultiAgentConfig
Configuration for creating and coordinating subagents.
-
#name ⇒ String?
The reusable agent's name when the session was created, or null if no name was saved.
-
#reasoning ⇒ OpenAI::Models::Beta::AgentReasoning
The agent's reasoning configuration.
-
#service_tier ⇒ Symbol, OpenAI::Models::Beta::AgentSession::Agent::ServiceTier
The effective service-tier policy for model requests.
-
#text ⇒ OpenAI::Models::Beta::AgentText
Configuration for text generated by the agent.
-
#tools ⇒ Array<OpenAI::Models::Beta::AgentTool::Function, OpenAI::Models::Beta::AgentTool::ProgrammaticToolCalling, OpenAI::Models::Beta::AgentTool::Mcp, OpenAI::Models::Beta::AgentTool::WebSearch>
Tools available to the agent.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(id:, instructions:, model:, multi_agent:, name:, reasoning:, service_tier:, text:, tools:) ⇒ Object
constructor
The agent running in the session.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, instructions:, model:, multi_agent:, name:, reasoning:, service_tier:, text:, tools:) ⇒ Object
The agent running in the session.
|
|
# File 'lib/openai/models/beta/agent_session.rb', line 178
|
Instance Attribute Details
#id ⇒ String
The ID of the agent.
127 |
# File 'lib/openai/models/beta/agent_session.rb', line 127 required :id, String |
#instructions ⇒ String?
Custom instructions appended to the agent's default base instructions.
133 |
# File 'lib/openai/models/beta/agent_session.rb', line 133 required :instructions, String, nil?: true |
#model ⇒ String
The model used by the agent.
139 |
# File 'lib/openai/models/beta/agent_session.rb', line 139 required :model, String |
#multi_agent ⇒ OpenAI::Models::Beta::MultiAgentConfig
Configuration for creating and coordinating subagents.
145 |
# File 'lib/openai/models/beta/agent_session.rb', line 145 required :multi_agent, -> { OpenAI::Beta::MultiAgentConfig } |
#name ⇒ String?
The reusable agent's name when the session was created, or null if no name was saved. Later changes to the agent's name do not affect this value.
152 |
# File 'lib/openai/models/beta/agent_session.rb', line 152 required :name, String, nil?: true |
#reasoning ⇒ OpenAI::Models::Beta::AgentReasoning
The agent's reasoning configuration.
158 |
# File 'lib/openai/models/beta/agent_session.rb', line 158 required :reasoning, -> { OpenAI::Beta::AgentReasoning } |
#service_tier ⇒ Symbol, OpenAI::Models::Beta::AgentSession::Agent::ServiceTier
The effective service-tier policy for model requests. Defaults to auto.
164 |
# File 'lib/openai/models/beta/agent_session.rb', line 164 required :service_tier, enum: -> { OpenAI::Beta::AgentSession::Agent::ServiceTier } |
#text ⇒ OpenAI::Models::Beta::AgentText
Configuration for text generated by the agent.
170 |
# File 'lib/openai/models/beta/agent_session.rb', line 170 required :text, -> { OpenAI::Beta::AgentText } |
#tools ⇒ Array<OpenAI::Models::Beta::AgentTool::Function, OpenAI::Models::Beta::AgentTool::ProgrammaticToolCalling, OpenAI::Models::Beta::AgentTool::Mcp, OpenAI::Models::Beta::AgentTool::WebSearch>
Tools available to the agent.
176 |
# File 'lib/openai/models/beta/agent_session.rb', line 176 required :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::AgentTool] } |
Instance Method Details
#to_hash ⇒ {
119 |
# File 'sig/openai/models/beta/agent_session.rbs', line 119
def to_hash: -> {
|