Module: OpenAI::Models::Beta::AgentSession::RequiredAction

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/beta/agent_session.rb,
sig/openai/models/beta/agent_session.rbs

Overview

An action that must be completed before a session can continue.

Defined Under Namespace

Classes: EnvironmentConnection, FunctionCall

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(arguments:, call_id:, name:, turn_id:, type: :function_call) ⇒ Object

Run a function tool and submit its result.

Parameters:

  • arguments (Object)

    The arguments supplied by the model.

  • call_id (String)

    The ID to include when submitting the function result.

  • name (String)

    The function name.

  • turn_id (String)

    The ID of the turn that requested the function call.

  • type (Symbol, :function_call) (defaults to: :function_call)

    The type of the object. Always function_call.



# File 'lib/openai/models/beta/agent_session.rb', line 269

#self?.variants::Array[OpenAI::Models::Beta::AgentSession::required_action]

Returns:

  • (::Array[OpenAI::Models::Beta::AgentSession::required_action])


209
# File 'sig/openai/models/beta/agent_session.rbs', line 209

def self?.variants: -> ::Array[OpenAI::Models::Beta::AgentSession::required_action]