Module: OpenAI::Models::Beta::AgentSession::RequiredAction::ComputerUseApprovalRequest::Request

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/beta/agent_session.rb,
sig/openai/models/beta/agent_session.rbs

Overview

The information needed to render the request.

See Also:

  • OpenAI::Models::Beta::AgentSession::RequiredAction::ComputerUseApprovalRequest#request

Defined Under Namespace

Classes: BrowserAuthentication, BrowserOriginAccess

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(id:, field_ids:, label:) ⇒ Object

A sign-in method and the fields that belong to it.

Parameters:

  • id (String) —

    The option ID to submit as selected_option.

  • field_ids (Array<String>) —

    IDs from the registered fields that this method accepts.

  • label (String) —

    The method label to display.



# File 'lib/openai/models/beta/agent_session.rb', line 436

#self?.variants ⇒ ::Array[OpenAI::Models::Beta::AgentSession::RequiredAction::ComputerUseApprovalRequest::request]

Returns:

  • (::Array[OpenAI::Models::Beta::AgentSession::RequiredAction::ComputerUseApprovalRequest::request])


432
# File 'sig/openai/models/beta/agent_session.rbs', line 432

def self?.variants: -> ::Array[OpenAI::Models::Beta::AgentSession::RequiredAction::ComputerUseApprovalRequest::request]