Class: OpenAI::Models::Beta::AgentSession::RequiredAction::ComputerUseApprovalRequest::Request::BrowserOriginAccess

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/beta/agent_session.rb,
sig/openai/models/beta/agent_session.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • origin —

    The origin the browser needs permission to access.

  • reason —

    The browser's explanation for this request, or null when unavailable.

  • type —

    The type of the object. Always browser_origin_access.



419
# File 'sig/openai/models/beta/agent_session.rbs', line 419

def initialize: (

Instance Attribute Details

#origin ⇒ String

The origin the browser needs permission to access.

Returns:

  • (String)


455
# File 'lib/openai/models/beta/agent_session.rb', line 455

required :origin, String

#reason ⇒ String?

The browser's explanation for this request, or null when unavailable.

Returns:

  • (String, nil)


461
# File 'lib/openai/models/beta/agent_session.rb', line 461

required :reason, String, nil?: true

#type ⇒ :browser_origin_access

The type of the object. Always browser_origin_access.

Returns:

  • (:browser_origin_access)


467
# File 'lib/openai/models/beta/agent_session.rb', line 467

required :type, const: :browser_origin_access

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


425
# File 'sig/openai/models/beta/agent_session.rbs', line 425

def to_hash: -> {