Class: OpenAI::Models::Beta::AgentSession::RequiredAction::FunctionCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agent_session.rb,
sig/openai/models/beta/agent_session.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Parameters:

  • arguments

    The arguments supplied by the model.

  • call_id

    The ID to include when submitting the function result.

  • name

    The function name.

  • turn_id

    The ID of the turn that requested the function call.

  • type

    The type of the object. Always function_call.



255
# File 'sig/openai/models/beta/agent_session.rbs', line 255

def initialize: (

Instance Attribute Details

#argumentstop

The arguments supplied by the model.

Returns:

  • (top)


245
# File 'lib/openai/models/beta/agent_session.rb', line 245

required :arguments, OpenAI::Internal::Type::Unknown

#call_idString

The ID to include when submitting the function result.

Returns:

  • (String)


251
# File 'lib/openai/models/beta/agent_session.rb', line 251

required :call_id, String

#nameString

The function name.

Returns:

  • (String)


257
# File 'lib/openai/models/beta/agent_session.rb', line 257

required :name, String

#turn_idString

The ID of the turn that requested the function call.

Returns:

  • (String)


263
# File 'lib/openai/models/beta/agent_session.rb', line 263

required :turn_id, String

#type:function_call

The type of the object. Always function_call.

Returns:

  • (:function_call)


269
# File 'lib/openai/models/beta/agent_session.rb', line 269

required :type, const: :function_call

Instance Method Details

#to_hash{

Returns:

  • ({)


263
# File 'sig/openai/models/beta/agent_session.rbs', line 263

def to_hash: -> {