Module: OpenAI::Models::Beta::AgentSession::Status
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/beta/agent_session.rb,
sig/openai/models/beta/agent_session.rbs
Overview
The current status of the session.
Constant Summary collapse
- IDLE =
The session has no turn in progress and is ready for input. A hosted environment may still be provisioning.
:idle- IN_PROGRESS =
The session is processing a turn.
:in_progress- REQUIRES_ACTION =
The session is waiting for one or more required actions.
:requires_action- FAILED =
The session failed.
:failed
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/agent_session.rb', line 333
|
Instance Method Details
#self?.values ⇒ ::Array[OpenAI::Models::Beta::AgentSession::status]
229 |
# File 'sig/openai/models/beta/agent_session.rbs', line 229
def self?.values: -> ::Array[OpenAI::Models::Beta::AgentSession::status]
|