Class: OpenAI::Models::Beta::AgentSessionItem::ComputerUseApprovalRequest::Request

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agent_session_item.rb,
sig/openai/models/beta/agent_session_item.rbs

Overview

See Also:

  • OpenAI::Models::Beta::AgentSessionItem::ComputerUseApprovalRequest#request

Defined Under Namespace

Classes: Field, Option

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, label:, required:, type:) ⇒ Object

Parameters:

  • The registered form or frame origin where values will be entered.

  • Controls to render. All submitted values are sensitive.

  • Sign-in methods. Empty for a plain form.

  • Why the agent needs the user to sign in.

  • The type of the object. Always browser_authentication.



# File 'lib/openai/models/beta/agent_session_item.rb', line 412


Instance Attribute Details

#credential_origin ⇒ String?

The registered form or frame origin where values will be entered.

Returns:



330
# File 'lib/openai/models/beta/agent_session_item.rb', line 330

required :credential_origin, String, nil?: true

#fields ⇒ ::Array[OpenAI::Beta::AgentSessionItem::ComputerUseApprovalRequest::Request::Field]

Controls to render. All submitted values are sensitive.

Returns:



336
337
338
339
340
341
342
343
# File 'lib/openai/models/beta/agent_session_item.rb', line 336

required(
  :fields,
  -> {
    OpenAI::Internal::Type::ArrayOf[
      OpenAI::Beta::AgentSessionItem::ComputerUseApprovalRequest::Request::Field
    ]
  }
)

#options ⇒ ::Array[OpenAI::Beta::AgentSessionItem::ComputerUseApprovalRequest::Request::Option]

Sign-in methods. Empty for a plain form.

Returns:



349
350
351
352
353
354
355
356
# File 'lib/openai/models/beta/agent_session_item.rb', line 349

required(
  :options,
  -> {
    OpenAI::Internal::Type::ArrayOf[
      OpenAI::Beta::AgentSessionItem::ComputerUseApprovalRequest::Request::Option
    ]
  }
)

#reason ⇒ String?

Why the agent needs the user to sign in.

Returns:



362
# File 'lib/openai/models/beta/agent_session_item.rb', line 362

required :reason, String, nil?: true

#type ⇒ :browser_authentication

The type of the object. Always browser_authentication.

Returns:



368
# File 'lib/openai/models/beta/agent_session_item.rb', line 368

required :type, const: :browser_authentication

Instance Method Details

#to_hash ⇒ {

Returns:



325
# File 'sig/openai/models/beta/agent_session_item.rbs', line 325

def to_hash: -> {