Class: OpenAI::Models::Beta::AgentSessionItem::ComputerUseApprovalRequestResult::Response::Submit

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/beta/agent_session_item.rb,
sig/openai/models/beta/agent_session_item.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • selected_option —

    The chosen sign-in method, or null when no options were offered.



478
# File 'sig/openai/models/beta/agent_session_item.rbs', line 478

def initialize: (

Instance Attribute Details

#action ⇒ Symbol, :submit

Parameters:

  • value (:submit)

Returns:

  • (Symbol, :submit)


528
# File 'lib/openai/models/beta/agent_session_item.rb', line 528

required :action, const: :submit

#selected_option ⇒ String?

The chosen sign-in method, or null when no options were offered.

Returns:

  • (String, nil)


534
# File 'lib/openai/models/beta/agent_session_item.rb', line 534

required :selected_option, String, nil?: true

#type ⇒ Symbol, :browser_authentication

Parameters:

  • value (:browser_authentication)

Returns:

  • (Symbol, :browser_authentication)


539
# File 'lib/openai/models/beta/agent_session_item.rb', line 539

required :type, const: :browser_authentication

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


484
# File 'sig/openai/models/beta/agent_session_item.rbs', line 484

def to_hash: -> {