Class: OpenAI::Models::Beta::AgentSessionItem::FunctionCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::AgentSessionItem::FunctionCallOutput
- Defined in:
- lib/openai/models/beta/agent_session_item.rb,
sig/openai/models/beta/agent_session_item.rbs
Instance Attribute Summary collapse
-
#call_id ⇒ String
The ID of the function call that produced this output.
-
#error ⇒ String?
The error message, if the call failed.
-
#id ⇒ String
The ID of the function call output item.
-
#output ⇒ String, ...
The text or model-input content supplied as a function result.
-
#status ⇒ Symbol, OpenAI::Models::Beta::AgentFunctionCallStatus
The status of the function call.
-
#turn_id ⇒ String
The ID of the turn that contains this item.
-
#type ⇒ Symbol, :function_call_output
The item type.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
49 |
# File 'sig/openai/models/beta/agent_session_item.rbs', line 49
def initialize: (
|
Instance Attribute Details
#call_id ⇒ String
The ID of the function call that produced this output.
65 |
# File 'lib/openai/models/beta/agent_session_item.rb', line 65 required :call_id, String |
#error ⇒ String?
The error message, if the call failed.
71 |
# File 'lib/openai/models/beta/agent_session_item.rb', line 71 required :error, String, nil?: true |
#id ⇒ String
The ID of the function call output item.
59 |
# File 'lib/openai/models/beta/agent_session_item.rb', line 59 required :id, String |
#output ⇒ String, ...
The text or model-input content supplied as a function result.
77 |
# File 'lib/openai/models/beta/agent_session_item.rb', line 77 required :output, union: -> { OpenAI::Beta::AgentFunctionCallOutput }, nil?: true |
#status ⇒ Symbol, OpenAI::Models::Beta::AgentFunctionCallStatus
The status of the function call.
83 |
# File 'lib/openai/models/beta/agent_session_item.rb', line 83 required :status, enum: -> { OpenAI::Beta::AgentFunctionCallStatus } |
#turn_id ⇒ String
The ID of the turn that contains this item.
89 |
# File 'lib/openai/models/beta/agent_session_item.rb', line 89 required :turn_id, String |
#type ⇒ Symbol, :function_call_output
The item type. Always function_call_output.
95 |
# File 'lib/openai/models/beta/agent_session_item.rb', line 95 required :type, const: :function_call_output |
Instance Method Details
#to_hash ⇒ {
59 |
# File 'sig/openai/models/beta/agent_session_item.rbs', line 59
def to_hash: -> {
|