Class: OpenAI::Models::Beta::AgentSessionTurnFailedEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agent_session_turn_failed_event.rb,
sig/openai/models/beta/agent_session_turn_failed_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_id:, session_id:, turn:, turn_id:, usage:, type: :"agent.session.turn.failed") ⇒ Object

Parameters:

  • event_id

    The unique ID of the event.

  • session_id

    The ID of the session associated with the event.

  • turn

    The failed turn.

  • turn_id

    The ID of the turn associated with the event.

  • usage

    Token usage by the root agent during the turn, when available.

  • type (defaults to: :"agent.session.turn.failed")

    The type of the object. Always agent.session.turn.failed.



# File 'lib/openai/models/beta/agent_session_turn_failed_event.rb', line 43


Instance Attribute Details

#event_idString

The unique ID of the event.

Returns:

  • (String)


11
# File 'lib/openai/models/beta/agent_session_turn_failed_event.rb', line 11

required :event_id, String

#session_idString

The ID of the session associated with the event.

Returns:

  • (String)


17
# File 'lib/openai/models/beta/agent_session_turn_failed_event.rb', line 17

required :session_id, String

#turnOpenAI::Beta::Agents::Sessions::Turn

The failed turn.

Returns:

  • (OpenAI::Beta::Agents::Sessions::Turn)


23
# File 'lib/openai/models/beta/agent_session_turn_failed_event.rb', line 23

required :turn, -> { OpenAI::Beta::Agents::Sessions::Turn }

#turn_idString

The ID of the turn associated with the event.

Returns:

  • (String)


29
# File 'lib/openai/models/beta/agent_session_turn_failed_event.rb', line 29

required :turn_id, String

#type:"agent.session.turn.failed"

The type of the object. Always agent.session.turn.failed.

Returns:

  • (:"agent.session.turn.failed")


35
# File 'lib/openai/models/beta/agent_session_turn_failed_event.rb', line 35

required :type, const: :"agent.session.turn.failed"

#usageOpenAI::Beta::TokenUsage?

Token usage by the root agent during the turn, when available.

Returns:

  • (OpenAI::Beta::TokenUsage, nil)


41
# File 'lib/openai/models/beta/agent_session_turn_failed_event.rb', line 41

required :usage, -> { OpenAI::Beta::TokenUsage }, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


54
# File 'sig/openai/models/beta/agent_session_turn_failed_event.rbs', line 54

def to_hash: -> {