Class: OpenAI::Models::Beta::AgentSessionTurnItemDoneEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agent_session_turn_item_done_event.rb,
sig/openai/models/beta/agent_session_turn_item_done_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_id:, item:, output_index:, session_id:, turn_id:, type: :"agent.session.turn.item.done") ⇒ Object

Emitted when an output item is complete.

Parameters:



# File 'lib/openai/models/beta/agent_session_turn_item_done_event.rb', line 43

Instance Attribute Details

#event_idString

The unique ID of the event.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/openai/models/beta/agent_session_turn_item_done_event.rb', line 11

required :event_id, String

#itemOpenAI::Models::Beta::AgentSessionAssistantMessage, ...

The completed output item.



17
# File 'lib/openai/models/beta/agent_session_turn_item_done_event.rb', line 17

required :item, union: -> { OpenAI::Beta::AgentOutputItem }

#output_indexInteger

The index of the output item in the turn output.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


23
# File 'lib/openai/models/beta/agent_session_turn_item_done_event.rb', line 23

required :output_index, Integer

#session_idString

The ID of the session associated with the event.

Parameters:

  • value (String)

Returns:

  • (String)


29
# File 'lib/openai/models/beta/agent_session_turn_item_done_event.rb', line 29

required :session_id, String

#turn_idString?

The ID of the turn associated with the event, when applicable.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


35
# File 'lib/openai/models/beta/agent_session_turn_item_done_event.rb', line 35

required :turn_id, String, nil?: true

#typeSymbol, :"agent.session.turn.item.done"

The type of the object. Always agent.session.turn.item.done.

Parameters:

  • value (:"agent.session.turn.item.done")

Returns:

  • (Symbol, :"agent.session.turn.item.done")


41
# File 'lib/openai/models/beta/agent_session_turn_item_done_event.rb', line 41

required :type, const: :"agent.session.turn.item.done"

Instance Method Details

#to_hash{

Returns:

  • ({)


36
# File 'sig/openai/models/beta/agent_session_turn_item_done_event.rbs', line 36

def to_hash: -> {