Class: OpenAI::Models::Beta::AgentSessionTurnOutputTextDeltaEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::AgentSessionTurnOutputTextDeltaEvent
- Defined in:
- lib/openai/models/beta/agent_session_turn_output_text_delta_event.rb,
sig/openai/models/beta/agent_session_turn_output_text_delta_event.rbs
Instance Attribute Summary collapse
-
#content_index ⇒ Integer
The index of the content part in the message.
-
#delta ⇒ String
The text that was appended.
-
#event_id ⇒ String
The unique ID of the event.
-
#item_id ⇒ String
The ID of the message item.
-
#output_index ⇒ Integer
The index of the item in the turn output.
-
#session_id ⇒ String
The ID of the session associated with the event.
-
#turn_id ⇒ String?
The ID of the turn associated with the event, when applicable.
-
#type ⇒ Symbol, :"agent.session.turn.output_text.delta"
The type of the object.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(content_index:, delta:, event_id:, item_id:, output_index:, session_id:, turn_id:, type: :"agent.session.turn.output_text.delta") ⇒ Object
constructor
Emitted when text is appended to an output text content part.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content_index:, delta:, event_id:, item_id:, output_index:, session_id:, turn_id:, type: :"agent.session.turn.output_text.delta") ⇒ Object
Emitted when text is appended to an output text content part.
|
|
# File 'lib/openai/models/beta/agent_session_turn_output_text_delta_event.rb', line 55
|
Instance Attribute Details
#content_index ⇒ Integer
The index of the content part in the message.
11 |
# File 'lib/openai/models/beta/agent_session_turn_output_text_delta_event.rb', line 11 required :content_index, Integer |
#delta ⇒ String
The text that was appended.
17 |
# File 'lib/openai/models/beta/agent_session_turn_output_text_delta_event.rb', line 17 required :delta, String |
#event_id ⇒ String
The unique ID of the event.
23 |
# File 'lib/openai/models/beta/agent_session_turn_output_text_delta_event.rb', line 23 required :event_id, String |
#item_id ⇒ String
The ID of the message item.
29 |
# File 'lib/openai/models/beta/agent_session_turn_output_text_delta_event.rb', line 29 required :item_id, String |
#output_index ⇒ Integer
The index of the item in the turn output.
35 |
# File 'lib/openai/models/beta/agent_session_turn_output_text_delta_event.rb', line 35 required :output_index, Integer |
#session_id ⇒ String
The ID of the session associated with the event.
41 |
# File 'lib/openai/models/beta/agent_session_turn_output_text_delta_event.rb', line 41 required :session_id, String |
#turn_id ⇒ String?
The ID of the turn associated with the event, when applicable.
47 |
# File 'lib/openai/models/beta/agent_session_turn_output_text_delta_event.rb', line 47 required :turn_id, String, nil?: true |
#type ⇒ Symbol, :"agent.session.turn.output_text.delta"
The type of the object. Always agent.session.turn.output_text.delta.
53 |
# File 'lib/openai/models/beta/agent_session_turn_output_text_delta_event.rb', line 53 required :type, const: :"agent.session.turn.output_text.delta" |
Instance Method Details
#to_hash ⇒ {
44 |
# File 'sig/openai/models/beta/agent_session_turn_output_text_delta_event.rbs', line 44
def to_hash: -> {
|