Class: OpenAI::Models::Beta::AgentSessionTurnOutputTextDoneEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agent_session_turn_output_text_done_event.rb,
sig/openai/models/beta/agent_session_turn_output_text_done_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content_index:, event_id:, item_id:, output_index:, session_id:, text:, turn_id:, type: :"agent.session.turn.output_text.done") ⇒ Object

Emitted when an output text content part is complete.

Parameters:

  • content_index (Integer)

    The index of the content part in the message.

  • event_id (String)

    The unique ID of the event.

  • item_id (String)

    The ID of the message item.

  • output_index (Integer)

    The index of the item in the turn output.

  • session_id (String)

    The ID of the session associated with the event.

  • text (String)

    The complete output text.

  • turn_id (String, nil)

    The ID of the turn associated with the event, when applicable.

  • type (Symbol, :"agent.session.turn.output_text.done") (defaults to: :"agent.session.turn.output_text.done")

    The type of the object. Always agent.session.turn.output_text.done.



# File 'lib/openai/models/beta/agent_session_turn_output_text_done_event.rb', line 55

Instance Attribute Details

#content_indexInteger

The index of the content part in the message.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


11
# File 'lib/openai/models/beta/agent_session_turn_output_text_done_event.rb', line 11

required :content_index, Integer

#event_idString

The unique ID of the event.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/openai/models/beta/agent_session_turn_output_text_done_event.rb', line 17

required :event_id, String

#item_idString

The ID of the message item.

Parameters:

  • value (String)

Returns:

  • (String)


23
# File 'lib/openai/models/beta/agent_session_turn_output_text_done_event.rb', line 23

required :item_id, String

#output_indexInteger

The index of the item in the turn output.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


29
# File 'lib/openai/models/beta/agent_session_turn_output_text_done_event.rb', line 29

required :output_index, Integer

#session_idString

The ID of the session associated with the event.

Parameters:

  • value (String)

Returns:

  • (String)


35
# File 'lib/openai/models/beta/agent_session_turn_output_text_done_event.rb', line 35

required :session_id, String

#textString

The complete output text.

Parameters:

  • value (String)

Returns:

  • (String)


41
# File 'lib/openai/models/beta/agent_session_turn_output_text_done_event.rb', line 41

required :text, String

#turn_idString?

The ID of the turn associated with the event, when applicable.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


47
# File 'lib/openai/models/beta/agent_session_turn_output_text_done_event.rb', line 47

required :turn_id, String, nil?: true

#typeSymbol, :"agent.session.turn.output_text.done"

The type of the object. Always agent.session.turn.output_text.done.

Parameters:

  • value (:"agent.session.turn.output_text.done")

Returns:

  • (Symbol, :"agent.session.turn.output_text.done")


53
# File 'lib/openai/models/beta/agent_session_turn_output_text_done_event.rb', line 53

required :type, const: :"agent.session.turn.output_text.done"

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/openai/models/beta/agent_session_turn_output_text_done_event.rbs', line 44

def to_hash: -> {