Class: OpenAI::Models::Beta::AgentSessionTurnReasoningSummaryPartDoneEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agent_session_turn_reasoning_summary_part_done_event.rb,
sig/openai/models/beta/agent_session_turn_reasoning_summary_part_done_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_id:, item_id:, output_index:, part:, session_id:, summary_index:, turn_id:, status: :incomplete, type: :"agent.session.turn.reasoning_summary_part.done") ⇒ Object

Emitted when a reasoning summary part is complete.

Parameters:

  • event_id (String)

    The unique ID of the event.

  • item_id (String)

    The ID of the reasoning item.

  • output_index (Integer)

    The index of the item in the turn output.

  • part (OpenAI::Models::Beta::SummaryText)

    The completed summary part.

  • session_id (String)

    The ID of the session associated with the event.

  • summary_index (Integer)

    The index of the summary part.

  • turn_id (String, nil)

    The ID of the turn associated with the event, when applicable.

  • status (Symbol, :incomplete, nil) (defaults to: :incomplete)

    Present as incomplete when summary generation was interrupted.

  • type (Symbol, :"agent.session.turn.reasoning_summary_part.done") (defaults to: :"agent.session.turn.reasoning_summary_part.done")

    The type of the object. Always agent.session.turn.reasoning_summary_part.done.



# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_part_done_event.rb', line 61

Instance Attribute Details

#event_idString

The unique ID of the event.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_part_done_event.rb', line 11

required :event_id, String

#item_idString

The ID of the reasoning item.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_part_done_event.rb', line 17

required :item_id, String

#output_indexInteger

The index of the item in the turn output.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


23
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_part_done_event.rb', line 23

required :output_index, Integer

#partOpenAI::Models::Beta::SummaryText

The completed summary part.

Parameters:

  • value (OpenAI::Beta::SummaryText)

Returns:



29
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_part_done_event.rb', line 29

required :part, -> { OpenAI::Beta::SummaryText }

#session_idString

The ID of the session associated with the event.

Parameters:

  • value (String)

Returns:

  • (String)


35
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_part_done_event.rb', line 35

required :session_id, String

#statusSymbol, ...

Present as incomplete when summary generation was interrupted.

Parameters:

  • (:incomplete, nil)

Returns:

  • (Symbol, :incomplete, nil)


41
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_part_done_event.rb', line 41

required :status, const: :incomplete, nil?: true

#summary_indexInteger

The index of the summary part.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


47
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_part_done_event.rb', line 47

required :summary_index, Integer

#turn_idString?

The ID of the turn associated with the event, when applicable.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


53
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_part_done_event.rb', line 53

required :turn_id, String, nil?: true

#typeSymbol, :"agent.session.turn.reasoning_summary_part.done"

The type of the object. Always agent.session.turn.reasoning_summary_part.done.

Parameters:

  • value (:"agent.session.turn.reasoning_summary_part.done")

Returns:

  • (Symbol, :"agent.session.turn.reasoning_summary_part.done")


59
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_part_done_event.rb', line 59

required :type, const: :"agent.session.turn.reasoning_summary_part.done"

Instance Method Details

#to_hash{

Returns:

  • ({)


50
# File 'sig/openai/models/beta/agent_session_turn_reasoning_summary_part_done_event.rbs', line 50

def to_hash: -> {