Class: OpenAI::Models::Beta::AgentSessionTurnReasoningSummaryTextDoneEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::AgentSessionTurnReasoningSummaryTextDoneEvent
- Defined in:
- lib/openai/models/beta/agent_session_turn_reasoning_summary_text_done_event.rb,
sig/openai/models/beta/agent_session_turn_reasoning_summary_text_done_event.rbs
Instance Attribute Summary collapse
-
#event_id ⇒ String
The unique ID of the event.
-
#item_id ⇒ String
The ID of the reasoning item.
-
#output_index ⇒ Integer
The index of the item in the turn output.
-
#session_id ⇒ String
The ID of the session associated with the event.
-
#summary_index ⇒ Integer
The index of the summary content part.
-
#text ⇒ String
The complete reasoning summary text.
-
#turn_id ⇒ String?
The ID of the turn associated with the event, when applicable.
-
#type ⇒ Symbol, :"agent.session.turn.reasoning_summary_text.done"
The type of the object.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(event_id:, item_id:, output_index:, session_id:, summary_index:, text:, turn_id:, type: :"agent.session.turn.reasoning_summary_text.done") ⇒ Object
constructor
Emitted when a reasoning summary content part is complete.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(event_id:, item_id:, output_index:, session_id:, summary_index:, text:, turn_id:, type: :"agent.session.turn.reasoning_summary_text.done") ⇒ Object
Emitted when a reasoning summary content part is complete.
|
|
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_text_done_event.rb', line 55
|
Instance Attribute Details
#event_id ⇒ String
The unique ID of the event.
11 |
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_text_done_event.rb', line 11 required :event_id, String |
#item_id ⇒ String
The ID of the reasoning item.
17 |
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_text_done_event.rb', line 17 required :item_id, String |
#output_index ⇒ Integer
The index of the item in the turn output.
23 |
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_text_done_event.rb', line 23 required :output_index, Integer |
#session_id ⇒ String
The ID of the session associated with the event.
29 |
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_text_done_event.rb', line 29 required :session_id, String |
#summary_index ⇒ Integer
The index of the summary content part.
35 |
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_text_done_event.rb', line 35 required :summary_index, Integer |
#text ⇒ String
The complete reasoning summary text.
41 |
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_text_done_event.rb', line 41 required :text, String |
#turn_id ⇒ String?
The ID of the turn associated with the event, when applicable.
47 |
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_text_done_event.rb', line 47 required :turn_id, String, nil?: true |
#type ⇒ Symbol, :"agent.session.turn.reasoning_summary_text.done"
The type of the object. Always agent.session.turn.reasoning_summary_text.done.
53 |
# File 'lib/openai/models/beta/agent_session_turn_reasoning_summary_text_done_event.rb', line 53 required :type, const: :"agent.session.turn.reasoning_summary_text.done" |
Instance Method Details
#to_hash ⇒ {
44 |
# File 'sig/openai/models/beta/agent_session_turn_reasoning_summary_text_done_event.rbs', line 44
def to_hash: -> {
|