Class: OpenAI::Models::Beta::AgentTool::WebSearch

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agent_tool.rb,
sig/openai/models/beta/agent_tool.rbs

Defined Under Namespace

Modules: ContextSize, Mode Classes: Location

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country:, region:, timezone:) ⇒ Object

Parameters:

  • allowed_domains

    Allowed search domains, or null when the search is unrestricted.

  • context_size

    The amount of search context made available to the model. Defaults to medium.

  • location

    Approximate location used to localize search results, if provided.

  • mode

    The source used for web search results.

  • type

    The type of the object. Always web_search.



# File 'lib/openai/models/beta/agent_tool.rb', line 220

Instance Attribute Details

#allowed_domains::Array[String]?

Allowed search domains, or null when the search is unrestricted.

Returns:

  • (::Array[String], nil)


194
# File 'lib/openai/models/beta/agent_tool.rb', line 194

required :allowed_domains, OpenAI::Internal::Type::ArrayOf[String], nil?: true

#context_sizeOpenAI::Models::Beta::AgentTool::WebSearch::context_size

The amount of search context made available to the model. Defaults to medium.

Returns:

  • (OpenAI::Models::Beta::AgentTool::WebSearch::context_size)


200
# File 'lib/openai/models/beta/agent_tool.rb', line 200

required :context_size, enum: -> { OpenAI::Beta::AgentTool::WebSearch::ContextSize }

#locationOpenAI::Beta::AgentTool::WebSearch::Location?

Approximate location used to localize search results, if provided.

Returns:

  • (OpenAI::Beta::AgentTool::WebSearch::Location, nil)


206
# File 'lib/openai/models/beta/agent_tool.rb', line 206

required :location, -> { OpenAI::Beta::AgentTool::WebSearch::Location }, nil?: true

#modeOpenAI::Models::Beta::AgentTool::WebSearch::mode

The source used for web search results.

Returns:

  • (OpenAI::Models::Beta::AgentTool::WebSearch::mode)


212
# File 'lib/openai/models/beta/agent_tool.rb', line 212

required :mode, enum: -> { OpenAI::Beta::AgentTool::WebSearch::Mode }

#type:web_search

The type of the object. Always web_search.

Returns:

  • (:web_search)


218
# File 'lib/openai/models/beta/agent_tool.rb', line 218

required :type, const: :web_search

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/agent_tool.rb', line 248

Instance Method Details

#to_hash{

Returns:

  • ({)


219
# File 'sig/openai/models/beta/agent_tool.rbs', line 219

def to_hash: -> {