Class: OpenAI::Models::Beta::AgentToolParam::WebSearch

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agent_tool_param.rb,
sig/openai/models/beta/agent_tool_param.rbs

Defined Under Namespace

Modules: ContextSize, Mode Classes: Location

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city: nil, country: nil, region: nil, timezone: nil) ⇒ Object

Parameters:

  • allowed_domains

    Domains the search may include.

  • context_size

    The amount of search context made available to the model. Defaults to medium.

  • location

    Approximate location used to localize search results.

  • mode

    The source used for web search results. Defaults to live.

  • type

    The type of the object. Always web_search.



# File 'lib/openai/models/beta/agent_tool_param.rb', line 266

Instance Attribute Details

#allowed_domains::Array[String]?

Domains the search may include.

Returns:

  • (::Array[String], nil)


240
# File 'lib/openai/models/beta/agent_tool_param.rb', line 240

optional :allowed_domains, OpenAI::Internal::Type::ArrayOf[String], nil?: true

#context_sizeOpenAI::Models::Beta::AgentToolParam::WebSearch::context_size?

The amount of search context made available to the model. Defaults to medium.

Returns:

  • (OpenAI::Models::Beta::AgentToolParam::WebSearch::context_size, nil)


246
247
248
249
250
251
252
# File 'lib/openai/models/beta/agent_tool_param.rb', line 246

optional(
  :context_size,
  enum: -> {
    OpenAI::Beta::AgentToolParam::WebSearch::ContextSize
  },
  nil?: true
)

#locationOpenAI::Beta::AgentToolParam::WebSearch::Location?

Approximate location used to localize search results.

Returns:

  • (OpenAI::Beta::AgentToolParam::WebSearch::Location, nil)


258
# File 'lib/openai/models/beta/agent_tool_param.rb', line 258

optional :location, -> { OpenAI::Beta::AgentToolParam::WebSearch::Location }, nil?: true

#modeOpenAI::Models::Beta::AgentToolParam::WebSearch::mode?

The source used for web search results. Defaults to live.

Returns:

  • (OpenAI::Models::Beta::AgentToolParam::WebSearch::mode, nil)


264
# File 'lib/openai/models/beta/agent_tool_param.rb', line 264

optional :mode, enum: -> { OpenAI::Beta::AgentToolParam::WebSearch::Mode }, nil?: true

#type:web_search

The type of the object. Always web_search.

Returns:

  • (:web_search)


234
# File 'lib/openai/models/beta/agent_tool_param.rb', line 234

required :type, const: :web_search

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/agent_tool_param.rb', line 294

Instance Method Details

#to_hash{

Returns:

  • ({)


255
# File 'sig/openai/models/beta/agent_tool_param.rbs', line 255

def to_hash: -> {