Class: OpenAI::Models::Beta::AgentUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/beta/agent_update_params.rb,
sig/openai/models/beta/agent_update_params.rbs

Overview

See Also:

  • OpenAI::Resources::Beta::Agents#update

Defined Under Namespace

Modules: ServiceTier

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_id:, instructions: nil, metadata: nil, model: nil, multi_agent: nil, name: nil, reasoning: nil, service_tier: nil, text: nil, tools: nil, request_options: {}) ⇒ Object

Parameters:



# File 'lib/openai/models/beta/agent_update_params.rb', line 77

Instance Attribute Details

#agent_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/openai/models/beta/agent_update_params.rb', line 14

required :agent_id, String

#instructionsString?

Additional instructions appended to the agent's default base instructions. Omit to leave unchanged.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


21
# File 'lib/openai/models/beta/agent_update_params.rb', line 21

optional :instructions, String, nil?: true

#metadataHash{Symbol=>String}?

Replaces all metadata. Omit to leave unchanged, or pass null or {} to clear it. Up to 16 string key-value pairs, with keys up to 64 and values up to 512 characters.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


29
# File 'lib/openai/models/beta/agent_update_params.rb', line 29

optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true

#modelString?

The model to use for the agent. The requested model name is preserved.

Parameters:

  • (String)

Returns:

  • (String, nil)


35
# File 'lib/openai/models/beta/agent_update_params.rb', line 35

optional :model, String

#multi_agentOpenAI::Models::Beta::MultiAgentConfigParam?

Explicit configuration for creating and coordinating subagents.

Parameters:

  • value (OpenAI::Beta::MultiAgentConfigParam, nil)

Returns:



41
# File 'lib/openai/models/beta/agent_update_params.rb', line 41

optional :multi_agent, -> { OpenAI::Beta::MultiAgentConfigParam }, nil?: true

#nameString?

A replacement name. Omit to leave unchanged, or pass null to clear it.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


47
# File 'lib/openai/models/beta/agent_update_params.rb', line 47

optional :name, String, nil?: true

#reasoningOpenAI::Models::Beta::AgentReasoningParam?

Reasoning configuration for the agent.

Parameters:

  • value (OpenAI::Beta::AgentReasoningParam, nil)

Returns:



53
# File 'lib/openai/models/beta/agent_update_params.rb', line 53

optional :reasoning, -> { OpenAI::Beta::AgentReasoningParam }, nil?: true

#service_tierSymbol, ...

The service tier used for model requests.

Parameters:

  • value (OpenAI::Models::Beta::AgentUpdateParams::service_tier, nil)

Returns:



59
# File 'lib/openai/models/beta/agent_update_params.rb', line 59

optional :service_tier, enum: -> { OpenAI::Beta::AgentUpdateParams::ServiceTier }, nil?: true

#textOpenAI::Models::Beta::AgentTextParam?

Configuration for text generated by the agent.

Parameters:

  • value (OpenAI::Beta::AgentTextParam, nil)

Returns:



65
# File 'lib/openai/models/beta/agent_update_params.rb', line 65

optional :text, -> { OpenAI::Beta::AgentTextParam }, nil?: true

#toolsArray<OpenAI::Models::Beta::PersistedAgentToolParam::Function, OpenAI::Models::Beta::PersistedAgentToolParam::ToolSearch, OpenAI::Models::Beta::PersistedAgentToolParam::ProgrammaticToolCalling, OpenAI::Models::Beta::PersistedAgentToolParam::Mcp, OpenAI::Models::Beta::PersistedAgentToolParam::WebSearch>?

Tools available to the agent.



71
72
73
74
75
# File 'lib/openai/models/beta/agent_update_params.rb', line 71

optional(
  :tools,
  -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::PersistedAgentToolParam] },
  nil?: true
)

Instance Method Details

#to_hash{

Returns:

  • ({)


59
# File 'sig/openai/models/beta/agent_update_params.rbs', line 59

def to_hash: -> {