Class: OpenAI::Models::Beta::AgentWaitForSubagentsCallItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::AgentWaitForSubagentsCallItem
- Defined in:
- lib/openai/models/beta/agent_wait_for_subagents_call_item.rb,
sig/openai/models/beta/agent_wait_for_subagents_call_item.rbs
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of the tool call item.
-
#recipient_agent_ids ⇒ Array<String>
The IDs of the agents to wait for.
-
#sender_agent_id ⇒ String
The ID of the agent waiting for results.
-
#status ⇒ Symbol, OpenAI::Models::Beta::AgentFunctionCallStatus
The status of the tool call.
-
#turn_id ⇒ String
The ID of the turn that contains this item.
-
#type ⇒ Symbol, :wait_for_subagents_call
The item type.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(id:, recipient_agent_ids:, sender_agent_id:, status:, turn_id:, type: :wait_for_subagents_call) ⇒ Object
constructor
A request to wait for one or more subagents.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, recipient_agent_ids:, sender_agent_id:, status:, turn_id:, type: :wait_for_subagents_call) ⇒ Object
A request to wait for one or more subagents.
|
|
# File 'lib/openai/models/beta/agent_wait_for_subagents_call_item.rb', line 43
|
Instance Attribute Details
#id ⇒ String
The ID of the tool call item.
11 |
# File 'lib/openai/models/beta/agent_wait_for_subagents_call_item.rb', line 11 required :id, String |
#recipient_agent_ids ⇒ Array<String>
The IDs of the agents to wait for.
17 |
# File 'lib/openai/models/beta/agent_wait_for_subagents_call_item.rb', line 17 required :recipient_agent_ids, OpenAI::Internal::Type::ArrayOf[String] |
#sender_agent_id ⇒ String
The ID of the agent waiting for results.
23 |
# File 'lib/openai/models/beta/agent_wait_for_subagents_call_item.rb', line 23 required :sender_agent_id, String |
#status ⇒ Symbol, OpenAI::Models::Beta::AgentFunctionCallStatus
The status of the tool call.
29 |
# File 'lib/openai/models/beta/agent_wait_for_subagents_call_item.rb', line 29 required :status, enum: -> { OpenAI::Beta::AgentFunctionCallStatus } |
#turn_id ⇒ String
The ID of the turn that contains this item.
35 |
# File 'lib/openai/models/beta/agent_wait_for_subagents_call_item.rb', line 35 required :turn_id, String |
#type ⇒ Symbol, :wait_for_subagents_call
The item type. Always wait_for_subagents_call.
41 |
# File 'lib/openai/models/beta/agent_wait_for_subagents_call_item.rb', line 41 required :type, const: :wait_for_subagents_call |
Instance Method Details
#to_hash ⇒ {
36 |
# File 'sig/openai/models/beta/agent_wait_for_subagents_call_item.rbs', line 36
def to_hash: -> {
|