Class: OpenAI::Models::Beta::Agents::Environments::FileListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/beta/agents/environments/file_list_params.rb,
sig/openai/models/beta/agents/environments/file_list_params.rbs

Overview

See Also:

  • OpenAI::Resources::Beta::Agents::Environments::Files#list

Defined Under Namespace

Modules: Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(environment_id:, limit: nil, order: nil, page: nil, path: nil, request_options: {}) ⇒ Object

Parameters:

  • environment_id (String)
  • limit (Integer, nil) (defaults to: nil)

    The maximum number of files to return, between 1 and 100.

  • order (Symbol, OpenAI::Models::Beta::Agents::Environments::FileListParams::Order) (defaults to: nil)

    Sort by case-sensitive path components. Defaults to descending.

  • page (String) (defaults to: nil)

    The opaque token from the previous page. Keep the same path, order, and limit.

  • path (String, nil) (defaults to: nil)

    Restrict the listing to this absolute workspace directory.

  • request_options (OpenAI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/openai/models/beta/agents/environments/file_list_params.rb', line 42

Instance Attribute Details

#environment_idString

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/openai/models/beta/agents/environments/file_list_params.rb', line 16

required :environment_id, String

#limitInteger?

The maximum number of files to return, between 1 and 100.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


22
# File 'lib/openai/models/beta/agents/environments/file_list_params.rb', line 22

optional :limit, Integer, nil?: true

#orderSymbol, ...

Sort by case-sensitive path components. Defaults to descending.



28
# File 'lib/openai/models/beta/agents/environments/file_list_params.rb', line 28

optional :order, enum: -> { OpenAI::Beta::Agents::Environments::FileListParams::Order }

#pageString?

The opaque token from the previous page. Keep the same path, order, and limit.

Parameters:

  • (String)

Returns:

  • (String, nil)


34
# File 'lib/openai/models/beta/agents/environments/file_list_params.rb', line 34

optional :page, String

#pathString?

Restrict the listing to this absolute workspace directory.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


40
# File 'lib/openai/models/beta/agents/environments/file_list_params.rb', line 40

optional :path, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


45
# File 'sig/openai/models/beta/agents/environments/file_list_params.rbs', line 45

def to_hash: -> {