Class: OpenAI::Models::Beta::Agents::Environments::TemplateUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/beta/agents/environments/template_update_params.rb,
sig/openai/models/beta/agents/environments/template_update_params.rbs

Overview

See Also:

  • OpenAI::Resources::Beta::Agents::Environments::Templates#update

Defined Under Namespace

Classes: Network, Packages

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Parameters:

  • capability_directories

    Directories that expose capabilities to the agent.

  • env

    Replacement confidential environment values.

  • files

    Replacement file configuration materialized for each new session.

  • name

    A replacement human-readable display name, or null to clear the name.

  • network

    Network access available after setup completes. Omit to preserve the current policy, or pass null to reset to disabled for GA requests or enabled for alpha/beta requests.

  • packages

    Packages installed before the runtime network policy applies.

  • plugins

    Replacement plugin configuration installed for each new session.

  • setup_commands

    Replacement confidential setup commands, never included in returned resources.

  • skills

    Replacement skill configuration installed for each new session.



76
# File 'sig/openai/models/beta/agents/environments/template_update_params.rbs', line 76

def initialize: (

Instance Attribute Details

#capability_directories::Array[String]?

Directories that expose capabilities to the agent.

Returns:

  • (::Array[String], nil)


22
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 22

optional :capability_directories, OpenAI::Internal::Type::ArrayOf[String], nil?: true

#env::Hash[Symbol, String]?

Replacement confidential environment values.

Returns:

  • (::Hash[Symbol, String], nil)


28
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 28

optional :env, OpenAI::Internal::Type::HashOf[String], nil?: true

#environment_template_idString

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 16

required :environment_template_id, String

#files::Array[OpenAI::Models::Beta::hosted_environment_file_param]?

Replacement file configuration materialized for each new session.

Returns:

  • (::Array[OpenAI::Models::Beta::hosted_environment_file_param], nil)


34
35
36
37
38
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 34

optional(
  :files,
  -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::HostedEnvironmentFileParam] },
  nil?: true
)

#nameString?

A replacement human-readable display name, or null to clear the name.

Returns:

  • (String, nil)


44
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 44

optional :name, String, nil?: true

#networkOpenAI::Beta::Agents::Environments::TemplateUpdateParams::Network?

Network access available after setup completes. Omit to preserve the current policy, or pass null to reset to disabled for GA requests or enabled for alpha/beta requests.

Returns:

  • (OpenAI::Beta::Agents::Environments::TemplateUpdateParams::Network, nil)


52
53
54
55
56
57
58
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 52

optional(
  :network,
  -> {
    OpenAI::Beta::Agents::Environments::TemplateUpdateParams::Network
  },
  nil?: true
)

#packagesOpenAI::Beta::Agents::Environments::TemplateUpdateParams::Packages?

Packages installed before the runtime network policy applies.

Returns:

  • (OpenAI::Beta::Agents::Environments::TemplateUpdateParams::Packages, nil)


64
65
66
67
68
69
70
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 64

optional(
  :packages,
  -> {
    OpenAI::Beta::Agents::Environments::TemplateUpdateParams::Packages
  },
  nil?: true
)

#plugins::Array[OpenAI::Beta::HostedPluginParam]?

Replacement plugin configuration installed for each new session.

Returns:

  • (::Array[OpenAI::Beta::HostedPluginParam], nil)


76
77
78
79
80
81
82
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 76

optional(
  :plugins,
  -> {
    OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::HostedPluginParam]
  },
  nil?: true
)

#setup_commands::Array[OpenAI::Beta::SetupCommandParam]?

Replacement confidential setup commands, never included in returned resources.

Returns:

  • (::Array[OpenAI::Beta::SetupCommandParam], nil)


88
89
90
91
92
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 88

optional(
  :setup_commands,
  -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::SetupCommandParam] },
  nil?: true
)

#skills::Array[OpenAI::Models::Beta::hosted_skill_param]?

Replacement skill configuration installed for each new session.

Returns:

  • (::Array[OpenAI::Models::Beta::hosted_skill_param], nil)


98
99
100
101
102
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 98

optional(
  :skills,
  -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::HostedSkillParam] },
  nil?: true
)

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 177

Instance Method Details

#to_hash{

Returns:

  • ({)


90
# File 'sig/openai/models/beta/agents/environments/template_update_params.rbs', line 90

def to_hash: -> {