Class: OpenAI::Models::Beta::Agents::Environments::TemplateUpdateParams::Desktop

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agents/environments/template_update_params.rb,
sig/openai/models/beta/agents/environments/template_update_params.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(environment_template_id:, capability_directories: nil, desktop: nil, env: nil, files: nil, name: nil, network: nil, packages: nil, plugins: nil, setup_commands: nil, skills: nil, request_options: {}) ⇒ Desktop

Returns a new instance of Desktop.

Parameters:

  • enabled —

    Whether to provision the desktop and its browser proxy.

  • enabled: (Boolean)


153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 153

class Desktop < OpenAI::Internal::Type::BaseModel
  # @!attribute enabled
  #   Whether to provision the desktop and its browser proxy.
  #
  #   @return [Boolean]
  required :enabled, OpenAI::Internal::Type::Boolean

  # @!method initialize(enabled:)
  #   Replacement desktop configuration, or null to disable the desktop.
  #
  #   @param enabled [Boolean]
  #     Whether to provision the desktop and its browser proxy.
end

Instance Attribute Details

#enabled ⇒ Boolean

Whether to provision the desktop and its browser proxy.

Returns:



158
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 158

required :enabled, OpenAI::Internal::Type::Boolean

Instance Method Details

#to_hash ⇒ { enabled: bool }

Returns:

  • ({ enabled: bool })


122
# File 'sig/openai/models/beta/agents/environments/template_update_params.rbs', line 122

def to_hash: -> { enabled: bool }