Class: OpenAI::Models::Beta::Agents::SessionUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/beta/agents/session_update_params.rb,
sig/openai/models/beta/agents/session_update_params.rbs

Overview

See Also:

  • OpenAI::Resources::Beta::Agents::Sessions#update

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(session_id:, metadata: nil, request_options: {}) ⇒ Object

Parameters:

  • session_id (String)
  • metadata (Hash{Symbol=>String}, nil) (defaults to: nil)

    Replaces all metadata. Omit to leave unchanged, or pass null or {} to clear it. Up to 16 string key-value pairs, with keys up to 64 and values up to 512 characters.

  • request_options (OpenAI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/openai/models/beta/agents/session_update_params.rb', line 25

Instance Attribute Details

#metadataHash{Symbol=>String}?

Replaces all metadata. Omit to leave unchanged, or pass null or {} to clear it. Up to 16 string key-value pairs, with keys up to 64 and values up to 512 characters.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


23
# File 'lib/openai/models/beta/agents/session_update_params.rb', line 23

optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true

#session_idString

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/openai/models/beta/agents/session_update_params.rb', line 15

required :session_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


26
# File 'sig/openai/models/beta/agents/session_update_params.rbs', line 26

def to_hash: -> {