Class: OpenAI::Models::Beta::Agents::Sessions::ArtifactListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/beta/agents/sessions/artifact_list_params.rb,
sig/openai/models/beta/agents/sessions/artifact_list_params.rbs

Overview

See Also:

  • OpenAI::Resources::Beta::Agents::Sessions::Artifacts#list

Defined Under Namespace

Modules: Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(session_id:, after: nil, environment_id: nil, limit: nil, order: nil, request_options: {}) ⇒ Object

Parameters:

  • session_id (String)
  • after (String, nil) (defaults to: nil)

    Return artifacts after this immutable artifact ID.

  • environment_id (String, nil) (defaults to: nil)

    Restrict the listing to artifacts produced by this environment.

  • limit (Integer, nil) (defaults to: nil)

    The maximum number of artifacts to return, between 1 and 100.

  • order (Symbol, OpenAI::Models::Beta::Agents::Sessions::ArtifactListParams::Order) (defaults to: nil)

    Sort by creation time and ID. Defaults to descending.

  • request_options (OpenAI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/openai/models/beta/agents/sessions/artifact_list_params.rb', line 42

Instance Attribute Details

#afterString?

Return artifacts after this immutable artifact ID.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


22
# File 'lib/openai/models/beta/agents/sessions/artifact_list_params.rb', line 22

optional :after, String, nil?: true

#environment_idString?

Restrict the listing to artifacts produced by this environment.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


28
# File 'lib/openai/models/beta/agents/sessions/artifact_list_params.rb', line 28

optional :environment_id, String, nil?: true

#limitInteger?

The maximum number of artifacts to return, between 1 and 100.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


34
# File 'lib/openai/models/beta/agents/sessions/artifact_list_params.rb', line 34

optional :limit, Integer, nil?: true

#orderSymbol, ...

Sort by creation time and ID. Defaults to descending.



40
# File 'lib/openai/models/beta/agents/sessions/artifact_list_params.rb', line 40

optional :order, enum: -> { OpenAI::Beta::Agents::Sessions::ArtifactListParams::Order }

#session_idString

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/openai/models/beta/agents/sessions/artifact_list_params.rb', line 16

required :session_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


43
# File 'sig/openai/models/beta/agents/sessions/artifact_list_params.rbs', line 43

def to_hash: -> {