Class: OpenAI::Models::Beta::Agents::Sessions::SessionArtifact

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agents/sessions/session_artifact.rb,
sig/openai/models/beta/agents/sessions/session_artifact.rbs

Overview

See Also:

  • OpenAI::Resources::Beta::Agents::Sessions::Artifacts#retrieve

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



37
# File 'sig/openai/models/beta/agents/sessions/session_artifact.rbs', line 37

def initialize: (

Instance Attribute Details

#created_atInteger

The Unix timestamp, in seconds, when the artifact was published.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


20
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 20

required :created_at, Integer

#environment_idString

The ID of the environment that produced the artifact.

Parameters:

  • value (String)

Returns:

  • (String)


26
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 26

required :environment_id, String

#idString

The immutable artifact ID.

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 14

required :id, String

#objectSymbol, :"agent.session.artifact"

The object type. Always agent.session.artifact.

Parameters:

  • value (:"agent.session.artifact")

Returns:

  • (Symbol, :"agent.session.artifact")


32
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 32

required :object, const: :"agent.session.artifact"

#pathString

The original absolute file path in the execution environment.

Parameters:

  • value (String)

Returns:

  • (String)


38
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 38

required :path, String

#session_idString

The ID of the session that owns the artifact.

Parameters:

  • value (String)

Returns:

  • (String)


44
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 44

required :session_id, String

#size_bytesInteger

The immutable artifact size in bytes.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


50
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 50

required :size_bytes, Integer

#turn_idString

The ID of the completed turn that published the artifact.

Parameters:

  • value (String)

Returns:

  • (String)


56
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 56

required :turn_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


48
# File 'sig/openai/models/beta/agents/sessions/session_artifact.rbs', line 48

def to_hash: -> {