Class: OpenAI::Models::Beta::Agents::Sessions::Subagents::TurnListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Agents::Sessions::Subagents::TurnListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/beta/agents/sessions/subagents/turn_list_params.rb,
sig/openai/models/beta/agents/sessions/subagents/turn_list_params.rbs
Overview
Defined Under Namespace
Modules: Order
Instance Attribute Summary collapse
-
#after ⇒ String?
Return resources after this resource ID in the selected order.
-
#limit ⇒ Integer?
The maximum number of resources to return, between 1 and 100.
-
#order ⇒ Symbol, ...
The order in which resources are returned.
- #session_id ⇒ String
- #subagent_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(session_id:, subagent_id:, after: nil, limit: nil, order: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(session_id:, subagent_id:, after: nil, limit: nil, order: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/openai/models/beta/agents/sessions/subagents/turn_list_params.rb', line 42
|
Instance Attribute Details
#after ⇒ String?
Return resources after this resource ID in the selected order.
28 |
# File 'lib/openai/models/beta/agents/sessions/subagents/turn_list_params.rb', line 28 optional :after, String |
#limit ⇒ Integer?
The maximum number of resources to return, between 1 and 100. Defaults to 20.
34 |
# File 'lib/openai/models/beta/agents/sessions/subagents/turn_list_params.rb', line 34 optional :limit, Integer |
#order ⇒ Symbol, ...
The order in which resources are returned. Defaults to desc.
40 |
# File 'lib/openai/models/beta/agents/sessions/subagents/turn_list_params.rb', line 40 optional :order, enum: -> { OpenAI::Beta::Agents::Sessions::Subagents::TurnListParams::Order } |
#session_id ⇒ String
17 |
# File 'lib/openai/models/beta/agents/sessions/subagents/turn_list_params.rb', line 17 required :session_id, String |
#subagent_id ⇒ String
22 |
# File 'lib/openai/models/beta/agents/sessions/subagents/turn_list_params.rb', line 22 required :subagent_id, String |
Instance Method Details
#to_hash ⇒ {
48 |
# File 'sig/openai/models/beta/agents/sessions/subagents/turn_list_params.rbs', line 48
def to_hash: -> {
|