Class: OpenAI::Models::Beta::Agents::Vault

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agents/vault.rb,
sig/openai/models/beta/agents/vault.rbs

Overview

See Also:

  • OpenAI::Resources::Beta::Agents::Vaults#create

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, metadata:, name:, object: :vault) ⇒ Object

A collection of credentials that agent tools can use to authenticate to MCP servers.

Parameters:

  • id (String)

    The ID of the vault.

  • created_at (Integer)

    The Unix timestamp, in seconds, when the vault was created.

  • metadata (Hash{Symbol=>String})

    Key-value pairs associated with the vault, such as an application or team identifier.

  • name (String, nil)

    The human-readable name of the vault, if set.

  • object (Symbol, :vault) (defaults to: :vault)

    The object type. Always vault.



# File 'lib/openai/models/beta/agents/vault.rb', line 40

Instance Attribute Details

#created_atInteger

The Unix timestamp, in seconds, when the vault was created.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


19
# File 'lib/openai/models/beta/agents/vault.rb', line 19

required :created_at, Integer

#idString

The ID of the vault.

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/openai/models/beta/agents/vault.rb', line 13

required :id, String

#metadataHash{Symbol=>String}

Key-value pairs associated with the vault, such as an application or team identifier.

Parameters:

  • value (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String})


26
# File 'lib/openai/models/beta/agents/vault.rb', line 26

required :metadata, OpenAI::Internal::Type::HashOf[String]

#nameString?

The human-readable name of the vault, if set.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


32
# File 'lib/openai/models/beta/agents/vault.rb', line 32

required :name, String, nil?: true

#objectSymbol, :vault

The object type. Always vault.

Parameters:

  • value (:vault)

Returns:

  • (Symbol, :vault)


38
# File 'lib/openai/models/beta/agents/vault.rb', line 38

required :object, const: :vault

Instance Method Details

#to_hash{

Returns:

  • ({)


33
# File 'sig/openai/models/beta/agents/vault.rbs', line 33

def to_hash: -> {