Class: OpenAI::Models::Beta::Agents::VaultCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Agents::VaultCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/beta/agents/vault_create_params.rb,
sig/openai/models/beta/agents/vault_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#metadata ⇒ Hash{Symbol=>String}?
Key-value pairs to associate with the vault, such as an application or team identifier.
-
#name ⇒ String?
The name is trimmed before storage.
Attributes included from Internal::Type::RequestParameters
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(metadata: nil, name: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/openai/models/beta/agents/vault_create_params.rb', line 26
|
Instance Attribute Details
#metadata ⇒ Hash{Symbol=>String}?
Key-value pairs to associate with the vault, such as an application or team identifier.
17 |
# File 'lib/openai/models/beta/agents/vault_create_params.rb', line 17 optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true |
#name ⇒ String?
The name is trimmed before storage. It must contain 1 to 256 UTF-8 bytes after trimming.
24 |
# File 'lib/openai/models/beta/agents/vault_create_params.rb', line 24 optional :name, String |
Instance Method Details
#to_hash ⇒ {
28 |
# File 'sig/openai/models/beta/agents/vault_create_params.rbs', line 28
def to_hash: -> {
|