Class: OpenAI::Models::Beta::Agents::Vaults::Credential

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agents/vaults/credential.rb,
sig/openai/models/beta/agents/vaults/credential.rbs

Overview

See Also:

  • OpenAI::Resources::Beta::Agents::Vaults::Credentials#create

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, auth:, created_at:, name:, updated_at:, vault_id:, object: :"vault.credential") ⇒ Object

Parameters:

  • id

    The ID of the credential.

  • auth

    The authentication method and non-secret configuration of the credential.

  • created_at

    The Unix timestamp, in seconds, when the credential was created.

  • name

    The human-readable name of the credential.

  • updated_at

    The Unix timestamp, in seconds, when the credential was last updated.

  • vault_id

    The ID of the vault containing this credential.

  • object (defaults to: :"vault.credential")

    The object type. Always vault.credential.



# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 52

Instance Attribute Details

#authOpenAI::Models::Beta::Agents::Vaults::credential_auth

The authentication method and non-secret configuration of the credential.

Returns:

  • (OpenAI::Models::Beta::Agents::Vaults::credential_auth)


20
# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 20

required :auth, union: -> { OpenAI::Beta::Agents::Vaults::CredentialAuth }

#created_atInteger

The Unix timestamp, in seconds, when the credential was created.

Returns:

  • (Integer)


26
# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 26

required :created_at, Integer

#idString

The ID of the credential.

Returns:

  • (String)


14
# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 14

required :id, String

#nameString

The human-readable name of the credential.

Returns:

  • (String)


32
# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 32

required :name, String

#object:"vault.credential"

The object type. Always vault.credential.

Returns:

  • (:"vault.credential")


38
# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 38

required :object, const: :"vault.credential"

#updated_atInteger

The Unix timestamp, in seconds, when the credential was last updated.

Returns:

  • (Integer)


44
# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 44

required :updated_at, Integer

#vault_idString

The ID of the vault containing this credential.

Returns:

  • (String)


50
# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 50

required :vault_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


63
# File 'sig/openai/models/beta/agents/vaults/credential.rbs', line 63

def to_hash: -> {