Class: OpenAI::Models::Beta::Agents::Vaults::CredentialAuth::EnvironmentVariable

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agents/vaults/credential_auth.rb,
sig/openai/models/beta/agents/vaults/credential_auth.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(networking:, secret_name:, type: :environment_variable) ⇒ Object

Parameters:

  • networking

    The destinations where the proxy can substitute the secret, subject to the environment network policy.

  • secret_name

    The environment variable name that receives the placeholder in the sandbox.

  • type (defaults to: :environment_variable)

    The type of the object. Always environment_variable.



# File 'lib/openai/models/beta/agents/vaults/credential_auth.rb', line 167

Instance Attribute Details

#networkingOpenAI::Models::Beta::Agents::Vaults::credential_networking

The destinations where the proxy can substitute the secret, subject to the environment network policy.

Returns:

  • (OpenAI::Models::Beta::Agents::Vaults::credential_networking)


153
# File 'lib/openai/models/beta/agents/vaults/credential_auth.rb', line 153

required :networking, union: -> { OpenAI::Beta::Agents::Vaults::CredentialNetworking }

#secret_nameString

The environment variable name that receives the placeholder in the sandbox.

Returns:

  • (String)


159
# File 'lib/openai/models/beta/agents/vaults/credential_auth.rb', line 159

required :secret_name, String

#type:environment_variable

The type of the object. Always environment_variable.

Returns:

  • (:environment_variable)


165
# File 'lib/openai/models/beta/agents/vaults/credential_auth.rb', line 165

required :type, const: :environment_variable

Instance Method Details

#to_hash{

Returns:

  • ({)


165
# File 'sig/openai/models/beta/agents/vaults/credential_auth.rbs', line 165

def to_hash: -> {