Class: OpenAI::Models::Beta::Agents::Vaults::CredentialAuth::McpOauth::Refresh
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Agents::Vaults::CredentialAuth::McpOauth::Refresh
- Defined in:
- lib/openai/models/beta/agents/vaults/credential_auth.rb,
sig/openai/models/beta/agents/vaults/credential_auth.rbs
Overview
Instance Attribute Summary collapse
-
#client_id ⇒ String
The OAuth client ID used when requesting a new access token.
-
#resource ⇒ String?
The resource URI sent to the OAuth token endpoint during refresh, if configured.
-
#scope ⇒ String?
Space-separated OAuth scopes requested during refresh, if configured.
-
#token_endpoint ⇒ String
The HTTPS OAuth token endpoint used for refresh.
-
#token_endpoint_auth ⇒ OpenAI::Models::Beta::Agents::Vaults::McpOauthTokenEndpointAuth::None, ...
How the OAuth client authenticates to the token endpoint, excluding its client secret.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
64 |
# File 'sig/openai/models/beta/agents/vaults/credential_auth.rbs', line 64
def initialize: (
|
Instance Attribute Details
#client_id ⇒ String
The OAuth client ID used when requesting a new access token.
76 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth.rb', line 76 required :client_id, String |
#resource ⇒ String?
The resource URI sent to the OAuth token endpoint during refresh, if configured.
82 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth.rb', line 82 required :resource, String, nil?: true |
#scope ⇒ String?
Space-separated OAuth scopes requested during refresh, if configured.
88 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth.rb', line 88 required :scope, String, nil?: true |
#token_endpoint ⇒ String
The HTTPS OAuth token endpoint used for refresh.
94 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth.rb', line 94 required :token_endpoint, String |
#token_endpoint_auth ⇒ OpenAI::Models::Beta::Agents::Vaults::McpOauthTokenEndpointAuth::None, ...
How the OAuth client authenticates to the token endpoint, excluding its client secret.
101 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth.rb', line 101 required :token_endpoint_auth, union: -> { OpenAI::Beta::Agents::Vaults::McpOauthTokenEndpointAuth } |
Instance Method Details
#to_hash ⇒ {
72 |
# File 'sig/openai/models/beta/agents/vaults/credential_auth.rbs', line 72
def to_hash: -> {
|