Class: OpenAI::Models::Beta::Agents::Vaults::CredentialAuthCreateParam::EnvironmentVariable

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agents/vaults/credential_auth_create_param.rb,
sig/openai/models/beta/agents/vaults/credential_auth_create_param.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(networking:, secret_name:, secret_value:, type: :environment_variable) ⇒ Object

Parameters:

  • networking

    The destinations where the proxy can substitute this secret. The environment network policy must also allow them.

  • secret_name

    The environment variable name that receives the placeholder, such as SERVICE_API_KEY. Use ASCII letters, digits, and underscores, starting with a letter or underscore. Names starting with CODEX_ and managed proxy or certificate variable names are reserved.

  • secret_value

    The write-only secret to store. Never returned in credential resources or supplied directly to sandbox code. Must be nonempty and must not contain carriage returns, newlines, or NUL bytes.

  • type (defaults to: :environment_variable)

    The type of the object. Always environment_variable.



# File 'lib/openai/models/beta/agents/vaults/credential_auth_create_param.rb', line 214

Instance Attribute Details

#networkingOpenAI::Models::Beta::Agents::Vaults::credential_networking_param

The destinations where the proxy can substitute this secret. The environment network policy must also allow them.

Returns:

  • (OpenAI::Models::Beta::Agents::Vaults::credential_networking_param)


189
# File 'lib/openai/models/beta/agents/vaults/credential_auth_create_param.rb', line 189

required :networking, union: -> { OpenAI::Beta::Agents::Vaults::CredentialNetworkingParam }

#secret_nameString

The environment variable name that receives the placeholder, such as SERVICE_API_KEY. Use ASCII letters, digits, and underscores, starting with a letter or underscore. Names starting with CODEX_ and managed proxy or certificate variable names are reserved.

Returns:

  • (String)


198
# File 'lib/openai/models/beta/agents/vaults/credential_auth_create_param.rb', line 198

required :secret_name, String

#secret_valueString

The write-only secret to store. Never returned in credential resources or supplied directly to sandbox code. Must be nonempty and must not contain carriage returns, newlines, or NUL bytes.

Returns:

  • (String)


206
# File 'lib/openai/models/beta/agents/vaults/credential_auth_create_param.rb', line 206

required :secret_value, String

#type:environment_variable

The type of the object. Always environment_variable.

Returns:

  • (:environment_variable)


212
# File 'lib/openai/models/beta/agents/vaults/credential_auth_create_param.rb', line 212

required :type, const: :environment_variable

Instance Method Details

#to_hash{

Returns:

  • ({)


214
# File 'sig/openai/models/beta/agents/vaults/credential_auth_create_param.rbs', line 214

def to_hash: -> {