Class: OpenAI::Models::Beta::Agents::Vaults::CredentialAuthCreateParam::McpOauth::Refresh
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Agents::Vaults::CredentialAuthCreateParam::McpOauth::Refresh
- Defined in:
- lib/openai/models/beta/agents/vaults/credential_auth_create_param.rb,
sig/openai/models/beta/agents/vaults/credential_auth_create_param.rbs
Overview
Instance Attribute Summary collapse
-
#client_id ⇒ String
The OAuth client ID used when requesting a new access token.
-
#refresh_token ⇒ String
The refresh token to store.
-
#resource ⇒ String?
The resource URI to send to the OAuth token endpoint during refresh, if required.
-
#scope ⇒ String?
Space-separated OAuth scopes to request during refresh, if required.
-
#token_endpoint ⇒ String
The HTTPS OAuth token endpoint used to exchange the refresh token for a new access token.
-
#token_endpoint_auth ⇒ OpenAI::Models::Beta::Agents::Vaults::McpOauthTokenEndpointAuthCreateParam::None, ...
How the OAuth client authenticates to the token endpoint.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
72 |
# File 'sig/openai/models/beta/agents/vaults/credential_auth_create_param.rbs', line 72
def initialize: (
|
Instance Attribute Details
#client_id ⇒ String
The OAuth client ID used when requesting a new access token.
79 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth_create_param.rb', line 79 required :client_id, String |
#refresh_token ⇒ String
The refresh token to store. This secret is never returned in credential resources.
86 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth_create_param.rb', line 86 required :refresh_token, String |
#resource ⇒ String?
The resource URI to send to the OAuth token endpoint during refresh, if required.
109 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth_create_param.rb', line 109 optional :resource, String, nil?: true |
#scope ⇒ String?
Space-separated OAuth scopes to request during refresh, if required.
115 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth_create_param.rb', line 115 optional :scope, String, nil?: true |
#token_endpoint ⇒ String
The HTTPS OAuth token endpoint used to exchange the refresh token for a new access token.
93 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth_create_param.rb', line 93 required :token_endpoint, String |
#token_endpoint_auth ⇒ OpenAI::Models::Beta::Agents::Vaults::McpOauthTokenEndpointAuthCreateParam::None, ...
How the OAuth client authenticates to the token endpoint.
99 100 101 102 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth_create_param.rb', line 99 required( :token_endpoint_auth, union: -> { OpenAI::Beta::Agents::Vaults::McpOauthTokenEndpointAuthCreateParam } ) |
Instance Method Details
#to_hash ⇒ {
81 |
# File 'sig/openai/models/beta/agents/vaults/credential_auth_create_param.rbs', line 81
def to_hash: -> {
|