Class: OpenAI::Models::Beta::Agents::Vaults::CredentialAuthRotateParam::McpOauth

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb,
sig/openai/models/beta/agents/vaults/credential_auth_rotate_param.rbs

Defined Under Namespace

Classes: Refresh

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(access_token: nil, expires_at: nil, refresh: nil, type: :mcp_oauth) ⇒ Object

Parameters:

  • access_token (defaults to: nil)

    A write-only replacement OAuth access token.

  • expires_at (defaults to: nil)

    The replacement expiry as an RFC 3339 timestamp, or null to clear it. Omitting this field preserves the expiry unless a new access token is supplied, in which case the expiry is cleared.

  • refresh (defaults to: nil)

    Optional write-only refresh-token and client-secret updates.

  • type (defaults to: :mcp_oauth)

    The type of the object. Always mcp_oauth.



# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 58

Instance Attribute Details

#access_tokenString?

A write-only replacement OAuth access token.

Returns:

  • (String, nil)


38
# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 38

optional :access_token, String, nil?: true

#expires_atString?

The replacement expiry as an RFC 3339 timestamp, or null to clear it. Omitting this field preserves the expiry unless a new access token is supplied, in which case the expiry is cleared.

Returns:

  • (String, nil)


46
# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 46

optional :expires_at, String, nil?: true

#refreshOpenAI::Beta::Agents::Vaults::CredentialAuthRotateParam::McpOauth::Refresh?

Optional write-only refresh-token and client-secret updates.

Returns:

  • (OpenAI::Beta::Agents::Vaults::CredentialAuthRotateParam::McpOauth::Refresh, nil)


52
53
54
55
56
# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 52

optional(
  :refresh,
  -> { OpenAI::Beta::Agents::Vaults::CredentialAuthRotateParam::McpOauth::Refresh },
  nil?: true
)

#type:mcp_oauth

The type of the object. Always mcp_oauth.

Returns:

  • (:mcp_oauth)


32
# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 32

required :type, const: :mcp_oauth

Instance Method Details

#to_hash{

Returns:

  • ({)


54
# File 'sig/openai/models/beta/agents/vaults/credential_auth_rotate_param.rbs', line 54

def to_hash: -> {