Class: OpenAI::Models::Beta::Agents::Vaults::CredentialAuthRotateParam::McpOauth::Refresh
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Agents::Vaults::CredentialAuthRotateParam::McpOauth::Refresh
- Defined in:
- lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb,
sig/openai/models/beta/agents/vaults/credential_auth_rotate_param.rbs
Overview
Instance Attribute Summary collapse
-
#refresh_token ⇒ String?
The replacement refresh token.
-
#scope ⇒ String?
Replacement space-separated OAuth scopes for refresh requests.
-
#token_endpoint_auth ⇒ OpenAI::Models::Beta::Agents::Vaults::McpOauthTokenEndpointAuthRotateParam::ClientSecretBasic, ...
Client-secret updates that preserve the credential's OAuth authentication method.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
58 |
# File 'sig/openai/models/beta/agents/vaults/credential_auth_rotate_param.rbs', line 58
def initialize: (
|
Instance Attribute Details
#refresh_token ⇒ String?
The replacement refresh token. Omit or pass null to keep the stored token.
This secret is never returned in resources.
76 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 76 optional :refresh_token, String, nil?: true |
#scope ⇒ String?
Replacement space-separated OAuth scopes for refresh requests. Omit to keep the
scopes, or pass null to stop sending a scope parameter.
83 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 83 optional :scope, String, nil?: true |
#token_endpoint_auth ⇒ OpenAI::Models::Beta::Agents::Vaults::McpOauthTokenEndpointAuthRotateParam::ClientSecretBasic, ...
Client-secret updates that preserve the credential's OAuth authentication method.
90 91 92 93 94 95 96 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 90 optional( :token_endpoint_auth, union: -> { OpenAI::Beta::Agents::Vaults::McpOauthTokenEndpointAuthRotateParam }, nil?: true ) |
Instance Method Details
#to_hash ⇒ {
64 |
# File 'sig/openai/models/beta/agents/vaults/credential_auth_rotate_param.rbs', line 64
def to_hash: -> {
|