Class: OpenAI::Models::Beta::Agents::Vaults::CredentialCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Agents::Vaults::CredentialCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/beta/agents/vaults/credential_create_params.rb,
sig/openai/models/beta/agents/vaults/credential_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#auth ⇒ OpenAI::Models::Beta::Agents::Vaults::CredentialAuthCreateParam::McpOauth, OpenAI::Models::Beta::Agents::Vaults::CredentialAuthCreateParam::StaticBearer
The authentication method and secret values to store for the MCP server.
-
#name ⇒ String
The name is trimmed before storage.
- #vault_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(vault_id:, auth:, name:, request_options: {}) ⇒ Object
|
|
# File 'lib/openai/models/beta/agents/vaults/credential_create_params.rb', line 31
|
Instance Attribute Details
#auth ⇒ OpenAI::Models::Beta::Agents::Vaults::CredentialAuthCreateParam::McpOauth, OpenAI::Models::Beta::Agents::Vaults::CredentialAuthCreateParam::StaticBearer
The authentication method and secret values to store for the MCP server.
22 |
# File 'lib/openai/models/beta/agents/vaults/credential_create_params.rb', line 22 required :auth, union: -> { OpenAI::Beta::Agents::Vaults::CredentialAuthCreateParam } |
#name ⇒ String
The name is trimmed before storage. It must contain 1 to 256 UTF-8 bytes after trimming.
29 |
# File 'lib/openai/models/beta/agents/vaults/credential_create_params.rb', line 29 required :name, String |
#vault_id ⇒ String
16 |
# File 'lib/openai/models/beta/agents/vaults/credential_create_params.rb', line 16 required :vault_id, String |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/openai/models/beta/agents/vaults/credential_create_params.rbs', line 31
def to_hash: -> {
|