Class: OpenAI::Models::Beta::Agents::Vaults::CredentialListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Agents::Vaults::CredentialListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/beta/agents/vaults/credential_list_params.rb,
sig/openai/models/beta/agents/vaults/credential_list_params.rbs
Overview
Defined Under Namespace
Modules: Order
Instance Attribute Summary collapse
-
#after ⇒ String?
Return resources after this resource ID in the selected order.
-
#limit ⇒ Integer?
The maximum number of resources to return.
-
#order ⇒ Symbol, ...
Sort order by the
created_attimestamp. -
#status ⇒ Symbol, ...
Filter by one status or a list, such as
status=activeorstatus[]=active&status[]=archived. - #vault_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(vault_id:, after: nil, limit: nil, order: nil, status: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(vault_id:, after: nil, limit: nil, order: nil, status: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/openai/models/beta/agents/vaults/credential_list_params.rb', line 45
|
Instance Attribute Details
#after ⇒ String?
Return resources after this resource ID in the selected order.
22 |
# File 'lib/openai/models/beta/agents/vaults/credential_list_params.rb', line 22 optional :after, String |
#limit ⇒ Integer?
The maximum number of resources to return. Defaults to 20. Values are clamped between 1 and 100.
29 |
# File 'lib/openai/models/beta/agents/vaults/credential_list_params.rb', line 29 optional :limit, Integer, nil?: true |
#order ⇒ Symbol, ...
Sort order by the created_at timestamp. Use asc for ascending order or
desc for descending order. Defaults to desc.
36 |
# File 'lib/openai/models/beta/agents/vaults/credential_list_params.rb', line 36 optional :order, enum: -> { OpenAI::Beta::Agents::Vaults::CredentialListParams::Order } |
#status ⇒ Symbol, ...
Filter by one status or a list, such as status=active or
status[]=active&status[]=archived. Both statuses are included by default.
43 |
# File 'lib/openai/models/beta/agents/vaults/credential_list_params.rb', line 43 optional :status, union: -> { OpenAI::Beta::Agents::VaultStatusFilter } |
#vault_id ⇒ String
16 |
# File 'lib/openai/models/beta/agents/vaults/credential_list_params.rb', line 16 required :vault_id, String |
Instance Method Details
#to_hash ⇒ {
49 |
# File 'sig/openai/models/beta/agents/vaults/credential_list_params.rbs', line 49
def to_hash: -> {
|