Module: OpenAI::Models::Beta::Agents::Vaults::CredentialNetworking

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/beta/agents/vaults/credential_networking.rb,
sig/openai/models/beta/agents/vaults/credential_networking.rbs

Overview

Destination permissions for an environment-variable credential. These do not grant network access to the environment.

Defined Under Namespace

Classes: Limited, Unrestricted

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.variantsArray(OpenAI::Models::Beta::Agents::Vaults::CredentialNetworking::Unrestricted, OpenAI::Models::Beta::Agents::Vaults::CredentialNetworking::Limited)



# File 'lib/openai/models/beta/agents/vaults/credential_networking.rb', line 65

Instance Method Details

#initialize(type: :unrestricted) ⇒ Object

Allows substitution for destinations permitted by the environment network policy. Requires environment.network.access to be restricted, with explicit allowed_domains.

Parameters:

  • type (Symbol, :unrestricted) (defaults to: :unrestricted)

    The type of the object. Always unrestricted.



# File 'lib/openai/models/beta/agents/vaults/credential_networking.rb', line 28

#self?.variants::Array[OpenAI::Models::Beta::Agents::Vaults::credential_networking]

Returns:

  • (::Array[OpenAI::Models::Beta::Agents::Vaults::credential_networking])


54
# File 'sig/openai/models/beta/agents/vaults/credential_networking.rbs', line 54

def self?.variants: -> ::Array[OpenAI::Models::Beta::Agents::Vaults::credential_networking]