Class: OpenAI::Models::Beta::Agents::Vaults::McpOauthTokenEndpointAuthRotateParam::ClientSecretPost

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/beta/agents/vaults/mcp_oauth_token_endpoint_auth_rotate_param.rb,
sig/openai/models/beta/agents/vaults/mcp_oauth_token_endpoint_auth_rotate_param.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(client_secret: nil, type: :client_secret_post) ⇒ Object

Updates credentials sent in the token request body.

Parameters:

  • client_secret (String, nil) (defaults to: nil)

    The replacement OAuth client secret. Omit or pass null to keep the stored secret. This secret is never returned in resources.

  • type (Symbol, :client_secret_post) (defaults to: :client_secret_post)

    The type of the object. Always client_secret_post.



# File 'lib/openai/models/beta/agents/vaults/mcp_oauth_token_endpoint_auth_rotate_param.rb', line 66

Instance Attribute Details

#client_secretString?

The replacement OAuth client secret. Omit or pass null to keep the stored secret. This secret is never returned in resources.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


64
# File 'lib/openai/models/beta/agents/vaults/mcp_oauth_token_endpoint_auth_rotate_param.rb', line 64

optional :client_secret, String, nil?: true

#typeSymbol, :client_secret_post

The type of the object. Always client_secret_post.

Parameters:

  • value (:client_secret_post)

Returns:

  • (Symbol, :client_secret_post)


57
# File 'lib/openai/models/beta/agents/vaults/mcp_oauth_token_endpoint_auth_rotate_param.rb', line 57

required :type, const: :client_secret_post

Instance Method Details

#to_hash{

Returns:

  • ({)


45
# File 'sig/openai/models/beta/agents/vaults/mcp_oauth_token_endpoint_auth_rotate_param.rbs', line 45

def to_hash: -> {