Module: OpenAI::Models::Beta::AssistantToolChoiceOption
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/beta/assistant_tool_choice_option.rb,
sig/openai/models/beta/assistant_tool_choice_option.rbs
Overview
Controls which (if any) tool is called by the model. none means the model will
not call any tools and instead generates a message. auto is the default value
and means the model can pick between generating a message or calling one or more
tools. required means the model must call one or more tools before responding
to the user. Specifying a particular tool like {"type": "file_search"} or
{"type": "function", "function": {"name": "my_function"}} forces the model to
call that tool.
Defined Under Namespace
Modules: Auto
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Symbol, OpenAI::Models::Beta::AssistantToolChoiceOption::Auto, OpenAI::Models::Beta::AssistantToolChoice)
|
|
# File 'lib/openai/models/beta/assistant_tool_choice_option.rb', line 37
|
Instance Method Details
#self?.variants ⇒ ::Array[OpenAI::Models::Beta::assistant_tool_choice_option]
23 |
# File 'sig/openai/models/beta/assistant_tool_choice_option.rbs', line 23
def self?.variants: -> ::Array[OpenAI::Models::Beta::assistant_tool_choice_option]
|