Module: OpenAI::Models::Beta::AssistantToolChoiceOption::Auto
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/beta/assistant_tool_choice_option.rb,
sig/openai/models/beta/assistant_tool_choice_option.rbs
Overview
none means the model will not call any tools and instead generates a message.
auto means the model can pick between generating a message or calling one or
more tools. required means the model must call one or more tools before
responding to the user.
Constant Summary collapse
- NONE =
:none- AUTO =
:auto- REQUIRED =
:required
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/assistant_tool_choice_option.rb', line 33
|
Instance Method Details
#self?.values ⇒ ::Array[OpenAI::Models::Beta::AssistantToolChoiceOption::auto]
20 |
# File 'sig/openai/models/beta/assistant_tool_choice_option.rbs', line 20
def self?.values: -> ::Array[OpenAI::Models::Beta::AssistantToolChoiceOption::auto]
|