Module: OpenAI::Models::Beta::BetaApplyPatchTool::AllowedCaller
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/beta/beta_apply_patch_tool.rb,
sig/openai/models/beta/beta_apply_patch_tool.rbs
Constant Summary collapse
- DIRECT =
:direct- PROGRAMMATIC =
:programmatic
Instance Method Summary collapse
-
#initialize(allowed_callers: nil, type: :apply_patch) ⇒ Object
Allows the assistant to create, delete, or update files using unified diffs.
- #self?.values ⇒ ::Array[OpenAI::Models::Beta::BetaApplyPatchTool::allowed_caller]
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(allowed_callers: nil, type: :apply_patch) ⇒ Object
Allows the assistant to create, delete, or update files using unified diffs.
30 31 32 33 34 35 36 37 38 |
# File 'lib/openai/models/beta/beta_apply_patch_tool.rb', line 30 module AllowedCaller extend OpenAI::Internal::Type::Enum DIRECT = :direct PROGRAMMATIC = :programmatic # @!method self.values # @return [Array<Symbol>] end |
#self?.values ⇒ ::Array[OpenAI::Models::Beta::BetaApplyPatchTool::allowed_caller]
35 |
# File 'sig/openai/models/beta/beta_apply_patch_tool.rbs', line 35
def self?.values: -> ::Array[OpenAI::Models::Beta::BetaApplyPatchTool::allowed_caller]
|