Class: OpenAI::Models::Beta::BetaContainerNetworkPolicyDomainSecret
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaContainerNetworkPolicyDomainSecret
- Defined in:
- lib/openai/models/beta/beta_container_network_policy_domain_secret.rb,
sig/openai/models/beta/beta_container_network_policy_domain_secret.rbs
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain associated with the secret.
-
#name ⇒ String
The name of the secret to inject for the domain.
-
#value ⇒ String
The secret value to inject for the domain.
Instance Method Summary collapse
-
#initialize ⇒ BetaContainerNetworkPolicyDomainSecret
constructor
A new instance of BetaContainerNetworkPolicyDomainSecret.
- #to_hash ⇒ { domain: String, name: String, value: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ BetaContainerNetworkPolicyDomainSecret
Returns a new instance of BetaContainerNetworkPolicyDomainSecret.
16 |
# File 'sig/openai/models/beta/beta_container_network_policy_domain_secret.rbs', line 16
def initialize: (domain: String, name: String, value: String) -> void
|
Instance Attribute Details
#domain ⇒ String
The domain associated with the secret.
11 |
# File 'lib/openai/models/beta/beta_container_network_policy_domain_secret.rb', line 11 required :domain, String |
#name ⇒ String
The name of the secret to inject for the domain.
17 |
# File 'lib/openai/models/beta/beta_container_network_policy_domain_secret.rb', line 17 required :name, String |
#value ⇒ String
The secret value to inject for the domain.
23 |
# File 'lib/openai/models/beta/beta_container_network_policy_domain_secret.rb', line 23 required :value, String |
Instance Method Details
#to_hash ⇒ { domain: String, name: String, value: String }
18 |
# File 'sig/openai/models/beta/beta_container_network_policy_domain_secret.rbs', line 18
def to_hash: -> { domain: String, name: String, value: String }
|