Class: OpenAI::Models::Beta::BetaFileSearchTool::Filters::ComparisonFilter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaFileSearchTool::Filters::ComparisonFilter
- Defined in:
- lib/openai/models/beta/beta_file_search_tool.rb,
sig/openai/models/beta/beta_file_search_tool.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#key ⇒ String
The key to compare against the value.
-
#type ⇒ Symbol, OpenAI::Models::Beta::BetaFileSearchTool::Filters::ComparisonFilter::Type
Specifies the comparison operator:
eq,ne,gt,gte,lt,lte,in,nin. -
#value ⇒ String, ...
The value to compare against the attribute key; supports string, number, or boolean types.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(key:, type:, value:) ⇒ Object
constructor
A filter used to compare a specified attribute key to a given value using a defined comparison operation.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(key:, type:, value:) ⇒ Object
A filter used to compare a specified attribute key to a given value using a defined comparison operation.
|
|
# File 'lib/openai/models/beta/beta_file_search_tool.rb', line 101
|
Instance Attribute Details
#key ⇒ String
The key to compare against the value.
76 |
# File 'lib/openai/models/beta/beta_file_search_tool.rb', line 76 required :key, String |
#type ⇒ Symbol, OpenAI::Models::Beta::BetaFileSearchTool::Filters::ComparisonFilter::Type
Specifies the comparison operator: eq, ne, gt, gte, lt, lte, in,
nin.
eq: equalsne: not equalgt: greater thangte: greater than or equallt: less thanlte: less than or equalin: innin: not in
92 |
# File 'lib/openai/models/beta/beta_file_search_tool.rb', line 92 required :type, enum: -> { OpenAI::Beta::BetaFileSearchTool::Filters::ComparisonFilter::Type } |
#value ⇒ String, ...
The value to compare against the attribute key; supports string, number, or boolean types.
99 |
# File 'lib/openai/models/beta/beta_file_search_tool.rb', line 99 required :value, union: -> { OpenAI::Beta::BetaFileSearchTool::Filters::ComparisonFilter::Value } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_file_search_tool.rb', line 150
|
Instance Method Details
#to_hash ⇒ {
75 |
# File 'sig/openai/models/beta/beta_file_search_tool.rbs', line 75
def to_hash: -> {
|