Class: OpenAI::Models::Beta::BetaFunctionTool
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaFunctionTool
- Defined in:
- lib/openai/models/beta/beta_function_tool.rb,
sig/openai/models/beta/beta_function_tool.rbs
Defined Under Namespace
Modules: AllowedCaller
Instance Attribute Summary collapse
-
#allowed_callers ⇒ Array<Symbol, OpenAI::Models::Beta::BetaFunctionTool::AllowedCaller>?
The tool invocation context(s).
-
#defer_loading ⇒ Boolean?
Whether this function is deferred and loaded via tool search.
-
#description ⇒ String?
A description of the function.
-
#name ⇒ String
The name of the function to call.
-
#output_schema ⇒ Hash{Symbol=>Object}?
A JSON schema object describing the JSON value encoded in string outputs for this function.
-
#parameters ⇒ Hash{Symbol=>Object}?
A JSON schema object describing the parameters of the function.
-
#strict ⇒ Boolean?
Whether strict parameter validation is enforced for this function tool.
-
#type ⇒ Symbol, :function
The type of the function tool.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
37 |
# File 'sig/openai/models/beta/beta_function_tool.rbs', line 37
def initialize: (
|
Instance Attribute Details
#allowed_callers ⇒ Array<Symbol, OpenAI::Models::Beta::BetaFunctionTool::AllowedCaller>?
The tool invocation context(s).
35 36 37 |
# File 'lib/openai/models/beta/beta_function_tool.rb', line 35 optional :allowed_callers, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Beta::BetaFunctionTool::AllowedCaller] }, nil?: true |
#defer_loading ⇒ Boolean?
Whether this function is deferred and loaded via tool search.
43 |
# File 'lib/openai/models/beta/beta_function_tool.rb', line 43 optional :defer_loading, OpenAI::Internal::Type::Boolean |
#description ⇒ String?
A description of the function. Used by the model to determine whether or not to call the function.
50 |
# File 'lib/openai/models/beta/beta_function_tool.rb', line 50 optional :description, String, nil?: true |
#name ⇒ String
The name of the function to call.
11 |
# File 'lib/openai/models/beta/beta_function_tool.rb', line 11 required :name, String |
#output_schema ⇒ Hash{Symbol=>Object}?
A JSON schema object describing the JSON value encoded in string outputs for this function.
57 |
# File 'lib/openai/models/beta/beta_function_tool.rb', line 57 optional :output_schema, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Unknown], nil?: true |
#parameters ⇒ Hash{Symbol=>Object}?
A JSON schema object describing the parameters of the function.
17 |
# File 'lib/openai/models/beta/beta_function_tool.rb', line 17 required :parameters, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Unknown], nil?: true |
#strict ⇒ Boolean?
Whether strict parameter validation is enforced for this function tool.
23 |
# File 'lib/openai/models/beta/beta_function_tool.rb', line 23 required :strict, OpenAI::Internal::Type::Boolean, nil?: true |
#type ⇒ Symbol, :function
The type of the function tool. Always function.
29 |
# File 'lib/openai/models/beta/beta_function_tool.rb', line 29 required :type, const: :function |
Instance Method Details
#to_hash ⇒ {
48 |
# File 'sig/openai/models/beta/beta_function_tool.rbs', line 48
def to_hash: -> {
|