Module: OpenAI::Models::Beta::BetaFunctionTool::AllowedCaller
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/beta/beta_function_tool.rb,
sig/openai/models/beta/beta_function_tool.rbs
Constant Summary collapse
- DIRECT =
:direct- PROGRAMMATIC =
:programmatic
Instance Method Summary collapse
-
#initialize(name:, parameters:, strict:, allowed_callers: nil, async: nil, defer_loading: nil, description: nil, output_schema: nil, type: :function) ⇒ Object
Defines a function in your own code the model can choose to call.
- #self?.values ⇒ ::Array[OpenAI::Models::Beta::BetaFunctionTool::allowed_caller]
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(name:, parameters:, strict:, allowed_callers: nil, async: nil, defer_loading: nil, description: nil, output_schema: nil, type: :function) ⇒ Object
Defines a function in your own code the model can choose to call. Learn more about function calling.
98 99 100 101 102 103 104 105 106 |
# File 'lib/openai/models/beta/beta_function_tool.rb', line 98 module AllowedCaller extend OpenAI::Internal::Type::Enum DIRECT = :direct PROGRAMMATIC = :programmatic # @!method self.values # @return [Array<Symbol>] end |
#self?.values ⇒ ::Array[OpenAI::Models::Beta::BetaFunctionTool::allowed_caller]
74 |
# File 'sig/openai/models/beta/beta_function_tool.rbs', line 74
def self?.values: -> ::Array[OpenAI::Models::Beta::BetaFunctionTool::allowed_caller]
|