Class: OpenAI::Models::Beta::BetaNamespaceTool::Tool::Function
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaNamespaceTool::Tool::Function
- Defined in:
- lib/openai/models/beta/beta_namespace_tool.rb,
sig/openai/models/beta/beta_namespace_tool.rbs
Defined Under Namespace
Modules: AllowedCaller
Instance Attribute Summary collapse
-
#allowed_callers ⇒ Array<Symbol, OpenAI::Models::Beta::BetaNamespaceTool::Tool::Function::AllowedCaller>?
The tool invocation context(s).
-
#async ⇒ Boolean?
Whether the tool response can be returned asynchronously versus immediately returned on next response creation.
-
#defer_loading ⇒ Boolean?
Whether this function should be deferred and discovered via tool search.
- #description ⇒ String?
- #name ⇒ String
-
#output_schema ⇒ Hash{Symbol=>Object}?
A JSON Schema describing the JSON value encoded in string outputs for this function tool.
- #parameters ⇒ Object?
-
#strict ⇒ Boolean?
Whether to enforce strict parameter validation.
- #type ⇒ Symbol, :function
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
80 |
# File 'sig/openai/models/beta/beta_namespace_tool.rbs', line 80
def initialize: (
|
Instance Attribute Details
#allowed_callers ⇒ Array<Symbol, OpenAI::Models::Beta::BetaNamespaceTool::Tool::Function::AllowedCaller>?
The tool invocation context(s).
72 73 74 75 76 77 78 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 72 optional( :allowed_callers, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Beta::BetaNamespaceTool::Tool::Function::AllowedCaller] }, nil?: true ) |
#async ⇒ Boolean?
Whether the tool response can be returned asynchronously versus immediately returned on next response creation.
85 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 85 optional :async, OpenAI::Internal::Type::Boolean |
#defer_loading ⇒ Boolean?
Whether this function should be deferred and discovered via tool search.
91 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 91 optional :defer_loading, OpenAI::Internal::Type::Boolean |
#description ⇒ String?
96 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 96 optional :description, String, nil?: true |
#name ⇒ String
61 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 61 required :name, String |
#output_schema ⇒ Hash{Symbol=>Object}?
A JSON Schema describing the JSON value encoded in string outputs for this function tool. This does not describe content-array outputs.
103 104 105 106 107 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 103 optional( :output_schema, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Unknown], nil?: true ) |
#parameters ⇒ Object?
112 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 112 optional :parameters, OpenAI::Internal::Type::Unknown, nil?: true |
#strict ⇒ Boolean?
Whether to enforce strict parameter validation. If omitted, Responses attempts to use strict validation when the schema is compatible, and falls back to non-strict validation otherwise.
120 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 120 optional :strict, OpenAI::Internal::Type::Boolean, nil?: true |
#type ⇒ Symbol, :function
66 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 66 required :type, const: :function |
Instance Method Details
#to_hash ⇒ {
92 |
# File 'sig/openai/models/beta/beta_namespace_tool.rbs', line 92
def to_hash: -> {
|