Module: OpenAI::Models::Beta::BetaNamespaceTool::Tool::Function::AllowedCaller

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/beta/beta_namespace_tool.rb,
sig/openai/models/beta/beta_namespace_tool.rbs

Constant Summary collapse

DIRECT =

Returns:

  • (:direct)
:direct
PROGRAMMATIC =

Returns:

  • (:programmatic)
:programmatic

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(name:, allowed_callers: nil, async: nil, defer_loading: nil, description: nil, output_schema: nil, parameters: nil, strict: nil, type: :function) ⇒ Object

Parameters:

  • name (String)
  • allowed_callers (Array<Symbol, OpenAI::Models::Beta::BetaNamespaceTool::Tool::Function::AllowedCaller>, nil) (defaults to: nil)

    The tool invocation context(s).

  • async (Boolean) (defaults to: nil)

    Whether the tool response can be returned asynchronously versus immediately returned on next response creation.

  • defer_loading (Boolean) (defaults to: nil)

    Whether this function should be deferred and discovered via tool search.

  • description (String, nil) (defaults to: nil)
  • output_schema (Hash{Symbol=>Object}, nil) (defaults to: nil)

    A JSON Schema describing the JSON value encoded in string outputs for this function tool. This does not describe content-array outputs.

  • parameters (Object, nil) (defaults to: nil)
  • strict (Boolean, nil) (defaults to: nil)

    Whether to enforce strict parameter validation. If omitted, Responses attempts to use strict validation when the schema is compatible, and falls back to non-strict validation otherwise.

  • type (Symbol, :function) (defaults to: :function)


150
151
152
153
154
155
156
157
158
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 150

module AllowedCaller
  extend OpenAI::Internal::Type::Enum

  DIRECT = :direct
  PROGRAMMATIC = :programmatic

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[OpenAI::Models::Beta::BetaNamespaceTool::Tool::Function::allowed_caller]

Returns:

  • (::Array[OpenAI::Models::Beta::BetaNamespaceTool::Tool::Function::allowed_caller])


112
# File 'sig/openai/models/beta/beta_namespace_tool.rbs', line 112

def self?.values: -> ::Array[OpenAI::Models::Beta::BetaNamespaceTool::Tool::Function::allowed_caller]