Class: OpenAI::Models::Beta::BetaResponse::IncompleteDetails

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response.rb,
sig/openai/models/beta/beta_response.rbs

Overview

See Also:

  • OpenAI::Models::Beta::BetaResponse#incomplete_details

Defined Under Namespace

Modules: Reason

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(reason: nil) ⇒ Object

Parameters:

  • reason (defaults to: nil) —

    The reason why the response is incomplete. steered means the response stopped at a safe output boundary after a WebSocket response.steer event. The server can then create a successor response automatically with the queued input.



# File 'lib/openai/models/beta/beta_response.rb', line 600

Instance Attribute Details

#reason ⇒ OpenAI::Models::Beta::BetaResponse::IncompleteDetails::reason?

The reason why the response is incomplete. steered means the response stopped at a safe output boundary after a WebSocket response.steer event. The server can then create a successor response automatically with the queued input.

Returns:

  • (OpenAI::Models::Beta::BetaResponse::IncompleteDetails::reason, nil)


598
# File 'lib/openai/models/beta/beta_response.rb', line 598

optional :reason, enum: -> { OpenAI::Beta::BetaResponse::IncompleteDetails::Reason }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


618
# File 'sig/openai/models/beta/beta_response.rbs', line 618

def to_hash: -> {