Class: OpenAI::Models::Beta::BetaResponseApplyPatchToolCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_apply_patch_tool_call.rb,
sig/openai/models/beta/beta_response_apply_patch_tool_call.rbs

Defined Under Namespace

Modules: Caller, Operation, Status Classes: Agent

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_name:) ⇒ Object

Parameters:

  • id

    The unique ID of the apply patch tool call. Populated when this item is returned via API.

  • call_id

    The unique ID of the apply patch tool call generated by the model.

  • operation

    One of the create_file, delete_file, or update_file operations applied via apply_patch.

  • status

    The status of the apply patch tool call. One of in_progress or completed.

  • agent

    The agent that produced this item.

  • caller_

    The execution context that produced this tool call.

  • created_by

    The ID of the entity that created this tool call.

  • type

    The type of the item. Always apply_patch_call.



# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 62

Instance Attribute Details

#agentOpenAI::Beta::BetaResponseApplyPatchToolCall::Agent?

The agent that produced this item.

Returns:

  • (OpenAI::Beta::BetaResponseApplyPatchToolCall::Agent, nil)


43
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 43

optional :agent, -> { OpenAI::Beta::BetaResponseApplyPatchToolCall::Agent }

#call_idString

The unique ID of the apply patch tool call generated by the model.

Returns:

  • (String)


18
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 18

required :call_id, String

#caller_OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::caller_?

The execution context that produced this tool call.

Returns:

  • (OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::caller_, nil)


49
50
51
52
53
54
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 49

optional(
  :caller_,
  union: -> { OpenAI::Beta::BetaResponseApplyPatchToolCall::Caller },
  api_name: :caller,
  nil?: true
)

#created_byString?

The ID of the entity that created this tool call.

Returns:

  • (String, nil)


60
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 60

optional :created_by, String

#idString

The unique ID of the apply patch tool call. Populated when this item is returned via API.

Returns:

  • (String)


12
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 12

required :id, String

#operationOpenAI::Models::Beta::BetaResponseApplyPatchToolCall::operation

One of the create_file, delete_file, or update_file operations applied via apply_patch.

Returns:

  • (OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::operation)


25
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 25

required :operation, union: -> { OpenAI::Beta::BetaResponseApplyPatchToolCall::Operation }

#statusOpenAI::Models::Beta::BetaResponseApplyPatchToolCall::status

The status of the apply patch tool call. One of in_progress or completed.

Returns:

  • (OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::status)


31
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 31

required :status, enum: -> { OpenAI::Beta::BetaResponseApplyPatchToolCall::Status }

#type:apply_patch_call

The type of the item. Always apply_patch_call.

Returns:

  • (:apply_patch_call)


37
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 37

required :type, const: :apply_patch_call

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 209

.variantsArray(OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Operation::CreateFile, OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Operation::DeleteFile, OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Operation::UpdateFile)



# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 196

Instance Method Details

#to_hash{

Returns:

  • ({)


82
# File 'sig/openai/models/beta/beta_response_apply_patch_tool_call.rbs', line 82

def to_hash: -> {