Module: OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Operation
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/beta/beta_response_apply_patch_tool_call.rb,
sig/openai/models/beta/beta_response_apply_patch_tool_call.rbs
Overview
One of the create_file, delete_file, or update_file operations applied via apply_patch.
Defined Under Namespace
Classes: CreateFile, DeleteFile, UpdateFile
Instance Method Summary collapse
-
#initialize(path:, type: :delete_file) ⇒ Object
Instruction describing how to delete a file via the apply_patch tool.
- #self?.variants ⇒ ::Array[OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::operation]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(path:, type: :delete_file) ⇒ Object
Instruction describing how to delete a file via the apply_patch tool.
|
|
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 119
|
#self?.variants ⇒ ::Array[OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::operation]
119 |
# File 'sig/openai/models/beta/beta_response_apply_patch_tool_call.rbs', line 119
def self?.variants: -> ::Array[OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::operation]
|