Class: OpenAI::Models::Beta::BetaResponseCodeInterpreterCallCodeDoneEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseCodeInterpreterCallCodeDoneEvent
- Defined in:
- lib/openai/models/beta/beta_response_code_interpreter_call_code_done_event.rb,
sig/openai/models/beta/beta_response_code_interpreter_call_code_done_event.rbs
Defined Under Namespace
Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseCodeInterpreterCallCodeDoneEvent::Agent?
The agent that owns this multi-agent streaming event.
-
#code ⇒ String
The final code snippet output by the code interpreter.
-
#item_id ⇒ String
The unique identifier of the code interpreter tool call item.
-
#output_index ⇒ Integer
The index of the output item in the response for which the code is finalized.
-
#sequence_number ⇒ Integer
The sequence number of this event, used to order streaming events.
-
#type ⇒ Symbol, :"response.code_interpreter_call_code.done"
The type of the event.
Instance Method Summary collapse
-
#initialize(code:, item_id:, output_index:, sequence_number:, agent: nil, type: :"response.code_interpreter_call_code.done") ⇒ Object
constructor
Emitted when the code snippet is finalized by the code interpreter.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code:, item_id:, output_index:, sequence_number:, agent: nil, type: :"response.code_interpreter_call_code.done") ⇒ Object
Emitted when the code snippet is finalized by the code interpreter.
|
|
# File 'lib/openai/models/beta/beta_response_code_interpreter_call_code_done_event.rb', line 43
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseCodeInterpreterCallCodeDoneEvent::Agent?
The agent that owns this multi-agent streaming event.
41 |
# File 'lib/openai/models/beta/beta_response_code_interpreter_call_code_done_event.rb', line 41 optional :agent, -> { OpenAI::Beta::BetaResponseCodeInterpreterCallCodeDoneEvent::Agent }, nil?: true |
#code ⇒ String
The final code snippet output by the code interpreter.
11 |
# File 'lib/openai/models/beta/beta_response_code_interpreter_call_code_done_event.rb', line 11 required :code, String |
#item_id ⇒ String
The unique identifier of the code interpreter tool call item.
17 |
# File 'lib/openai/models/beta/beta_response_code_interpreter_call_code_done_event.rb', line 17 required :item_id, String |
#output_index ⇒ Integer
The index of the output item in the response for which the code is finalized.
23 |
# File 'lib/openai/models/beta/beta_response_code_interpreter_call_code_done_event.rb', line 23 required :output_index, Integer |
#sequence_number ⇒ Integer
The sequence number of this event, used to order streaming events.
29 |
# File 'lib/openai/models/beta/beta_response_code_interpreter_call_code_done_event.rb', line 29 required :sequence_number, Integer |
#type ⇒ Symbol, :"response.code_interpreter_call_code.done"
The type of the event. Always response.code_interpreter_call_code.done.
35 |
# File 'lib/openai/models/beta/beta_response_code_interpreter_call_code_done_event.rb', line 35 required :type, const: :"response.code_interpreter_call_code.done" |
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/openai/models/beta/beta_response_code_interpreter_call_code_done_event.rbs', line 38
def to_hash: -> {
|