Class: OpenAI::Models::Beta::BetaResponseCodeInterpreterToolCall::Output::Image

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_code_interpreter_tool_call.rb,
sig/openai/models/beta/beta_response_code_interpreter_tool_call.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Image

Returns a new instance of Image.

Parameters:

  • url —

    The URL of the image output from the code interpreter.

  • type —

    The type of the output. Always image.

  • url: (String)
  • type: (:image)


115
# File 'sig/openai/models/beta/beta_response_code_interpreter_tool_call.rbs', line 115

def initialize: (url: String, ?type: :image) -> void

Instance Attribute Details

#type ⇒ :image

The type of the output. Always image.

Returns:

  • (:image)


123
# File 'lib/openai/models/beta/beta_response_code_interpreter_tool_call.rb', line 123

required :type, const: :image

#url ⇒ String

The URL of the image output from the code interpreter.

Returns:

  • (String)


129
# File 'lib/openai/models/beta/beta_response_code_interpreter_tool_call.rb', line 129

required :url, String

Instance Method Details

#to_hash ⇒ { ?type: :image, url: String }

Returns:

  • ({ ?type: :image, url: String })


117
# File 'sig/openai/models/beta/beta_response_code_interpreter_tool_call.rbs', line 117

def to_hash: -> { ?type: :image, url: String }