Class: OpenAI::Models::Beta::BetaResponseComputerToolCallOutputItem

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb,
sig/openai/models/beta/beta_response_computer_tool_call_output_item.rbs

Defined Under Namespace

Modules: Status Classes: AcknowledgedSafetyCheck, Agent

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, code: nil, message: nil) ⇒ Object

Parameters:

  • id —

    The unique ID of the computer call tool output.

  • call_id —

    The ID of the computer tool call that produced the output.

  • output —

    A computer screenshot image used with the computer use tool.

  • status —

    The status of the message input. One of in_progress, completed, or incomplete. Populated when input items are returned via API.

  • acknowledged_safety_checks —

    The safety checks reported by the API that have been acknowledged by the developer.

  • agent —

    The agent that produced this item.

  • created_by —

    The identifier of the actor that created the item.

  • type —

    The type of the computer tool call output. Always computer_call_output.



# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 64

Instance Attribute Details

#acknowledged_safety_checks ⇒ ::Array[OpenAI::Beta::BetaResponseComputerToolCallOutputItem::AcknowledgedSafetyCheck]?

The safety checks reported by the API that have been acknowledged by the developer.

Returns:

  • (::Array[OpenAI::Beta::BetaResponseComputerToolCallOutputItem::AcknowledgedSafetyCheck], nil)


43
44
45
46
47
48
49
50
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 43

optional(
  :acknowledged_safety_checks,
  -> {
    OpenAI::Internal::Type::ArrayOf[
      OpenAI::Beta::BetaResponseComputerToolCallOutputItem::AcknowledgedSafetyCheck
    ]
  }
)

#agent ⇒ OpenAI::Beta::BetaResponseComputerToolCallOutputItem::Agent?

The agent that produced this item.

Returns:

  • (OpenAI::Beta::BetaResponseComputerToolCallOutputItem::Agent, nil)


56
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 56

optional :agent, -> { OpenAI::Beta::BetaResponseComputerToolCallOutputItem::Agent }, nil?: true

#call_id ⇒ String

The ID of the computer tool call that produced the output.

Returns:

  • (String)


17
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 17

required :call_id, String

#created_by ⇒ String?

The identifier of the actor that created the item.

Returns:

  • (String, nil)


62
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 62

optional :created_by, String

#id ⇒ String

The unique ID of the computer call tool output.

Returns:

  • (String)


11
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 11

required :id, String

#output ⇒ OpenAI::Beta::BetaResponseComputerToolCallOutputScreenshot

A computer screenshot image used with the computer use tool.

Returns:

  • (OpenAI::Beta::BetaResponseComputerToolCallOutputScreenshot)


23
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 23

required :output, -> { OpenAI::Beta::BetaResponseComputerToolCallOutputScreenshot }

#status ⇒ OpenAI::Models::Beta::BetaResponseComputerToolCallOutputItem::status

The status of the message input. One of in_progress, completed, or incomplete. Populated when input items are returned via API.

Returns:

  • (OpenAI::Models::Beta::BetaResponseComputerToolCallOutputItem::status)


30
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 30

required :status, enum: -> { OpenAI::Beta::BetaResponseComputerToolCallOutputItem::Status }

#type ⇒ :computer_call_output

The type of the computer tool call output. Always computer_call_output.

Returns:

  • (:computer_call_output)


36
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 36

required :type, const: :computer_call_output

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 103

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


83
# File 'sig/openai/models/beta/beta_response_computer_tool_call_output_item.rbs', line 83

def to_hash: -> {