Class: OpenAI::Models::Beta::BetaResponseComputerToolCallOutputScreenshot

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_computer_tool_call_output_screenshot.rb,
sig/openai/models/beta/beta_response_computer_tool_call_output_screenshot.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



20
# File 'sig/openai/models/beta/beta_response_computer_tool_call_output_screenshot.rbs', line 20

def initialize: (

Instance Attribute Details

#file_idString?

The identifier of an uploaded file that contains the screenshot.

Parameters:

  • (String)

Returns:

  • (String, nil)


18
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_screenshot.rb', line 18

optional :file_id, String

#image_urlString?

The URL of the screenshot image.

Parameters:

  • (String)

Returns:

  • (String, nil)


24
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_screenshot.rb', line 24

optional :image_url, String

#typeSymbol, :computer_screenshot

Specifies the event type. For a computer screenshot, this property is always set to computer_screenshot.

Parameters:

  • value (:computer_screenshot)

Returns:

  • (Symbol, :computer_screenshot)


12
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_screenshot.rb', line 12

required :type, const: :computer_screenshot

Instance Method Details

#to_hash{

Returns:

  • ({)


26
# File 'sig/openai/models/beta/beta_response_computer_tool_call_output_screenshot.rbs', line 26

def to_hash: -> {