Class: OpenAI::Models::Beta::BetaResponseCustomToolCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_custom_tool_call.rb,
sig/openai/models/beta/beta_response_custom_tool_call.rbs

Direct Known Subclasses

BetaResponseCustomToolCallItem

Defined Under Namespace

Modules: Caller Classes: Agent

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_name:) ⇒ Object

The agent that produced this item.

Parameters:

  • agent_name (String)

    The canonical name of the agent that produced this item.



# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 58

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseCustomToolCall::Agent?

The agent that produced this item.

Parameters:

  • value (OpenAI::Beta::BetaResponseCustomToolCall::Agent, nil)

Returns:



41
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 41

optional :agent, -> { OpenAI::Beta::BetaResponseCustomToolCall::Agent }, nil?: true

#call_idString

An identifier used to map this custom tool call to a tool call output.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 11

required :call_id, String

#caller_OpenAI::Models::Beta::BetaResponseCustomToolCall::Caller::Direct, ...

The execution context that produced this tool call.

Parameters:

  • value (OpenAI::Models::Beta::BetaResponseCustomToolCall::caller_, nil)

Returns:



47
48
49
50
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 47

optional :caller_,
union: -> { OpenAI::Beta::BetaResponseCustomToolCall::Caller },
api_name: :caller,
nil?: true

#idString?

The unique ID of the custom tool call in the OpenAI platform.

Parameters:

  • (String)

Returns:

  • (String, nil)


35
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 35

optional :id, String

#inputString

The input for the custom tool call generated by the model.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 17

required :input, String

#nameString

The name of the custom tool being called.

Parameters:

  • value (String)

Returns:

  • (String)


23
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 23

required :name, String

#namespaceString?

The namespace of the custom tool being called.

Parameters:

  • (String)

Returns:

  • (String, nil)


56
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 56

optional :namespace, String

#typeSymbol, :custom_tool_call

The type of the custom tool call. Always custom_tool_call.

Parameters:

  • value (:custom_tool_call)

Returns:

  • (Symbol, :custom_tool_call)


29
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 29

required :type, const: :custom_tool_call

Instance Method Details

#to_hash{

Returns:

  • ({)


50
# File 'sig/openai/models/beta/beta_response_custom_tool_call.rbs', line 50

def to_hash: -> {