Class: OpenAI::Models::Beta::BetaResponseFileSearchToolCall::Result

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_file_search_tool_call.rb,
sig/openai/models/beta/beta_response_file_search_tool_call.rbs

Defined Under Namespace

Modules: Attribute

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



100
# File 'sig/openai/models/beta/beta_response_file_search_tool_call.rbs', line 100

def initialize: (

Instance Attribute Details

#attributesHash{Symbol=>String, Float, Boolean}?

Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard. Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters, booleans, or numbers.

Parameters:

  • value (::Hash[Symbol, OpenAI::Models::Beta::BetaResponseFileSearchToolCall::Result::attribute], nil)

Returns:

  • (Hash{Symbol=>String, Float, Boolean}, nil)


106
107
108
109
110
# File 'lib/openai/models/beta/beta_response_file_search_tool_call.rb', line 106

optional :attributes,
-> {
  OpenAI::Internal::Type::HashOf[union: OpenAI::Beta::BetaResponseFileSearchToolCall::Result::Attribute]
},
nil?: true

#file_idString?

The unique ID of the file.

Parameters:

  • (String)

Returns:

  • (String, nil)


116
# File 'lib/openai/models/beta/beta_response_file_search_tool_call.rb', line 116

optional :file_id, String

#filenameString?

The name of the file.

Parameters:

  • (String)

Returns:

  • (String, nil)


122
# File 'lib/openai/models/beta/beta_response_file_search_tool_call.rb', line 122

optional :filename, String

#scoreFloat?

The relevance score of the file - a value between 0 and 1.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


128
# File 'lib/openai/models/beta/beta_response_file_search_tool_call.rb', line 128

optional :score, Float

#textString?

The text that was retrieved from the file.

Parameters:

  • (String)

Returns:

  • (String, nil)


134
# File 'lib/openai/models/beta/beta_response_file_search_tool_call.rb', line 134

optional :text, String

Instance Method Details

#to_hash{

Returns:

  • ({)


108
# File 'sig/openai/models/beta/beta_response_file_search_tool_call.rbs', line 108

def to_hash: -> {