Module: OpenAI::Models::Beta::BetaResponseFormatTextConfig

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/beta/beta_response_format_text_config.rb

Overview

An object specifying the format that the model must output.

Configuring { "type": "json_schema" } enables Structured Outputs, which ensures the model will match your supplied JSON schema. Learn more in the Structured Outputs guide.

The default format is { "type": "text" } with no additional options.

Not recommended for gpt-4o and newer models:

Setting to { "type": "json_object" } enables the older JSON mode, which ensures the message the model generates is valid JSON. Using json_schema is preferred for models that support it.

Defined Under Namespace

Classes: JSONObject, Text

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(type: :text) ⇒ Object

Default response format. Used to generate text responses.

Parameters:

  • type (Symbol, :text) (defaults to: :text)

    The type of response format being defined. Always text.



# File 'lib/openai/models/beta/beta_response_format_text_config.rb', line 44