Class: OpenAI::Models::Beta::BetaResponseFunctionCallArgumentsDeltaEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_function_call_arguments_delta_event.rb,
sig/openai/models/beta/beta_response_function_call_arguments_delta_event.rbs

Defined Under Namespace

Classes: Agent

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(delta:, item_id:, output_index:, sequence_number:, agent: nil, type: :"response.function_call_arguments.delta") ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Beta::BetaResponseFunctionCallArgumentsDeltaEvent for more details.

Emitted when there is a partial function-call arguments delta.

Parameters:

  • delta (String)

    The function-call arguments delta that is added.

  • item_id (String)

    The ID of the output item that the function-call arguments delta is added to.

  • output_index (Integer)

    The index of the output item that the function-call arguments delta is added to.

  • sequence_number (Integer)

    The sequence number of this event.

  • agent (OpenAI::Models::Beta::BetaResponseFunctionCallArgumentsDeltaEvent::Agent, nil) (defaults to: nil)

    The agent that owns this multi-agent streaming event.

  • type (Symbol, :"response.function_call_arguments.delta") (defaults to: :"response.function_call_arguments.delta")

    The type of the event. Always response.function_call_arguments.delta.



# File 'lib/openai/models/beta/beta_response_function_call_arguments_delta_event.rb', line 43

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseFunctionCallArgumentsDeltaEvent::Agent?

The agent that owns this multi-agent streaming event.

Parameters:

  • value (OpenAI::Beta::BetaResponseFunctionCallArgumentsDeltaEvent::Agent, nil)

Returns:



41
# File 'lib/openai/models/beta/beta_response_function_call_arguments_delta_event.rb', line 41

optional :agent, -> { OpenAI::Beta::BetaResponseFunctionCallArgumentsDeltaEvent::Agent }, nil?: true

#deltaString

The function-call arguments delta that is added.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/openai/models/beta/beta_response_function_call_arguments_delta_event.rb', line 11

required :delta, String

#item_idString

The ID of the output item that the function-call arguments delta is added to.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/openai/models/beta/beta_response_function_call_arguments_delta_event.rb', line 17

required :item_id, String

#output_indexInteger

The index of the output item that the function-call arguments delta is added to.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


23
# File 'lib/openai/models/beta/beta_response_function_call_arguments_delta_event.rb', line 23

required :output_index, Integer

#sequence_numberInteger

The sequence number of this event.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


29
# File 'lib/openai/models/beta/beta_response_function_call_arguments_delta_event.rb', line 29

required :sequence_number, Integer

#typeSymbol, :"response.function_call_arguments.delta"

The type of the event. Always response.function_call_arguments.delta.

Parameters:

  • value (:"response.function_call_arguments.delta")

Returns:

  • (Symbol, :"response.function_call_arguments.delta")


35
# File 'lib/openai/models/beta/beta_response_function_call_arguments_delta_event.rb', line 35

required :type, const: :"response.function_call_arguments.delta"

Instance Method Details

#to_hash{

Returns:

  • ({)


38
# File 'sig/openai/models/beta/beta_response_function_call_arguments_delta_event.rbs', line 38

def to_hash: -> {