Class: OpenAI::Models::Beta::BetaResponseFunctionShellCallOutputContent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseFunctionShellCallOutputContent
- Defined in:
- lib/openai/models/beta/beta_response_function_shell_call_output_content.rb,
sig/openai/models/beta/beta_response_function_shell_call_output_content.rbs
Defined Under Namespace
Modules: Outcome
Instance Attribute Summary collapse
-
#outcome ⇒ OpenAI::Models::Beta::BetaResponseFunctionShellCallOutputContent::Outcome::Timeout, OpenAI::Models::Beta::BetaResponseFunctionShellCallOutputContent::Outcome::Exit
The exit or timeout outcome associated with this shell call.
-
#stderr ⇒ String
Captured stderr output for the shell call.
-
#stdout ⇒ String
Captured stdout output for the shell call.
Instance Method Summary collapse
-
#initialize(outcome:, stderr:, stdout:) ⇒ Object
constructor
Captured stdout and stderr for a portion of a shell tool call output.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(outcome:, stderr:, stdout:) ⇒ Object
Captured stdout and stderr for a portion of a shell tool call output.
|
|
# File 'lib/openai/models/beta/beta_response_function_shell_call_output_content.rb', line 25
|
Instance Attribute Details
#outcome ⇒ OpenAI::Models::Beta::BetaResponseFunctionShellCallOutputContent::Outcome::Timeout, OpenAI::Models::Beta::BetaResponseFunctionShellCallOutputContent::Outcome::Exit
The exit or timeout outcome associated with this shell call.
11 |
# File 'lib/openai/models/beta/beta_response_function_shell_call_output_content.rb', line 11 required :outcome, union: -> { OpenAI::Beta::BetaResponseFunctionShellCallOutputContent::Outcome } |
#stderr ⇒ String
Captured stderr output for the shell call.
17 |
# File 'lib/openai/models/beta/beta_response_function_shell_call_output_content.rb', line 17 required :stderr, String |
#stdout ⇒ String
Captured stdout output for the shell call.
23 |
# File 'lib/openai/models/beta/beta_response_function_shell_call_output_content.rb', line 23 required :stdout, String |
Instance Method Details
#to_hash ⇒ {
26 |
# File 'sig/openai/models/beta/beta_response_function_shell_call_output_content.rbs', line 26
def to_hash: -> {
|