Module: OpenAI::Models::Beta::BetaResponseFunctionShellCallOutputContent::Outcome
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/beta/beta_response_function_shell_call_output_content.rb,
sig/openai/models/beta/beta_response_function_shell_call_output_content.rbs
Overview
The exit or timeout outcome associated with this shell call.
Defined Under Namespace
Instance Method Summary collapse
-
#initialize(type: :timeout) ⇒ Object
Indicates that the shell call exceeded its configured time limit.
- #self?.variants ⇒ ::Array[OpenAI::Models::Beta::BetaResponseFunctionShellCallOutputContent::outcome]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(type: :timeout) ⇒ Object
Indicates that the shell call exceeded its configured time limit.
|
|
# File 'lib/openai/models/beta/beta_response_function_shell_call_output_content.rb', line 55
|
#self?.variants ⇒ ::Array[OpenAI::Models::Beta::BetaResponseFunctionShellCallOutputContent::outcome]
61 |
# File 'sig/openai/models/beta/beta_response_function_shell_call_output_content.rbs', line 61
def self?.variants: -> ::Array[OpenAI::Models::Beta::BetaResponseFunctionShellCallOutputContent::outcome]
|