Class: OpenAI::Models::Beta::BetaResponseFunctionShellToolCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseFunctionShellToolCall
- Defined in:
- lib/openai/models/beta/beta_response_function_shell_tool_call.rb,
sig/openai/models/beta/beta_response_function_shell_tool_call.rbs
Defined Under Namespace
Modules: Caller, Environment, Status Classes: Action, Agent
Instance Attribute Summary collapse
-
#action ⇒ OpenAI::Models::Beta::BetaResponseFunctionShellToolCall::Action
The shell commands and limits that describe how to run the tool call.
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseFunctionShellToolCall::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseFunctionShellToolCall::Caller::Direct, ...
The execution context that produced this tool call.
-
#created_by ⇒ String?
The ID of the entity that created this tool call.
-
#environment ⇒ OpenAI::Models::Beta::BetaResponseLocalEnvironment, ...
Represents the use of a local environment to perform shell actions.
-
#id ⇒ String
The unique ID of the shell tool call.
-
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseFunctionShellToolCall::Status
The status of the shell call.
-
#type ⇒ Symbol, :shell_call
The type of the item.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(OpenAI::Models::Beta::BetaResponseLocalEnvironment, OpenAI::Models::Beta::BetaResponseContainerReference)
Instance Method Summary collapse
-
#initialize(agent_name:) ⇒ Object
constructor
The agent that produced this item.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_name:) ⇒ Object
The agent that produced this item.
|
|
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call.rb', line 68
|
Instance Attribute Details
#action ⇒ OpenAI::Models::Beta::BetaResponseFunctionShellToolCall::Action
The shell commands and limits that describe how to run the tool call.
18 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call.rb', line 18 required :action, -> { OpenAI::Beta::BetaResponseFunctionShellToolCall::Action } |
#agent ⇒ OpenAI::Models::Beta::BetaResponseFunctionShellToolCall::Agent?
The agent that produced this item.
51 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call.rb', line 51 optional :agent, -> { OpenAI::Beta::BetaResponseFunctionShellToolCall::Agent } |
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
24 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call.rb', line 24 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseFunctionShellToolCall::Caller::Direct, ...
The execution context that produced this tool call.
57 58 59 60 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call.rb', line 57 optional :caller_, union: -> { OpenAI::Beta::BetaResponseFunctionShellToolCall::Caller }, api_name: :caller, nil?: true |
#created_by ⇒ String?
The ID of the entity that created this tool call.
66 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call.rb', line 66 optional :created_by, String |
#environment ⇒ OpenAI::Models::Beta::BetaResponseLocalEnvironment, ...
Represents the use of a local environment to perform shell actions.
30 31 32 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call.rb', line 30 required :environment, union: -> { OpenAI::Beta::BetaResponseFunctionShellToolCall::Environment }, nil?: true |
#id ⇒ String
The unique ID of the shell tool call. Populated when this item is returned via API.
12 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call.rb', line 12 required :id, String |
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseFunctionShellToolCall::Status
The status of the shell call. One of in_progress, completed, or
incomplete.
39 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call.rb', line 39 required :status, enum: -> { OpenAI::Beta::BetaResponseFunctionShellToolCall::Status } |
#type ⇒ Symbol, :shell_call
The type of the item. Always shell_call.
45 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call.rb', line 45 required :type, const: :shell_call |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call.rb', line 150
|
.variants ⇒ Array(OpenAI::Models::Beta::BetaResponseLocalEnvironment, OpenAI::Models::Beta::BetaResponseContainerReference)
|
|
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call.rb', line 135
|
Instance Method Details
#to_hash ⇒ {
56 |
# File 'sig/openai/models/beta/beta_response_function_shell_tool_call.rbs', line 56
def to_hash: -> {
|