Class: OpenAI::Models::Beta::BetaResponseFunctionShellToolCall::Action
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseFunctionShellToolCall::Action
- Defined in:
- lib/openai/models/beta/beta_response_function_shell_tool_call.rb,
sig/openai/models/beta/beta_response_function_shell_tool_call.rbs
Overview
Instance Attribute Summary collapse
- #commands ⇒ Array<String>
-
#max_output_length ⇒ Integer?
Optional maximum number of characters to return from each command.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the commands.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
82 |
# File 'sig/openai/models/beta/beta_response_function_shell_tool_call.rbs', line 82
def initialize: (
|
Instance Attribute Details
#commands ⇒ Array<String>
97 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call.rb', line 97 required :commands, OpenAI::Internal::Type::ArrayOf[String] |
#max_output_length ⇒ Integer?
Optional maximum number of characters to return from each command.
103 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call.rb', line 103 required :max_output_length, Integer, nil?: true |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the commands.
109 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call.rb', line 109 required :timeout_ms, Integer, nil?: true |
Instance Method Details
#to_hash ⇒ {
88 |
# File 'sig/openai/models/beta/beta_response_function_shell_tool_call.rbs', line 88
def to_hash: -> {
|