Class: OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb,
sig/openai/models/beta/beta_response_function_shell_tool_call_output.rbs

Defined Under Namespace

Modules: Caller, Status Classes: Agent, Output

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_name:) ⇒ Object

The agent that produced this item.

Parameters:

  • agent_name (String)

    The canonical name of the agent that produced this item.



# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 175

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Agent?

The agent that produced this item.



51
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 51

optional :agent, -> { OpenAI::Beta::BetaResponseFunctionShellToolCallOutput::Agent }

#call_idString

The unique ID of the shell tool call generated by the model.

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 18

required :call_id, String

#caller_OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Caller::Direct, ...

The execution context that produced this tool call.

Parameters:

  • value (OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::caller_, nil)

Returns:



57
58
59
60
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 57

optional :caller_,
union: -> { OpenAI::Beta::BetaResponseFunctionShellToolCallOutput::Caller },
api_name: :caller,
nil?: true

#created_byString?

The identifier of the actor that created the item.

Parameters:

  • (String)

Returns:

  • (String, nil)


66
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 66

optional :created_by, String

#idString

The unique ID of the shell call output. Populated when this item is returned via API.

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 12

required :id, String

#max_output_lengthInteger?

The maximum length of the shell command output. This is generated by the model and should be passed back with the raw output.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


25
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 25

required :max_output_length, Integer, nil?: true

#outputArray<OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Output>

An array of shell call output contents

Parameters:

  • value (::Array[OpenAI::Beta::BetaResponseFunctionShellToolCallOutput::Output])

Returns:



31
32
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 31

required :output,
-> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::BetaResponseFunctionShellToolCallOutput::Output] }

#statusSymbol, OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Status

The status of the shell call output. One of in_progress, completed, or incomplete.

Parameters:

  • value (OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::status)

Returns:



39
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 39

required :status, enum: -> { OpenAI::Beta::BetaResponseFunctionShellToolCallOutput::Status }

#typeSymbol, :shell_call_output

The type of the shell call output. Always shell_call_output.

Parameters:

  • value (:shell_call_output)

Returns:

  • (Symbol, :shell_call_output)


45
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 45

required :type, const: :shell_call_output

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 199

Instance Method Details

#to_hash{

Returns:

  • ({)


56
# File 'sig/openai/models/beta/beta_response_function_shell_tool_call_output.rbs', line 56

def to_hash: -> {