Class: OpenAI::Models::Beta::BetaResponseFunctionToolCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseFunctionToolCall
- Defined in:
- lib/openai/models/beta/beta_response_function_tool_call.rb,
sig/openai/models/beta/beta_response_function_tool_call.rbs
Direct Known Subclasses
Defined Under Namespace
Modules: Caller, Status Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseFunctionToolCall::Agent?
The agent that produced this item.
-
#arguments ⇒ String
A JSON string of the arguments to pass to the function.
-
#call_id ⇒ String
The unique ID of the function tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseFunctionToolCall::Caller::Direct, ...
The execution context that produced this tool call.
-
#id ⇒ String?
The unique ID of the function tool call.
-
#name ⇒ String
The name of the function to run.
-
#namespace ⇒ String?
The namespace of the function to run.
-
#status ⇒ Symbol, ...
The status of the item.
-
#type ⇒ Symbol, :function_call
The type of the function tool call.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caller_id:, type: :program) ⇒ Object
|
|
# File 'lib/openai/models/beta/beta_response_function_tool_call.rb', line 65
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseFunctionToolCall::Agent?
The agent that produced this item.
41 |
# File 'lib/openai/models/beta/beta_response_function_tool_call.rb', line 41 optional :agent, -> { OpenAI::Beta::BetaResponseFunctionToolCall::Agent }, nil?: true |
#arguments ⇒ String
A JSON string of the arguments to pass to the function.
11 |
# File 'lib/openai/models/beta/beta_response_function_tool_call.rb', line 11 required :arguments, String |
#call_id ⇒ String
The unique ID of the function tool call generated by the model.
17 |
# File 'lib/openai/models/beta/beta_response_function_tool_call.rb', line 17 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseFunctionToolCall::Caller::Direct, ...
The execution context that produced this tool call.
47 48 49 50 |
# File 'lib/openai/models/beta/beta_response_function_tool_call.rb', line 47 optional :caller_, union: -> { OpenAI::Beta::BetaResponseFunctionToolCall::Caller }, api_name: :caller, nil?: true |
#id ⇒ String?
The unique ID of the function tool call.
35 |
# File 'lib/openai/models/beta/beta_response_function_tool_call.rb', line 35 optional :id, String |
#name ⇒ String
The name of the function to run.
23 |
# File 'lib/openai/models/beta/beta_response_function_tool_call.rb', line 23 required :name, String |
#namespace ⇒ String?
The namespace of the function to run.
56 |
# File 'lib/openai/models/beta/beta_response_function_tool_call.rb', line 56 optional :namespace, String |
#status ⇒ Symbol, ...
The status of the item. One of in_progress, completed, or incomplete.
Populated when items are returned via API.
63 |
# File 'lib/openai/models/beta/beta_response_function_tool_call.rb', line 63 optional :status, enum: -> { OpenAI::Beta::BetaResponseFunctionToolCall::Status } |
#type ⇒ Symbol, :function_call
The type of the function tool call. Always function_call.
29 |
# File 'lib/openai/models/beta/beta_response_function_tool_call.rb', line 29 required :type, const: :function_call |
Class Method Details
.variants ⇒ Array(OpenAI::Models::Beta::BetaResponseFunctionToolCall::Caller::Direct, OpenAI::Models::Beta::BetaResponseFunctionToolCall::Caller::Program)
|
|
# File 'lib/openai/models/beta/beta_response_function_tool_call.rb', line 145
|
Instance Method Details
#to_hash ⇒ {
58 |
# File 'sig/openai/models/beta/beta_response_function_tool_call.rbs', line 58
def to_hash: -> {
|