Class: OpenAI::Models::Beta::BetaResponseFunctionToolCallOutputItem

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_function_tool_call_output_item.rb,
sig/openai/models/beta/beta_response_function_tool_call_output_item.rbs

Defined Under Namespace

Modules: Caller, Output, Status Classes: Agent

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_name:) ⇒ Object

The agent that produced this item.

Parameters:

  • agent_name (String)

    The canonical name of the agent that produced this item.



# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 60

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseFunctionToolCallOutputItem::Agent?

The agent that produced this item.

Parameters:

  • value (OpenAI::Beta::BetaResponseFunctionToolCallOutputItem::Agent, nil)

Returns:



43
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 43

optional :agent, -> { OpenAI::Beta::BetaResponseFunctionToolCallOutputItem::Agent }, nil?: true

#call_idString

The unique ID of the function tool call generated by the model.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 17

required :call_id, String

#caller_OpenAI::Models::Beta::BetaResponseFunctionToolCallOutputItem::Caller::Direct, ...

The execution context that produced this tool call.

Parameters:

  • value (OpenAI::Models::Beta::BetaResponseFunctionToolCallOutputItem::caller_, nil)

Returns:



49
50
51
52
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 49

optional :caller_,
union: -> { OpenAI::Beta::BetaResponseFunctionToolCallOutputItem::Caller },
api_name: :caller,
nil?: true

#created_byString?

The identifier of the actor that created the item.

Parameters:

  • (String)

Returns:

  • (String, nil)


58
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 58

optional :created_by, String

#idString

The unique ID of the function call tool output.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 11

required :id, String

#outputString, Array<OpenAI::Models::Beta::BetaResponseInputText, OpenAI::Models::Beta::BetaResponseInputImage, OpenAI::Models::Beta::BetaResponseInputFile>

The output from the function call generated by your code. Can be a string or an list of output content.

Parameters:

  • value (OpenAI::Models::Beta::BetaResponseFunctionToolCallOutputItem::output)

Returns:



24
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 24

required :output, union: -> { OpenAI::Beta::BetaResponseFunctionToolCallOutputItem::Output }

#statusSymbol, OpenAI::Models::Beta::BetaResponseFunctionToolCallOutputItem::Status

The status of the item. One of in_progress, completed, or incomplete. Populated when items are returned via API.

Parameters:

  • value (OpenAI::Models::Beta::BetaResponseFunctionToolCallOutputItem::status)

Returns:



31
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 31

required :status, enum: -> { OpenAI::Beta::BetaResponseFunctionToolCallOutputItem::Status }

#typeSymbol, :function_call_output

The type of the function tool call output. Always function_call_output.

Parameters:

  • value (:function_call_output)

Returns:

  • (Symbol, :function_call_output)


37
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 37

required :type, const: :function_call_output

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 133

Instance Method Details

#to_hash{

Returns:

  • ({)


48
# File 'sig/openai/models/beta/beta_response_function_tool_call_output_item.rbs', line 48

def to_hash: -> {