Module: OpenAI::Models::Beta::BetaResponseInputFileContent::Detail

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/beta/beta_response_input_file_content.rb,
sig/openai/models/beta/beta_response_input_file_content.rbs

Overview

The detail level of the file to be sent to the model. Use auto to let the system select the detail level; for GPT-5.6 and later models, auto uses high-quality rendering, which may increase input token usage. Use low for lower-cost rendering, or high to render the file at higher quality. Defaults to auto.

See Also:

  • OpenAI::Models::Beta::BetaResponseInputFileContent#detail

Constant Summary collapse

AUTO =

Returns:

  • (:auto)
:auto
LOW =

Returns:

  • (:low)
:low
HIGH =

Returns:

  • (:high)
:high

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[OpenAI::Models::Beta::BetaResponseInputFileContent::detail]

Returns:

  • (::Array[OpenAI::Models::Beta::BetaResponseInputFileContent::detail])


65
# File 'sig/openai/models/beta/beta_response_input_file_content.rbs', line 65

def self?.values: -> ::Array[OpenAI::Models::Beta::BetaResponseInputFileContent::detail]