Class: OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_input_item.rb

Defined Under Namespace

Modules: Caller, Operation, Status Classes: Agent

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_name:) ⇒ Object

The agent that produced this item.

Parameters:

  • agent_name (String)

    The canonical name of the agent that produced this item.



# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1910

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Agent?

The agent that produced this item.



1897
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1897

optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCall::Agent }, nil?: true

#call_idString

The unique ID of the apply patch tool call generated by the model.

Returns:

  • (String)


1865
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1865

required :call_id, String

#caller_OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Caller::Direct, ...

The execution context that produced this tool call.



1903
1904
1905
1906
1907
1908
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1903

optional(
  :caller_,
  union: -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCall::Caller },
  api_name: :caller,
  nil?: true
)

#idString?

The unique ID of the apply patch tool call. Populated when this item is returned via API.

Returns:

  • (String, nil)


1891
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1891

optional :id, String, nil?: true

#operationOpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Operation::CreateFile, ...

The specific create, delete, or update instruction for the apply_patch tool call.



1872
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1872

required :operation, union: -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCall::Operation }

#statusSymbol, OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Status

The status of the apply patch tool call. One of in_progress or completed.



1878
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1878

required :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCall::Status }

#typeSymbol, :apply_patch_call

The type of the item. Always apply_patch_call.

Returns:

  • (Symbol, :apply_patch_call)


1884
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1884

required :type, const: :apply_patch_call