Class: OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_input_item.rb

Defined Under Namespace

Modules: Caller, Status Classes: Agent

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_name:) ⇒ Object

The agent that produced this item.

Parameters:

  • agent_name (String)

    The canonical name of the agent that produced this item.



# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2470

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Agent?

The agent that produced this item.



2450
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2450

optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Agent }, nil?: true

#call_idString

The unique ID of the apply patch tool call generated by the model.

Returns:

  • (String)


2425
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2425

required :call_id, String

#caller_OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Caller::Direct, ...

The execution context that produced this tool call.



2456
2457
2458
2459
2460
2461
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2456

optional(
  :caller_,
  union: -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Caller },
  api_name: :caller,
  nil?: true
)

#idString?

The unique ID of the apply patch tool call output. Populated when this item is returned via API.

Returns:

  • (String, nil)


2444
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2444

optional :id, String, nil?: true

#outputString?

Optional human-readable log text from the apply patch tool (e.g., patch results or errors).

Returns:

  • (String, nil)


2468
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2468

optional :output, String, nil?: true

#statusSymbol, OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Status

The status of the apply patch tool call output. One of completed or failed.



2431
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2431

required :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Status }

#typeSymbol, :apply_patch_call_output

The type of the item. Always apply_patch_call_output.

Returns:

  • (Symbol, :apply_patch_call_output)


2437
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2437

required :type, const: :apply_patch_call_output

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2505