Class: OpenAI::Models::Beta::BetaResponseInputItem::ComputerCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_input_item.rb

Defined Under Namespace

Modules: Status Classes: AcknowledgedSafetyCheck, Agent

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_name:) ⇒ Object

The agent that produced this item.

Parameters:

  • agent_name (String)

    The canonical name of the agent that produced this item.



# File 'lib/openai/models/beta/beta_response_input_item.rb', line 347

Instance Attribute Details

#acknowledged_safety_checksArray<OpenAI::Models::Beta::BetaResponseInputItem::ComputerCallOutput::AcknowledgedSafetyCheck>?

The safety checks reported by the API that have been acknowledged by the developer.



274
275
276
277
278
279
280
281
282
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 274

optional(
  :acknowledged_safety_checks,
  -> {
    OpenAI::Internal::Type::ArrayOf[
      OpenAI::Beta::BetaResponseInputItem::ComputerCallOutput::AcknowledgedSafetyCheck
    ]
  },
  nil?: true
)

#agentOpenAI::Models::Beta::BetaResponseInputItem::ComputerCallOutput::Agent?

The agent that produced this item.



288
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 288

optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ComputerCallOutput::Agent }, nil?: true

#call_idString

The ID of the computer tool call that produced the output.

Returns:

  • (String)


249
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 249

required :call_id, String

#idString?

The ID of the computer tool call output.

Returns:

  • (String, nil)


267
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 267

optional :id, String, nil?: true

#outputOpenAI::Models::Beta::BetaResponseComputerToolCallOutputScreenshot

A computer screenshot image used with the computer use tool.



255
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 255

required :output, -> { OpenAI::Beta::BetaResponseComputerToolCallOutputScreenshot }

#statusSymbol, ...

The status of the message input. One of in_progress, completed, or incomplete. Populated when input items are returned via API.



295
296
297
298
299
300
301
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 295

optional(
  :status,
  enum: -> {
    OpenAI::Beta::BetaResponseInputItem::ComputerCallOutput::Status
  },
  nil?: true
)

#typeSymbol, :computer_call_output

The type of the computer tool call output. Always computer_call_output.

Returns:

  • (Symbol, :computer_call_output)


261
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 261

required :type, const: :computer_call_output