Class: OpenAI::Models::Beta::BetaResponseInputItem::FunctionCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_input_item.rb

Defined Under Namespace

Modules: Caller, Output, Status Classes: Agent

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(caller_id:, type: :program) ⇒ Object

Parameters:

  • caller_id (String)

    The call ID of the program item that produced this tool call.

  • type (Symbol, :program) (defaults to: :program)

    The caller type. Always program.



# File 'lib/openai/models/beta/beta_response_input_item.rb', line 441

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseInputItem::FunctionCallOutput::Agent?

The agent that produced this item.



403
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 403

optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::FunctionCallOutput::Agent }, nil?: true

#call_idString

The unique ID of the function tool call generated by the model.

Returns:

  • (String)


378
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 378

required :call_id, String

#caller_OpenAI::Models::Beta::BetaResponseInputItem::FunctionCallOutput::Caller::Direct, ...

The execution context that produced this tool call.



409
410
411
412
413
414
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 409

optional(
  :caller_,
  union: -> { OpenAI::Beta::BetaResponseInputItem::FunctionCallOutput::Caller },
  api_name: :caller,
  nil?: true
)

#idString?

The unique ID of the function tool call output. Populated when this item is returned via API.

Returns:

  • (String, nil)


397
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 397

optional :id, String, nil?: true

#nameString?

The name of the tool that produced the output.

Returns:

  • (String, nil)


420
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 420

optional :name, String, nil?: true

#namespaceString?

The namespace of the tool that produced the output.

Returns:

  • (String, nil)


426
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 426

optional :namespace, String, nil?: true

#outputString, Array<OpenAI::Models::Beta::BetaResponseInputTextContent, OpenAI::Models::Beta::BetaResponseInputImageContent, OpenAI::Models::Beta::BetaResponseInputFileContent>

Text, image, or file output of the function tool call.



384
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 384

required :output, union: -> { OpenAI::Beta::BetaResponseInputItem::FunctionCallOutput::Output }

#statusSymbol, ...

The status of the item. One of in_progress, completed, or incomplete. Populated when items are returned via API.



433
434
435
436
437
438
439
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 433

optional(
  :status,
  enum: -> {
    OpenAI::Beta::BetaResponseInputItem::FunctionCallOutput::Status
  },
  nil?: true
)

#typeSymbol, :function_call_output

The type of the function tool call output. Always function_call_output.

Returns:

  • (Symbol, :function_call_output)


390
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 390

required :type, const: :function_call_output