Class: OpenAI::Models::Beta::BetaResponseInputItem::ImageGenerationCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_input_item.rb

Defined Under Namespace

Modules: Action, Background, OutputFormat, Quality, Size, Status Classes: Agent

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_name:) ⇒ Object

The agent that produced this item.

Parameters:

  • agent_name (String)

    The canonical name of the agent that produced this item.



# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1364

Instance Attribute Details

#actionSymbol, ...

The action used for image generation.



1303
1304
1305
1306
1307
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1303

optional(
  :action,
  enum: -> { OpenAI::Beta::BetaResponseInputItem::ImageGenerationCall::Action },
  nil?: true
)

#agentOpenAI::Models::Beta::BetaResponseInputItem::ImageGenerationCall::Agent?

The agent that produced this item.



1313
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1313

optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ImageGenerationCall::Agent }, nil?: true

#backgroundSymbol, ...

The background setting used for generation.



1319
1320
1321
1322
1323
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1319

optional(
  :background,
  enum: -> { OpenAI::Beta::BetaResponseInputItem::ImageGenerationCall::Background },
  nil?: true
)

#idString

The unique ID of the image generation call.

Returns:

  • (String)


1279
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1279

required :id, String

#output_formatSymbol, ...

The output format used for generation.



1329
1330
1331
1332
1333
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1329

optional(
  :output_format,
  enum: -> { OpenAI::Beta::BetaResponseInputItem::ImageGenerationCall::OutputFormat },
  nil?: true
)

#qualitySymbol, ...

The quality of the image generated by the image generation tool call. One of low, medium, high, xhigh, max, or auto.



1340
1341
1342
1343
1344
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1340

optional(
  :quality,
  enum: -> { OpenAI::Beta::BetaResponseInputItem::ImageGenerationCall::Quality },
  nil?: true
)

#resultString?

The generated image encoded in base64.

Returns:

  • (String, nil)


1285
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1285

required :result, String, nil?: true

#revised_promptString?

The prompt that was used after any model prompt rewriting.

Returns:

  • (String, nil)


1350
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1350

optional :revised_prompt, String, nil?: true

#sizeString, ...

The image dimensions as a WIDTHxHEIGHT string, for example 1536x864.



1356
1357
1358
1359
1360
1361
1362
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1356

optional(
  :size,
  union: -> {
    OpenAI::Beta::BetaResponseInputItem::ImageGenerationCall::Size
  },
  nil?: true
)

#statusSymbol, OpenAI::Models::Beta::BetaResponseInputItem::ImageGenerationCall::Status

The status of the image generation call.



1291
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1291

required :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::ImageGenerationCall::Status }

#typeSymbol, :image_generation_call

The type of the image generation call. Always image_generation_call.

Returns:

  • (Symbol, :image_generation_call)


1297
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1297

required :type, const: :image_generation_call

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1412