Class: OpenAI::Models::Beta::BetaResponseInputItem::LocalShellCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseInputItem::LocalShellCall
- Defined in:
- lib/openai/models/beta/beta_response_input_item.rb
Defined Under Namespace
Modules: Status Classes: Action, Agent
Instance Attribute Summary collapse
-
#action ⇒ OpenAI::Models::Beta::BetaResponseInputItem::LocalShellCall::Action
Execute a shell command on the server.
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::LocalShellCall::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The unique ID of the local shell tool call generated by the model.
-
#id ⇒ String
The unique ID of the local shell call.
-
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseInputItem::LocalShellCall::Status
The status of the local shell call.
-
#type ⇒ Symbol, :local_shell_call
The type of the local shell call.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(command:, env:, timeout_ms: nil, user: nil, working_directory: nil, type: :exec) ⇒ Object
constructor
Execute a shell command on the server.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(command:, env:, timeout_ms: nil, user: nil, working_directory: nil, type: :exec) ⇒ Object
Execute a shell command on the server.
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1274
|
Instance Attribute Details
#action ⇒ OpenAI::Models::Beta::BetaResponseInputItem::LocalShellCall::Action
Execute a shell command on the server.
1248 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1248 required :action, -> { OpenAI::Beta::BetaResponseInputItem::LocalShellCall::Action } |
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::LocalShellCall::Agent?
The agent that produced this item.
1272 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1272 optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::LocalShellCall::Agent }, nil?: true |
#call_id ⇒ String
The unique ID of the local shell tool call generated by the model.
1254 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1254 required :call_id, String |
#id ⇒ String
The unique ID of the local shell call.
1242 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1242 required :id, String |
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseInputItem::LocalShellCall::Status
The status of the local shell call.
1260 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1260 required :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::LocalShellCall::Status } |
#type ⇒ Symbol, :local_shell_call
The type of the local shell call. Always local_shell_call.
1266 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1266 required :type, const: :local_shell_call |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1356
|