Class: OpenAI::Models::Beta::BetaResponseInputItem::LocalShellCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseInputItem::LocalShellCallOutput
- Defined in:
- lib/openai/models/beta/beta_response_input_item.rb
Defined Under Namespace
Modules: Status Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::LocalShellCallOutput::Agent?
The agent that produced this item.
-
#id ⇒ String
The unique ID of the local shell tool call generated by the model.
-
#output ⇒ String
A JSON string of the output of the local shell tool call.
-
#status ⇒ Symbol, ...
The status of the item.
-
#type ⇒ Symbol, :local_shell_call_output
The type of the local shell tool call output.
Instance Method Summary collapse
-
#initialize(agent_name:) ⇒ Object
constructor
The agent that produced this item.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_name:) ⇒ Object
The agent that produced this item.
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1408
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::LocalShellCallOutput::Agent?
The agent that produced this item.
1398 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1398 optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::LocalShellCallOutput::Agent }, nil?: true |
#id ⇒ String
The unique ID of the local shell tool call generated by the model.
1380 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1380 required :id, String |
#output ⇒ String
A JSON string of the output of the local shell tool call.
1386 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1386 required :output, String |
#status ⇒ Symbol, ...
The status of the item. One of in_progress, completed, or incomplete.
1404 1405 1406 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1404 optional :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::LocalShellCallOutput::Status }, nil?: true |
#type ⇒ Symbol, :local_shell_call_output
The type of the local shell tool call output. Always local_shell_call_output.
1392 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1392 required :type, const: :local_shell_call_output |