Class: OpenAI::Models::Beta::BetaResponseInputItem::McpCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_input_item.rb

Defined Under Namespace

Modules: Status Classes: Agent

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_name:) ⇒ Object

The agent that produced this item.

Parameters:

  • agent_name (String)

    The canonical name of the agent that produced this item.



# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2521

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseInputItem::McpCall::Agent?

The agent that produced this item.



2492
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2492

optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::McpCall::Agent }, nil?: true

#approval_request_idString?

Unique identifier for the MCP tool call approval request. Include this value in a subsequent mcp_approval_response input to approve or reject the corresponding tool call.

Returns:

  • (String, nil)


2500
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2500

optional :approval_request_id, String, nil?: true

#argumentsString

A JSON string of the arguments passed to the tool.

Returns:

  • (String)


2468
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2468

required :arguments, String

#errorString?

The error from the tool call, if any.

Returns:

  • (String, nil)


2506
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2506

optional :error, String, nil?: true

#idString

The unique ID of the tool call.

Returns:

  • (String)


2462
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2462

required :id, String

#nameString

The name of the tool that was run.

Returns:

  • (String)


2474
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2474

required :name, String

#outputString?

The output from the tool call.

Returns:

  • (String, nil)


2512
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2512

optional :output, String, nil?: true

#server_labelString

The label of the MCP server running the tool.

Returns:

  • (String)


2480
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2480

required :server_label, String

#statusSymbol, ...

The status of the tool call. One of in_progress, completed, incomplete, calling, or failed.



2519
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2519

optional :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::McpCall::Status }

#typeSymbol, :mcp_call

The type of the item. Always mcp_call.

Returns:

  • (Symbol, :mcp_call)


2486
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2486

required :type, const: :mcp_call