Module: OpenAI::Models::Beta::BetaResponseInputItem::MultiAgentCallOutput::Output::Annotations

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/beta/beta_response_input_item.rb

Overview

Citations associated with the text content.

See Also:

  • OpenAI::Models::Beta::BetaResponseInputItem::MultiAgentCallOutput::Output#annotations

Defined Under Namespace

Classes: UnionMember0, UnionMember1, UnionMember2

Constant Summary collapse

UnionMember0Array =
OpenAI::Internal::Type::ArrayOf[-> {
  OpenAI::Beta::BetaResponseInputItem::MultiAgentCallOutput::Output::Annotations::UnionMember0
}]
UnionMember1Array =
OpenAI::Internal::Type::ArrayOf[-> {
  OpenAI::Beta::BetaResponseInputItem::MultiAgentCallOutput::Output::Annotations::UnionMember1
}]
UnionMember2Array =
OpenAI::Internal::Type::ArrayOf[-> {
  OpenAI::Beta::BetaResponseInputItem::MultiAgentCallOutput::Output::Annotations::UnionMember2
}]

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(container_id:, end_index:, file_id:, filename:, start_index:, type: :container_file_citation) ⇒ Object

Parameters:

  • container_id (String)

    The ID of the container.

  • end_index (Integer)

    The index of the last character of the citation in the message.

  • file_id (String)

    The ID of the container file.

  • filename (String)

    The filename of the container file cited.

  • start_index (Integer)

    The index of the first character of the citation in the message.

  • type (Symbol, :container_file_citation) (defaults to: :container_file_citation)

    The citation type. Always container_file_citation.



# File 'lib/openai/models/beta/beta_response_input_item.rb', line 856