Class: OpenAI::Models::Beta::BetaResponseInputItem::MultiAgentCallOutput::Output::Annotations::UnionMember0
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseInputItem::MultiAgentCallOutput::Output::Annotations::UnionMember0
- Defined in:
- lib/openai/models/beta/beta_response_input_item.rb
Instance Attribute Summary collapse
-
#file_id ⇒ String
The ID of the file.
-
#filename ⇒ String
The filename of the file cited.
-
#index ⇒ Integer
The index of the file in the list of files.
-
#type ⇒ Symbol, :file_citation
The citation type.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#file_id ⇒ String
The ID of the file.
836 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 836 required :file_id, String |
#filename ⇒ String
The filename of the file cited.
842 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 842 required :filename, String |
#index ⇒ Integer
The index of the file in the list of files.
848 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 848 required :index, Integer |
#type ⇒ Symbol, :file_citation
The citation type. Always file_citation.
854 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 854 required :type, const: :file_citation |