Class: OpenAI::Models::Beta::BetaResponseInputItem::MultiAgentCallOutput::Output::Annotations::UnionMember2
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseInputItem::MultiAgentCallOutput::Output::Annotations::UnionMember2
- Defined in:
- lib/openai/models/beta/beta_response_input_item.rb
Instance Attribute Summary collapse
-
#container_id ⇒ String
The ID of the container.
-
#end_index ⇒ Integer
The index of the last character of the citation in the message.
-
#file_id ⇒ String
The ID of the container file.
-
#filename ⇒ String
The filename of the container file cited.
-
#start_index ⇒ Integer
The index of the first character of the citation in the message.
-
#type ⇒ Symbol, :container_file_citation
The citation type.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#container_id ⇒ String
The ID of the container.
914 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 914 required :container_id, String |
#end_index ⇒ Integer
The index of the last character of the citation in the message.
920 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 920 required :end_index, Integer |
#file_id ⇒ String
The ID of the container file.
926 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 926 required :file_id, String |
#filename ⇒ String
The filename of the container file cited.
932 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 932 required :filename, String |
#start_index ⇒ Integer
The index of the first character of the citation in the message.
938 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 938 required :start_index, Integer |
#type ⇒ Symbol, :container_file_citation
The citation type. Always container_file_citation.
944 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 944 required :type, const: :container_file_citation |