Class: OpenAI::Models::Beta::BetaResponseInputItem::ShellCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_input_item.rb

Defined Under Namespace

Modules: Caller, Status Classes: Agent

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(caller_id:, type: :program) ⇒ Object

Parameters:

  • caller_id (String)

    The call ID of the program item that produced this tool call.

  • type (Symbol, :program) (defaults to: :program)

    The caller type. Always program.



# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1763

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseInputItem::ShellCallOutput::Agent?

The agent that produced this item.



1731
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1731

optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ShellCallOutput::Agent }, nil?: true

#call_idString

The unique ID of the shell tool call generated by the model.

Returns:

  • (String)


1702
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1702

required :call_id, String

#caller_OpenAI::Models::Beta::BetaResponseInputItem::ShellCallOutput::Caller::Direct, ...

The execution context that produced this tool call.



1737
1738
1739
1740
1741
1742
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1737

optional(
  :caller_,
  union: -> { OpenAI::Beta::BetaResponseInputItem::ShellCallOutput::Caller },
  api_name: :caller,
  nil?: true
)

#idString?

The unique ID of the shell tool call output. Populated when this item is returned via API.

Returns:

  • (String, nil)


1725
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1725

optional :id, String, nil?: true

#max_output_lengthInteger?

The maximum number of UTF-8 characters captured for this shell call's combined output.

Returns:

  • (Integer, nil)


1749
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1749

optional :max_output_length, Integer, nil?: true

#outputArray<OpenAI::Models::Beta::BetaResponseFunctionShellCallOutputContent>

Captured chunks of stdout and stderr output, along with their associated outcomes.



1709
1710
1711
1712
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1709

required(
  :output,
  -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::BetaResponseFunctionShellCallOutputContent] }
)

#statusSymbol, ...

The status of the shell call output.



1755
1756
1757
1758
1759
1760
1761
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1755

optional(
  :status,
  enum: -> {
    OpenAI::Beta::BetaResponseInputItem::ShellCallOutput::Status
  },
  nil?: true
)

#typeSymbol, :shell_call_output

The type of the item. Always shell_call_output.

Returns:

  • (Symbol, :shell_call_output)


1718
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1718

required :type, const: :shell_call_output