Class: OpenAI::Models::Beta::BetaResponseInputItem::ToolSearchCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_input_item.rb

Defined Under Namespace

Modules: Execution, Status Classes: Agent

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_name:) ⇒ Object

The agent that produced this item.

Parameters:

  • agent_name (String)

    The canonical name of the agent that produced this item.



# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1045

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseInputItem::ToolSearchCall::Agent?

The agent that produced this item.



1021
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1021

optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ToolSearchCall::Agent }, nil?: true

#argumentsObject

The arguments supplied to the tool search call.

Returns:

  • (Object)


1003
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1003

required :arguments, OpenAI::Internal::Type::Unknown

#call_idString?

The unique ID of the tool search call generated by the model.

Returns:

  • (String, nil)


1027
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1027

optional :call_id, String, nil?: true

#executionSymbol, ...

Whether tool search was executed by the server or by the client.



1033
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1033

optional :execution, enum: -> { OpenAI::Beta::BetaResponseInputItem::ToolSearchCall::Execution }

#idString?

The unique ID of this tool search call.

Returns:

  • (String, nil)


1015
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1015

optional :id, String, nil?: true

#statusSymbol, ...

The status of the tool search call.



1039
1040
1041
1042
1043
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1039

optional :status,
enum: -> {
  OpenAI::Beta::BetaResponseInputItem::ToolSearchCall::Status
},
nil?: true

#typeSymbol, :tool_search_call

The item type. Always tool_search_call.

Returns:

  • (Symbol, :tool_search_call)


1009
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1009

required :type, const: :tool_search_call

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1083