Class: OpenAI::Models::Beta::BetaResponseInputText

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_input_text.rb,
sig/openai/models/beta/beta_response_input_text.rbs

Defined Under Namespace

Classes: PromptCacheBreakpoint

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(text:, prompt_cache_breakpoint: nil, type: :input_text) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Beta::BetaResponseInputText for more details.

A text input to the model.

Parameters:

  • text (String)

    The text input to the model.

  • prompt_cache_breakpoint (OpenAI::Models::Beta::BetaResponseInputText::PromptCacheBreakpoint) (defaults to: nil)

    Marks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL

  • type (Symbol, :input_text) (defaults to: :input_text)

    The type of the input item. Always input_text.



# File 'lib/openai/models/beta/beta_response_input_text.rb', line 27

Instance Attribute Details

#prompt_cache_breakpointOpenAI::Models::Beta::BetaResponseInputText::PromptCacheBreakpoint?

Marks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL from the request's prompt_cache_options.ttl; the boundary is not rounded to a token block.



25
# File 'lib/openai/models/beta/beta_response_input_text.rb', line 25

optional :prompt_cache_breakpoint, -> { OpenAI::Beta::BetaResponseInputText::PromptCacheBreakpoint }

#textString

The text input to the model.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/openai/models/beta/beta_response_input_text.rb', line 11

required :text, String

#typeSymbol, :input_text

The type of the input item. Always input_text.

Parameters:

  • value (:input_text)

Returns:

  • (Symbol, :input_text)


17
# File 'lib/openai/models/beta/beta_response_input_text.rb', line 17

required :type, const: :input_text

Instance Method Details

#to_hash{

Returns:

  • ({)


30
# File 'sig/openai/models/beta/beta_response_input_text.rbs', line 30

def to_hash: -> {