Class: OpenAI::Models::Beta::BetaResponseItem::AgentMessage::Content::ComputerScreenshot
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseItem::AgentMessage::Content::ComputerScreenshot
- Defined in:
- lib/openai/models/beta/beta_response_item.rb
Defined Under Namespace
Modules: Detail Classes: PromptCacheBreakpoint
Instance Attribute Summary collapse
-
#detail ⇒ Symbol, OpenAI::Models::Beta::BetaResponseItem::AgentMessage::Content::ComputerScreenshot::Detail
The detail level of the screenshot image to be sent to the model.
-
#file_id ⇒ String?
The identifier of an uploaded file that contains the screenshot.
-
#image_url ⇒ String?
The URL of the screenshot image.
-
#prompt_cache_breakpoint ⇒ OpenAI::Models::Beta::BetaResponseItem::AgentMessage::Content::ComputerScreenshot::PromptCacheBreakpoint?
Marks the exact end of a reusable prompt prefix.
-
#type ⇒ Symbol, :computer_screenshot
Specifies the event type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(detail:, file_id:, image_url:, prompt_cache_breakpoint: nil, type: :computer_screenshot) ⇒ Object
constructor
Some parameter documentations has been truncated, see ComputerScreenshot for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(detail:, file_id:, image_url:, prompt_cache_breakpoint: nil, type: :computer_screenshot) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Beta::BetaResponseItem::AgentMessage::Content::ComputerScreenshot for more details.
A screenshot of a computer.
|
|
# File 'lib/openai/models/beta/beta_response_item.rb', line 289
|
Instance Attribute Details
#detail ⇒ Symbol, OpenAI::Models::Beta::BetaResponseItem::AgentMessage::Content::ComputerScreenshot::Detail
The detail level of the screenshot image to be sent to the model. One of high,
low, auto, or original. Defaults to auto.
258 259 |
# File 'lib/openai/models/beta/beta_response_item.rb', line 258 required :detail, enum: -> { OpenAI::Beta::BetaResponseItem::AgentMessage::Content::ComputerScreenshot::Detail } |
#file_id ⇒ String?
The identifier of an uploaded file that contains the screenshot.
265 |
# File 'lib/openai/models/beta/beta_response_item.rb', line 265 required :file_id, String, nil?: true |
#image_url ⇒ String?
The URL of the screenshot image.
271 |
# File 'lib/openai/models/beta/beta_response_item.rb', line 271 required :image_url, String, nil?: true |
#prompt_cache_breakpoint ⇒ OpenAI::Models::Beta::BetaResponseItem::AgentMessage::Content::ComputerScreenshot::PromptCacheBreakpoint?
Marks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL
from the request's prompt_cache_options.ttl; the boundary is not rounded to a
token block.
286 287 |
# File 'lib/openai/models/beta/beta_response_item.rb', line 286 optional :prompt_cache_breakpoint, -> { OpenAI::Beta::BetaResponseItem::AgentMessage::Content::ComputerScreenshot::PromptCacheBreakpoint } |
#type ⇒ Symbol, :computer_screenshot
Specifies the event type. For a computer screenshot, this property is always set
to computer_screenshot.
278 |
# File 'lib/openai/models/beta/beta_response_item.rb', line 278 required :type, const: :computer_screenshot |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_response_item.rb', line 318
|