Class: OpenAI::Models::Beta::BetaResponseItem::LocalShellCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_item.rb

Defined Under Namespace

Modules: Status Classes: Agent

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_name:) ⇒ Object

The agent that produced this item.

Parameters:

  • agent_name (String)

    The canonical name of the agent that produced this item.



# File 'lib/openai/models/beta/beta_response_item.rb', line 1013

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseItem::LocalShellCallOutput::Agent?

The agent that produced this item.



1001
# File 'lib/openai/models/beta/beta_response_item.rb', line 1001

optional :agent, -> { OpenAI::Beta::BetaResponseItem::LocalShellCallOutput::Agent }, nil?: true

#idString

The unique ID of the local shell tool call generated by the model.

Returns:

  • (String)


983
# File 'lib/openai/models/beta/beta_response_item.rb', line 983

required :id, String

#outputString

A JSON string of the output of the local shell tool call.

Returns:

  • (String)


989
# File 'lib/openai/models/beta/beta_response_item.rb', line 989

required :output, String

#statusSymbol, ...

The status of the item. One of in_progress, completed, or incomplete.



1007
1008
1009
1010
1011
# File 'lib/openai/models/beta/beta_response_item.rb', line 1007

optional :status,
enum: -> {
  OpenAI::Beta::BetaResponseItem::LocalShellCallOutput::Status
},
nil?: true

#typeSymbol, :local_shell_call_output

The type of the local shell tool call output. Always local_shell_call_output.

Returns:

  • (Symbol, :local_shell_call_output)


995
# File 'lib/openai/models/beta/beta_response_item.rb', line 995

required :type, const: :local_shell_call_output