Class: OpenAI::Models::Beta::BetaResponseItem::McpApprovalRequest::Agent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseItem::McpApprovalRequest::Agent
- Defined in:
- lib/openai/models/beta/beta_response_item.rb
Overview
Instance Attribute Summary collapse
-
#agent_name ⇒ String
The canonical name of the agent that produced this item.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#agent_name ⇒ String
The canonical name of the agent that produced this item.
1230 |
# File 'lib/openai/models/beta/beta_response_item.rb', line 1230 required :agent_name, String |