Class: OpenAI::Models::Beta::BetaResponseMcpCallArgumentsDeltaEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_mcp_call_arguments_delta_event.rb,
sig/openai/models/beta/beta_response_mcp_call_arguments_delta_event.rbs

Defined Under Namespace

Classes: Agent

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(delta:, item_id:, output_index:, sequence_number:, agent: nil, type: :"response.mcp_call_arguments.delta") ⇒ Object

Parameters:

  • delta —

    A JSON string containing the partial update to the arguments for the MCP tool call.

  • item_id —

    The unique identifier of the MCP tool call item being processed.

  • output_index —

    The index of the output item in the response's output array.

  • sequence_number —

    The sequence number of this event.

  • agent (defaults to: nil) —

    The agent that owns this multi-agent streaming event.

  • type (defaults to: :"response.mcp_call_arguments.delta") —

    The type of the event. Always 'response.mcp_call_arguments.delta'.



# File 'lib/openai/models/beta/beta_response_mcp_call_arguments_delta_event.rb', line 44

Instance Attribute Details

#agent ⇒ OpenAI::Beta::BetaResponseMcpCallArgumentsDeltaEvent::Agent?

The agent that owns this multi-agent streaming event.

Returns:

  • (OpenAI::Beta::BetaResponseMcpCallArgumentsDeltaEvent::Agent, nil)


42
# File 'lib/openai/models/beta/beta_response_mcp_call_arguments_delta_event.rb', line 42

optional :agent, -> { OpenAI::Beta::BetaResponseMcpCallArgumentsDeltaEvent::Agent }, nil?: true

#delta ⇒ String

A JSON string containing the partial update to the arguments for the MCP tool call.

Returns:

  • (String)


12
# File 'lib/openai/models/beta/beta_response_mcp_call_arguments_delta_event.rb', line 12

required :delta, String

#item_id ⇒ String

The unique identifier of the MCP tool call item being processed.

Returns:

  • (String)


18
# File 'lib/openai/models/beta/beta_response_mcp_call_arguments_delta_event.rb', line 18

required :item_id, String

#output_index ⇒ Integer

The index of the output item in the response's output array.

Returns:

  • (Integer)


24
# File 'lib/openai/models/beta/beta_response_mcp_call_arguments_delta_event.rb', line 24

required :output_index, Integer

#sequence_number ⇒ Integer

The sequence number of this event.

Returns:

  • (Integer)


30
# File 'lib/openai/models/beta/beta_response_mcp_call_arguments_delta_event.rb', line 30

required :sequence_number, Integer

#type ⇒ :"response.mcp_call_arguments.delta"

The type of the event. Always 'response.mcp_call_arguments.delta'.

Returns:

  • (:"response.mcp_call_arguments.delta")


36
# File 'lib/openai/models/beta/beta_response_mcp_call_arguments_delta_event.rb', line 36

required :type, const: :"response.mcp_call_arguments.delta"

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


58
# File 'sig/openai/models/beta/beta_response_mcp_call_arguments_delta_event.rbs', line 58

def to_hash: -> {