Class: OpenAI::Models::Beta::BetaResponseOutputAudio

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_output_audio.rb,
sig/openai/models/beta/beta_response_output_audio.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • data —

    Base64-encoded audio data from the model.

  • transcript —

    The transcript of the audio data from the model.

  • type —

    The type of the output audio. Always output_audio.



25
# File 'sig/openai/models/beta/beta_response_output_audio.rbs', line 25

def initialize: (

Instance Attribute Details

#data ⇒ String

Base64-encoded audio data from the model.

Returns:

  • (String)


11
# File 'lib/openai/models/beta/beta_response_output_audio.rb', line 11

required :data, String

#transcript ⇒ String

The transcript of the audio data from the model.

Returns:

  • (String)


17
# File 'lib/openai/models/beta/beta_response_output_audio.rb', line 17

required :transcript, String

#type ⇒ :output_audio

The type of the output audio. Always output_audio.

Returns:

  • (:output_audio)


23
# File 'lib/openai/models/beta/beta_response_output_audio.rb', line 23

required :type, const: :output_audio

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


31
# File 'sig/openai/models/beta/beta_response_output_audio.rbs', line 31

def to_hash: -> {