Class: OpenAI::Models::Beta::BetaResponseOutputItem::AgentMessage::Content::ComputerScreenshot

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_output_item.rb

Defined Under Namespace

Modules: Detail Classes: PromptCacheBreakpoint

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(detail:, file_id:, image_url:, prompt_cache_breakpoint: nil, type: :computer_screenshot) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Beta::BetaResponseOutputItem::AgentMessage::Content::ComputerScreenshot for more details.

A screenshot of a computer.

Parameters:



# File 'lib/openai/models/beta/beta_response_output_item.rb', line 288

Instance Attribute Details

#detailSymbol, OpenAI::Models::Beta::BetaResponseOutputItem::AgentMessage::Content::ComputerScreenshot::Detail

The detail level of the screenshot image to be sent to the model. One of high, low, auto, or original. Defaults to auto.



257
258
# File 'lib/openai/models/beta/beta_response_output_item.rb', line 257

required :detail,
enum: -> { OpenAI::Beta::BetaResponseOutputItem::AgentMessage::Content::ComputerScreenshot::Detail }

#file_idString?

The identifier of an uploaded file that contains the screenshot.

Returns:

  • (String, nil)


264
# File 'lib/openai/models/beta/beta_response_output_item.rb', line 264

required :file_id, String, nil?: true

#image_urlString?

The URL of the screenshot image.

Returns:

  • (String, nil)


270
# File 'lib/openai/models/beta/beta_response_output_item.rb', line 270

required :image_url, String, nil?: true

#prompt_cache_breakpointOpenAI::Models::Beta::BetaResponseOutputItem::AgentMessage::Content::ComputerScreenshot::PromptCacheBreakpoint?

Marks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL from the request's prompt_cache_options.ttl; the boundary is not rounded to a token block.



285
286
# File 'lib/openai/models/beta/beta_response_output_item.rb', line 285

optional :prompt_cache_breakpoint,
-> { OpenAI::Beta::BetaResponseOutputItem::AgentMessage::Content::ComputerScreenshot::PromptCacheBreakpoint }

#typeSymbol, :computer_screenshot

Specifies the event type. For a computer screenshot, this property is always set to computer_screenshot.

Returns:

  • (Symbol, :computer_screenshot)


277
# File 'lib/openai/models/beta/beta_response_output_item.rb', line 277

required :type, const: :computer_screenshot

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/beta_response_output_item.rb', line 317