Class: OpenAI::Models::Beta::BetaResponseOutputItem::McpListTools
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseOutputItem::McpListTools
- Defined in:
- lib/openai/models/beta/beta_response_output_item.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseOutputItem::McpListTools::Agent?
The agent that produced this item.
-
#error ⇒ String?
Error message if the server could not list tools.
-
#id ⇒ String
The unique ID of the list.
-
#server_label ⇒ String
The label of the MCP server.
-
#tools ⇒ Array<OpenAI::Models::Beta::BetaResponseOutputItem::McpListTools::Tool>
The tools available on the server.
-
#type ⇒ Symbol, :mcp_list_tools
The type of the item.
Instance Method Summary collapse
-
#initialize(input_schema:, name:, annotations: nil, description: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Tool for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(input_schema:, name:, annotations: nil, description: nil) ⇒ Object
Some parameter documentations has been truncated, see Tool for more details.
A tool available on an MCP server.
|
|
# File 'lib/openai/models/beta/beta_response_output_item.rb', line 1264
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseOutputItem::McpListTools::Agent?
The agent that produced this item.
1213 |
# File 'lib/openai/models/beta/beta_response_output_item.rb', line 1213 optional :agent, -> { OpenAI::Beta::BetaResponseOutputItem::McpListTools::Agent }, nil?: true |
#error ⇒ String?
Error message if the server could not list tools.
1219 |
# File 'lib/openai/models/beta/beta_response_output_item.rb', line 1219 optional :error, String, nil?: true |
#id ⇒ String
The unique ID of the list.
1188 |
# File 'lib/openai/models/beta/beta_response_output_item.rb', line 1188 required :id, String |
#server_label ⇒ String
The label of the MCP server.
1194 |
# File 'lib/openai/models/beta/beta_response_output_item.rb', line 1194 required :server_label, String |
#tools ⇒ Array<OpenAI::Models::Beta::BetaResponseOutputItem::McpListTools::Tool>
The tools available on the server.
1200 1201 |
# File 'lib/openai/models/beta/beta_response_output_item.rb', line 1200 required :tools, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::BetaResponseOutputItem::McpListTools::Tool] } |
#type ⇒ Symbol, :mcp_list_tools
The type of the item. Always mcp_list_tools.
1207 |
# File 'lib/openai/models/beta/beta_response_output_item.rb', line 1207 required :type, const: :mcp_list_tools |