Module: OpenAI::Models::Beta::BetaResponseOutputText::Annotation

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/beta/beta_response_output_text.rb,
sig/openai/models/beta/beta_response_output_text.rbs

Overview

An annotation that applies to a span of output text.

Defined Under Namespace

Classes: ContainerFileCitation, FileCitation, FilePath, URLCitation

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(container_id:, end_index:, file_id:, filename:, start_index:, type: :container_file_citation) ⇒ Object

A citation for a container file used to generate a model response.

Parameters:

  • container_id (String)

    The ID of the container file.

  • end_index (Integer)

    The index of the last character of the container file citation in the message.

  • file_id (String)

    The ID of the file.

  • filename (String)

    The filename of the container file cited.

  • start_index (Integer)

    The index of the first character of the container file citation in the message.

  • type (Symbol, :container_file_citation) (defaults to: :container_file_citation)

    The type of the container file citation. Always container_file_citation.



# File 'lib/openai/models/beta/beta_response_output_text.rb', line 86

#self?.variants::Array[OpenAI::Models::Beta::BetaResponseOutputText::annotation]

Returns:

  • (::Array[OpenAI::Models::Beta::BetaResponseOutputText::annotation])


183
# File 'sig/openai/models/beta/beta_response_output_text.rbs', line 183

def self?.variants: -> ::Array[OpenAI::Models::Beta::BetaResponseOutputText::annotation]