Class: OpenAI::Models::Beta::BetaResponseOutputText::Annotation::FileCitation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseOutputText::Annotation::FileCitation
- Defined in:
- lib/openai/models/beta/beta_response_output_text.rb,
sig/openai/models/beta/beta_response_output_text.rbs
Instance Attribute Summary collapse
-
#file_id ⇒ String
The ID of the file.
-
#filename ⇒ String
The filename of the file cited.
-
#index ⇒ Integer
The index of the file in the list of files.
-
#type ⇒ Symbol, :file_citation
The type of the file citation.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
67 |
# File 'sig/openai/models/beta/beta_response_output_text.rbs', line 67
def initialize: (
|
Instance Attribute Details
#file_id ⇒ String
The ID of the file.
66 |
# File 'lib/openai/models/beta/beta_response_output_text.rb', line 66 required :file_id, String |
#filename ⇒ String
The filename of the file cited.
72 |
# File 'lib/openai/models/beta/beta_response_output_text.rb', line 72 required :filename, String |
#index ⇒ Integer
The index of the file in the list of files.
78 |
# File 'lib/openai/models/beta/beta_response_output_text.rb', line 78 required :index, Integer |
#type ⇒ Symbol, :file_citation
The type of the file citation. Always file_citation.
84 |
# File 'lib/openai/models/beta/beta_response_output_text.rb', line 84 required :type, const: :file_citation |
Instance Method Details
#to_hash ⇒ {
74 |
# File 'sig/openai/models/beta/beta_response_output_text.rbs', line 74
def to_hash: -> {
|