Class: OpenAI::Models::Beta::BetaResponseOutputTextAnnotationAddedEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb,
sig/openai/models/beta/beta_response_output_text_annotation_added_event.rbs

Defined Under Namespace

Modules: Annotation Classes: Agent

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(file_id:, index:, type: :file_path) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Beta::BetaResponseOutputTextAnnotationAddedEvent::Annotation::FilePath for more details.

A path to a file.

Parameters:

  • file_id (String)

    The ID of the file.

  • index (Integer)

    The index of the file in the list of files.

  • type (Symbol, :file_path) (defaults to: :file_path)

    The type of the file path. Always file_path.



# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 57

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseOutputTextAnnotationAddedEvent::Agent?

The agent that owns this multi-agent streaming event.

Parameters:

  • value (OpenAI::Beta::BetaResponseOutputTextAnnotationAddedEvent::Agent, nil)

Returns:



55
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 55

optional :agent, -> { OpenAI::Beta::BetaResponseOutputTextAnnotationAddedEvent::Agent }, nil?: true

#annotationOpenAI::Models::Beta::BetaResponseOutputTextAnnotationAddedEvent::Annotation::FileCitation, ...

An annotation that applies to a span of output text.



11
12
13
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 11

required :annotation,
union: -> { OpenAI::Beta::BetaResponseOutputTextAnnotationAddedEvent::Annotation },
nil?: true

#annotation_indexInteger

The index of the annotation within the content part.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


19
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 19

required :annotation_index, Integer

#content_indexInteger

The index of the content part within the output item.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


25
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 25

required :content_index, Integer

#item_idString

The unique identifier of the item to which the annotation is being added.

Parameters:

  • value (String)

Returns:

  • (String)


31
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 31

required :item_id, String

#output_indexInteger

The index of the output item in the response's output array.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


37
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 37

required :output_index, Integer

#sequence_numberInteger

The sequence number of this event.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


43
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 43

required :sequence_number, Integer

#typeSymbol, :"response.output_text.annotation.added"

The type of the event. Always 'response.output_text.annotation.added'.

Parameters:

  • value (:"response.output_text.annotation.added")

Returns:

  • (Symbol, :"response.output_text.annotation.added")


49
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 49

required :type, const: :"response.output_text.annotation.added"

Instance Method Details

#to_hash{

Returns:

  • ({)


46
# File 'sig/openai/models/beta/beta_response_output_text_annotation_added_event.rbs', line 46

def to_hash: -> {