Class: OpenAI::Models::Beta::BetaResponseOutputTextAnnotationAddedEvent::Annotation::ContainerFileCitation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseOutputTextAnnotationAddedEvent::Annotation::ContainerFileCitation
- Defined in:
- lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb,
sig/openai/models/beta/beta_response_output_text_annotation_added_event.rbs
Instance Attribute Summary collapse
-
#container_id ⇒ String
The ID of the container file.
-
#end_index ⇒ Integer
The index of the last character of the container file citation in the message.
-
#file_id ⇒ String
The ID of the file.
-
#filename ⇒ String
The filename of the container file cited.
-
#start_index ⇒ Integer
The index of the first character of the container file citation in the message.
-
#type ⇒ Symbol, :container_file_citation
The type of the container file citation.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
158 |
# File 'sig/openai/models/beta/beta_response_output_text_annotation_added_event.rbs', line 158
def initialize: (
|
Instance Attribute Details
#container_id ⇒ String
The ID of the container file.
186 |
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 186 required :container_id, String |
#end_index ⇒ Integer
The index of the last character of the container file citation in the message.
192 |
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 192 required :end_index, Integer |
#file_id ⇒ String
The ID of the file.
198 |
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 198 required :file_id, String |
#filename ⇒ String
The filename of the container file cited.
204 |
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 204 required :filename, String |
#start_index ⇒ Integer
The index of the first character of the container file citation in the message.
210 |
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 210 required :start_index, Integer |
#type ⇒ Symbol, :container_file_citation
The type of the container file citation. Always container_file_citation.
216 |
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 216 required :type, const: :container_file_citation |
Instance Method Details
#to_hash ⇒ {
167 |
# File 'sig/openai/models/beta/beta_response_output_text_annotation_added_event.rbs', line 167
def to_hash: -> {
|