Class: OpenAI::Models::Beta::BetaResponseOutputTextAnnotationAddedEvent::Annotation::URLCitation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb,
sig/openai/models/beta/beta_response_output_text_annotation_added_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



118
# File 'sig/openai/models/beta/beta_response_output_text_annotation_added_event.rbs', line 118

def initialize: (

Instance Attribute Details

#end_indexInteger

The index of the last character of the URL citation in the message.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


141
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 141

required :end_index, Integer

#start_indexInteger

The index of the first character of the URL citation in the message.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


147
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 147

required :start_index, Integer

#titleString

The title of the web resource.

Parameters:

  • value (String)

Returns:

  • (String)


153
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 153

required :title, String

#typeSymbol, :url_citation

The type of the URL citation. Always url_citation.

Parameters:

  • value (:url_citation)

Returns:

  • (Symbol, :url_citation)


159
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 159

required :type, const: :url_citation

#urlString

The URL of the web resource.

Parameters:

  • value (String)

Returns:

  • (String)


165
# File 'lib/openai/models/beta/beta_response_output_text_annotation_added_event.rb', line 165

required :url, String

Instance Method Details

#to_hash{

Returns:

  • ({)


126
# File 'sig/openai/models/beta/beta_response_output_text_annotation_added_event.rbs', line 126

def to_hash: -> {