Class: OpenAI::Models::Beta::BetaResponseReasoningItem::Summary

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_reasoning_item.rb,
sig/openai/models/beta/beta_response_reasoning_item.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, summary:, agent: nil, content: nil, encrypted_content: nil, status: nil, type: :reasoning) ⇒ Summary

Returns a new instance of Summary.

Parameters:

  • text —

    A summary of the reasoning output from the model so far.

  • type (defaults to: :reasoning) —

    The type of the object. Always summary_text.

  • text: (String)
  • type: (:summary_text) (defaults to: :reasoning)


97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/openai/models/beta/beta_response_reasoning_item.rb', line 97

class Summary < OpenAI::Internal::Type::BaseModel
  # @!attribute text
  #   A summary of the reasoning output from the model so far.
  #
  #   @return [String]
  required :text, String

  # @!attribute type
  #   The type of the object. Always `summary_text`.
  #
  #   @return [Symbol, :summary_text]
  required :type, const: :summary_text

  # @!method initialize(text:, type: :summary_text)
  #   A summary text from the model.
  #
  #   @param text [String]
  #     A summary of the reasoning output from the model so far.
  #
  #   @param type [Symbol, :summary_text]
  #     The type of the object. Always `summary_text`.
end

Instance Attribute Details

#text ⇒ String

A summary of the reasoning output from the model so far.

Returns:

  • (String)


102
# File 'lib/openai/models/beta/beta_response_reasoning_item.rb', line 102

required :text, String

#type ⇒ :summary_text

The type of the object. Always summary_text.

Returns:

  • (:summary_text)


108
# File 'lib/openai/models/beta/beta_response_reasoning_item.rb', line 108

required :type, const: :summary_text

Instance Method Details

#to_hash ⇒ { text: String, ?type: :summary_text }

Returns:

  • ({ text: String, ?type: :summary_text })


115
# File 'sig/openai/models/beta/beta_response_reasoning_item.rbs', line 115

def to_hash: -> { text: String, ?type: :summary_text }