Class: OpenAI::Models::Beta::BetaResponseReasoningSummaryPartDoneEvent::Agent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseReasoningSummaryPartDoneEvent::Agent
- Defined in:
- lib/openai/models/beta/beta_response_reasoning_summary_part_done_event.rb,
sig/openai/models/beta/beta_response_reasoning_summary_part_done_event.rbs
Overview
Instance Attribute Summary collapse
-
#agent_name ⇒ String
The canonical name of the agent that produced this item.
Instance Method Summary collapse
-
#initialize ⇒ Agent
constructor
A new instance of Agent.
- #to_hash ⇒ { agent_name: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Agent
Returns a new instance of Agent.
78 |
# File 'sig/openai/models/beta/beta_response_reasoning_summary_part_done_event.rbs', line 78
def initialize: (agent_name: String) -> void
|
Instance Attribute Details
#agent_name ⇒ String
The canonical name of the agent that produced this item.
107 |
# File 'lib/openai/models/beta/beta_response_reasoning_summary_part_done_event.rb', line 107 required :agent_name, String |
Instance Method Details
#to_hash ⇒ { agent_name: String }
80 |
# File 'sig/openai/models/beta/beta_response_reasoning_summary_part_done_event.rbs', line 80
def to_hash: -> { agent_name: String }
|