Class: OpenAI::Models::Beta::BetaResponseRefusalDeltaEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseRefusalDeltaEvent
- Defined in:
- lib/openai/models/beta/beta_response_refusal_delta_event.rb,
sig/openai/models/beta/beta_response_refusal_delta_event.rbs
Defined Under Namespace
Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseRefusalDeltaEvent::Agent?
The agent that owns this multi-agent streaming event.
-
#content_index ⇒ Integer
The index of the content part that the refusal text is added to.
-
#delta ⇒ String
The refusal text that is added.
-
#item_id ⇒ String
The ID of the output item that the refusal text is added to.
-
#output_index ⇒ Integer
The index of the output item that the refusal text is added to.
-
#sequence_number ⇒ Integer
The sequence number of this event.
-
#type ⇒ Symbol, :"response.refusal.delta"
The type of the event.
Instance Method Summary collapse
-
#initialize(content_index:, delta:, item_id:, output_index:, sequence_number:, agent: nil, type: :"response.refusal.delta") ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaResponseRefusalDeltaEvent for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content_index:, delta:, item_id:, output_index:, sequence_number:, agent: nil, type: :"response.refusal.delta") ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Beta::BetaResponseRefusalDeltaEvent for more details.
Emitted when there is a partial refusal text.
|
|
# File 'lib/openai/models/beta/beta_response_refusal_delta_event.rb', line 49
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseRefusalDeltaEvent::Agent?
The agent that owns this multi-agent streaming event.
47 |
# File 'lib/openai/models/beta/beta_response_refusal_delta_event.rb', line 47 optional :agent, -> { OpenAI::Beta::BetaResponseRefusalDeltaEvent::Agent }, nil?: true |
#content_index ⇒ Integer
The index of the content part that the refusal text is added to.
11 |
# File 'lib/openai/models/beta/beta_response_refusal_delta_event.rb', line 11 required :content_index, Integer |
#delta ⇒ String
The refusal text that is added.
17 |
# File 'lib/openai/models/beta/beta_response_refusal_delta_event.rb', line 17 required :delta, String |
#item_id ⇒ String
The ID of the output item that the refusal text is added to.
23 |
# File 'lib/openai/models/beta/beta_response_refusal_delta_event.rb', line 23 required :item_id, String |
#output_index ⇒ Integer
The index of the output item that the refusal text is added to.
29 |
# File 'lib/openai/models/beta/beta_response_refusal_delta_event.rb', line 29 required :output_index, Integer |
#sequence_number ⇒ Integer
The sequence number of this event.
35 |
# File 'lib/openai/models/beta/beta_response_refusal_delta_event.rb', line 35 required :sequence_number, Integer |
#type ⇒ Symbol, :"response.refusal.delta"
The type of the event. Always response.refusal.delta.
41 |
# File 'lib/openai/models/beta/beta_response_refusal_delta_event.rb', line 41 required :type, const: :"response.refusal.delta" |
Instance Method Details
#to_hash ⇒ {
42 |
# File 'sig/openai/models/beta/beta_response_refusal_delta_event.rbs', line 42
def to_hash: -> {
|