Class: OpenAI::Models::Beta::BetaResponseShellCallCommandDeltaEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseShellCallCommandDeltaEvent
- Defined in:
- lib/openai/models/beta/beta_response_shell_call_command_delta_event.rb,
sig/openai/models/beta/beta_response_shell_call_command_delta_event.rbs
Direct Known Subclasses
OpenAI::Models::Beta::BetaResponsesServerEvent::BetaResponseShellCallCommandWsDelta, OpenAI::Models::BetaResponsesServerEvent::Beta::BetaResponsesServerEvent::BetaResponseShellCallCommandWsDelta
Defined Under Namespace
Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseShellCallCommandDeltaEvent::Agent?
The agent that owns this multi-agent streaming event.
-
#command_index ⇒ Integer
The index of the shell command that was updated.
-
#delta ⇒ String
The shell command delta that was appended.
-
#obfuscation ⇒ String?
An obfuscation string that was added to pad the event payload.
-
#output_index ⇒ Integer
The index of the output item that was updated.
-
#sequence_number ⇒ Integer
The sequence number of the event that was emitted.
-
#type ⇒ Symbol, :"response.shell_call_command.delta"
The type of the event, always
response.shell_call_command.delta.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(command_index:, delta:, output_index:, sequence_number:, agent: nil, obfuscation: nil, type: :"response.shell_call_command.delta") ⇒ Object
constructor
A streaming event that indicated a shell command was incrementally updated.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(command_index:, delta:, output_index:, sequence_number:, agent: nil, obfuscation: nil, type: :"response.shell_call_command.delta") ⇒ Object
A streaming event that indicated a shell command was incrementally updated.
|
|
# File 'lib/openai/models/beta/beta_response_shell_call_command_delta_event.rb', line 49
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseShellCallCommandDeltaEvent::Agent?
The agent that owns this multi-agent streaming event.
41 |
# File 'lib/openai/models/beta/beta_response_shell_call_command_delta_event.rb', line 41 optional :agent, -> { OpenAI::Beta::BetaResponseShellCallCommandDeltaEvent::Agent } |
#command_index ⇒ Integer
The index of the shell command that was updated.
11 |
# File 'lib/openai/models/beta/beta_response_shell_call_command_delta_event.rb', line 11 required :command_index, Integer |
#delta ⇒ String
The shell command delta that was appended.
17 |
# File 'lib/openai/models/beta/beta_response_shell_call_command_delta_event.rb', line 17 required :delta, String |
#obfuscation ⇒ String?
An obfuscation string that was added to pad the event payload.
47 |
# File 'lib/openai/models/beta/beta_response_shell_call_command_delta_event.rb', line 47 optional :obfuscation, String |
#output_index ⇒ Integer
The index of the output item that was updated.
23 |
# File 'lib/openai/models/beta/beta_response_shell_call_command_delta_event.rb', line 23 required :output_index, Integer |
#sequence_number ⇒ Integer
The sequence number of the event that was emitted.
29 |
# File 'lib/openai/models/beta/beta_response_shell_call_command_delta_event.rb', line 29 required :sequence_number, Integer |
#type ⇒ Symbol, :"response.shell_call_command.delta"
The type of the event, always response.shell_call_command.delta.
35 |
# File 'lib/openai/models/beta/beta_response_shell_call_command_delta_event.rb', line 35 required :type, const: :"response.shell_call_command.delta" |
Instance Method Details
#to_hash ⇒ {
48 |
# File 'sig/openai/models/beta/beta_response_shell_call_command_delta_event.rbs', line 48
def to_hash: -> {
|