Class: OpenAI::Models::Beta::BetaResponseShellCallOutputContentDoneEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_shell_call_output_content_done_event.rb,
sig/openai/models/beta/beta_response_shell_call_output_content_done_event.rbs

Defined Under Namespace

Classes: Agent, Output

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(exit_code:, type: :exit) ⇒ Object

Indicates that the shell commands finished and returned an exit code.

Parameters:

  • exit_code (Integer)

    Exit code from the shell process.

  • type (Symbol, :exit) (defaults to: :exit)

    The outcome type. Always exit.



# File 'lib/openai/models/beta/beta_response_shell_call_output_content_done_event.rb', line 157

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseShellCallOutputContentDoneEvent::Agent?

The agent that owns this multi-agent streaming event.



50
# File 'lib/openai/models/beta/beta_response_shell_call_output_content_done_event.rb', line 50

optional :agent, -> { OpenAI::Beta::BetaResponseShellCallOutputContentDoneEvent::Agent }

#command_indexInteger

The index of the shell command that produced output.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


11
# File 'lib/openai/models/beta/beta_response_shell_call_output_content_done_event.rb', line 11

required :command_index, Integer

#item_idString

The ID of the output item that was updated.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/openai/models/beta/beta_response_shell_call_output_content_done_event.rb', line 17

required :item_id, String

#outputArray<OpenAI::Models::Beta::BetaResponseShellCallOutputContentDoneEvent::Output>

The output contents emitted for the shell command.

Parameters:

  • value (::Array[OpenAI::Beta::BetaResponseShellCallOutputContentDoneEvent::Output])

Returns:



23
24
25
26
# File 'lib/openai/models/beta/beta_response_shell_call_output_content_done_event.rb', line 23

required(
  :output,
  -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::BetaResponseShellCallOutputContentDoneEvent::Output] }
)

#output_indexInteger

The index of the output item that was updated.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


32
# File 'lib/openai/models/beta/beta_response_shell_call_output_content_done_event.rb', line 32

required :output_index, Integer

#sequence_numberInteger

The sequence number of the event that was emitted.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


38
# File 'lib/openai/models/beta/beta_response_shell_call_output_content_done_event.rb', line 38

required :sequence_number, Integer

#typeSymbol, :"response.shell_call_output_content.done"

The type of the event, always response.shell_call_output_content.done.

Parameters:

  • value (:"response.shell_call_output_content.done")

Returns:

  • (Symbol, :"response.shell_call_output_content.done")


44
# File 'lib/openai/models/beta/beta_response_shell_call_output_content_done_event.rb', line 44

required :type, const: :"response.shell_call_output_content.done"

Instance Method Details

#to_hash{

Returns:

  • ({)


46
# File 'sig/openai/models/beta/beta_response_shell_call_output_content_done_event.rbs', line 46

def to_hash: -> {