Class: OpenAI::Models::Beta::BetaResponseSteerEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_steer_event.rb,
sig/openai/models/beta/beta_response_steer_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



20
# File 'sig/openai/models/beta/beta_response_steer_event.rbs', line 20

def initialize: (

Instance Attribute Details

#inputString, Array<Hash{Symbol=>Object}>

Input to queue for a continuation of the response. Uses the same string or input-item shape as response.create.input, with a non-empty array when supplying input items.

Steering accepts only messages with the user role. Each message may contain only type, role, and content, with content as a string or an array of input_text, input_image, and input_file parts. The optional type must be message. Other roles, tool outputs, and item types are not supported for steering.

Parameters:

  • value (OpenAI::Models::Beta::beta_response_steer_input)

Returns:

  • (String, Array<Hash{Symbol=>Object}>)


19
# File 'lib/openai/models/beta/beta_response_steer_event.rb', line 19

required :input, union: -> { OpenAI::Beta::BetaResponseSteerInput }

#previous_response_idString

The ID of the response to steer on this WebSocket connection.

Parameters:

  • value (String)

Returns:

  • (String)


25
# File 'lib/openai/models/beta/beta_response_steer_event.rb', line 25

required :previous_response_id, String

#typeSymbol, :"response.steer"

The event discriminator. Always response.steer.

Parameters:

  • value (:"response.steer")

Returns:

  • (Symbol, :"response.steer")


31
# File 'lib/openai/models/beta/beta_response_steer_event.rb', line 31

required :type, const: :"response.steer"

Instance Method Details

#to_hash{

Returns:

  • ({)


26
# File 'sig/openai/models/beta/beta_response_steer_event.rbs', line 26

def to_hash: -> {