Class: OpenAI::Models::Beta::BetaResponseSteerFailedEvent::Steer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_steer_failed_event.rb,
sig/openai/models/beta/beta_response_steer_failed_event.rbs

Overview

See Also:

  • OpenAI::Models::Beta::BetaResponseSteerFailedEvent#steer

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • input —

    Input to queue for a continuation of the response. Uses the same string or input-item shape as response.create.input, with a non-empty array when supplying input items.

    Steering accepts only messages with the user role. Each message may contain only type, role, and content, with content as a string or an array of input_text, input_image, and input_file parts. The optional type must be message. Other roles, tool outputs, and item types are not supported for steering.

  • previous_response_id —

    The ID of the response that was targeted for steering.

  • id —

    The ID assigned to the steering submission, if one was allocated.



165
# File 'sig/openai/models/beta/beta_response_steer_failed_event.rbs', line 165

def initialize: (

Instance Attribute Details

#id ⇒ String?

The ID assigned to the steering submission, if one was allocated.

Returns:

  • (String, nil)


147
# File 'lib/openai/models/beta/beta_response_steer_failed_event.rb', line 147

optional :id, String

#input ⇒ OpenAI::Models::Beta::beta_response_steer_input

Input to queue for a continuation of the response. Uses the same string or input-item shape as response.create.input, with a non-empty array when supplying input items.

Steering accepts only messages with the user role. Each message may contain only type, role, and content, with content as a string or an array of input_text, input_image, and input_file parts. The optional type must be message. Other roles, tool outputs, and item types are not supported for steering.

Returns:

  • (OpenAI::Models::Beta::beta_response_steer_input)


135
# File 'lib/openai/models/beta/beta_response_steer_failed_event.rb', line 135

required :input, union: -> { OpenAI::Beta::BetaResponseSteerInput }

#previous_response_id ⇒ String

The ID of the response that was targeted for steering.

Returns:

  • (String)


141
# File 'lib/openai/models/beta/beta_response_steer_failed_event.rb', line 141

required :previous_response_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


171
# File 'sig/openai/models/beta/beta_response_steer_failed_event.rbs', line 171

def to_hash: -> {