Class: OpenAI::Models::Beta::BetaResponseToolSearchOutputItem

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_tool_search_output_item.rb,
sig/openai/models/beta/beta_response_tool_search_output_item.rbs

Defined Under Namespace

Modules: Execution, Status Classes: Agent

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, call_id:, execution:, status:, tools:, agent: nil, created_by: nil, type: :tool_search_output) ⇒ Object

Parameters:



# File 'lib/openai/models/beta/beta_response_tool_search_output_item.rb', line 55

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseToolSearchOutputItem::Agent?

The agent that produced this item.



47
# File 'lib/openai/models/beta/beta_response_tool_search_output_item.rb', line 47

optional :agent, -> { OpenAI::Beta::BetaResponseToolSearchOutputItem::Agent }

#call_idString?

The unique ID of the tool search call generated by the model.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


17
# File 'lib/openai/models/beta/beta_response_tool_search_output_item.rb', line 17

required :call_id, String, nil?: true

#created_byString?

The identifier of the actor that created the item.

Parameters:

  • (String)

Returns:

  • (String, nil)


53
# File 'lib/openai/models/beta/beta_response_tool_search_output_item.rb', line 53

optional :created_by, String

#executionSymbol, OpenAI::Models::Beta::BetaResponseToolSearchOutputItem::Execution

Whether tool search was executed by the server or by the client.

Parameters:

  • value (OpenAI::Models::Beta::BetaResponseToolSearchOutputItem::execution)

Returns:



23
# File 'lib/openai/models/beta/beta_response_tool_search_output_item.rb', line 23

required :execution, enum: -> { OpenAI::Beta::BetaResponseToolSearchOutputItem::Execution }

#idString

The unique ID of the tool search output item.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/openai/models/beta/beta_response_tool_search_output_item.rb', line 11

required :id, String

#statusSymbol, OpenAI::Models::Beta::BetaResponseToolSearchOutputItem::Status

The status of the tool search output item that was recorded.

Parameters:

  • value (OpenAI::Models::Beta::BetaResponseToolSearchOutputItem::status)

Returns:



29
# File 'lib/openai/models/beta/beta_response_tool_search_output_item.rb', line 29

required :status, enum: -> { OpenAI::Beta::BetaResponseToolSearchOutputItem::Status }

#toolsArray<OpenAI::Models::Beta::BetaFunctionTool, OpenAI::Models::Beta::BetaFileSearchTool, OpenAI::Models::Beta::BetaComputerTool, OpenAI::Models::Beta::BetaComputerUsePreviewTool, OpenAI::Models::Beta::BetaTool::Mcp, OpenAI::Models::Beta::BetaTool::CodeInterpreter, OpenAI::Models::Beta::BetaTool::ProgrammaticToolCalling, OpenAI::Models::Beta::BetaTool::ImageGeneration, OpenAI::Models::Beta::BetaTool::LocalShell, OpenAI::Models::Beta::BetaFunctionShellTool, OpenAI::Models::Beta::BetaCustomTool, OpenAI::Models::Beta::BetaNamespaceTool, OpenAI::Models::Beta::BetaToolSearchTool, OpenAI::Models::Beta::BetaApplyPatchTool, OpenAI::Models::Beta::BetaWebSearchTool, OpenAI::Models::Beta::BetaWebSearchPreviewTool>

The loaded tool definitions returned by tool search.



35
# File 'lib/openai/models/beta/beta_response_tool_search_output_item.rb', line 35

required :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::BetaTool] }

#typeSymbol, :tool_search_output

The type of the item. Always tool_search_output.

Parameters:

  • value (:tool_search_output)

Returns:

  • (Symbol, :tool_search_output)


41
# File 'lib/openai/models/beta/beta_response_tool_search_output_item.rb', line 41

required :type, const: :tool_search_output

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/beta_response_tool_search_output_item.rb', line 81

Instance Method Details

#to_hash{

Returns:

  • ({)


52
# File 'sig/openai/models/beta/beta_response_tool_search_output_item.rbs', line 52

def to_hash: -> {