Class: OpenAI::Models::Beta::BetaResponseToolSearchOutputItemParam

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_tool_search_output_item_param.rb,
sig/openai/models/beta/beta_response_tool_search_output_item_param.rbs

Defined Under Namespace

Modules: Execution, Status Classes: Agent

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_name:) ⇒ Object

The agent that produced this item.

Parameters:

  • agent_name (String)

    The canonical name of the agent that produced this item.



# File 'lib/openai/models/beta/beta_response_tool_search_output_item_param.rb', line 49

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseToolSearchOutputItemParam::Agent?

The agent that produced this item.

Parameters:

  • value (OpenAI::Beta::BetaResponseToolSearchOutputItemParam::Agent, nil)

Returns:



29
# File 'lib/openai/models/beta/beta_response_tool_search_output_item_param.rb', line 29

optional :agent, -> { OpenAI::Beta::BetaResponseToolSearchOutputItemParam::Agent }, nil?: true

#call_idString?

The unique ID of the tool search call generated by the model.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


35
# File 'lib/openai/models/beta/beta_response_tool_search_output_item_param.rb', line 35

optional :call_id, String, nil?: true

#executionSymbol, ...

Whether tool search was executed by the server or by the client.



41
# File 'lib/openai/models/beta/beta_response_tool_search_output_item_param.rb', line 41

optional :execution, enum: -> { OpenAI::Beta::BetaResponseToolSearchOutputItemParam::Execution }

#idString?

The unique ID of this tool search output.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


23
# File 'lib/openai/models/beta/beta_response_tool_search_output_item_param.rb', line 23

optional :id, String, nil?: true

#statusSymbol, ...

The status of the tool search output.

Parameters:

  • value (OpenAI::Models::Beta::BetaResponseToolSearchOutputItemParam::status, nil)

Returns:



47
# File 'lib/openai/models/beta/beta_response_tool_search_output_item_param.rb', line 47

optional :status, enum: -> { OpenAI::Beta::BetaResponseToolSearchOutputItemParam::Status }, nil?: true

#toolsArray<OpenAI::Models::Beta::BetaFunctionTool, OpenAI::Models::Beta::BetaFileSearchTool, OpenAI::Models::Beta::BetaComputerTool, OpenAI::Models::Beta::BetaComputerUsePreviewTool, OpenAI::Models::Beta::BetaTool::Mcp, OpenAI::Models::Beta::BetaTool::CodeInterpreter, OpenAI::Models::Beta::BetaTool::ProgrammaticToolCalling, OpenAI::Models::Beta::BetaTool::ImageGeneration, OpenAI::Models::Beta::BetaTool::LocalShell, OpenAI::Models::Beta::BetaFunctionShellTool, OpenAI::Models::Beta::BetaCustomTool, OpenAI::Models::Beta::BetaNamespaceTool, OpenAI::Models::Beta::BetaToolSearchTool, OpenAI::Models::Beta::BetaApplyPatchTool, OpenAI::Models::Beta::BetaWebSearchTool, OpenAI::Models::Beta::BetaWebSearchPreviewTool>

The loaded tool definitions returned by the tool search output.



11
# File 'lib/openai/models/beta/beta_response_tool_search_output_item_param.rb', line 11

required :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::BetaTool] }

#typeSymbol, :tool_search_output

The item type. Always tool_search_output.

Parameters:

  • value (:tool_search_output)

Returns:

  • (Symbol, :tool_search_output)


17
# File 'lib/openai/models/beta/beta_response_tool_search_output_item_param.rb', line 17

required :type, const: :tool_search_output

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/beta_response_tool_search_output_item_param.rb', line 87

Instance Method Details

#to_hash{

Returns:

  • ({)


46
# File 'sig/openai/models/beta/beta_response_tool_search_output_item_param.rbs', line 46

def to_hash: -> {