Class: OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::AccessPrograms

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_responses_client_event.rb

Overview

See Also:

  • OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate#access_programs

Defined Under Namespace

Modules: Cyber

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cyber: nil) ⇒ Object

Domain-specific access programs to use for this request.

Parameters:

  • cyber (Symbol, OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::AccessPrograms::Cyber) (defaults to: nil) —

    The Cyber access program to use for this request. Supported values are standard, daybreak_blue, and daybreak_red. If omitted, the API resolves the program from the model's Cyber tier and your organization and project access, subject to model-specific eligibility restrictions. By default, models without a Cyber tier use Standard. Blue-tier models use Daybreak Blue when authorized; otherwise they fall back to Standard unless the model requires Daybreak access. Red-tier models use Daybreak Red and require authorization. Requests that require unavailable Daybreak access return 403. An implicit Standard fallback is represented by null in the response's access_programs field, rather than an explicit Standard selection.



# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 785

Instance Attribute Details

#cyber ⇒ Symbol, ...

The Cyber access program to use for this request. Supported values are standard, daybreak_blue, and daybreak_red. If omitted, the API resolves the program from the model's Cyber tier and your organization and project access, subject to model-specific eligibility restrictions. By default, models without a Cyber tier use Standard. Blue-tier models use Daybreak Blue when authorized; otherwise they fall back to Standard unless the model requires Daybreak access. Red-tier models use Daybreak Red and require authorization. Requests that require unavailable Daybreak access return 403. An implicit Standard fallback is represented by null in the response's access_programs field, rather than an explicit Standard selection.



780
781
782
783
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 780

optional(
  :cyber,
  enum: -> { OpenAI::Beta::BetaResponsesClientEvent::ResponseCreate::AccessPrograms::Cyber }
)