Class: OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::ContextManagement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::ContextManagement
- Defined in:
- lib/openai/models/beta/beta_responses_client_event.rb
Instance Attribute Summary collapse
-
#compact_threshold ⇒ Integer?
Token threshold at which compaction should be triggered for this entry.
-
#type ⇒ String
The context management entry type.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(background: nil, context_management: nil, conversation: nil, include: nil, input: nil, instructions: nil, max_output_tokens: nil, max_tool_calls: nil, metadata: nil, model: nil, moderation: nil, multi_agent: nil, parallel_tool_calls: nil, previous_response_id: nil, prompt: nil, prompt_cache_key: nil, prompt_cache_options: nil, prompt_cache_retention: nil, reasoning: nil, safety_identifier: nil, service_tier: nil, store: nil, stream: nil, stream_id: nil, stream_options: nil, temperature: nil, text: nil, tool_choice: nil, tools: nil, top_logprobs: nil, top_p: nil, truncation: nil, user: nil, type: :"response.create") ⇒ Object
constructor
Some parameter documentations has been truncated, see OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(background: nil, context_management: nil, conversation: nil, include: nil, input: nil, instructions: nil, max_output_tokens: nil, max_tool_calls: nil, metadata: nil, model: nil, moderation: nil, multi_agent: nil, parallel_tool_calls: nil, previous_response_id: nil, prompt: nil, prompt_cache_key: nil, prompt_cache_options: nil, prompt_cache_retention: nil, reasoning: nil, safety_identifier: nil, service_tier: nil, store: nil, stream: nil, stream_id: nil, stream_options: nil, temperature: nil, text: nil, tool_choice: nil, tools: nil, top_logprobs: nil, top_p: nil, truncation: nil, user: nil, type: :"response.create") ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate for more details.
Client event for creating a response over a persistent WebSocket connection.
This payload uses the same top-level fields as POST /v1/responses, plus
WebSocket-only envelope metadata.
Notes:
streamis implicit over WebSocket and should not be sent.backgroundis not supported over WebSocket.stream_idis WebSocket-only and is not part ofPOST /v1/responses.
502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 |
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 502 class ContextManagement < OpenAI::Internal::Type::BaseModel # @!attribute type # The context management entry type. Currently only 'compaction' is supported. # # @return [String] required :type, String # @!attribute compact_threshold # Token threshold at which compaction should be triggered for this entry. # # @return [Integer, nil] optional :compact_threshold, Integer, nil?: true # @!method initialize(type:, compact_threshold: nil) # @param type [String] The context management entry type. Currently only 'compaction' is supported. # # @param compact_threshold [Integer, nil] Token threshold at which compaction should be triggered for this entry. end |
Instance Attribute Details
#compact_threshold ⇒ Integer?
Token threshold at which compaction should be triggered for this entry.
513 |
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 513 optional :compact_threshold, Integer, nil?: true |
#type ⇒ String
The context management entry type. Currently only 'compaction' is supported.
507 |
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 507 required :type, String |