Class: OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy
- Defined in:
- lib/openai/models/beta/beta_responses_client_event.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#input ⇒ OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy::Input?
The moderation policy for the response input.
-
#output ⇒ OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy::Output?
The moderation policy for the response output.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(input: nil, output: nil) ⇒ Object
constructor
The policy to apply to moderated response input and output.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(input: nil, output: nil) ⇒ Object
The policy to apply to moderated response input and output.
|
|
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1409
|
Instance Attribute Details
#input ⇒ OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy::Input?
The moderation policy for the response input.
1389 1390 1391 1392 1393 1394 1395 |
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1389 optional( :input, -> { OpenAI::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy::Input }, nil?: true ) |
#output ⇒ OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy::Output?
The moderation policy for the response output.
1401 1402 1403 1404 1405 1406 1407 |
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1401 optional( :output, -> { OpenAI::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy::Output }, nil?: true ) |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1440
|