Class: OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Reasoning

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_responses_client_event.rb

Overview

See Also:

  • OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate#reasoning

Defined Under Namespace

Modules: Context, Effort, GenerateSummary, Mode, Summary

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(context: nil, effort: nil, generate_summary: nil, mode: nil, summary: nil) ⇒ Object

Configuration options for reasoning models.

Parameters:



# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1711

Instance Attribute Details

#contextSymbol, ...

Controls which reasoning items are rendered back to the model on later turns. If omitted or set to auto, the model determines the context mode. The gpt-5.6 model family defaults to all_turns; earlier models default to current_turn.

When returned on a response, this is the effective reasoning context mode used for the response.



1649
1650
1651
1652
1653
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1649

optional(
  :context,
  enum: -> { OpenAI::Beta::BetaResponsesClientEvent::ResponseCreate::Reasoning::Context },
  nil?: true
)

#effortSymbol, ...

Constrains effort on reasoning for reasoning models. Currently supported values are none, minimal, low, medium, high, xhigh, and max. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response. Not all reasoning models support every value. See the reasoning guide for model-specific support.



1664
1665
1666
1667
1668
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1664

optional(
  :effort,
  enum: -> { OpenAI::Beta::BetaResponsesClientEvent::ResponseCreate::Reasoning::Effort },
  nil?: true
)

#generate_summarySymbol, ...

Deprecated.

Deprecated: use summary instead.

A summary of the reasoning performed by the model. This can be useful for debugging and understanding the model's reasoning process. One of auto, concise, or detailed.



1680
1681
1682
1683
1684
1685
1686
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1680

optional(
  :generate_summary,
  enum: -> {
    OpenAI::Beta::BetaResponsesClientEvent::ResponseCreate::Reasoning::GenerateSummary
  },
  nil?: true
)

#modeString, ...

Controls the reasoning execution mode for the request.

When returned on a response, this is the effective execution mode.



1694
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1694

optional :mode, union: -> { OpenAI::Beta::BetaResponsesClientEvent::ResponseCreate::Reasoning::Mode }

#summarySymbol, ...

A summary of the reasoning performed by the model. This can be useful for debugging and understanding the model's reasoning process. One of auto, concise, or detailed.

concise is supported for computer-use-preview models and all reasoning models after gpt-5.



1705
1706
1707
1708
1709
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1705

optional(
  :summary,
  enum: -> { OpenAI::Beta::BetaResponsesClientEvent::ResponseCreate::Reasoning::Summary },
  nil?: true
)

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1766