Module: OpenAI::Models::Beta::BetaResponsesServerEvent

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/beta/beta_responses_server_event.rb

Overview

Server events emitted by the Responses WebSocket server.

Defined Under Namespace

Classes: BetaResponseAudioTranscriptWsDelta, BetaResponseAudioTranscriptWsDone, BetaResponseAudioWsDelta, BetaResponseAudioWsDone, BetaResponseCodeInterpreterCallCodeWsDelta, BetaResponseCodeInterpreterCallCodeWsDone, BetaResponseCodeInterpreterCallInWsProgress, BetaResponseCodeInterpreterCallWsCompleted, BetaResponseCodeInterpreterCallWsInterpreting, BetaResponseContentPartWsAdded, BetaResponseContentPartWsDone, BetaResponseCustomToolCallInputWsDelta, BetaResponseCustomToolCallInputWsDone, BetaResponseFileSearchCallInWsProgress, BetaResponseFileSearchCallWsCompleted, BetaResponseFileSearchCallWsSearching, BetaResponseFunctionCallArgumentsWsDelta, BetaResponseFunctionCallArgumentsWsDone, BetaResponseImageGenCallInWsProgress, BetaResponseImageGenCallPartialWsImage, BetaResponseImageGenCallWsCompleted, BetaResponseImageGenCallWsGenerating, BetaResponseInWsProgress, BetaResponseMcpCallArgumentsWsDelta, BetaResponseMcpCallArgumentsWsDone, BetaResponseMcpCallInWsProgress, BetaResponseMcpCallWsCompleted, BetaResponseMcpCallWsFailed, BetaResponseMcpListToolsInWsProgress, BetaResponseMcpListToolsWsCompleted, BetaResponseMcpListToolsWsFailed, BetaResponseOutputItemWsAdded, BetaResponseOutputItemWsDone, BetaResponseOutputTextAnnotationWsAdded, BetaResponseReasoningSummaryPartWsAdded, BetaResponseReasoningSummaryPartWsDone, BetaResponseReasoningSummaryTextWsDelta, BetaResponseReasoningSummaryTextWsDone, BetaResponseReasoningTextWsDelta, BetaResponseReasoningTextWsDone, BetaResponseRefusalWsDelta, BetaResponseRefusalWsDone, BetaResponseShellCallCommandWsAdded, BetaResponseShellCallCommandWsDelta, BetaResponseShellCallCommandWsDone, BetaResponseShellCallOutputContentWsDelta, BetaResponseShellCallOutputContentWsDone, BetaResponseTextWsDelta, BetaResponseTextWsDone, BetaResponseWebSearchCallInWsProgress, BetaResponseWebSearchCallWsCompleted, BetaResponseWebSearchCallWsSearching, BetaResponseWsCompleted, BetaResponseWsCreated, BetaResponseWsError, BetaResponseWsFailed, BetaResponseWsIncomplete, BetaResponseWsQueued

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(input:, item_id:, output_index:, sequence_number:, agent: nil, stream_id: nil, type: :"response.custom_tool_call_input.done") ⇒ Object

Some parameter documentations has been truncated, see BetaResponseCustomToolCallInputWsDone for more details.

Event indicating that input for a custom tool call is complete.

Parameters:

  • input (String)

    The complete input data for the custom tool call.

  • item_id (String)

    Unique identifier for the API item associated with this event.

  • output_index (Integer)

    The index of the output this event applies to.

  • sequence_number (Integer)

    The sequence number of this event.

  • agent (OpenAI::Models::Beta::BetaResponseCustomToolCallInputDoneEvent::Agent, nil) (defaults to: nil)

    The agent that owns this multi-agent streaming event.

  • stream_id (String) (defaults to: nil)

    The WebSocket lane that emitted this event. This field is present

  • type (Symbol, :"response.custom_tool_call_input.done") (defaults to: :"response.custom_tool_call_input.done")

    The event type identifier.



# File 'lib/openai/models/beta/beta_responses_server_event.rb', line 347