Class: OpenAI::Models::Beta::BetaTool::ImageGeneration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaTool::ImageGeneration
- Defined in:
- lib/openai/models/beta/beta_tool.rb
Defined Under Namespace
Modules: Action, Background, InputFidelity, Model, Moderation, OutputFormat, Quality, Size Classes: InputImageMask
Instance Attribute Summary collapse
-
#action ⇒ Symbol, ...
Whether to generate a new image or edit an existing image.
-
#background ⇒ Symbol, ...
Allows to set transparency for the background of the generated image(s).
-
#input_fidelity ⇒ Symbol, ...
Control how much effort the model will exert to match the style and features, especially facial features, of input images.
-
#input_image_mask ⇒ OpenAI::Models::Beta::BetaTool::ImageGeneration::InputImageMask?
Optional mask for inpainting.
-
#model ⇒ String, ...
The image generation model to use.
-
#moderation ⇒ Symbol, ...
Moderation level for the generated image.
-
#output_compression ⇒ Integer?
Compression level for the output image.
-
#output_format ⇒ Symbol, ...
The output format of the generated image.
-
#partial_images ⇒ Integer?
Number of partial images to generate in streaming mode, from 0 (default value) to 3.
-
#quality ⇒ Symbol, ...
The quality of the generated image.
-
#size ⇒ String, ...
The size of the generated images.
-
#type ⇒ Symbol, :image_generation
The type of the image generation tool.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(file_id: nil, image_url: nil) ⇒ Object
constructor
Optional mask for inpainting.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(file_id: nil, image_url: nil) ⇒ Object
Optional mask for inpainting. Contains image_url (string, optional) and
file_id (string, optional).
|
|
# File 'lib/openai/models/beta/beta_tool.rb', line 702
|
Instance Attribute Details
#action ⇒ Symbol, ...
Whether to generate a new image or edit an existing image. Default: auto.
602 |
# File 'lib/openai/models/beta/beta_tool.rb', line 602 optional :action, enum: -> { OpenAI::Beta::BetaTool::ImageGeneration::Action } |
#background ⇒ Symbol, ...
Allows to set transparency for the background of the generated image(s). Must be
one of transparent, opaque, or auto (default value). When auto is used,
the model will automatically determine the best background for the image.
gpt-image-2.5-sunburst and gpt-image-2.5-flare, including their 2026-09-08
snapshots, support opaque and transparent backgrounds. Transparent
backgrounds are available for supported GPT Image models. For gpt-image-2 and
gpt-image-2-2026-04-21, this support is in preview. When using transparent,
set the output format to png or webp.
616 |
# File 'lib/openai/models/beta/beta_tool.rb', line 616 optional :background, enum: -> { OpenAI::Beta::BetaTool::ImageGeneration::Background } |
#input_fidelity ⇒ Symbol, ...
Control how much effort the model will exert to match the style and features,
especially facial features, of input images. This parameter is only supported
for gpt-image-1 and gpt-image-1.5 and later models, unsupported for
gpt-image-1-mini. Supports high and low. Defaults to low.
625 626 627 628 629 630 631 |
# File 'lib/openai/models/beta/beta_tool.rb', line 625 optional( :input_fidelity, enum: -> { OpenAI::Beta::BetaTool::ImageGeneration::InputFidelity }, nil?: true ) |
#input_image_mask ⇒ OpenAI::Models::Beta::BetaTool::ImageGeneration::InputImageMask?
Optional mask for inpainting. Contains image_url (string, optional) and
file_id (string, optional).
638 |
# File 'lib/openai/models/beta/beta_tool.rb', line 638 optional :input_image_mask, -> { OpenAI::Beta::BetaTool::ImageGeneration::InputImageMask } |
#model ⇒ String, ...
The image generation model to use. One of gpt-image-1, gpt-image-1-mini,
gpt-image-1.5, gpt-image-2, gpt-image-2-2026-04-21,
gpt-image-2.5-sunburst, gpt-image-2.5-sunburst-2026-09-08,
gpt-image-2.5-flare, gpt-image-2.5-flare-2026-09-08, or
chatgpt-image-latest. Default: gpt-image-1.
648 |
# File 'lib/openai/models/beta/beta_tool.rb', line 648 optional :model, union: -> { OpenAI::Beta::BetaTool::ImageGeneration::Model } |
#moderation ⇒ Symbol, ...
Moderation level for the generated image. Default: auto.
654 |
# File 'lib/openai/models/beta/beta_tool.rb', line 654 optional :moderation, enum: -> { OpenAI::Beta::BetaTool::ImageGeneration::Moderation } |
#output_compression ⇒ Integer?
Compression level for the output image. Default: 100.
660 |
# File 'lib/openai/models/beta/beta_tool.rb', line 660 optional :output_compression, Integer |
#output_format ⇒ Symbol, ...
The output format of the generated image. One of png, webp, or jpeg.
Default: png.
667 |
# File 'lib/openai/models/beta/beta_tool.rb', line 667 optional :output_format, enum: -> { OpenAI::Beta::BetaTool::ImageGeneration::OutputFormat } |
#partial_images ⇒ Integer?
Number of partial images to generate in streaming mode, from 0 (default value) to 3.
674 |
# File 'lib/openai/models/beta/beta_tool.rb', line 674 optional :partial_images, Integer |
#quality ⇒ Symbol, ...
The quality of the generated image. The GPT image models support low,
medium, and high. gpt-image-2.5-sunburst and gpt-image-2.5-flare,
including their 2026-09-08 snapshots, also support xhigh and max. Default:
auto.
683 |
# File 'lib/openai/models/beta/beta_tool.rb', line 683 optional :quality, enum: -> { OpenAI::Beta::BetaTool::ImageGeneration::Quality } |
#size ⇒ String, ...
The size of the generated images. For gpt-image-2, gpt-image-2-2026-04-21,
gpt-image-2.5-sunburst, gpt-image-2.5-sunburst-2026-09-08,
gpt-image-2.5-flare, and gpt-image-2.5-flare-2026-09-08, arbitrary
resolutions are supported as WIDTHxHEIGHT strings, for example 1536x864.
Width and height must both be divisible by 16 and the requested aspect ratio
must be between 1:3 and 3:1. Resolutions above 2560x1440 are experimental, and
the maximum supported resolution is 3840x2160. The requested size must also
satisfy the model's current pixel and edge limits. The standard sizes
1024x1024, 1536x1024, and 1024x1536 are supported by the GPT image models;
auto is supported for models that allow automatic sizing. For dall-e-2, use
one of 256x256, 512x512, or 1024x1024. For dall-e-3, use one of
1024x1024, 1792x1024, or 1024x1792.
700 |
# File 'lib/openai/models/beta/beta_tool.rb', line 700 optional :size, union: -> { OpenAI::Beta::BetaTool::ImageGeneration::Size } |
#type ⇒ Symbol, :image_generation
The type of the image generation tool. Always image_generation.
596 |
# File 'lib/openai/models/beta/beta_tool.rb', line 596 required :type, const: :image_generation |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_tool.rb', line 783
|