Module: OpenAI::Models::Beta::BetaToolChoiceOptions

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/beta/beta_tool_choice_options.rb

Overview

Controls which (if any) tool is called by the model.

none means the model will not call any tool and instead generates a message.

auto means the model can pick between generating a message or calling one or more tools.

required means the model must call one or more tools.

Constant Summary collapse

NONE =
:none
AUTO =
:auto
REQUIRED =
:required

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info