Class: OpenAI::Models::Beta::BetaWebSearchPreviewTool

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_web_search_preview_tool.rb,
sig/openai/models/beta/beta_web_search_preview_tool.rbs

Defined Under Namespace

Modules: SearchContentType, SearchContextSize, Type Classes: UserLocation

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type:, search_content_types: nil, search_context_size: nil, user_location: nil) ⇒ Object

Parameters:

  • type

    The type of the web search tool. One of web_search_preview or web_search_preview_2025_03_11.

  • search_context_size (defaults to: nil)

    High level guidance for the amount of context window space to use for the search. One of low, medium, or high. medium is the default.

  • user_location (defaults to: nil)

    The user's location.



# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 35

Instance Attribute Details

#search_content_typesArray<Symbol, OpenAI::Models::Beta::BetaWebSearchPreviewTool::SearchContentType>?



17
18
19
20
# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 17

optional(
  :search_content_types,
  -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Beta::BetaWebSearchPreviewTool::SearchContentType] }
)

#search_context_sizeOpenAI::Models::Beta::BetaWebSearchPreviewTool::search_context_size?

High level guidance for the amount of context window space to use for the search. One of low, medium, or high. medium is the default.

Returns:

  • (OpenAI::Models::Beta::BetaWebSearchPreviewTool::search_context_size, nil)


27
# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 27

optional :search_context_size, enum: -> { OpenAI::Beta::BetaWebSearchPreviewTool::SearchContextSize }

#typeOpenAI::Models::Beta::BetaWebSearchPreviewTool::type_

The type of the web search tool. One of web_search_preview or web_search_preview_2025_03_11.

Returns:

  • (OpenAI::Models::Beta::BetaWebSearchPreviewTool::type_)


12
# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 12

required :type, enum: -> { OpenAI::Beta::BetaWebSearchPreviewTool::Type }

#user_locationOpenAI::Beta::BetaWebSearchPreviewTool::UserLocation?

The user's location.

Returns:

  • (OpenAI::Beta::BetaWebSearchPreviewTool::UserLocation, nil)


33
# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 33

optional :user_location, -> { OpenAI::Beta::BetaWebSearchPreviewTool::UserLocation }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 63

Instance Method Details

#to_hash{

Returns:

  • ({)


53
# File 'sig/openai/models/beta/beta_web_search_preview_tool.rbs', line 53

def to_hash: -> {