Class: OpenAI::Models::Beta::BetaWebSearchTool::UserLocation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaWebSearchTool::UserLocation
- Defined in:
- lib/openai/models/beta/beta_web_search_tool.rb,
sig/openai/models/beta/beta_web_search_tool.rbs
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#city ⇒ String?
Free text input for the city of the user, e.g.
-
#country ⇒ String?
The two-letter ISO country code of the user, e.g.
-
#region ⇒ String?
Free text input for the region of the user, e.g.
-
#timezone ⇒ String?
The IANA timezone of the user, e.g.
-
#type ⇒ Symbol, ...
The type of location approximation.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, region: nil, timezone: nil, type: nil) ⇒ Object
constructor
The approximate location of the user.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city: nil, country: nil, region: nil, timezone: nil, type: nil) ⇒ Object
The approximate location of the user.
|
|
# File 'lib/openai/models/beta/beta_web_search_tool.rb', line 145
|
Instance Attribute Details
#city ⇒ String?
Free text input for the city of the user, e.g. San Francisco.
117 |
# File 'lib/openai/models/beta/beta_web_search_tool.rb', line 117 optional :city, String, nil?: true |
#country ⇒ String?
The two-letter ISO country code of
the user, e.g. US.
124 |
# File 'lib/openai/models/beta/beta_web_search_tool.rb', line 124 optional :country, String, nil?: true |
#region ⇒ String?
Free text input for the region of the user, e.g. California.
130 |
# File 'lib/openai/models/beta/beta_web_search_tool.rb', line 130 optional :region, String, nil?: true |
#timezone ⇒ String?
The IANA timezone of the
user, e.g. America/Los_Angeles.
137 |
# File 'lib/openai/models/beta/beta_web_search_tool.rb', line 137 optional :timezone, String, nil?: true |
#type ⇒ Symbol, ...
The type of location approximation. Always approximate.
143 |
# File 'lib/openai/models/beta/beta_web_search_tool.rb', line 143 optional :type, enum: -> { OpenAI::Beta::BetaWebSearchTool::UserLocation::Type } |
Instance Method Details
#to_hash ⇒ {
113 |
# File 'sig/openai/models/beta/beta_web_search_tool.rbs', line 113
def to_hash: -> {
|