Module: OpenAI::Models::Beta::ChatKit::ChatKitThread::Status
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/beta/chatkit/chatkit_thread.rb,
sig/openai/models/beta/chatkit/chatkit_thread.rbs
Overview
Current status for the thread. Defaults to active for newly created threads.
Defined Under Namespace
Classes: Active, Closed, Locked
Instance Method Summary collapse
-
#initialize(reason:, type: :locked) ⇒ Object
Indicates that a thread is locked and cannot accept new input.
- #self?.variants ⇒ ::Array[OpenAI::Models::Beta::ChatKit::ChatKitThread::status]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(reason:, type: :locked) ⇒ Object
Indicates that a thread is locked and cannot accept new input.
|
|
# File 'lib/openai/models/beta/chatkit/chatkit_thread.rb', line 88
|
#self?.variants ⇒ ::Array[OpenAI::Models::Beta::ChatKit::ChatKitThread::status]
90 |
# File 'sig/openai/models/beta/chatkit/chatkit_thread.rbs', line 90
def self?.variants: -> ::Array[OpenAI::Models::Beta::ChatKit::ChatKitThread::status]
|