Class: OpenAI::Models::Beta::ChatKit::ChatSessionChatKitConfigurationParam::FileUpload

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/chatkit/chat_session_chatkit_configuration_param.rb,
sig/openai/models/beta/chatkit/chat_session_chatkit_configuration_param.rbs

Overview

See Also:

  • OpenAI::Models::Beta::ChatKit::ChatSessionChatKitConfigurationParam#file_upload

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • enabled —

    Enable uploads for this session. Defaults to false.

  • max_file_size —

    Maximum size in megabytes for each uploaded file. Defaults to 512 MB, which is the maximum allowable size.

  • max_files —

    Maximum number of files that can be uploaded to the session. Defaults to 10.



111
# File 'sig/openai/models/beta/chatkit/chat_session_chatkit_configuration_param.rbs', line 111

def initialize: (

Instance Attribute Details

#enabled ⇒ Boolean?

Enable uploads for this session. Defaults to false.

Returns:



69
# File 'lib/openai/models/beta/chatkit/chat_session_chatkit_configuration_param.rb', line 69

optional :enabled, OpenAI::Internal::Type::Boolean

#max_file_size ⇒ Integer?

Maximum size in megabytes for each uploaded file. Defaults to 512 MB, which is the maximum allowable size.

Returns:

  • (Integer, nil)


76
# File 'lib/openai/models/beta/chatkit/chat_session_chatkit_configuration_param.rb', line 76

optional :max_file_size, Integer

#max_files ⇒ Integer?

Maximum number of files that can be uploaded to the session. Defaults to 10.

Returns:

  • (Integer, nil)


82
# File 'lib/openai/models/beta/chatkit/chat_session_chatkit_configuration_param.rb', line 82

optional :max_files, Integer

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


117
# File 'sig/openai/models/beta/chatkit/chat_session_chatkit_configuration_param.rbs', line 117

def to_hash: -> {