Class: OpenAI::Models::Beta::ChatKit::ChatSessionWorkflowParam

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/chatkit/chat_session_workflow_param.rb,
sig/openai/models/beta/chatkit/chat_session_workflow_param.rbs

Defined Under Namespace

Modules: StateVariable Classes: Tracing

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • id —

    Identifier for the workflow invoked by the session.

  • state_variables —

    State variables forwarded to the workflow. Keys may be up to 64 characters, values must be primitive types, and the map defaults to an empty object.

  • tracing —

    Optional tracing overrides for the workflow invocation. When omitted, tracing is enabled by default.

  • version —

    Specific workflow version to run. Defaults to the latest deployed version.



53
# File 'sig/openai/models/beta/chatkit/chat_session_workflow_param.rbs', line 53

def initialize: (

Instance Attribute Details

#id ⇒ String

Identifier for the workflow invoked by the session.

Returns:

  • (String)


12
# File 'lib/openai/models/beta/chatkit/chat_session_workflow_param.rb', line 12

required :id, String

#state_variables ⇒ ::Hash[Symbol, OpenAI::Models::Beta::ChatKit::ChatSessionWorkflowParam::state_variable]?

State variables forwarded to the workflow. Keys may be up to 64 characters, values must be primitive types, and the map defaults to an empty object.

Returns:

  • (::Hash[Symbol, OpenAI::Models::Beta::ChatKit::ChatSessionWorkflowParam::state_variable], nil)


19
20
21
22
23
24
# File 'lib/openai/models/beta/chatkit/chat_session_workflow_param.rb', line 19

optional(
  :state_variables,
  -> {
    OpenAI::Internal::Type::HashOf[union: OpenAI::Beta::ChatKit::ChatSessionWorkflowParam::StateVariable]
  }
)

#tracing ⇒ OpenAI::Beta::ChatKit::ChatSessionWorkflowParam::Tracing?

Optional tracing overrides for the workflow invocation. When omitted, tracing is enabled by default.

Returns:

  • (OpenAI::Beta::ChatKit::ChatSessionWorkflowParam::Tracing, nil)


31
# File 'lib/openai/models/beta/chatkit/chat_session_workflow_param.rb', line 31

optional :tracing, -> { OpenAI::Beta::ChatKit::ChatSessionWorkflowParam::Tracing }

#version ⇒ String?

Specific workflow version to run. Defaults to the latest deployed version.

Returns:

  • (String, nil)


37
# File 'lib/openai/models/beta/chatkit/chat_session_workflow_param.rb', line 37

optional :version, String

Class Method Details

.variants ⇒ Array(String, Boolean, Float)

Returns:



# File 'lib/openai/models/beta/chatkit/chat_session_workflow_param.rb', line 64

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


60
# File 'sig/openai/models/beta/chatkit/chat_session_workflow_param.rbs', line 60

def to_hash: -> {