Class: OpenAI::Models::Beta::Environment::OpenAIHosted::Desktop

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/environment.rb,
sig/openai/models/beta/environment.rbs

Overview

See Also:

  • OpenAI::Models::Beta::Environment::OpenAIHosted#desktop

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Desktop

Returns a new instance of Desktop.

Parameters:

  • enabled —

    Whether the environment provisions a desktop and browser proxy.

  • enabled: (Boolean)


202
# File 'sig/openai/models/beta/environment.rbs', line 202

def initialize: (enabled: bool) -> void

Instance Attribute Details

#enabled ⇒ Boolean

Whether the environment provisions a desktop and browser proxy.

Returns:



203
# File 'lib/openai/models/beta/environment.rb', line 203

required :enabled, OpenAI::Internal::Type::Boolean

Instance Method Details

#to_hash ⇒ { enabled: bool }

Returns:

  • ({ enabled: bool })


204
# File 'sig/openai/models/beta/environment.rbs', line 204

def to_hash: -> { enabled: bool }