Class: OpenAI::Models::Beta::EnvironmentParam::OpenAIHosted::Network
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::EnvironmentParam::OpenAIHosted::Network
- Defined in:
- lib/openai/models/beta/environment_param.rb,
sig/openai/models/beta/environment_param.rbs
Overview
Defined Under Namespace
Modules: Access
Instance Attribute Summary collapse
-
#access ⇒ Symbol, OpenAI::Models::Beta::EnvironmentParam::OpenAIHosted::Network::Access
The environment's network access mode.
-
#allowed_domains ⇒ Array<String>?
Domains the environment may access when network access is restricted.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(access:, allowed_domains: nil) ⇒ Object
constructor
Network access for an OpenAI-hosted environment.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(access:, allowed_domains: nil) ⇒ Object
Network access for an OpenAI-hosted environment.
|
|
# File 'lib/openai/models/beta/environment_param.rb', line 167
|
Instance Attribute Details
#access ⇒ Symbol, OpenAI::Models::Beta::EnvironmentParam::OpenAIHosted::Network::Access
The environment's network access mode.
159 |
# File 'lib/openai/models/beta/environment_param.rb', line 159 required :access, enum: -> { OpenAI::Beta::EnvironmentParam::OpenAIHosted::Network::Access } |
#allowed_domains ⇒ Array<String>?
Domains the environment may access when network access is restricted.
165 |
# File 'lib/openai/models/beta/environment_param.rb', line 165 optional :allowed_domains, OpenAI::Internal::Type::ArrayOf[String], nil?: true |
Instance Method Details
#to_hash ⇒ {
101 |
# File 'sig/openai/models/beta/environment_param.rbs', line 101
def to_hash: -> {
|