Class: OpenAI::Models::Beta::FileSearchTool::FileSearch::RankingOptions

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/file_search_tool.rb,
sig/openai/models/beta/file_search_tool.rbs

Overview

See Also:

  • OpenAI::Models::Beta::FileSearchTool::FileSearch#ranking_options

Defined Under Namespace

Modules: Ranker

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(score_threshold:, ranker: nil) ⇒ Object

Parameters:

  • score_threshold —

    The score threshold for the file search. All values must be a floating point number between 0 and 1.

  • ranker (defaults to: nil) —

    The ranker to use for the file search. If not specified will use the auto ranker.



# File 'lib/openai/models/beta/file_search_tool.rb', line 89

Instance Attribute Details

#ranker ⇒ OpenAI::Models::Beta::FileSearchTool::FileSearch::RankingOptions::ranker?

The ranker to use for the file search. If not specified will use the auto ranker.

Returns:

  • (OpenAI::Models::Beta::FileSearchTool::FileSearch::RankingOptions::ranker, nil)


87
# File 'lib/openai/models/beta/file_search_tool.rb', line 87

optional :ranker, enum: -> { OpenAI::Beta::FileSearchTool::FileSearch::RankingOptions::Ranker }

#score_threshold ⇒ Float

The score threshold for the file search. All values must be a floating point number between 0 and 1.

Returns:

  • (Float)


80
# File 'lib/openai/models/beta/file_search_tool.rb', line 80

required :score_threshold, Float

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


139
# File 'sig/openai/models/beta/file_search_tool.rbs', line 139

def to_hash: -> {