Class: OpenAI::Models::Beta::InputContent::InputImage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::InputContent::InputImage
- Defined in:
- lib/openai/models/beta/input_content.rb,
sig/openai/models/beta/input_content.rbs
Instance Attribute Summary collapse
-
#image_url ⇒ String
The URL of the image supplied to the agent, which may be a base64-encoded data URL.
-
#type ⇒ Symbol, :input_image
The type of the object.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(image_url:, type: :input_image) ⇒ InputImage
constructor
Image input recorded in a session item.
- #to_hash ⇒ { image_url: String, ?type: :input_image }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(image_url:, type: :input_image) ⇒ InputImage
Image input recorded in a session item.
|
|
# File 'lib/openai/models/beta/input_content.rb', line 55
|
Instance Attribute Details
#image_url ⇒ String
The URL of the image supplied to the agent, which may be a base64-encoded data URL.
47 |
# File 'lib/openai/models/beta/input_content.rb', line 47 required :image_url, String |
#type ⇒ Symbol, :input_image
The type of the object. Always input_image.
53 |
# File 'lib/openai/models/beta/input_content.rb', line 53 required :type, const: :input_image |
Instance Method Details
#to_hash ⇒ { image_url: String, ?type: :input_image }
32 |
# File 'sig/openai/models/beta/input_content.rbs', line 32
def to_hash: -> { image_url: String, ?type: :input_image }
|