Class: OpenAI::Models::Beta::MultiAgentConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/multi_agent_config.rb,
sig/openai/models/beta/multi_agent_config.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(enabled:, max_concurrent_subagents:) ⇒ Object

The resolved configuration for creating and coordinating subagents.

Parameters:

  • enabled (Boolean)

    Whether subagent tools are enabled. Defaults to false.

  • max_concurrent_subagents (Integer, nil)

    Maximum number of subagents that may run concurrently, or null when disabled. Defaults to 6 when enabled.



# File 'lib/openai/models/beta/multi_agent_config.rb', line 20

Instance Attribute Details

#enabledBoolean

Whether subagent tools are enabled. Defaults to false.

Parameters:

Returns:



11
# File 'lib/openai/models/beta/multi_agent_config.rb', line 11

required :enabled, OpenAI::Internal::Type::Boolean

#max_concurrent_subagentsInteger?

Maximum number of subagents that may run concurrently, or null when disabled. Defaults to 6 when enabled.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


18
# File 'lib/openai/models/beta/multi_agent_config.rb', line 18

required :max_concurrent_subagents, Integer, nil?: true

Instance Method Details

#to_hash{ enabled: bool, max_concurrent_subagents: Integer? }

Returns:

  • ({ enabled: bool, max_concurrent_subagents: Integer? })


17
# File 'sig/openai/models/beta/multi_agent_config.rbs', line 17

def to_hash: -> { enabled: bool, max_concurrent_subagents: Integer? }