Class: OpenAI::Models::Beta::PersistedAgentTool::Function
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::PersistedAgentTool::Function
- Defined in:
- lib/openai/models/beta/persisted_agent_tool.rb,
sig/openai/models/beta/persisted_agent_tool.rbs
Instance Attribute Summary collapse
-
#defer_loading ⇒ Boolean
Whether the function is deferred and discovered through tool search.
-
#description ⇒ String
A description of what the function does.
-
#name ⇒ String
The name of the function.
-
#parameters ⇒ Hash{Symbol=>Object}
A JSON Schema object describing the function's arguments.
-
#type ⇒ Symbol, :function
The type of the object.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
34 |
# File 'sig/openai/models/beta/persisted_agent_tool.rbs', line 34
def initialize: (
|
Instance Attribute Details
#defer_loading ⇒ Boolean
Whether the function is deferred and discovered through tool search.
32 |
# File 'lib/openai/models/beta/persisted_agent_tool.rb', line 32 required :defer_loading, OpenAI::Internal::Type::Boolean |
#description ⇒ String
A description of what the function does.
38 |
# File 'lib/openai/models/beta/persisted_agent_tool.rb', line 38 required :description, String |
#name ⇒ String
The name of the function.
44 |
# File 'lib/openai/models/beta/persisted_agent_tool.rb', line 44 required :name, String |
#parameters ⇒ Hash{Symbol=>Object}
A JSON Schema object describing the function's arguments.
50 |
# File 'lib/openai/models/beta/persisted_agent_tool.rb', line 50 required :parameters, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Unknown] |
#type ⇒ Symbol, :function
The type of the object. Always function.
56 |
# File 'lib/openai/models/beta/persisted_agent_tool.rb', line 56 required :type, const: :function |
Instance Method Details
#to_hash ⇒ {
42 |
# File 'sig/openai/models/beta/persisted_agent_tool.rbs', line 42
def to_hash: -> {
|