Class: OpenAI::Models::Beta::PersistedAgentToolParam::Function

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/persisted_agent_tool_param.rb,
sig/openai/models/beta/persisted_agent_tool_param.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Parameters:

  • description

    A description of what the function does.

  • name

    The name of the function.

  • parameters

    A JSON Schema object describing the function's arguments.

  • defer_loading

    Whether this function is deferred and discovered through tool search. Defaults to false.

  • type

    The type of the object. Always function.



55
# File 'sig/openai/models/beta/persisted_agent_tool_param.rbs', line 55

def initialize: (

Instance Attribute Details

#defer_loadingBoolean?

Whether this function is deferred and discovered through tool search. Defaults to false.

Returns:



57
# File 'lib/openai/models/beta/persisted_agent_tool_param.rb', line 57

optional :defer_loading, OpenAI::Internal::Type::Boolean

#descriptionString

A description of what the function does.

Returns:

  • (String)


32
# File 'lib/openai/models/beta/persisted_agent_tool_param.rb', line 32

required :description, String

#nameString

The name of the function.

Returns:

  • (String)


38
# File 'lib/openai/models/beta/persisted_agent_tool_param.rb', line 38

required :name, String

#parameters::Hash[Symbol, top]

A JSON Schema object describing the function's arguments.

Returns:

  • (::Hash[Symbol, top])


44
# File 'lib/openai/models/beta/persisted_agent_tool_param.rb', line 44

required :parameters, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Unknown]

#type:function

The type of the object. Always function.

Returns:

  • (:function)


50
# File 'lib/openai/models/beta/persisted_agent_tool_param.rb', line 50

required :type, const: :function

Instance Method Details

#to_hash{

Returns:

  • ({)


63
# File 'sig/openai/models/beta/persisted_agent_tool_param.rbs', line 63

def to_hash: -> {