Class: OpenAI::Models::Beta::ResponseCompactParams::PromptCacheOptions

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/response_compact_params.rb,
sig/openai/models/beta/response_compact_params.rbs

Defined Under Namespace

Modules: Mode, Ttl

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(mode: nil, ttl: nil) ⇒ Object

Parameters:

  • mode (defaults to: nil) —

    Controls whether OpenAI automatically creates an implicit cache breakpoint. Defaults to implicit. With implicit, OpenAI creates one implicit breakpoint and writes up to the latest three explicit breakpoints in the request. With explicit, OpenAI does not create an implicit breakpoint and writes up to the latest four explicit breakpoints. If there are no explicit breakpoints, the request does not use prompt caching.

  • ttl (defaults to: nil) —

    The minimum lifetime applied to every implicit and explicit cache breakpoint written by the request. Defaults to 30m, which is currently the only supported value. The backend may retain cache entries for longer.



# File 'lib/openai/models/beta/response_compact_params.rb', line 558


Instance Attribute Details

#mode ⇒ OpenAI::Models::Beta::ResponseCompactParams::PromptCacheOptions::mode?

Controls whether OpenAI automatically creates an implicit cache breakpoint. Defaults to implicit. With implicit, OpenAI creates one implicit breakpoint and writes up to the latest three explicit breakpoints in the request. With explicit, OpenAI does not create an implicit breakpoint and writes up to the latest four explicit breakpoints. If there are no explicit breakpoints, the request does not use prompt caching.

Returns:

  • (OpenAI::Models::Beta::ResponseCompactParams::PromptCacheOptions::mode, nil)


548
# File 'lib/openai/models/beta/response_compact_params.rb', line 548

optional :mode, enum: -> { OpenAI::Beta::ResponseCompactParams::PromptCacheOptions::Mode }

#ttl ⇒ OpenAI::Models::Beta::ResponseCompactParams::PromptCacheOptions::ttl?

The minimum lifetime applied to every implicit and explicit cache breakpoint written by the request. Defaults to 30m, which is currently the only supported value. The backend may retain cache entries for longer.

Returns:

  • (OpenAI::Models::Beta::ResponseCompactParams::PromptCacheOptions::ttl, nil)


556
# File 'lib/openai/models/beta/response_compact_params.rb', line 556

optional :ttl, enum: -> { OpenAI::Beta::ResponseCompactParams::PromptCacheOptions::Ttl }

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/response_compact_params.rb', line 596


Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


448
# File 'sig/openai/models/beta/response_compact_params.rbs', line 448

def to_hash: -> {