Class: OpenAI::Models::Beta::ResponseCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::ResponseCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/beta/response_create_params.rb,
sig/openai/models/beta/response_create_params.rbs
Overview
Defined Under Namespace
Modules: Beta, Conversation, Input, Model, PromptCacheRetention, ServiceTier, ToolChoice, Truncation Classes: ContextManagement, Moderation, MultiAgent, PromptCacheOptions, Reasoning, StreamOptions
Instance Attribute Summary collapse
-
#background ⇒ Boolean?
Whether to run the model response in the background.
- #betas ⇒ Array<Symbol, OpenAI::Models::Beta::ResponseCreateParams::Beta>?
-
#context_management ⇒ Array<OpenAI::Models::Beta::ResponseCreateParams::ContextManagement>?
Context management configuration for this request.
-
#conversation ⇒ String, ...
The conversation that this response belongs to.
-
#include ⇒ Array<Symbol, OpenAI::Models::Beta::BetaResponseIncludable>?
Specify additional output data to include in the model response.
-
#input ⇒ String, ...
Text, image, or file inputs to the model, used to generate a response.
-
#instructions ⇒ String?
A system (or developer) message inserted into the model's context.
-
#max_output_tokens ⇒ Integer?
An upper bound for the number of tokens that can be generated for a response, including visible output tokens and reasoning tokens.
-
#max_tool_calls ⇒ Integer?
The maximum number of total calls to built-in tools that can be processed in a response.
-
#metadata ⇒ Hash{Symbol=>String}?
Set of 16 key-value pairs that can be attached to an object.
-
#model ⇒ Symbol, ...
Model ID used to generate the response, like
gpt-4ooro3. -
#moderation ⇒ OpenAI::Models::Beta::ResponseCreateParams::Moderation?
Configuration for running moderation on the input and output of this response.
-
#multi_agent ⇒ OpenAI::Models::Beta::ResponseCreateParams::MultiAgent?
Configuration for server-hosted multi-agent execution.
-
#parallel_tool_calls ⇒ Boolean?
Whether to allow the model to run tool calls in parallel.
-
#previous_response_id ⇒ String?
The unique ID of the previous response to the model.
-
#prompt ⇒ OpenAI::Models::Beta::BetaResponsePrompt?
Reference to a prompt template and its variables.
-
#prompt_cache_key ⇒ String?
Used by OpenAI to cache responses for similar requests to optimize your cache hit rates.
-
#prompt_cache_options ⇒ OpenAI::Models::Beta::ResponseCreateParams::PromptCacheOptions?
Options for prompt caching.
- #prompt_cache_retention ⇒ Symbol, ... deprecated Deprecated.
-
#reasoning ⇒ OpenAI::Models::Beta::ResponseCreateParams::Reasoning?
gpt-5 and o-series models only.
-
#safety_identifier ⇒ String?
A stable identifier used to help detect users of your application that may be violating OpenAI's usage policies.
-
#service_tier ⇒ Symbol, ...
Specifies the processing type used for serving the request.
-
#store ⇒ Boolean?
Whether to store the generated model response for later retrieval via API.
-
#stream_options ⇒ OpenAI::Models::Beta::ResponseCreateParams::StreamOptions?
Options for streaming responses.
-
#temperature ⇒ Float?
What sampling temperature to use, between 0 and 2.
-
#text ⇒ OpenAI::Models::Beta::BetaResponseTextConfig?
Configuration options for a text response from the model.
-
#tool_choice ⇒ Symbol, ...
How the model should select which tool (or tools) to use when generating a response.
-
#tools ⇒ Array<OpenAI::Models::Beta::BetaFunctionTool, OpenAI::Models::Beta::BetaFileSearchTool, OpenAI::Models::Beta::BetaComputerTool, OpenAI::Models::Beta::BetaComputerUsePreviewTool, OpenAI::Models::Beta::BetaTool::Mcp, OpenAI::Models::Beta::BetaTool::CodeInterpreter, OpenAI::Models::Beta::BetaTool::ProgrammaticToolCalling, OpenAI::Models::Beta::BetaTool::ImageGeneration, OpenAI::Models::Beta::BetaTool::LocalShell, OpenAI::Models::Beta::BetaFunctionShellTool, OpenAI::Models::Beta::BetaCustomTool, OpenAI::Models::Beta::BetaNamespaceTool, OpenAI::Models::Beta::BetaToolSearchTool, OpenAI::Models::Beta::BetaApplyPatchTool, OpenAI::Models::Beta::BetaWebSearchTool, OpenAI::Models::Beta::BetaWebSearchPreviewTool>?
An array of tools the model may call while generating a response.
-
#top_logprobs ⇒ Integer?
An integer between 0 and 20 specifying the maximum number of most likely tokens to return at each token position, each with an associated log probability.
-
#top_p ⇒ Float?
An alternative to sampling with temperature, called nucleus sampling, where the model considers the results of the tokens with top_p probability mass.
- #truncation ⇒ Symbol, ... deprecated Deprecated.
- #user ⇒ String? deprecated Deprecated.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Symbol, OpenAI::Models::Beta::BetaToolChoiceOptions, OpenAI::Models::Beta::BetaToolChoiceAllowed, OpenAI::Models::Beta::BetaToolChoiceTypes, OpenAI::Models::Beta::BetaToolChoiceFunction, OpenAI::Models::Beta::BetaToolChoiceMcp, OpenAI::Models::Beta::BetaToolChoiceCustom, OpenAI::Models::Beta::ResponseCreateParams::ToolChoice::BetaSpecificProgrammaticToolCallingParam, OpenAI::Models::Beta::BetaToolChoiceApplyPatch, OpenAI::Models::Beta::BetaToolChoiceShell)
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type: :programmatic_tool_calling) ⇒ Object
|
|
# File 'lib/openai/models/beta/response_create_params.rb', line 444
|
Instance Attribute Details
#background ⇒ Boolean?
Whether to run the model response in the background. Learn more.
18 |
# File 'lib/openai/models/beta/response_create_params.rb', line 18 optional :background, OpenAI::Internal::Type::Boolean, nil?: true |
#betas ⇒ Array<Symbol, OpenAI::Models::Beta::ResponseCreateParams::Beta>?
359 |
# File 'lib/openai/models/beta/response_create_params.rb', line 359 optional :betas, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Beta::ResponseCreateParams::Beta] } |
#context_management ⇒ Array<OpenAI::Models::Beta::ResponseCreateParams::ContextManagement>?
Context management configuration for this request.
24 25 26 27 28 |
# File 'lib/openai/models/beta/response_create_params.rb', line 24 optional :context_management, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::ResponseCreateParams::ContextManagement] }, nil?: true |
#conversation ⇒ String, ...
The conversation that this response belongs to. Items from this conversation are
prepended to input_items for this response request. Input items and output
items from this response are automatically added to this conversation after this
response completes.
37 |
# File 'lib/openai/models/beta/response_create_params.rb', line 37 optional :conversation, union: -> { OpenAI::Beta::ResponseCreateParams::Conversation }, nil?: true |
#include ⇒ Array<Symbol, OpenAI::Models::Beta::BetaResponseIncludable>?
Specify additional output data to include in the model response. Currently supported values are:
web_search_call.action.sources: Include the sources of the web search tool call.code_interpreter_call.outputs: Includes the outputs of python code execution in code interpreter tool call items.computer_call_output.output.image_url: Include image urls from the computer call output.file_search_call.results: Include the search results of the file search tool call.message.input_image.image_url: Include image urls from the input message.message.output_text.logprobs: Include logprobs with assistant messages.reasoning.encrypted_content: Includes an encrypted version of reasoning tokens in reasoning item outputs. This enables reasoning items to be used in multi-turn conversations when using the Responses API statelessly (like when thestoreparameter is set tofalse, or when an organization is enrolled in the zero data retention program).
60 61 62 |
# File 'lib/openai/models/beta/response_create_params.rb', line 60 optional :include, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Beta::BetaResponseIncludable] }, nil?: true |
#input ⇒ String, ...
Text, image, or file inputs to the model, used to generate a response.
Learn more:
76 |
# File 'lib/openai/models/beta/response_create_params.rb', line 76 optional :input, union: -> { OpenAI::Beta::ResponseCreateParams::Input } |
#instructions ⇒ String?
A system (or developer) message inserted into the model's context.
When using along with previous_response_id, the instructions from a previous
response will not be carried over to the next response. This makes it simple to
swap out system (or developer) messages in new responses.
86 |
# File 'lib/openai/models/beta/response_create_params.rb', line 86 optional :instructions, String, nil?: true |
#max_output_tokens ⇒ Integer?
An upper bound for the number of tokens that can be generated for a response, including visible output tokens and reasoning tokens.
94 |
# File 'lib/openai/models/beta/response_create_params.rb', line 94 optional :max_output_tokens, Integer, nil?: true |
#max_tool_calls ⇒ Integer?
The maximum number of total calls to built-in tools that can be processed in a response. This maximum number applies across all built-in tool calls, not per individual tool. Any further attempts to call a tool by the model will be ignored.
103 |
# File 'lib/openai/models/beta/response_create_params.rb', line 103 optional :max_tool_calls, Integer, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
114 |
# File 'lib/openai/models/beta/response_create_params.rb', line 114 optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true |
#model ⇒ Symbol, ...
Model ID used to generate the response, like gpt-4o or o3. OpenAI offers a
wide range of models with different capabilities, performance characteristics,
and price points. Refer to the
model guide to browse and compare
available models.
124 |
# File 'lib/openai/models/beta/response_create_params.rb', line 124 optional :model, union: -> { OpenAI::Beta::ResponseCreateParams::Model } |
#moderation ⇒ OpenAI::Models::Beta::ResponseCreateParams::Moderation?
Configuration for running moderation on the input and output of this response.
130 |
# File 'lib/openai/models/beta/response_create_params.rb', line 130 optional :moderation, -> { OpenAI::Beta::ResponseCreateParams::Moderation }, nil?: true |
#multi_agent ⇒ OpenAI::Models::Beta::ResponseCreateParams::MultiAgent?
Configuration for server-hosted multi-agent execution.
136 |
# File 'lib/openai/models/beta/response_create_params.rb', line 136 optional :multi_agent, -> { OpenAI::Beta::ResponseCreateParams::MultiAgent }, nil?: true |
#parallel_tool_calls ⇒ Boolean?
Whether to allow the model to run tool calls in parallel.
142 |
# File 'lib/openai/models/beta/response_create_params.rb', line 142 optional :parallel_tool_calls, OpenAI::Internal::Type::Boolean, nil?: true |
#previous_response_id ⇒ String?
The unique ID of the previous response to the model. Use this to create
multi-turn conversations. Learn more about
conversation state.
Cannot be used in conjunction with conversation.
151 |
# File 'lib/openai/models/beta/response_create_params.rb', line 151 optional :previous_response_id, String, nil?: true |
#prompt ⇒ OpenAI::Models::Beta::BetaResponsePrompt?
Reference to a prompt template and its variables. Learn more.
158 |
# File 'lib/openai/models/beta/response_create_params.rb', line 158 optional :prompt, -> { OpenAI::Beta::BetaResponsePrompt }, nil?: true |
#prompt_cache_key ⇒ String?
Used by OpenAI to cache responses for similar requests to optimize your cache
hit rates. Replaces the user field.
Learn more.
166 |
# File 'lib/openai/models/beta/response_create_params.rb', line 166 optional :prompt_cache_key, String |
#prompt_cache_options ⇒ OpenAI::Models::Beta::ResponseCreateParams::PromptCacheOptions?
Options for prompt caching. Supported for gpt-5.6 and later models. By
default, OpenAI automatically chooses one implicit cache breakpoint. You can add
explicit breakpoints to content blocks with prompt_cache_breakpoint. Each
request can write up to four breakpoints. For cache matching, OpenAI considers
up to the latest 80 breakpoints in the conversation, without a content-block
lookback limit. Set mode to explicit to disable the implicit breakpoint. The
ttl defaults to 30m, which is currently the only supported value. See the
prompt caching guide
for current details.
180 |
# File 'lib/openai/models/beta/response_create_params.rb', line 180 optional :prompt_cache_options, -> { OpenAI::Beta::ResponseCreateParams::PromptCacheOptions } |
#prompt_cache_retention ⇒ Symbol, ...
Deprecated. Use prompt_cache_options.ttl instead.
The retention policy for the prompt cache. Set to 24h to enable extended
prompt caching, which keeps cached prefixes active for longer, up to a maximum
of 24 hours.
Learn more.
This field expresses a maximum retention policy, while
prompt_cache_options.ttl expresses a minimum cache lifetime. The two fields
are independent and do not interact. For gpt-5.5, gpt-5.5-pro, and future
models, only 24h is supported.
For older models that support both in_memory and 24h, the default depends on
your organization's data retention policy:
- Organizations without ZDR enabled default to
24h. - Organizations with ZDR enabled default to
in_memorywhenprompt_cache_retentionis not specified.
204 205 206 |
# File 'lib/openai/models/beta/response_create_params.rb', line 204 optional :prompt_cache_retention, enum: -> { OpenAI::Beta::ResponseCreateParams::PromptCacheRetention }, nil?: true |
#reasoning ⇒ OpenAI::Models::Beta::ResponseCreateParams::Reasoning?
gpt-5 and o-series models only
Configuration options for reasoning models.
215 |
# File 'lib/openai/models/beta/response_create_params.rb', line 215 optional :reasoning, -> { OpenAI::Beta::ResponseCreateParams::Reasoning }, nil?: true |
#safety_identifier ⇒ String?
A stable identifier used to help detect users of your application that may be violating OpenAI's usage policies. The IDs should be a string that uniquely identifies each user, with a maximum length of 64 characters. We recommend hashing their username or email address, in order to avoid sending us any identifying information. Learn more.
226 |
# File 'lib/openai/models/beta/response_create_params.rb', line 226 optional :safety_identifier, String |
#service_tier ⇒ Symbol, ...
Specifies the processing type used for serving the request.
- If set to 'auto', then the request will be processed with the service tier configured in the Project settings. Unless otherwise configured, the Project will use 'default'.
- If set to 'default', then the request will be processed with the standard pricing and performance for the selected model.
- If set to 'flex' or 'priority', then the request will be processed with the corresponding service tier.
- When not set, the default behavior is 'auto'.
When the service_tier parameter is set, the response body will include the
service_tier value based on the processing mode actually used to serve the
request. This response value may be different from the value set in the
parameter.
247 |
# File 'lib/openai/models/beta/response_create_params.rb', line 247 optional :service_tier, enum: -> { OpenAI::Beta::ResponseCreateParams::ServiceTier }, nil?: true |
#store ⇒ Boolean?
Whether to store the generated model response for later retrieval via API.
253 |
# File 'lib/openai/models/beta/response_create_params.rb', line 253 optional :store, OpenAI::Internal::Type::Boolean, nil?: true |
#stream_options ⇒ OpenAI::Models::Beta::ResponseCreateParams::StreamOptions?
Options for streaming responses. Only set this when you set stream: true.
259 |
# File 'lib/openai/models/beta/response_create_params.rb', line 259 optional :stream_options, -> { OpenAI::Beta::ResponseCreateParams::StreamOptions }, nil?: true |
#temperature ⇒ Float?
What sampling temperature to use, between 0 and 2. Higher values like 0.8 will
make the output more random, while lower values like 0.2 will make it more
focused and deterministic. We generally recommend altering this or top_p but
not both.
268 |
# File 'lib/openai/models/beta/response_create_params.rb', line 268 optional :temperature, Float, nil?: true |
#text ⇒ OpenAI::Models::Beta::BetaResponseTextConfig?
Configuration options for a text response from the model. Can be plain text or structured JSON data. Learn more:
278 |
# File 'lib/openai/models/beta/response_create_params.rb', line 278 optional :text, -> { OpenAI::Beta::BetaResponseTextConfig } |
#tool_choice ⇒ Symbol, ...
How the model should select which tool (or tools) to use when generating a
response. See the tools parameter to see how to specify which tools the model
can call.
286 |
# File 'lib/openai/models/beta/response_create_params.rb', line 286 optional :tool_choice, union: -> { OpenAI::Beta::ResponseCreateParams::ToolChoice } |
#tools ⇒ Array<OpenAI::Models::Beta::BetaFunctionTool, OpenAI::Models::Beta::BetaFileSearchTool, OpenAI::Models::Beta::BetaComputerTool, OpenAI::Models::Beta::BetaComputerUsePreviewTool, OpenAI::Models::Beta::BetaTool::Mcp, OpenAI::Models::Beta::BetaTool::CodeInterpreter, OpenAI::Models::Beta::BetaTool::ProgrammaticToolCalling, OpenAI::Models::Beta::BetaTool::ImageGeneration, OpenAI::Models::Beta::BetaTool::LocalShell, OpenAI::Models::Beta::BetaFunctionShellTool, OpenAI::Models::Beta::BetaCustomTool, OpenAI::Models::Beta::BetaNamespaceTool, OpenAI::Models::Beta::BetaToolSearchTool, OpenAI::Models::Beta::BetaApplyPatchTool, OpenAI::Models::Beta::BetaWebSearchTool, OpenAI::Models::Beta::BetaWebSearchPreviewTool>?
An array of tools the model may call while generating a response. You can
specify which tool to use by setting the tool_choice parameter.
We support the following categories of tools:
- Built-in tools: Tools that are provided by OpenAI that extend the model's capabilities, like web search or file search. Learn more about built-in tools.
- MCP Tools: Integrations with third-party systems via custom MCP servers or predefined connectors such as Google Drive and SharePoint. Learn more about MCP Tools.
- Function calls (custom tools): Functions that are defined by you, enabling the model to call your own code with strongly typed arguments and outputs. Learn more about function calling. You can also use custom tools to call your own code.
310 |
# File 'lib/openai/models/beta/response_create_params.rb', line 310 optional :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::BetaTool] } |
#top_logprobs ⇒ Integer?
An integer between 0 and 20 specifying the maximum number of most likely tokens to return at each token position, each with an associated log probability. In some cases, the number of returned tokens may be fewer than requested.
318 |
# File 'lib/openai/models/beta/response_create_params.rb', line 318 optional :top_logprobs, Integer, nil?: true |
#top_p ⇒ Float?
An alternative to sampling with temperature, called nucleus sampling, where the model considers the results of the tokens with top_p probability mass. So 0.1 means only the tokens comprising the top 10% probability mass are considered.
We generally recommend altering this or temperature but not both.
328 |
# File 'lib/openai/models/beta/response_create_params.rb', line 328 optional :top_p, Float, nil?: true |
#truncation ⇒ Symbol, ...
The truncation strategy to use for the model response.
auto: If the input to this Response exceeds the model's context window size, the model will truncate the response to fit the context window by dropping items from the beginning of the conversation.disabled(default): If the input size will exceed the context window size for a model, the request will fail with a 400 error.
342 |
# File 'lib/openai/models/beta/response_create_params.rb', line 342 optional :truncation, enum: -> { OpenAI::Beta::ResponseCreateParams::Truncation }, nil?: true |
#user ⇒ String?
This field is being replaced by safety_identifier and prompt_cache_key. Use
prompt_cache_key instead to maintain caching optimizations. A stable
identifier for your end-users. Used to boost cache hit rates by better bucketing
similar requests and to help OpenAI detect and prevent abuse.
Learn more.
354 |
# File 'lib/openai/models/beta/response_create_params.rb', line 354 optional :user, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/response_create_params.rb', line 891
|
.variants ⇒ Array(Symbol, OpenAI::Models::Beta::BetaToolChoiceOptions, OpenAI::Models::Beta::BetaToolChoiceAllowed, OpenAI::Models::Beta::BetaToolChoiceTypes, OpenAI::Models::Beta::BetaToolChoiceFunction, OpenAI::Models::Beta::BetaToolChoiceMcp, OpenAI::Models::Beta::BetaToolChoiceCustom, OpenAI::Models::Beta::ResponseCreateParams::ToolChoice::BetaSpecificProgrammaticToolCallingParam, OpenAI::Models::Beta::BetaToolChoiceApplyPatch, OpenAI::Models::Beta::BetaToolChoiceShell)
|
|
# File 'lib/openai/models/beta/response_create_params.rb', line 463
|
Instance Method Details
#to_hash ⇒ {
179 |
# File 'sig/openai/models/beta/response_create_params.rbs', line 179
def to_hash: -> {
|