Class: OpenAI::Models::Beta::ResponseCreateParams::AccessPrograms

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/response_create_params.rb,
sig/openai/models/beta/response_create_params.rbs

Defined Under Namespace

Modules: Cyber

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cyber: nil) ⇒ Object

Parameters:

  • cyber (defaults to: nil) —

    The Cyber access program to use for this request. Supported values are standard, daybreak_blue, and daybreak_red. If omitted, the API resolves the program from the model's Cyber tier and your organization and project access, subject to model-specific eligibility restrictions. By default, models without a Cyber tier use Standard. Blue-tier models use Daybreak Blue when authorized; otherwise they fall back to Standard unless the model requires Daybreak access. Red-tier models use Daybreak Red and require authorization. Requests that require unavailable Daybreak access return 403. An implicit Standard fallback is represented by null in the response's access_programs field, rather than an explicit Standard selection.



641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
# File 'lib/openai/models/beta/response_create_params.rb', line 641

class AccessPrograms < OpenAI::Internal::Type::BaseModel
  # @!attribute cyber
  #   The Cyber access program to use for this request. Supported values are
  #   `standard`, `daybreak_blue`, and `daybreak_red`. If omitted, the API resolves
  #   the program from the model's Cyber tier and your organization and project
  #   access, subject to model-specific eligibility restrictions. By default, models
  #   without a Cyber tier use Standard. Blue-tier models use Daybreak Blue when
  #   authorized; otherwise they fall back to Standard unless the model requires
  #   Daybreak access. Red-tier models use Daybreak Red and require authorization.
  #   Requests that require unavailable Daybreak access return 403. An implicit
  #   Standard fallback is represented by null in the response's access_programs
  #   field, rather than an explicit Standard selection.
  #
  #   @return [Symbol, OpenAI::Models::Beta::ResponseCreateParams::AccessPrograms::Cyber, nil]
  optional :cyber, enum: -> { OpenAI::Beta::ResponseCreateParams::AccessPrograms::Cyber }

  # @!method initialize(cyber: nil)
  #   Domain-specific access programs to use for this request.
  #
  #   @param cyber [Symbol, OpenAI::Models::Beta::ResponseCreateParams::AccessPrograms::Cyber]
  #     The Cyber access program to use for this request. Supported values are
  #     `standard`, `daybreak_blue`, and `daybreak_red`. If omitted, the API resolves
  #     the program from the model's Cyber tier and your organization and project
  #     access, subject to model-specific eligibility restrictions. By default, models
  #     without a Cyber tier use Standard. Blue-tier models use Daybreak Blue when
  #     authorized; otherwise they fall back to Standard unless the model requires
  #     Daybreak access. Red-tier models use Daybreak Red and require authorization.
  #     Requests that require unavailable Daybreak access return 403. An implicit
  #     Standard fallback is represented by null in the response's access_programs
  #     field, rather than an explicit Standard selection.

  # The Cyber access program to use for this request. Supported values are
  # `standard`, `daybreak_blue`, and `daybreak_red`. If omitted, the API resolves
  # the program from the model's Cyber tier and your organization and project
  # access, subject to model-specific eligibility restrictions. By default, models
  # without a Cyber tier use Standard. Blue-tier models use Daybreak Blue when
  # authorized; otherwise they fall back to Standard unless the model requires
  # Daybreak access. Red-tier models use Daybreak Red and require authorization.
  # Requests that require unavailable Daybreak access return 403. An implicit
  # Standard fallback is represented by null in the response's access_programs
  # field, rather than an explicit Standard selection.
  #
  # @see OpenAI::Models::Beta::ResponseCreateParams::AccessPrograms#cyber
  module Cyber
    extend OpenAI::Internal::Type::Enum

    STANDARD = :standard
    DAYBREAK_BLUE = :daybreak_blue
    DAYBREAK_RED = :daybreak_red

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#cyber ⇒ OpenAI::Models::Beta::ResponseCreateParams::AccessPrograms::cyber?

The Cyber access program to use for this request. Supported values are standard, daybreak_blue, and daybreak_red. If omitted, the API resolves the program from the model's Cyber tier and your organization and project access, subject to model-specific eligibility restrictions. By default, models without a Cyber tier use Standard. Blue-tier models use Daybreak Blue when authorized; otherwise they fall back to Standard unless the model requires Daybreak access. Red-tier models use Daybreak Red and require authorization. Requests that require unavailable Daybreak access return 403. An implicit Standard fallback is represented by null in the response's access_programs field, rather than an explicit Standard selection.

Returns:

  • (OpenAI::Models::Beta::ResponseCreateParams::AccessPrograms::cyber, nil)


655
# File 'lib/openai/models/beta/response_create_params.rb', line 655

optional :cyber, enum: -> { OpenAI::Beta::ResponseCreateParams::AccessPrograms::Cyber }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


730
# File 'sig/openai/models/beta/response_create_params.rbs', line 730

def to_hash: -> {