Module: OpenAI::Models::Beta::ResponseCreateParams::Conversation

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/beta/response_create_params.rb,
sig/openai/models/beta/response_create_params.rbs

Overview

The conversation that this response belongs to. Items from this conversation are prepended to input_items for this response request. Input items and output items from this response are automatically added to this conversation after this response completes.

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.variants::Array[OpenAI::Models::Beta::ResponseCreateParams::conversation]

Returns:

  • (::Array[OpenAI::Models::Beta::ResponseCreateParams::conversation])


232
# File 'sig/openai/models/beta/response_create_params.rbs', line 232

def self?.variants: -> ::Array[OpenAI::Models::Beta::ResponseCreateParams::conversation]