Class: OpenAI::Models::Beta::ResponseCreateParams::MultiAgent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/response_create_params.rb,
sig/openai/models/beta/response_create_params.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • enabled —

    Whether to enable server-hosted multi-agent execution for this response.

  • max_concurrent_subagents —

    max_concurrent_subagents sets the maximum number of subagents that can be active simultaneously across the entire agent tree. It includes all descendants—children, grandchildren, and deeper subagents—but excludes the root agent. The API does not impose a fixed upper bound on this setting. The default is 3, which is recommended for most workloads. Multi-agent runs also have no fixed limit on tree depth or the total number of subagents created during a run.



1075
# File 'sig/openai/models/beta/response_create_params.rbs', line 1075

def initialize: (

Instance Attribute Details

#enabled ⇒ Boolean

Whether to enable server-hosted multi-agent execution for this response.

Returns:



1151
# File 'lib/openai/models/beta/response_create_params.rb', line 1151

required :enabled, OpenAI::Internal::Type::Boolean

#max_concurrent_subagents ⇒ Integer?

max_concurrent_subagents sets the maximum number of subagents that can be active simultaneously across the entire agent tree. It includes all descendants—children, grandchildren, and deeper subagents—but excludes the root agent. The API does not impose a fixed upper bound on this setting. The default is 3, which is recommended for most workloads. Multi-agent runs also have no fixed limit on tree depth or the total number of subagents created during a run.

Returns:

  • (Integer, nil)


1162
# File 'lib/openai/models/beta/response_create_params.rb', line 1162

optional :max_concurrent_subagents, Integer

Instance Method Details

#to_hash ⇒ { enabled: bool, ?max_concurrent_subagents: Integer }

Returns:

  • ({ enabled: bool, ?max_concurrent_subagents: Integer })


1080
# File 'sig/openai/models/beta/response_create_params.rbs', line 1080

def to_hash: -> { enabled: bool, ?max_concurrent_subagents: Integer }