Class: OpenAI::Models::Beta::ResponseCreateParams::PromptCacheOptions
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::ResponseCreateParams::PromptCacheOptions
- Defined in:
- lib/openai/models/beta/response_create_params.rb,
sig/openai/models/beta/response_create_params.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#comparison_response_id ⇒ String?
The ID of a response to compare when diagnosing prompt cache reuse.
-
#mode ⇒ OpenAI::Models::Beta::ResponseCreateParams::PromptCacheOptions::mode?
Controls whether OpenAI automatically creates an implicit cache breakpoint.
-
#prewarm ⇒ Boolean?
Prepares the prompt cache without generating output.
-
#ttl ⇒ OpenAI::Models::Beta::ResponseCreateParams::PromptCacheOptions::ttl?
The minimum lifetime applied to every implicit and explicit cache breakpoint written by the request.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(comparison_response_id: nil, mode: nil, prewarm: nil, ttl: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(comparison_response_id: nil, mode: nil, prewarm: nil, ttl: nil) ⇒ Object
|
|
# File 'lib/openai/models/beta/response_create_params.rb', line 1213
|
Instance Attribute Details
#comparison_response_id ⇒ String?
The ID of a response to compare when diagnosing prompt cache reuse. Supplying this field requests prompt cache diagnostics when the feature is enabled.
1185 |
# File 'lib/openai/models/beta/response_create_params.rb', line 1185 optional :comparison_response_id, String, nil?: true |
#mode ⇒ OpenAI::Models::Beta::ResponseCreateParams::PromptCacheOptions::mode?
Controls whether OpenAI automatically creates an implicit cache breakpoint.
Defaults to implicit. With implicit, OpenAI creates one implicit breakpoint
and writes up to the latest three explicit breakpoints in the request. With
explicit, OpenAI does not create an implicit breakpoint and writes up to the
latest four explicit breakpoints. If there are no explicit breakpoints, the
request does not use prompt caching.
1196 |
# File 'lib/openai/models/beta/response_create_params.rb', line 1196 optional :mode, enum: -> { OpenAI::Beta::ResponseCreateParams::PromptCacheOptions::Mode } |
#prewarm ⇒ Boolean?
Prepares the prompt cache without generating output. Defaults to false. When
set to true, overrides the generate field to false.
1203 |
# File 'lib/openai/models/beta/response_create_params.rb', line 1203 optional :prewarm, OpenAI::Internal::Type::Boolean |
#ttl ⇒ OpenAI::Models::Beta::ResponseCreateParams::PromptCacheOptions::ttl?
The minimum lifetime applied to every implicit and explicit cache breakpoint
written by the request. Defaults to 30m, which is currently the only supported
value. The backend may retain cache entries for longer.
1211 |
# File 'lib/openai/models/beta/response_create_params.rb', line 1211 optional :ttl, enum: -> { OpenAI::Beta::ResponseCreateParams::PromptCacheOptions::Ttl } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/response_create_params.rb', line 1259
|
Instance Method Details
#to_hash ⇒ {
1158 |
# File 'sig/openai/models/beta/response_create_params.rbs', line 1158
def to_hash: -> {
|