Class: OpenAI::Models::Beta::ResponseCreateParams::Reasoning

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/response_create_params.rb,
sig/openai/models/beta/response_create_params.rbs

Defined Under Namespace

Modules: Context, Effort, GenerateSummary, Mode, Summary

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(context: nil, effort: nil, generate_summary: nil, mode: nil, summary: nil) ⇒ Object

Parameters:

  • context (defaults to: nil)

    Controls which reasoning items are rendered back to the model on later turns. If omitted or set to auto, the model determines the context mode. The gpt-5.6 model family defaults to all_turns; earlier models default to current_turn.

    When returned on a response, this is the effective reasoning context mode used for the response.

  • effort (defaults to: nil)

    Constrains effort on reasoning for reasoning models. Currently supported values are none, minimal, low, medium, high, xhigh, and max. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response. Not all reasoning models support every value. See the reasoning guide for model-specific support.

  • generate_summary (defaults to: nil)

    Deprecated: use summary instead.

    A summary of the reasoning performed by the model. This can be useful for debugging and understanding the model's reasoning process. One of auto, concise, or detailed.

  • mode (defaults to: nil)

    Controls the reasoning execution mode for the request.

    When returned on a response, this is the effective execution mode.

  • summary (defaults to: nil)

    A summary of the reasoning performed by the model. This can be useful for debugging and understanding the model's reasoning process. One of auto, concise, or detailed.

    concise is supported for computer-use-preview models and all reasoning models after gpt-5.



# File 'lib/openai/models/beta/response_create_params.rb', line 1365

Instance Attribute Details

#contextOpenAI::Models::Beta::ResponseCreateParams::Reasoning::context?

Controls which reasoning items are rendered back to the model on later turns. If omitted or set to auto, the model determines the context mode. The gpt-5.6 model family defaults to all_turns; earlier models default to current_turn.

When returned on a response, this is the effective reasoning context mode used for the response.

Returns:

  • (OpenAI::Models::Beta::ResponseCreateParams::Reasoning::context, nil)


1317
# File 'lib/openai/models/beta/response_create_params.rb', line 1317

optional :context, enum: -> { OpenAI::Beta::ResponseCreateParams::Reasoning::Context }, nil?: true

#effortOpenAI::Models::Beta::ResponseCreateParams::Reasoning::effort?

Constrains effort on reasoning for reasoning models. Currently supported values are none, minimal, low, medium, high, xhigh, and max. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response. Not all reasoning models support every value. See the reasoning guide for model-specific support.

Returns:

  • (OpenAI::Models::Beta::ResponseCreateParams::Reasoning::effort, nil)


1328
# File 'lib/openai/models/beta/response_create_params.rb', line 1328

optional :effort, enum: -> { OpenAI::Beta::ResponseCreateParams::Reasoning::Effort }, nil?: true

#generate_summaryOpenAI::Models::Beta::ResponseCreateParams::Reasoning::generate_summary?

Deprecated: use summary instead.

A summary of the reasoning performed by the model. This can be useful for debugging and understanding the model's reasoning process. One of auto, concise, or detailed.

Returns:

  • (OpenAI::Models::Beta::ResponseCreateParams::Reasoning::generate_summary, nil)


1340
1341
1342
1343
1344
# File 'lib/openai/models/beta/response_create_params.rb', line 1340

optional(
  :generate_summary,
  enum: -> { OpenAI::Beta::ResponseCreateParams::Reasoning::GenerateSummary },
  nil?: true
)

#modeOpenAI::Models::Beta::ResponseCreateParams::Reasoning::mode?

Controls the reasoning execution mode for the request.

When returned on a response, this is the effective execution mode.

Returns:

  • (OpenAI::Models::Beta::ResponseCreateParams::Reasoning::mode, nil)


1352
# File 'lib/openai/models/beta/response_create_params.rb', line 1352

optional :mode, union: -> { OpenAI::Beta::ResponseCreateParams::Reasoning::Mode }

#summaryOpenAI::Models::Beta::ResponseCreateParams::Reasoning::summary?

A summary of the reasoning performed by the model. This can be useful for debugging and understanding the model's reasoning process. One of auto, concise, or detailed.

concise is supported for computer-use-preview models and all reasoning models after gpt-5.

Returns:

  • (OpenAI::Models::Beta::ResponseCreateParams::Reasoning::summary, nil)


1363
# File 'lib/openai/models/beta/response_create_params.rb', line 1363

optional :summary, enum: -> { OpenAI::Beta::ResponseCreateParams::Reasoning::Summary }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/response_create_params.rb', line 1420

Instance Method Details

#to_hash{

Returns:

  • ({)


1290
# File 'sig/openai/models/beta/response_create_params.rbs', line 1290

def to_hash: -> {