Module: OpenAI::Models::Beta::ResponseCreateParams::Reasoning::Effort
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/beta/response_create_params.rb,
sig/openai/models/beta/response_create_params.rbs
Overview
Constrains effort on reasoning for reasoning models. Currently supported values
are none, minimal, low, medium, high, xhigh, and max. Reducing
reasoning effort can result in faster responses and fewer tokens used on
reasoning in a response. Not all reasoning models support every value. See the
reasoning guide for
model-specific support.
Constant Summary collapse
- NONE =
:none- MINIMAL =
:minimal- LOW =
:low- MEDIUM =
:medium- HIGH =
:high- XHIGH =
:xhigh- MAX =
:max
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[OpenAI::Models::Beta::ResponseCreateParams::Reasoning::effort]
688 |
# File 'sig/openai/models/beta/response_create_params.rbs', line 688
def self?.values: -> ::Array[OpenAI::Models::Beta::ResponseCreateParams::Reasoning::effort]
|