Class: OpenAI::Models::Beta::ResponseRetrieveParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::ResponseRetrieveParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/beta/response_retrieve_params.rb,
sig/openai/models/beta/response_retrieve_params.rbs
Overview
Defined Under Namespace
Modules: Beta
Instance Attribute Summary collapse
- #betas ⇒ Array<Symbol, OpenAI::Models::Beta::ResponseRetrieveParams::Beta>?
-
#include ⇒ Array<Symbol, OpenAI::Models::Beta::BetaResponseIncludable>?
Additional fields to include in the response.
-
#include_obfuscation ⇒ Boolean?
When true, stream obfuscation will be enabled.
- #response_id ⇒ String
-
#starting_after ⇒ Integer?
The sequence number of the event after which to start streaming.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
40 |
# File 'sig/openai/models/beta/response_retrieve_params.rbs', line 40
def initialize: (
|
Instance Attribute Details
#betas ⇒ Array<Symbol, OpenAI::Models::Beta::ResponseRetrieveParams::Beta>?
45 |
# File 'lib/openai/models/beta/response_retrieve_params.rb', line 45 optional :betas, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Beta::ResponseRetrieveParams::Beta] } |
#include ⇒ Array<Symbol, OpenAI::Models::Beta::BetaResponseIncludable>?
Additional fields to include in the response. See the include parameter for
Response creation above for more information.
23 |
# File 'lib/openai/models/beta/response_retrieve_params.rb', line 23 optional :include, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Beta::BetaResponseIncludable] } |
#include_obfuscation ⇒ Boolean?
When true, stream obfuscation will be enabled. Stream obfuscation adds random
characters to an obfuscation field on streaming delta events to normalize
payload sizes as a mitigation to certain side-channel attacks. These obfuscation
fields are included by default, but add a small amount of overhead to the data
stream. You can set include_obfuscation to false to optimize for bandwidth if
you trust the network links between your application and the OpenAI API.
34 |
# File 'lib/openai/models/beta/response_retrieve_params.rb', line 34 optional :include_obfuscation, OpenAI::Internal::Type::Boolean |
#response_id ⇒ String
16 |
# File 'lib/openai/models/beta/response_retrieve_params.rb', line 16 required :response_id, String |
#starting_after ⇒ Integer?
The sequence number of the event after which to start streaming.
40 |
# File 'lib/openai/models/beta/response_retrieve_params.rb', line 40 optional :starting_after, Integer |
Instance Method Details
#to_hash ⇒ {
49 |
# File 'sig/openai/models/beta/response_retrieve_params.rbs', line 49
def to_hash: -> {
|