Class: OpenAI::Models::Beta::Responses::InputItemListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/beta/responses/input_item_list_params.rb,
sig/openai/models/beta/responses/input_item_list_params.rbs

Overview

See Also:

  • OpenAI::Resources::Beta::Responses::InputItems#list

Defined Under Namespace

Modules: Beta, Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(response_id:, after: nil, include: nil, limit: nil, order: nil, betas: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Beta::Responses::InputItemListParams for more details.

Parameters:



# File 'lib/openai/models/beta/responses/input_item_list_params.rb', line 52

Instance Attribute Details

#afterString?

An item ID to list items after, used in pagination.

Parameters:

  • (String)

Returns:

  • (String, nil)


21
# File 'lib/openai/models/beta/responses/input_item_list_params.rb', line 21

optional :after, String

#betasArray<Symbol, OpenAI::Models::Beta::Responses::InputItemListParams::Beta>?



49
50
# File 'lib/openai/models/beta/responses/input_item_list_params.rb', line 49

optional :betas,
-> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Beta::Responses::InputItemListParams::Beta] }

#includeArray<Symbol, OpenAI::Models::Beta::BetaResponseIncludable>?

Additional fields to include in the response. See the include parameter for Response creation above for more information.

Returns:



28
# File 'lib/openai/models/beta/responses/input_item_list_params.rb', line 28

optional :include, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Beta::BetaResponseIncludable] }

#limitInteger?

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


35
# File 'lib/openai/models/beta/responses/input_item_list_params.rb', line 35

optional :limit, Integer

#orderSymbol, ...

The order to return the input items in. Default is desc.

  • asc: Return the input items in ascending order.
  • desc: Return the input items in descending order.


44
# File 'lib/openai/models/beta/responses/input_item_list_params.rb', line 44

optional :order, enum: -> { OpenAI::Beta::Responses::InputItemListParams::Order }

#response_idString

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/openai/models/beta/responses/input_item_list_params.rb', line 15

required :response_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/responses/input_item_list_params.rb', line 80

Instance Method Details

#to_hash{

Returns:

  • ({)


58
# File 'sig/openai/models/beta/responses/input_item_list_params.rbs', line 58

def to_hash: -> {