Module: OpenAI::Models::Beta::Responses::InputTokenCountParams::Truncation Deprecated
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/beta/responses/input_token_count_params.rb,
sig/openai/models/beta/responses/input_token_count_params.rbs
Overview
Deprecated.
The truncation strategy to use for the model response. - auto: If the input to
this Response exceeds the model's context window size, the model will truncate
the response to fit the context window by dropping items from the beginning of
the conversation. - disabled (default): If the input size will exceed the
context window size for a model, the request will fail with a 400 error.
Constant Summary collapse
- AUTO =
:auto- DISABLED =
:disabled
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[OpenAI::Models::Beta::Responses::InputTokenCountParams::truncation]
309 |
# File 'sig/openai/models/beta/responses/input_token_count_params.rbs', line 309
def self?.values: -> ::Array[OpenAI::Models::Beta::Responses::InputTokenCountParams::truncation]
|