Class: OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/thread_create_and_run_params.rb,
sig/openai/models/beta/thread_create_and_run_params.rbs

Defined Under Namespace

Classes: Message, ToolResources

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type: :file_search) ⇒ Object

Parameters:

  • A list of messages to start the thread with.

  • Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

    Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

  • A set of resources that are made available to the assistant's tools in this thread. The resources are specific to the type of tool. For example, the code_interpreter tool requires a list of file IDs, while the file_search tool requires a list of vector store IDs.



# File 'lib/openai/models/beta/thread_create_and_run_params.rb', line 508

Instance Attribute Details

#messages::Array[OpenAI::Beta::ThreadCreateAndRunParams::Thread::Message]?

A list of messages to start the thread with.

Returns:



303
304
305
306
# File 'lib/openai/models/beta/thread_create_and_run_params.rb', line 303

optional(
  :messages,
  -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::ThreadCreateAndRunParams::Thread::Message] }
)

#metadataOpenAI::Models::metadata?

Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

Returns:



317
# File 'lib/openai/models/beta/thread_create_and_run_params.rb', line 317

optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true

#tool_resourcesOpenAI::Beta::ThreadCreateAndRunParams::Thread::ToolResources?

A set of resources that are made available to the assistant's tools in this thread. The resources are specific to the type of tool. For example, the code_interpreter tool requires a list of file IDs, while the file_search tool requires a list of vector store IDs.

Returns:



326
327
328
329
330
331
332
# File 'lib/openai/models/beta/thread_create_and_run_params.rb', line 326

optional(
  :tool_resources,
  -> {
    OpenAI::Beta::ThreadCreateAndRunParams::Thread::ToolResources
  },
  nil?: true
)

Class Method Details

.variantsArray(OpenAI::Models::Beta::CodeInterpreterTool, OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::Message::Attachment::Tool::FileSearch)

Returns:



# File 'lib/openai/models/beta/thread_create_and_run_params.rb', line 513

Instance Method Details

#to_hash{

Returns:



334
# File 'sig/openai/models/beta/thread_create_and_run_params.rbs', line 334

def to_hash: -> {