Class: OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch
- Defined in:
- lib/openai/models/beta/thread_create_and_run_params.rb,
sig/openai/models/beta/thread_create_and_run_params.rbs
Overview
Defined Under Namespace
Classes: VectorStore
Instance Attribute Summary collapse
-
#vector_store_ids ⇒ Array<String>?
The vector store attached to this thread.
-
#vector_stores ⇒ Array<OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore>?
A helper to create a vector store with file_ids and attach it to this thread.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
301 |
# File 'sig/openai/models/beta/thread_create_and_run_params.rbs', line 301
def initialize: (
|
Instance Attribute Details
#vector_store_ids ⇒ Array<String>?
The vector store attached to this thread. There can be a maximum of 1 vector store attached to the thread.
450 |
# File 'lib/openai/models/beta/thread_create_and_run_params.rb', line 450 optional :vector_store_ids, OpenAI::Internal::Type::ArrayOf[String] |
#vector_stores ⇒ Array<OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore>?
A helper to create a vector store with file_ids and attach it to this thread. There can be a maximum of 1 vector store attached to the thread.
459 460 |
# File 'lib/openai/models/beta/thread_create_and_run_params.rb', line 459 optional :vector_stores, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore] } |
Instance Method Details
#to_hash ⇒ {
306 |
# File 'sig/openai/models/beta/thread_create_and_run_params.rbs', line 306
def to_hash: -> {
|