Class: OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/beta/thread_create_and_run_params.rb,
sig/openai/models/beta/thread_create_and_run_params.rbs

Defined Under Namespace

Modules: ChunkingStrategy

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(chunking_strategy: nil, file_ids: nil, metadata: nil) ⇒ Object

Parameters:

  • chunking_strategy (defaults to: nil) —

    The chunking strategy used to chunk the file(s). If not set, will use the auto strategy.

  • file_ids (defaults to: nil) —

    A list of file IDs to add to the vector store. For vector stores created before Nov 2025, there can be a maximum of 10,000 files in a vector store. For vector stores created starting in Nov 2025, the limit is 100,000,000 files.

  • metadata (defaults to: nil) —

    Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

    Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.



599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
# File 'lib/openai/models/beta/thread_create_and_run_params.rb', line 599

class VectorStore < OpenAI::Internal::Type::BaseModel
  # @!attribute chunking_strategy
  #   The chunking strategy used to chunk the file(s). If not set, will use the `auto`
  #   strategy.
  #
  #   @return [OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::ChunkingStrategy::Auto, OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::ChunkingStrategy::Static, nil]
  optional(
    :chunking_strategy,
    union: -> {
      OpenAI::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::ChunkingStrategy
    }
  )

  # @!attribute file_ids
  #   A list of [file](https://developers.openai.com/api/reference/resources/files)
  #   IDs to add to the vector store. For vector stores created before Nov 2025, there
  #   can be a maximum of 10,000 files in a vector store. For vector stores created
  #   starting in Nov 2025, the limit is 100,000,000 files.
  #
  #   @return [Array<String>, nil]
  optional :file_ids, OpenAI::Internal::Type::ArrayOf[String]

  # @!attribute metadata
  #   Set of 16 key-value pairs that can be attached to an object. This can be useful
  #   for storing additional information about the object in a structured format, and
  #   querying for objects via API or the dashboard.
  #
  #   Keys are strings with a maximum length of 64 characters. Values are strings with
  #   a maximum length of 512 characters.
  #
  #   @return [Hash{Symbol=>String}, nil]
  optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true

  # @!method initialize(chunking_strategy: nil, file_ids: nil, metadata: nil)
  #   @param chunking_strategy [OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::ChunkingStrategy::Auto, OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::ChunkingStrategy::Static]
  #     The chunking strategy used to chunk the file(s). If not set, will use the `auto`
  #     strategy.
  #
  #   @param file_ids [Array<String>]
  #     A list of [file](https://developers.openai.com/api/reference/resources/files)
  #     IDs to add to the vector store. For vector stores created before Nov 2025, there
  #     can be a maximum of 10,000 files in a vector store. For vector stores created
  #     starting in Nov 2025, the limit is 100,000,000 files.
  #
  #   @param metadata [Hash{Symbol=>String}, nil]
  #     Set of 16 key-value pairs that can be attached to an object. This can be useful
  #     for storing additional information about the object in a structured format, and
  #     querying for objects via API or the dashboard.
  #
  #     Keys are strings with a maximum length of 64 characters. Values are strings with
  #     a maximum length of 512 characters.

  # The chunking strategy used to chunk the file(s). If not set, will use the `auto`
  # strategy.
  #
  # @see OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore#chunking_strategy
  module ChunkingStrategy
    extend OpenAI::Internal::Type::Union

    discriminator :type

    # The default strategy. This strategy currently uses a `max_chunk_size_tokens` of `800` and `chunk_overlap_tokens` of `400`.
    variant(
      :auto,
      -> {
        OpenAI::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::ChunkingStrategy::Auto
      }
    )

    variant(
      :static,
      -> {
        OpenAI::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::ChunkingStrategy::Static
      }
    )

    class Auto < OpenAI::Internal::Type::BaseModel
      # @!attribute type
      #   Always `auto`.
      #
      #   @return [Symbol, :auto]
      required :type, const: :auto

      # @!method initialize(type: :auto)
      #   The default strategy. This strategy currently uses a `max_chunk_size_tokens` of
      #   `800` and `chunk_overlap_tokens` of `400`.
      #
      #   @param type [Symbol, :auto]
      #     Always `auto`.
    end

    class Static < OpenAI::Internal::Type::BaseModel
      # @!attribute static
      #
      #   @return [OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::ChunkingStrategy::Static::Static]
      required(
        :static,
        -> {
          OpenAI::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::ChunkingStrategy::Static::Static
        }
      )

      # @!attribute type
      #   Always `static`.
      #
      #   @return [Symbol, :static]
      required :type, const: :static

      # @!method initialize(static:, type: :static)
      #   @param static [OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::ChunkingStrategy::Static::Static]
      #
      #   @param type [Symbol, :static]
      #     Always `static`.

      # @see OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::ChunkingStrategy::Static#static
      class Static < OpenAI::Internal::Type::BaseModel
        # @!attribute chunk_overlap_tokens
        #   The number of tokens that overlap between chunks. The default value is `400`.
        #
        #   Note that the overlap must not exceed half of `max_chunk_size_tokens`.
        #
        #   @return [Integer]
        required :chunk_overlap_tokens, Integer

        # @!attribute max_chunk_size_tokens
        #   The maximum number of tokens in each chunk. The default value is `800`. The
        #   minimum value is `100` and the maximum value is `4096`.
        #
        #   @return [Integer]
        required :max_chunk_size_tokens, Integer

        # @!method initialize(chunk_overlap_tokens:, max_chunk_size_tokens:)
        #   @param chunk_overlap_tokens [Integer]
        #     The number of tokens that overlap between chunks. The default value is `400`.
        #
        #     Note that the overlap must not exceed half of `max_chunk_size_tokens`.
        #
        #   @param max_chunk_size_tokens [Integer]
        #     The maximum number of tokens in each chunk. The default value is `800`. The
        #     minimum value is `100` and the maximum value is `4096`.
      end
    end

    # @!method self.variants
    #   @return [Array(OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::ChunkingStrategy::Auto, OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::ChunkingStrategy::Static)]
  end
end

Instance Attribute Details

#chunking_strategy ⇒ OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::chunking_strategy?

The chunking strategy used to chunk the file(s). If not set, will use the auto strategy.

Returns:

  • (OpenAI::Models::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::chunking_strategy, nil)


605
606
607
608
609
610
# File 'lib/openai/models/beta/thread_create_and_run_params.rb', line 605

optional(
  :chunking_strategy,
  union: -> {
    OpenAI::Beta::ThreadCreateAndRunParams::Thread::ToolResources::FileSearch::VectorStore::ChunkingStrategy
  }
)

#file_ids ⇒ ::Array[String]?

A list of file IDs to add to the vector store. For vector stores created before Nov 2025, there can be a maximum of 10,000 files in a vector store. For vector stores created starting in Nov 2025, the limit is 100,000,000 files.

Returns:

  • (::Array[String], nil)


619
# File 'lib/openai/models/beta/thread_create_and_run_params.rb', line 619

optional :file_ids, OpenAI::Internal::Type::ArrayOf[String]

#metadata ⇒ OpenAI::Models::metadata?

Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

Returns:

  • (OpenAI::Models::metadata, nil)


630
# File 'lib/openai/models/beta/thread_create_and_run_params.rb', line 630

optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


649
# File 'sig/openai/models/beta/thread_create_and_run_params.rbs', line 649

def to_hash: -> {