Module: OpenAI::Models::Beta::ThreadCreateAndRunParams::TruncationStrategy::Type

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/beta/thread_create_and_run_params.rb,
sig/openai/models/beta/thread_create_and_run_params.rbs

Overview

The truncation strategy to use for the thread. The default is auto. If set to last_messages, the thread will be truncated to the n most recent messages in the thread. When set to auto, messages in the middle of the thread will be dropped to fit the context length of the model, max_prompt_tokens.

See Also:

  • OpenAI::Models::Beta::ThreadCreateAndRunParams::TruncationStrategy#type

Constant Summary collapse

AUTO =

Returns:

  • (:auto)
:auto
LAST_MESSAGES =

Returns:

  • (:last_messages)
:last_messages

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/thread_create_and_run_params.rb', line 850

Instance Method Details

#self?.values::Array[OpenAI::Models::Beta::ThreadCreateAndRunParams::TruncationStrategy::type_]

Returns:

  • (::Array[OpenAI::Models::Beta::ThreadCreateAndRunParams::TruncationStrategy::type_])


494
# File 'sig/openai/models/beta/thread_create_and_run_params.rbs', line 494

def self?.values: -> ::Array[OpenAI::Models::Beta::ThreadCreateAndRunParams::TruncationStrategy::type_]