Class: OpenAI::Models::Beta::ThreadCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/beta/thread_create_params.rb,
sig/openai/models/beta/thread_create_params.rbs

Overview

See Also:

  • OpenAI::Resources::Beta::Threads#create

Defined Under Namespace

Classes: Message, ToolResources

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type: :file_search) ⇒ Object

Parameters:

  • messages

    A list of messages to start the thread with.

  • metadata

    Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

    Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

  • tool_resources

    A set of resources that are made available to the assistant's tools in this thread. The resources are specific to the type of tool. For example, the code_interpreter tool requires a list of file IDs, while the file_search tool requires a list of vector store IDs.



# File 'lib/openai/models/beta/thread_create_params.rb', line 204

Instance Attribute Details

#messages::Array[OpenAI::Beta::ThreadCreateParams::Message]?

A list of messages to start the thread with.

Returns:

  • (::Array[OpenAI::Beta::ThreadCreateParams::Message], nil)


17
# File 'lib/openai/models/beta/thread_create_params.rb', line 17

optional :messages, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::ThreadCreateParams::Message] }

#metadataOpenAI::Models::metadata?

Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

Returns:

  • (OpenAI::Models::metadata, nil)


28
# File 'lib/openai/models/beta/thread_create_params.rb', line 28

optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true

#tool_resourcesOpenAI::Beta::ThreadCreateParams::ToolResources?

A set of resources that are made available to the assistant's tools in this thread. The resources are specific to the type of tool. For example, the code_interpreter tool requires a list of file IDs, while the file_search tool requires a list of vector store IDs.

Returns:

  • (OpenAI::Beta::ThreadCreateParams::ToolResources, nil)


37
# File 'lib/openai/models/beta/thread_create_params.rb', line 37

optional :tool_resources, -> { OpenAI::Beta::ThreadCreateParams::ToolResources }, nil?: true

Class Method Details

.variantsArray(OpenAI::Models::Beta::CodeInterpreterTool, OpenAI::Models::Beta::ThreadCreateParams::Message::Attachment::Tool::FileSearch)



# File 'lib/openai/models/beta/thread_create_params.rb', line 209

Instance Method Details

#to_hash{

Returns:

  • ({)


65
# File 'sig/openai/models/beta/thread_create_params.rbs', line 65

def to_hash: -> {