Class: OpenAI::Models::Beta::ThreadCreateParams::Message::Attachment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::ThreadCreateParams::Message::Attachment
- Defined in:
- lib/openai/models/beta/thread_create_params.rb,
sig/openai/models/beta/thread_create_params.rbs
Defined Under Namespace
Modules: Tool
Instance Attribute Summary collapse
-
#file_id ⇒ String?
The ID of the file to attach to the message.
-
#tools ⇒ Array<OpenAI::Models::Beta::CodeInterpreterTool, OpenAI::Models::Beta::ThreadCreateParams::Message::Attachment::Tool::FileSearch>?
The tools to add this file to.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
111 |
# File 'sig/openai/models/beta/thread_create_params.rbs', line 111
def initialize: (
|
Instance Attribute Details
#file_id ⇒ String?
The ID of the file to attach to the message.
144 |
# File 'lib/openai/models/beta/thread_create_params.rb', line 144 optional :file_id, String |
#tools ⇒ Array<OpenAI::Models::Beta::CodeInterpreterTool, OpenAI::Models::Beta::ThreadCreateParams::Message::Attachment::Tool::FileSearch>?
The tools to add this file to.
150 151 |
# File 'lib/openai/models/beta/thread_create_params.rb', line 150 optional :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::ThreadCreateParams::Message::Attachment::Tool] } |
Instance Method Details
#to_hash ⇒ {
116 |
# File 'sig/openai/models/beta/thread_create_params.rbs', line 116
def to_hash: -> {
|