Class: OpenAI::Models::Beta::ThreadCreateParams::ToolResources::FileSearch

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/thread_create_params.rb,
sig/openai/models/beta/thread_create_params.rbs

Overview

See Also:

  • OpenAI::Models::Beta::ThreadCreateParams::ToolResources#file_search

Defined Under Namespace

Classes: VectorStore

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • vector_store_ids —

    The vector store attached to this thread. There can be a maximum of 1 vector store attached to the thread.

  • vector_stores —

    A helper to create a vector store with file_ids and attach it to this thread. There can be a maximum of 1 vector store attached to the thread.



312
# File 'sig/openai/models/beta/thread_create_params.rbs', line 312

def initialize: (

Instance Attribute Details

#vector_store_ids ⇒ ::Array[String]?

The vector store attached to this thread. There can be a maximum of 1 vector store attached to the thread.

Returns:

  • (::Array[String], nil)


261
# File 'lib/openai/models/beta/thread_create_params.rb', line 261

optional :vector_store_ids, OpenAI::Internal::Type::ArrayOf[String]

#vector_stores ⇒ ::Array[OpenAI::Beta::ThreadCreateParams::ToolResources::FileSearch::VectorStore]?

A helper to create a vector store with file_ids and attach it to this thread. There can be a maximum of 1 vector store attached to the thread.

Returns:

  • (::Array[OpenAI::Beta::ThreadCreateParams::ToolResources::FileSearch::VectorStore], nil)


270
271
272
273
274
275
276
277
# File 'lib/openai/models/beta/thread_create_params.rb', line 270

optional(
  :vector_stores,
  -> {
    OpenAI::Internal::Type::ArrayOf[
      OpenAI::Beta::ThreadCreateParams::ToolResources::FileSearch::VectorStore
    ]
  }
)

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


317
# File 'sig/openai/models/beta/thread_create_params.rbs', line 317

def to_hash: -> {