Module: OpenAI::Models::Beta::Threads::AnnotationDelta
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/beta/threads/annotation_delta.rb,
sig/openai/models/beta/threads/annotation_delta.rbs
Overview
A citation within the message that points to a specific quote from a specific File associated with the assistant or the message. Generated when the assistant uses the "file_search" tool to search files.
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(OpenAI::Models::Beta::Threads::FileCitationDeltaAnnotation, OpenAI::Models::Beta::Threads::FilePathDeltaAnnotation)
|
|
# File 'lib/openai/models/beta/threads/annotation_delta.rb', line 21
|
Instance Method Details
#self?.variants ⇒ ::Array[OpenAI::Models::Beta::Threads::annotation_delta]
12 |
# File 'sig/openai/models/beta/threads/annotation_delta.rbs', line 12
def self?.variants: -> ::Array[OpenAI::Models::Beta::Threads::annotation_delta]
|