Class: OpenAI::Models::Beta::Threads::FileCitationDeltaAnnotation::FileCitation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Threads::FileCitationDeltaAnnotation::FileCitation
- Defined in:
- lib/openai/models/beta/threads/file_citation_delta_annotation.rb,
sig/openai/models/beta/threads/file_citation_delta_annotation.rbs
Overview
Instance Attribute Summary collapse
-
#file_id ⇒ String?
The ID of the specific File the citation is from.
-
#quote ⇒ String?
The specific quote in the file.
Instance Method Summary collapse
-
#initialize(file_id: nil, quote: nil) ⇒ FileCitation
constructor
A new instance of FileCitation.
- #to_hash ⇒ { file_id: String, quote: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(file_id: nil, quote: nil) ⇒ FileCitation
Returns a new instance of FileCitation.
|
|
# File 'lib/openai/models/beta/threads/file_citation_delta_annotation.rb', line 72
|
Instance Attribute Details
#file_id ⇒ String?
The ID of the specific File the citation is from.
64 |
# File 'lib/openai/models/beta/threads/file_citation_delta_annotation.rb', line 64 optional :file_id, String |
#quote ⇒ String?
The specific quote in the file.
70 |
# File 'lib/openai/models/beta/threads/file_citation_delta_annotation.rb', line 70 optional :quote, String |
Instance Method Details
#to_hash ⇒ { file_id: String, quote: String }
69 |
# File 'sig/openai/models/beta/threads/file_citation_delta_annotation.rbs', line 69
def to_hash: -> { file_id: String, quote: String }
|