Class: OpenAI::Models::Beta::Threads::Run::IncompleteDetails

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/threads/run.rb,
sig/openai/models/beta/threads/run.rbs

Overview

See Also:

  • OpenAI::Models::Beta::Threads::Run#incomplete_details

Defined Under Namespace

Modules: Reason

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(reason: nil) ⇒ Object

Parameters:

  • reason (defaults to: nil) —

    The reason why the run is incomplete. This will point to which specific token limit was reached over the course of the run.



# File 'lib/openai/models/beta/threads/run.rb', line 367

Instance Attribute Details

#reason ⇒ OpenAI::Models::Beta::Threads::Run::IncompleteDetails::reason?

The reason why the run is incomplete. This will point to which specific token limit was reached over the course of the run.

Returns:

  • (OpenAI::Models::Beta::Threads::Run::IncompleteDetails::reason, nil)


365
# File 'lib/openai/models/beta/threads/run.rb', line 365

optional :reason, enum: -> { OpenAI::Beta::Threads::Run::IncompleteDetails::Reason }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


355
# File 'sig/openai/models/beta/threads/run.rbs', line 355

def to_hash: -> {