Class: OpenAI::Models::Beta::Threads::Run::RequiredAction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/threads/run.rb,
sig/openai/models/beta/threads/run.rbs

Overview

See Also:

  • OpenAI::Models::Beta::Threads::Run#required_action

Defined Under Namespace

Classes: SubmitToolOutputs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(submit_tool_outputs:, type: :submit_tool_outputs) ⇒ Object

Parameters:

  • submit_tool_outputs —

    Details on the tool outputs needed for this run to continue.

  • type (defaults to: :submit_tool_outputs) —

    For now, this is always submit_tool_outputs.



# File 'lib/openai/models/beta/threads/run.rb', line 442


Instance Attribute Details

#submit_tool_outputs ⇒ OpenAI::Beta::Threads::Run::RequiredAction::SubmitToolOutputs

Details on the tool outputs needed for this run to continue.

Returns:

  • (OpenAI::Beta::Threads::Run::RequiredAction::SubmitToolOutputs)


434
# File 'lib/openai/models/beta/threads/run.rb', line 434

required :submit_tool_outputs, -> { OpenAI::Beta::Threads::Run::RequiredAction::SubmitToolOutputs }

#type ⇒ :submit_tool_outputs

For now, this is always submit_tool_outputs.

Returns:

  • (:submit_tool_outputs)


440
# File 'lib/openai/models/beta/threads/run.rb', line 440

required :type, const: :submit_tool_outputs

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


433
# File 'sig/openai/models/beta/threads/run.rbs', line 433

def to_hash: -> {