Class: OpenAI::Models::Beta::Threads::RunCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Threads::RunCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/beta/threads/run_create_params.rb,
sig/openai/models/beta/threads/run_create_params.rbs
Overview
Defined Under Namespace
Modules: Model Classes: AdditionalMessage, TruncationStrategy
Instance Attribute Summary collapse
-
#additional_instructions ⇒ String?
Appends additional instructions at the end of the instructions for the run.
-
#additional_messages ⇒ Array<OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage>?
Adds additional messages to the thread before creating the run.
-
#assistant_id ⇒ String
The ID of the assistant to use to execute this run.
-
#include ⇒ Array<Symbol, OpenAI::Models::Beta::Threads::Runs::RunStepInclude>?
A list of additional fields to include in the response.
-
#instructions ⇒ String?
Overrides the instructions of the assistant.
-
#max_completion_tokens ⇒ Integer?
The maximum number of completion tokens that may be used over the course of the run.
-
#max_prompt_tokens ⇒ Integer?
The maximum number of prompt tokens that may be used over the course of the run.
-
#metadata ⇒ Hash{Symbol=>String}?
Set of 16 key-value pairs that can be attached to an object.
-
#model ⇒ String, ...
The ID of the Model to be used to execute this run.
-
#parallel_tool_calls ⇒ Boolean?
Whether to enable parallel function calling during tool use.
-
#reasoning_effort ⇒ Symbol, ...
Constrains effort on reasoning for reasoning models.
-
#response_format ⇒ Symbol, ...
Specifies the format that the model must output.
-
#temperature ⇒ Float?
What sampling temperature to use, between 0 and 2.
- #thread_id ⇒ String
-
#tool_choice ⇒ Symbol, ...
Controls which (if any) tool is called by the model.
-
#tools ⇒ Array<OpenAI::Models::Beta::CodeInterpreterTool, OpenAI::Models::Beta::FileSearchTool, OpenAI::Models::Beta::FunctionTool>?
Override the tools the assistant can use for this run.
-
#top_p ⇒ Float?
An alternative to sampling with temperature, called nucleus sampling, where the model considers the results of the tokens with top_p probability mass.
-
#truncation_strategy ⇒ OpenAI::Models::Beta::Threads::RunCreateParams::TruncationStrategy?
Controls for how a thread will be truncated prior to the run.
Attributes included from Internal::Type::RequestParameters
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(type: :file_search) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type: :file_search) ⇒ Object
|
|
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 391
|
Instance Attribute Details
#additional_instructions ⇒ String?
Appends additional instructions at the end of the instructions for the run. This is useful for modifying the behavior on a per-run basis without overriding other instructions.
48 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 48 optional :additional_instructions, String, nil?: true |
#additional_messages ⇒ Array<OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage>?
Adds additional messages to the thread before creating the run.
54 55 56 57 58 59 60 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 54 optional( :additional_messages, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::Threads::RunCreateParams::AdditionalMessage] }, nil?: true ) |
#assistant_id ⇒ String
The ID of the assistant to use to execute this run.
25 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 25 required :assistant_id, String |
#include ⇒ Array<Symbol, OpenAI::Models::Beta::Threads::Runs::RunStepInclude>?
A list of additional fields to include in the response. Currently the only
supported value is step_details.tool_calls[*].file_search.results[*].content
to fetch the file search result content.
See the file search tool documentation for more information.
37 38 39 40 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 37 optional( :include, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Beta::Threads::Runs::RunStepInclude] } ) |
#instructions ⇒ String?
Overrides the instructions of the assistant. This is useful for modifying the behavior on a per-run basis.
68 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 68 optional :instructions, String, nil?: true |
#max_completion_tokens ⇒ Integer?
The maximum number of completion tokens that may be used over the course of the
run. The run will make a best effort to use only the number of completion tokens
specified, across multiple turns of the run. If the run exceeds the number of
completion tokens specified, the run will end with status incomplete. See
incomplete_details for more info.
78 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 78 optional :max_completion_tokens, Integer, nil?: true |
#max_prompt_tokens ⇒ Integer?
The maximum number of prompt tokens that may be used over the course of the run.
The run will make a best effort to use only the number of prompt tokens
specified, across multiple turns of the run. If the run exceeds the number of
prompt tokens specified, the run will end with status incomplete. See
incomplete_details for more info.
88 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 88 optional :max_prompt_tokens, Integer, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
99 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 99 optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true |
#model ⇒ String, ...
The ID of the Model to be used to execute this run. If a value is provided here, it will override the model associated with the assistant. If not, the model associated with the assistant will be used.
108 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 108 optional :model, union: -> { OpenAI::Beta::Threads::RunCreateParams::Model }, nil?: true |
#parallel_tool_calls ⇒ Boolean?
Whether to enable parallel function calling during tool use.
116 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 116 optional :parallel_tool_calls, OpenAI::Internal::Type::Boolean |
#reasoning_effort ⇒ Symbol, ...
Constrains effort on reasoning for reasoning models. Currently supported values
are none, minimal, low, medium, high, xhigh, and max. Reducing
reasoning effort can result in faster responses and fewer tokens used on
reasoning in a response. Not all reasoning models support every value. See the
reasoning guide for
model-specific support.
127 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 127 optional :reasoning_effort, enum: -> { OpenAI::ReasoningEffort }, nil?: true |
#response_format ⇒ Symbol, ...
Specifies the format that the model must output. Compatible with
GPT-4o,
GPT-4 Turbo,
and all GPT-3.5 Turbo models since gpt-3.5-turbo-1106.
Setting to { "type": "json_schema", "json_schema": {...} } enables Structured
Outputs which ensures the model will match your supplied JSON schema. Learn more
in the
Structured Outputs guide.
Setting to { "type": "json_object" } enables JSON mode, which ensures the
message the model generates is valid JSON.
Important: when using JSON mode, you must also instruct the model to
produce JSON yourself via a system or user message. Without this, the model may
generate an unending stream of whitespace until the generation reaches the token
limit, resulting in a long-running and seemingly "stuck" request. Also note that
the message content may be partially cut off if finish_reason="length", which
indicates the generation exceeded max_tokens or the conversation exceeded the
max context length.
152 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 152 optional :response_format, union: -> { OpenAI::Beta::AssistantResponseFormatOption }, nil?: true |
#temperature ⇒ Float?
What sampling temperature to use, between 0 and 2. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic.
160 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 160 optional :temperature, Float, nil?: true |
#thread_id ⇒ String
17 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 17 required :thread_id, String |
#tool_choice ⇒ Symbol, ...
Controls which (if any) tool is called by the model. none means the model will
not call any tools and instead generates a message. auto is the default value
and means the model can pick between generating a message or calling one or more
tools. required means the model must call one or more tools before responding
to the user. Specifying a particular tool like {"type": "file_search"} or
{"type": "function", "function": {"name": "my_function"}} forces the model to
call that tool.
172 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 172 optional :tool_choice, union: -> { OpenAI::Beta::AssistantToolChoiceOption }, nil?: true |
#tools ⇒ Array<OpenAI::Models::Beta::CodeInterpreterTool, OpenAI::Models::Beta::FileSearchTool, OpenAI::Models::Beta::FunctionTool>?
Override the tools the assistant can use for this run. This is useful for modifying the behavior on a per-run basis.
179 180 181 182 183 184 185 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 179 optional( :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::AssistantTool] }, nil?: true ) |
#top_p ⇒ Float?
An alternative to sampling with temperature, called nucleus sampling, where the model considers the results of the tokens with top_p probability mass. So 0.1 means only the tokens comprising the top 10% probability mass are considered.
We generally recommend altering this or temperature but not both.
195 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 195 optional :top_p, Float, nil?: true |
#truncation_strategy ⇒ OpenAI::Models::Beta::Threads::RunCreateParams::TruncationStrategy?
Controls for how a thread will be truncated prior to the run. Use this to control the initial context window of the run.
202 203 204 205 206 |
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 202 optional( :truncation_strategy, -> { OpenAI::Beta::Threads::RunCreateParams::TruncationStrategy }, nil?: true ) |
Class Method Details
.variants ⇒ Array(String, Symbol, OpenAI::Models::ChatModel)
|
|
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 395
|
Instance Method Details
#to_hash ⇒ {
96 |
# File 'sig/openai/models/beta/threads/run_create_params.rbs', line 96
def to_hash: -> {
|