Class: OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/threads/run_create_params.rb,
sig/openai/models/beta/threads/run_create_params.rbs

Defined Under Namespace

Modules: Content, Role Classes: Attachment

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content:, role:, attachments: nil, metadata: nil) ⇒ Object

Parameters:

  • content

    The text contents of the message.

  • role

    The role of the entity that is creating the message. Allowed values include:

    • user: Indicates the message is sent by an actual user and should be used in most cases to represent user-generated messages.
    • assistant: Indicates the message is generated by the assistant. Use this value to insert messages from the assistant into the conversation.
  • attachments (defaults to: nil)

    A list of files attached to the message, and the tools they should be added to.

  • metadata (defaults to: nil)

    Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

    Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 334

class AdditionalMessage < OpenAI::Internal::Type::BaseModel
  # @!attribute content
  #   The text contents of the message.
  #
  #   @return [String, Array<OpenAI::Models::Beta::Threads::ImageFileContentBlock, OpenAI::Models::Beta::Threads::ImageURLContentBlock, OpenAI::Models::Beta::Threads::TextContentBlockParam>]
  required :content, union: -> { OpenAI::Beta::Threads::RunCreateParams::AdditionalMessage::Content }

  # @!attribute role
  #   The role of the entity that is creating the message. Allowed values include:
  #
  #   - `user`: Indicates the message is sent by an actual user and should be used in
  #     most cases to represent user-generated messages.
  #   - `assistant`: Indicates the message is generated by the assistant. Use this
  #     value to insert messages from the assistant into the conversation.
  #
  #   @return [Symbol, OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::Role]
  required :role, enum: -> { OpenAI::Beta::Threads::RunCreateParams::AdditionalMessage::Role }

  # @!attribute attachments
  #   A list of files attached to the message, and the tools they should be added to.
  #
  #   @return [Array<OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::Attachment>, nil]
  optional(
    :attachments,
    -> {
      OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::Threads::RunCreateParams::AdditionalMessage::Attachment]
    },
    nil?: true
  )

  # @!attribute metadata
  #   Set of 16 key-value pairs that can be attached to an object. This can be useful
  #   for storing additional information about the object in a structured format, and
  #   querying for objects via API or the dashboard.
  #
  #   Keys are strings with a maximum length of 64 characters. Values are strings with
  #   a maximum length of 512 characters.
  #
  #   @return [Hash{Symbol=>String}, nil]
  optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true

  # @!method initialize(content:, role:, attachments: nil, metadata: nil)
  #   @param content [String, Array<OpenAI::Models::Beta::Threads::ImageFileContentBlock, OpenAI::Models::Beta::Threads::ImageURLContentBlock, OpenAI::Models::Beta::Threads::TextContentBlockParam>]
  #     The text contents of the message.
  #
  #   @param role [Symbol, OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::Role]
  #     The role of the entity that is creating the message. Allowed values include:
  #
  #     - `user`: Indicates the message is sent by an actual user and should be used in
  #       most cases to represent user-generated messages.
  #     - `assistant`: Indicates the message is generated by the assistant. Use this
  #       value to insert messages from the assistant into the conversation.
  #
  #   @param attachments [Array<OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::Attachment>, nil]
  #     A list of files attached to the message, and the tools they should be added to.
  #
  #   @param metadata [Hash{Symbol=>String}, nil]
  #     Set of 16 key-value pairs that can be attached to an object. This can be useful
  #     for storing additional information about the object in a structured format, and
  #     querying for objects via API or the dashboard.
  #
  #     Keys are strings with a maximum length of 64 characters. Values are strings with
  #     a maximum length of 512 characters.

  # The text contents of the message.
  #
  # @see OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage#content
  module Content
    extend OpenAI::Internal::Type::Union

    # The text contents of the message.
    variant String

    # An array of content parts with a defined type, each can be of type `text` or images can be passed with `image_url` or `image_file`. Image types are only supported on [Vision-compatible models](https://developers.openai.com/api/docs/models).
    variant(
      -> {
        OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::Content::MessageContentPartParamArray
      }
    )

    # @!method self.variants
    #   @return [Array(String, Array<OpenAI::Models::Beta::Threads::ImageFileContentBlock, OpenAI::Models::Beta::Threads::ImageURLContentBlock, OpenAI::Models::Beta::Threads::TextContentBlockParam>)]

    # @type [OpenAI::Internal::Type::Converter]
    MessageContentPartParamArray = OpenAI::Internal::Type::ArrayOf[
      union: -> { OpenAI::Beta::Threads::MessageContentPartParam }
    ]
  end

  # The role of the entity that is creating the message. Allowed values include:
  #
  # - `user`: Indicates the message is sent by an actual user and should be used in
  #   most cases to represent user-generated messages.
  # - `assistant`: Indicates the message is generated by the assistant. Use this
  #   value to insert messages from the assistant into the conversation.
  #
  # @see OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage#role
  module Role
    extend OpenAI::Internal::Type::Enum

    USER = :user
    ASSISTANT = :assistant

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  class Attachment < OpenAI::Internal::Type::BaseModel
    # @!attribute file_id
    #   The ID of the file to attach to the message.
    #
    #   @return [String, nil]
    optional :file_id, String

    # @!attribute tools
    #   The tools to add this file to.
    #
    #   @return [Array<OpenAI::Models::Beta::CodeInterpreterTool, OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::Attachment::Tool::FileSearch>, nil]
    optional(
      :tools,
      -> {
        OpenAI::Internal::Type::ArrayOf[
          union: OpenAI::Beta::Threads::RunCreateParams::AdditionalMessage::Attachment::Tool
        ]
      }
    )

    # @!method initialize(file_id: nil, tools: nil)
    #   @param file_id [String]
    #     The ID of the file to attach to the message.
    #
    #   @param tools [Array<OpenAI::Models::Beta::CodeInterpreterTool, OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::Attachment::Tool::FileSearch>]
    #     The tools to add this file to.
    module Tool
      extend OpenAI::Internal::Type::Union

      discriminator :type

      variant :code_interpreter, -> { OpenAI::Beta::CodeInterpreterTool }

      variant(
        :file_search,
        -> { OpenAI::Beta::Threads::RunCreateParams::AdditionalMessage::Attachment::Tool::FileSearch }
      )

      class FileSearch < OpenAI::Internal::Type::BaseModel
        # @!attribute type
        #   The type of tool being defined: `file_search`
        #
        #   @return [Symbol, :file_search]
        required :type, const: :file_search

        # @!method initialize(type: :file_search)
        #   @param type [Symbol, :file_search]
        #     The type of tool being defined: `file_search`
      end

      # @!method self.variants
      #   @return [Array(OpenAI::Models::Beta::CodeInterpreterTool, OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::Attachment::Tool::FileSearch)]
    end
  end
end

Instance Attribute Details

#attachments::Array[OpenAI::Beta::Threads::RunCreateParams::AdditionalMessage::Attachment]?

A list of files attached to the message, and the tools they should be added to.

Returns:

  • (::Array[OpenAI::Beta::Threads::RunCreateParams::AdditionalMessage::Attachment], nil)


356
357
358
359
360
361
362
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 356

optional(
  :attachments,
  -> {
    OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::Threads::RunCreateParams::AdditionalMessage::Attachment]
  },
  nil?: true
)

#contentOpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::content

The text contents of the message.

Returns:

  • (OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::content)


339
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 339

required :content, union: -> { OpenAI::Beta::Threads::RunCreateParams::AdditionalMessage::Content }

#metadataOpenAI::Models::metadata?

Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

Returns:

  • (OpenAI::Models::metadata, nil)


373
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 373

optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true

#roleOpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::role

The role of the entity that is creating the message. Allowed values include:

  • user: Indicates the message is sent by an actual user and should be used in most cases to represent user-generated messages.
  • assistant: Indicates the message is generated by the assistant. Use this value to insert messages from the assistant into the conversation.

Returns:

  • (OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::role)


350
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 350

required :role, enum: -> { OpenAI::Beta::Threads::RunCreateParams::AdditionalMessage::Role }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/threads/run_create_params.rb', line 437

Instance Method Details

#to_hash{

Returns:

  • ({)


373
# File 'sig/openai/models/beta/threads/run_create_params.rbs', line 373

def to_hash: -> {