Class: OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::Attachment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/threads/run_create_params.rb,
sig/openai/models/beta/threads/run_create_params.rbs

Defined Under Namespace

Modules: Tool

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Parameters:

  • file_id

    The ID of the file to attach to the message.

  • tools

    The tools to add this file to.



428
# File 'sig/openai/models/beta/threads/run_create_params.rbs', line 428

def initialize: (

Instance Attribute Details

#file_idString?

The ID of the file to attach to the message.

Returns:

  • (String, nil)


446
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 446

optional :file_id, String

#tools::Array[OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::Attachment::tool]?

The tools to add this file to.

Returns:

  • (::Array[OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::Attachment::tool], nil)


452
453
454
455
456
457
458
459
# File 'lib/openai/models/beta/threads/run_create_params.rb', line 452

optional(
  :tools,
  -> {
    OpenAI::Internal::Type::ArrayOf[
      union: OpenAI::Beta::Threads::RunCreateParams::AdditionalMessage::Attachment::Tool
    ]
  }
)

Instance Method Details

#to_hash{

Returns:

  • ({)


433
# File 'sig/openai/models/beta/threads/run_create_params.rbs', line 433

def to_hash: -> {