Module: OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::Role
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/beta/threads/run_create_params.rb,
sig/openai/models/beta/threads/run_create_params.rbs
Overview
The role of the entity that is creating the message. Allowed values include:
user: Indicates the message is sent by an actual user and should be used in most cases to represent user-generated messages.assistant: Indicates the message is generated by the assistant. Use this value to insert messages from the assistant into the conversation.
Constant Summary collapse
- USER =
:user- ASSISTANT =
:assistant
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::role]
169 |
# File 'sig/openai/models/beta/threads/run_create_params.rbs', line 169
def self?.values: -> ::Array[OpenAI::Models::Beta::Threads::RunCreateParams::AdditionalMessage::role]
|