Module: OpenAI::Models::Beta::Threads::RunCreateParams::Model

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/beta/threads/run_create_params.rb,
sig/openai/models/beta/threads/run_create_params.rbs

Overview

The ID of the Model to be used to execute this run. If a value is provided here, it will override the model associated with the assistant. If not, the model associated with the assistant will be used.

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.variants::Array[OpenAI::Models::Beta::Threads::RunCreateParams::model]

Returns:

  • (::Array[OpenAI::Models::Beta::Threads::RunCreateParams::model])


226
# File 'sig/openai/models/beta/threads/run_create_params.rbs', line 226

def self?.variants: -> ::Array[OpenAI::Models::Beta::Threads::RunCreateParams::model]