Class: OpenAI::Models::Beta::Threads::RunSubmitToolOutputsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/beta/threads/run_submit_tool_outputs_params.rb,
sig/openai/models/beta/threads/run_submit_tool_outputs_params.rbs

Overview

See Also:

  • OpenAI::Resources::Beta::Threads::Runs#submit_tool_outputs
  • OpenAI::Resources::Beta::Threads::Runs#submit_tool_outputs_stream_raw

Defined Under Namespace

Classes: ToolOutput

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • tool_outputs —

    A list of tools for which the outputs are being submitted.



26
# File 'sig/openai/models/beta/threads/run_submit_tool_outputs_params.rbs', line 26

def initialize: (

Instance Attribute Details

#run_id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


22
# File 'lib/openai/models/beta/threads/run_submit_tool_outputs_params.rb', line 22

required :run_id, String

#thread_id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/openai/models/beta/threads/run_submit_tool_outputs_params.rb', line 17

required :thread_id, String

#tool_outputs ⇒ ::Array[OpenAI::Beta::Threads::RunSubmitToolOutputsParams::ToolOutput]

A list of tools for which the outputs are being submitted.

Returns:

  • (::Array[OpenAI::Beta::Threads::RunSubmitToolOutputsParams::ToolOutput])


28
29
30
31
# File 'lib/openai/models/beta/threads/run_submit_tool_outputs_params.rb', line 28

required(
  :tool_outputs,
  -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::Threads::RunSubmitToolOutputsParams::ToolOutput] }
)

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


33
# File 'sig/openai/models/beta/threads/run_submit_tool_outputs_params.rbs', line 33

def to_hash: -> {