Class: OpenAI::Models::Beta::Threads::RunSubmitToolOutputsParams::ToolOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/threads/run_submit_tool_outputs_params.rb,
sig/openai/models/beta/threads/run_submit_tool_outputs_params.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(output: nil, tool_call_id: nil) ⇒ ToolOutput

Returns a new instance of ToolOutput.

Parameters:

  • output (defaults to: nil) —

    The output of the tool call to be submitted to continue the run.

  • tool_call_id (defaults to: nil) —

    The ID of the tool call in the required_action object within the run object the output is being submitted for.

  • output: (String) (defaults to: nil)
  • tool_call_id: (String) (defaults to: nil)


43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/openai/models/beta/threads/run_submit_tool_outputs_params.rb', line 43

class ToolOutput < OpenAI::Internal::Type::BaseModel
  # @!attribute output
  #   The output of the tool call to be submitted to continue the run.
  #
  #   @return [String, nil]
  optional :output, String

  # @!attribute tool_call_id
  #   The ID of the tool call in the `required_action` object within the run object
  #   the output is being submitted for.
  #
  #   @return [String, nil]
  optional :tool_call_id, String

  # @!method initialize(output: nil, tool_call_id: nil)
  #   @param output [String]
  #     The output of the tool call to be submitted to continue the run.
  #
  #   @param tool_call_id [String]
  #     The ID of the tool call in the `required_action` object within the run object
  #     the output is being submitted for.
end

Instance Attribute Details

#output ⇒ String?

The output of the tool call to be submitted to continue the run.

Returns:

  • (String, nil)


48
# File 'lib/openai/models/beta/threads/run_submit_tool_outputs_params.rb', line 48

optional :output, String

#tool_call_id ⇒ String?

The ID of the tool call in the required_action object within the run object the output is being submitted for.

Returns:

  • (String, nil)


55
# File 'lib/openai/models/beta/threads/run_submit_tool_outputs_params.rb', line 55

optional :tool_call_id, String

Instance Method Details

#to_hash ⇒ { ?output: String, ?tool_call_id: String }

Returns:

  • ({ ?output: String, ?tool_call_id: String })


64
# File 'sig/openai/models/beta/threads/run_submit_tool_outputs_params.rbs', line 64

def to_hash: -> { ?output: String, ?tool_call_id: String }