Class: OpenAI::Models::Beta::Threads::Runs::CodeInterpreterLogs
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Threads::Runs::CodeInterpreterLogs
- Defined in:
- lib/openai/models/beta/threads/runs/code_interpreter_logs.rb,
sig/openai/models/beta/threads/runs/code_interpreter_logs.rbs
Instance Attribute Summary collapse
-
#index ⇒ Integer
The index of the output in the outputs array.
-
#logs ⇒ String?
The text output from the Code Interpreter tool call.
-
#type ⇒ :logs
Always
logs.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(index:, logs: nil, type: :logs) ⇒ Object constructor
- #to_hash ⇒ { index: Integer, ?type: :logs, ?logs: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(index:, logs: nil, type: :logs) ⇒ Object
|
|
# File 'lib/openai/models/beta/threads/runs/code_interpreter_logs.rb', line 27
|
Instance Attribute Details
#index ⇒ Integer
The index of the output in the outputs array.
13 |
# File 'lib/openai/models/beta/threads/runs/code_interpreter_logs.rb', line 13 required :index, Integer |
#logs ⇒ String?
The text output from the Code Interpreter tool call.
25 |
# File 'lib/openai/models/beta/threads/runs/code_interpreter_logs.rb', line 25 optional :logs, String |
#type ⇒ :logs
Always logs.
19 |
# File 'lib/openai/models/beta/threads/runs/code_interpreter_logs.rb', line 19 required :type, const: :logs |
Instance Method Details
#to_hash ⇒ { index: Integer, ?type: :logs, ?logs: String }
34 |
# File 'sig/openai/models/beta/threads/runs/code_interpreter_logs.rbs', line 34
def to_hash: -> { index: Integer, ?type: :logs, ?logs: String }
|