Class: OpenAI::Models::Beta::Threads::Runs::CodeInterpreterToolCall::CodeInterpreter::Output::Logs
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Threads::Runs::CodeInterpreterToolCall::CodeInterpreter::Output::Logs
- Defined in:
- lib/openai/models/beta/threads/runs/code_interpreter_tool_call.rb,
sig/openai/models/beta/threads/runs/code_interpreter_tool_call.rbs
Instance Attribute Summary collapse
-
#logs ⇒ String
The text output from the Code Interpreter tool call.
-
#type ⇒ Symbol, :logs
Always
logs.
Instance Method Summary collapse
-
#initialize ⇒ Logs
constructor
A new instance of Logs.
- #to_hash ⇒ { logs: String, type: :logs }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Logs
Returns a new instance of Logs.
67 |
# File 'sig/openai/models/beta/threads/runs/code_interpreter_tool_call.rbs', line 67
def initialize: (logs: String, ?type: :logs) -> void
|
Instance Attribute Details
#logs ⇒ String
The text output from the Code Interpreter tool call.
85 |
# File 'lib/openai/models/beta/threads/runs/code_interpreter_tool_call.rb', line 85 required :logs, String |
#type ⇒ Symbol, :logs
Always logs.
91 |
# File 'lib/openai/models/beta/threads/runs/code_interpreter_tool_call.rb', line 91 required :type, const: :logs |
Instance Method Details
#to_hash ⇒ { logs: String, type: :logs }
69 |
# File 'sig/openai/models/beta/threads/runs/code_interpreter_tool_call.rbs', line 69
def to_hash: -> { logs: String, type: :logs }
|