Class: OpenAI::Models::Beta::Threads::Runs::CodeInterpreterToolCallDelta::CodeInterpreter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/threads/runs/code_interpreter_tool_call_delta.rb,
sig/openai/models/beta/threads/runs/code_interpreter_tool_call_delta.rbs

Overview

See Also:

  • OpenAI::Models::Beta::Threads::Runs::CodeInterpreterToolCallDelta#code_interpreter

Defined Under Namespace

Modules: Output

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(input: nil, outputs: nil) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Beta::Threads::Runs::CodeInterpreterToolCallDelta::CodeInterpreter for more details.

The Code Interpreter tool call definition.

Parameters:



# File 'lib/openai/models/beta/threads/runs/code_interpreter_tool_call_delta.rb', line 75

Instance Attribute Details

#inputString?

The input to the Code Interpreter tool call.

Parameters:

  • (String)

Returns:

  • (String, nil)


58
# File 'lib/openai/models/beta/threads/runs/code_interpreter_tool_call_delta.rb', line 58

optional :input, String

#outputsArray<OpenAI::Models::Beta::Threads::Runs::CodeInterpreterLogs, OpenAI::Models::Beta::Threads::Runs::CodeInterpreterOutputImage>?

The outputs from the Code Interpreter tool call. Code Interpreter can output one or more items, including text (logs) or images (image). Each of these are represented by a different object type.



66
67
68
69
70
71
72
73
# File 'lib/openai/models/beta/threads/runs/code_interpreter_tool_call_delta.rb', line 66

optional(
  :outputs,
  -> {
    OpenAI::Internal::Type::ArrayOf[
      union: OpenAI::Beta::Threads::Runs::CodeInterpreterToolCallDelta::CodeInterpreter::Output
    ]
  }
)

Instance Method Details

#to_hash{

Returns:

  • ({)


65
# File 'sig/openai/models/beta/threads/runs/code_interpreter_tool_call_delta.rbs', line 65

def to_hash: -> {