Class: OpenAI::Models::Beta::Threads::Runs::FileSearchToolCallDelta

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/threads/runs/file_search_tool_call_delta.rb,
sig/openai/models/beta/threads/runs/file_search_tool_call_delta.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(file_search:, index:, id: nil, type: :file_search) ⇒ Object

Parameters:

  • file_search —

    For now, this is always going to be an empty object.

  • index —

    The index of the tool call in the tool calls array.

  • id (defaults to: nil) —

    The ID of the tool call object.

  • type (defaults to: :file_search) —

    The type of tool call. This is always going to be file_search for this type of tool call.



# File 'lib/openai/models/beta/threads/runs/file_search_tool_call_delta.rb', line 34

Instance Attribute Details

#file_search ⇒ top

For now, this is always going to be an empty object.

Returns:

  • (top)


13
# File 'lib/openai/models/beta/threads/runs/file_search_tool_call_delta.rb', line 13

required :file_search, OpenAI::Internal::Type::Unknown

#id ⇒ String?

The ID of the tool call object.

Returns:

  • (String, nil)


32
# File 'lib/openai/models/beta/threads/runs/file_search_tool_call_delta.rb', line 32

optional :id, String

#index ⇒ Integer

The index of the tool call in the tool calls array.

Returns:

  • (Integer)


19
# File 'lib/openai/models/beta/threads/runs/file_search_tool_call_delta.rb', line 19

required :index, Integer

#type ⇒ :file_search

The type of tool call. This is always going to be file_search for this type of tool call.

Returns:

  • (:file_search)


26
# File 'lib/openai/models/beta/threads/runs/file_search_tool_call_delta.rb', line 26

required :type, const: :file_search

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


47
# File 'sig/openai/models/beta/threads/runs/file_search_tool_call_delta.rbs', line 47

def to_hash: -> {