Class: OpenAI::Models::Beta::Threads::Runs::MessageCreationStepDetails::MessageCreation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/threads/runs/message_creation_step_details.rb,
sig/openai/models/beta/threads/runs/message_creation_step_details.rbs

Overview

See Also:

  • OpenAI::Models::Beta::Threads::Runs::MessageCreationStepDetails#message_creation

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(message_id:) ⇒ MessageCreation

Returns a new instance of MessageCreation.

Parameters:

  • message_id (String)

    The ID of the message that was created by this run step.

  • message_id: (String)


# File 'lib/openai/models/beta/threads/runs/message_creation_step_details.rb', line 36

Instance Attribute Details

#message_idString

The ID of the message that was created by this run step.

Parameters:

  • value (String)

Returns:

  • (String)


34
# File 'lib/openai/models/beta/threads/runs/message_creation_step_details.rb', line 34

required :message_id, String

Instance Method Details

#to_hash{ message_id: String }

Returns:

  • ({ message_id: String })


34
# File 'sig/openai/models/beta/threads/runs/message_creation_step_details.rbs', line 34

def to_hash: -> { message_id: String }