Class: OpenAI::Models::Beta::Threads::Runs::RunStepDeltaEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Threads::Runs::RunStepDeltaEvent
- Defined in:
- lib/openai/models/beta/threads/runs/run_step_delta_event.rb,
sig/openai/models/beta/threads/runs/run_step_delta_event.rbs
Instance Attribute Summary collapse
-
#delta ⇒ OpenAI::Models::Beta::Threads::Runs::RunStepDelta
The delta containing the fields that have changed on the run step.
-
#id ⇒ String
The identifier of the run step, which can be referenced in API endpoints.
-
#object ⇒ Symbol, :"thread.run.step.delta"
The object type, which is always
thread.run.step.delta.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
22 |
# File 'sig/openai/models/beta/threads/runs/run_step_delta_event.rbs', line 22
def initialize: (
|
Instance Attribute Details
#delta ⇒ OpenAI::Models::Beta::Threads::Runs::RunStepDelta
The delta containing the fields that have changed on the run step.
19 |
# File 'lib/openai/models/beta/threads/runs/run_step_delta_event.rb', line 19 required :delta, -> { OpenAI::Beta::Threads::Runs::RunStepDelta } |
#id ⇒ String
The identifier of the run step, which can be referenced in API endpoints.
13 |
# File 'lib/openai/models/beta/threads/runs/run_step_delta_event.rb', line 13 required :id, String |
#object ⇒ Symbol, :"thread.run.step.delta"
The object type, which is always thread.run.step.delta.
25 |
# File 'lib/openai/models/beta/threads/runs/run_step_delta_event.rb', line 25 required :object, const: :"thread.run.step.delta" |
Instance Method Details
#to_hash ⇒ {
28 |
# File 'sig/openai/models/beta/threads/runs/run_step_delta_event.rbs', line 28
def to_hash: -> {
|