Class: OpenAI::Models::Beta::Threads::Runs::StepListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/beta/threads/runs/step_list_params.rb,
sig/openai/models/beta/threads/runs/step_list_params.rbs

Overview

See Also:

  • OpenAI::Resources::Beta::Threads::Runs::Steps#list

Defined Under Namespace

Modules: Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(thread_id:, run_id:, after: nil, before: nil, include: nil, limit: nil, order: nil, request_options: {}) ⇒ Object

Parameters:

  • after (defaults to: nil) —

    A cursor for use in pagination. after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include after=obj_foo in order to fetch the next page of the list.

  • before (defaults to: nil) —

    A cursor for use in pagination. before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_foo, your subsequent call can include before=obj_foo in order to fetch the previous page of the list.

  • include (defaults to: nil) —

    A list of additional fields to include in the response. Currently the only supported value is step_details.tool_calls[*].file_search.results[*].content to fetch the file search result content.

    See the file search tool documentation for more information.

  • limit (defaults to: nil) —

    A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20.

  • order (defaults to: nil) —

    Sort order by the created_at timestamp of the objects. asc for ascending order and desc for descending order.



# File 'lib/openai/models/beta/threads/runs/step_list_params.rb', line 70

Instance Attribute Details

#after ⇒ String?

A cursor for use in pagination. after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include after=obj_foo in order to fetch the next page of the list.

Returns:

  • (String, nil)


30
# File 'lib/openai/models/beta/threads/runs/step_list_params.rb', line 30

optional :after, String

#before ⇒ String?

A cursor for use in pagination. before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_foo, your subsequent call can include before=obj_foo in order to fetch the previous page of the list.

Returns:

  • (String, nil)


39
# File 'lib/openai/models/beta/threads/runs/step_list_params.rb', line 39

optional :before, String

#include ⇒ ::Array[OpenAI::Models::Beta::Threads::Runs::run_step_include]?

A list of additional fields to include in the response. Currently the only supported value is step_details.tool_calls[*].file_search.results[*].content to fetch the file search result content.

See the file search tool documentation for more information.

Returns:

  • (::Array[OpenAI::Models::Beta::Threads::Runs::run_step_include], nil)


51
52
53
54
# File 'lib/openai/models/beta/threads/runs/step_list_params.rb', line 51

optional(
  :include,
  -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Beta::Threads::Runs::RunStepInclude] }
)

#limit ⇒ Integer?

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20.

Returns:

  • (Integer, nil)


61
# File 'lib/openai/models/beta/threads/runs/step_list_params.rb', line 61

optional :limit, Integer

#order ⇒ OpenAI::Models::Beta::Threads::Runs::StepListParams::order?

Sort order by the created_at timestamp of the objects. asc for ascending order and desc for descending order.

Returns:

  • (OpenAI::Models::Beta::Threads::Runs::StepListParams::order, nil)


68
# File 'lib/openai/models/beta/threads/runs/step_list_params.rb', line 68

optional :order, enum: -> { OpenAI::Beta::Threads::Runs::StepListParams::Order }

#run_id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


21
# File 'lib/openai/models/beta/threads/runs/step_list_params.rb', line 21

required :run_id, String

#thread_id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/openai/models/beta/threads/runs/step_list_params.rb', line 16

required :thread_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


123
# File 'sig/openai/models/beta/threads/runs/step_list_params.rbs', line 123

def to_hash: -> {