Class: OpenAI::Models::Beta::Threads::Runs::ToolCallDeltaObject

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/threads/runs/tool_call_delta_object.rb,
sig/openai/models/beta/threads/runs/tool_call_delta_object.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(tool_calls: nil, type: :tool_calls) ⇒ Object

Parameters:

  • tool_calls (defaults to: nil) —

    An array of tool calls the run step was involved in. These can be associated with one of three types of tools: code_interpreter, file_search, or function.

  • type (defaults to: :tool_calls) —

    Always tool_calls.



# File 'lib/openai/models/beta/threads/runs/tool_call_delta_object.rb', line 26

Instance Attribute Details

#tool_calls ⇒ ::Array[OpenAI::Models::Beta::Threads::Runs::tool_call_delta]?

An array of tool calls the run step was involved in. These can be associated with one of three types of tools: code_interpreter, file_search, or function.

Returns:

  • (::Array[OpenAI::Models::Beta::Threads::Runs::tool_call_delta], nil)


21
22
23
24
# File 'lib/openai/models/beta/threads/runs/tool_call_delta_object.rb', line 21

optional(
  :tool_calls,
  -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::Threads::Runs::ToolCallDelta] }
)

#type ⇒ :tool_calls

Always tool_calls.

Returns:

  • (:tool_calls)


13
# File 'lib/openai/models/beta/threads/runs/tool_call_delta_object.rb', line 13

required :type, const: :tool_calls

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


39
# File 'sig/openai/models/beta/threads/runs/tool_call_delta_object.rbs', line 39

def to_hash: -> {