Class: OpenAI::Models::Beta::Threads::Runs::ToolCallsStepDetails

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/threads/runs/tool_calls_step_details.rb,
sig/openai/models/beta/threads/runs/tool_calls_step_details.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(tool_calls:, type: :tool_calls) ⇒ Object

Parameters:

  • tool_calls —

    An array of tool calls the run step was involved in. These can be associated with one of three types of tools: code_interpreter, file_search, or function.

  • type (defaults to: :tool_calls) —

    Always tool_calls.



# File 'lib/openai/models/beta/threads/runs/tool_calls_step_details.rb', line 23

Instance Attribute Details

#tool_calls ⇒ ::Array[OpenAI::Models::Beta::Threads::Runs::tool_call]

An array of tool calls the run step was involved in. These can be associated with one of three types of tools: code_interpreter, file_search, or function.

Returns:

  • (::Array[OpenAI::Models::Beta::Threads::Runs::tool_call])


15
# File 'lib/openai/models/beta/threads/runs/tool_calls_step_details.rb', line 15

required :tool_calls, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::Threads::Runs::ToolCall] }

#type ⇒ :tool_calls

Always tool_calls.

Returns:

  • (:tool_calls)


21
# File 'lib/openai/models/beta/threads/runs/tool_calls_step_details.rb', line 21

required :type, const: :tool_calls

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


32
# File 'sig/openai/models/beta/threads/runs/tool_calls_step_details.rbs', line 32

def to_hash: -> {