Class: OpenAI::Models::BetaComputerAction::Beta::BetaComputerAction::Click

Inherits:
Internal::Type::BaseModel show all
Defined in:
sig/openai/models/beta/beta_computer_action.rbs

Defined Under Namespace

Modules: Button

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Parameters:

  • button

    Indicates which mouse button was pressed during the click. One of left, right, wheel, back, or forward.

  • x

    The x-coordinate where the click occurred.

  • y_

    The y-coordinate where the click occurred.

  • keys

    The keys being held while clicking.

  • type

    Specifies the event type. For a click action, this property is always click.



57
# File 'sig/openai/models/beta/beta_computer_action.rbs', line 57

def initialize: (

Instance Attribute Details

#buttonOpenAI::Models::Beta::BetaComputerAction::Click::button

Indicates which mouse button was pressed during the click. One of left, right, wheel, back, or forward.

Returns:

  • (OpenAI::Models::Beta::BetaComputerAction::Click::button)


32
33
34
# File 'sig/openai/models/beta/beta_computer_action.rbs', line 32

def button
  @button
end

#keys::Array[String]?

The keys being held while clicking.

Returns:

  • (::Array[String], nil)


44
45
46
# File 'sig/openai/models/beta/beta_computer_action.rbs', line 44

def keys
  @keys
end

#type:click

Specifies the event type. For a click action, this property is always click.

Returns:

  • (:click)


35
36
37
# File 'sig/openai/models/beta/beta_computer_action.rbs', line 35

def type
  @type
end

#xInteger

The x-coordinate where the click occurred.

Returns:

  • (Integer)


38
39
40
# File 'sig/openai/models/beta/beta_computer_action.rbs', line 38

def x
  @x
end

#y_Integer

The y-coordinate where the click occurred.

Returns:

  • (Integer)


41
42
43
# File 'sig/openai/models/beta/beta_computer_action.rbs', line 41

def y_
  @y_
end

Instance Method Details

#to_hash{

Returns:

  • ({)


65
# File 'sig/openai/models/beta/beta_computer_action.rbs', line 65

def to_hash: -> {