Class: OpenAI::Models::BetaResponseInputItem::Beta::BetaResponseInputItem::ApplyPatchCall::Operation::UpdateFile

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
sig/openai/models/beta/beta_response_input_item.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Parameters:

  • diff

    Unified diff content to apply to the existing file.

  • path

    Path of the file to update relative to the workspace root.

  • type

    The operation type. Always update_file.



2032
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 2032

def initialize: (

Instance Attribute Details

#diffString

Unified diff content to apply to the existing file.

Returns:

  • (String)


2018
2019
2020
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 2018

def diff
  @diff
end

#pathString

Path of the file to update relative to the workspace root.

Returns:

  • (String)


2021
2022
2023
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 2021

def path
  @path
end

#type:update_file

The operation type. Always update_file.

Returns:

  • (:update_file)


2024
2025
2026
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 2024

def type
  @type
end

Instance Method Details

#to_hash{

Returns:

  • ({)


2038
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 2038

def to_hash: -> {