Class: OpenAI::Models::BetaResponseInputItem::Beta::BetaResponseInputItem::LocalShellCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
sig/openai/models/beta/beta_response_input_item.rbs

Defined Under Namespace

Modules: Status Classes: Action, Agent

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • id —

    The unique ID of the local shell call.

  • action —

    Execute a shell command on the server.

  • call_id —

    The unique ID of the local shell tool call generated by the model.

  • status —

    The status of the local shell call.

  • agent —

    The agent that produced this item.

  • type —

    The type of the local shell call. Always local_shell_call.



1361
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1361

def initialize: (

Instance Attribute Details

#action ⇒ OpenAI::Beta::BetaResponseInputItem::LocalShellCall::Action

Execute a shell command on the server.

Returns:

  • (OpenAI::Beta::BetaResponseInputItem::LocalShellCall::Action)


1335
1336
1337
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1335

def action
  @action
end

#agent ⇒ OpenAI::Beta::BetaResponseInputItem::LocalShellCall::Agent?

The agent that produced this item.

Returns:

  • (OpenAI::Beta::BetaResponseInputItem::LocalShellCall::Agent, nil)


1347
1348
1349
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1347

def agent
  @agent
end

#call_id ⇒ String

The unique ID of the local shell tool call generated by the model.

Returns:

  • (String)


1338
1339
1340
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1338

def call_id
  @call_id
end

#id ⇒ String

The unique ID of the local shell call.

Returns:

  • (String)


1332
1333
1334
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1332

def id
  @id
end

#status ⇒ OpenAI::Models::Beta::BetaResponseInputItem::LocalShellCall::status

The status of the local shell call.

Returns:

  • (OpenAI::Models::Beta::BetaResponseInputItem::LocalShellCall::status)


1341
1342
1343
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1341

def status
  @status
end

#type ⇒ :local_shell_call

The type of the local shell call. Always local_shell_call.

Returns:

  • (:local_shell_call)


1344
1345
1346
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1344

def type
  @type
end

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


1370
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1370

def to_hash: -> {