Class: OpenAI::Models::BetaResponsesServerEvent::Beta::BetaResponsesServerEvent::BetaResponseShellCallCommandWsAdded

Inherits:
OpenAI::Models::Beta::BetaResponseShellCallCommandAddedEvent show all
Defined in:
sig/openai/models/beta/beta_responses_server_event.rbs

Instance Attribute Summary

Attributes inherited from OpenAI::Models::Beta::BetaResponseShellCallCommandAddedEvent

#agent, #command, #command_index, #output_index, #sequence_number, #type

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • command —

    The shell command that was added.

  • command_index —

    The index of the shell command that was added.

  • output_index —

    The index of the output item that was updated.

  • sequence_number —

    The sequence number of the event that was emitted.

  • agent —

    The agent that owns this multi-agent streaming event.

  • stream_id —

    The WebSocket lane that emitted this event. This field is present when the originating response.create event supplied a stream_id.

  • type —

    The type of the event, always response.shell_call_command.added.



1081
# File 'sig/openai/models/beta/beta_responses_server_event.rbs', line 1081

def initialize: (

Instance Method Details

#stream_id ⇒ String?

The WebSocket lane that emitted this event. This field is present when the originating response.create event supplied a stream_id.

Returns:

  • (String, nil)


1060
# File 'sig/openai/models/beta/beta_responses_server_event.rbs', line 1060

def stream_id: -> String?

#stream_id= ⇒ String

The WebSocket lane that emitted this event. This field is present when the originating response.create event supplied a stream_id.

Parameters:

  • _ (String)

Returns:

  • (String)


1064
# File 'sig/openai/models/beta/beta_responses_server_event.rbs', line 1064

def stream_id=: (String _) -> String

#to_hash ⇒ {

Returns:

  • ({)


1091
# File 'sig/openai/models/beta/beta_responses_server_event.rbs', line 1091

def to_hash: -> {