Module: OpenAI::Models::Chat::ChatCompletion::Choice::FinishReason

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/chat/chat_completion.rb,
sig/openai/models/chat/chat_completion.rbs

Overview

The reason the model stopped generating tokens. This will be stop if the model hit a natural stop point or a provided stop sequence, length if the maximum number of tokens specified in the request was reached, content_filter if content was omitted due to a flag from our content filters, tool_calls if the model called a tool, or function_call (deprecated) if the model called a function. Read the Model Spec for more.

See Also:

  • OpenAI::Models::Chat::ChatCompletion::Choice#finish_reason

Constant Summary collapse

STOP =

Returns:

  • (:stop)
:stop
LENGTH =

Returns:

  • (:length)
:length
TOOL_CALLS =

Returns:

  • (:tool_calls)
:tool_calls
CONTENT_FILTER =

Returns:

  • (:content_filter)
:content_filter
FUNCTION_CALL =

Returns:

  • (:function_call)
:function_call

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[OpenAI::Models::Chat::ChatCompletion::Choice::finish_reason]

Returns:

  • (::Array[OpenAI::Models::Chat::ChatCompletion::Choice::finish_reason])


109
# File 'sig/openai/models/chat/chat_completion.rbs', line 109

def self?.values: -> ::Array[OpenAI::Models::Chat::ChatCompletion::Choice::finish_reason]