Class: OpenAI::Models::Chat::ChatCompletion::Choice::Logprobs

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/chat/chat_completion.rb,
sig/openai/models/chat/chat_completion.rbs

Overview

See Also:

  • OpenAI::Models::Chat::ChatCompletion::Choice#logprobs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



123
# File 'sig/openai/models/chat/chat_completion.rbs', line 123

def initialize: (

Instance Attribute Details

#contentArray<OpenAI::Models::Chat::ChatCompletionTokenLogprob>?

A list of message content tokens with log probability information.

Parameters:

  • value (::Array[OpenAI::Chat::ChatCompletionTokenLogprob], nil)

Returns:



182
183
184
# File 'lib/openai/models/chat/chat_completion.rb', line 182

required :content,
-> { OpenAI::Internal::Type::ArrayOf[OpenAI::Chat::ChatCompletionTokenLogprob] },
nil?: true

#refusalArray<OpenAI::Models::Chat::ChatCompletionTokenLogprob>?

A list of message refusal tokens with log probability information.

Parameters:

  • value (::Array[OpenAI::Chat::ChatCompletionTokenLogprob], nil)

Returns:



190
191
192
# File 'lib/openai/models/chat/chat_completion.rb', line 190

required :refusal,
-> { OpenAI::Internal::Type::ArrayOf[OpenAI::Chat::ChatCompletionTokenLogprob] },
nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


128
# File 'sig/openai/models/chat/chat_completion.rbs', line 128

def to_hash: -> {