Class: OpenAI::Models::Chat::ChatCompletionAudioParam

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/chat/chat_completion_audio_param.rb

Defined Under Namespace

Modules: Format, Voice

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(format_:, voice:) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Chat::ChatCompletionAudioParam for more details.

Parameters for audio output. Required when audio output is requested with ‘modalities: [“audio”]`. [Learn more](platform.openai.com/docs/guides/audio).

Parameters:

  • Specifies the output audio format. Must be one of wav, mp3, flac,

  • The voice the model uses to respond. Supported built-in voices are



# File 'lib/openai/models/chat/chat_completion_audio_param.rb', line 23


Instance Attribute Details

#format_Symbol, OpenAI::Models::Chat::ChatCompletionAudioParam::Format

Specifies the output audio format. Must be one of wav, mp3, flac, opus, or pcm16.

Returns:



12
# File 'lib/openai/models/chat/chat_completion_audio_param.rb', line 12

required :format_, enum: -> { OpenAI::Chat::ChatCompletionAudioParam::Format }, api_name: :format

#voiceString, ...

The voice the model uses to respond. Supported built-in voices are alloy, ash, ballad, coral, echo, fable, nova, onyx, sage, shimmer, marin, and cedar. You may also provide a custom voice object with an id, for example ‘{ “id”: “voice_1234” }`.

Returns:



21
# File 'lib/openai/models/chat/chat_completion_audio_param.rb', line 21

required :voice, union: -> { OpenAI::Chat::ChatCompletionAudioParam::Voice }

Class Method Details

.valuesArray<Symbol>

Returns:



# File 'lib/openai/models/chat/chat_completion_audio_param.rb', line 49