Module: OpenAI::Models::Chat::ChatCompletionAudioParam::Voice

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/chat/chat_completion_audio_param.rb,
sig/openai/models/chat/chat_completion_audio_param.rbs

Overview

The voice the model uses to respond. Supported built-in voices are alloy, ash, ballad, coral, echo, fable, nova, onyx, sage, shimmer, marin, and cedar. You may also provide a custom voice object with an id, for example { "id": "voice_1234" }.

See Also:

  • OpenAI::Models::Chat::ChatCompletionAudioParam#voice

Defined Under Namespace

Classes: ID

collapse

ALLOY =

Returns:

  • (:alloy)
:alloy
ASH =

Returns:

  • (:ash)
:ash
BALLAD =

Returns:

  • (:ballad)
:ballad
CORAL =

Returns:

  • (:coral)
:coral
ECHO =

Returns:

  • (:echo)
:echo
SAGE =

Returns:

  • (:sage)
:sage
SHIMMER =

Returns:

  • (:shimmer)
:shimmer
VERSE =

Returns:

  • (:verse)
:verse
MARIN =

Returns:

  • (:marin)
:marin
CEDAR =

Returns:

  • (:cedar)
:cedar

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.variantsArray(String, Symbol, OpenAI::Models::Chat::ChatCompletionAudioParam::Voice::ID)



103
104
105
106
107
108
109
110
111
# File 'lib/openai/models/chat/chat_completion_audio_param.rb', line 103

define_sorbet_constant!(:Variants) do
  T.type_alias do
    T.any(
      String,
      OpenAI::Chat::ChatCompletionAudioParam::Voice::TaggedSymbol,
      OpenAI::Chat::ChatCompletionAudioParam::Voice::ID
    )
  end
end

Instance Method Details

#initialize(id:) ⇒ Object

Custom voice reference.

Parameters:

  • id (String)

    The custom voice ID, e.g. voice_1234.



# File 'lib/openai/models/chat/chat_completion_audio_param.rb', line 94

#self?.variants::Array[OpenAI::Models::Chat::ChatCompletionAudioParam::voice]

Returns:

  • (::Array[OpenAI::Models::Chat::ChatCompletionAudioParam::voice])


69
# File 'sig/openai/models/chat/chat_completion_audio_param.rbs', line 69

def self?.variants: -> ::Array[OpenAI::Models::Chat::ChatCompletionAudioParam::voice]