Class: OpenAI::Models::Chat::ChatCompletionChunk::Choice::Delta::ToolCall::Function

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/chat/chat_completion_chunk.rb,
sig/openai/models/chat/chat_completion_chunk.rbs

Overview

See Also:

  • OpenAI::Models::Chat::ChatCompletionChunk::Choice::Delta::ToolCall#function

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeFunction

Returns a new instance of Function.

Parameters:

  • arguments: (String)
  • name: (String)


225
# File 'sig/openai/models/chat/chat_completion_chunk.rbs', line 225

def initialize: (?arguments: String, ?name: String) -> void

Instance Attribute Details

#argumentsString?

The arguments to call the function with, as generated by the model in JSON format. Note that the model does not always generate valid JSON, and may hallucinate parameters not defined by your function schema. Validate the arguments in your code before calling your function.

Parameters:

  • (String)

Returns:

  • (String, nil)


302
# File 'lib/openai/models/chat/chat_completion_chunk.rb', line 302

optional :arguments, String

#nameString?

The name of the function to call.

Parameters:

  • (String)

Returns:

  • (String, nil)


308
# File 'lib/openai/models/chat/chat_completion_chunk.rb', line 308

optional :name, String

Instance Method Details

#to_hash{ arguments: String, name: String }

Returns:

  • ({ arguments: String, name: String })


227
# File 'sig/openai/models/chat/chat_completion_chunk.rbs', line 227

def to_hash: -> { arguments: String, name: String }