Class: OpenAI::Models::Chat::ChatCompletionChunk::Choice::Logprobs
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Chat::ChatCompletionChunk::Choice::Logprobs
- Defined in:
- lib/openai/models/chat/chat_completion_chunk.rb,
sig/openai/models/chat/chat_completion_chunk.rbs
Overview
Instance Attribute Summary collapse
-
#content ⇒ ::Array[OpenAI::Chat::ChatCompletionTokenLogprob]?
A list of message content tokens with log probability information.
-
#refusal ⇒ ::Array[OpenAI::Chat::ChatCompletionTokenLogprob]?
A list of message refusal tokens with log probability information.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
468 |
# File 'sig/openai/models/chat/chat_completion_chunk.rbs', line 468 def initialize: ( |
Instance Attribute Details
#content ⇒ ::Array[OpenAI::Chat::ChatCompletionTokenLogprob]?
A list of message content tokens with log probability information.
434 435 436 437 438 |
# File 'lib/openai/models/chat/chat_completion_chunk.rb', line 434 required( :content, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Chat::ChatCompletionTokenLogprob] }, nil?: true ) |
#refusal ⇒ ::Array[OpenAI::Chat::ChatCompletionTokenLogprob]?
A list of message refusal tokens with log probability information.
444 445 446 447 448 |
# File 'lib/openai/models/chat/chat_completion_chunk.rb', line 444 required( :refusal, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Chat::ChatCompletionTokenLogprob] }, nil?: true ) |
Instance Method Details
#to_hash ⇒ {
473 |
# File 'sig/openai/models/chat/chat_completion_chunk.rbs', line 473 def to_hash: -> { |