Class: OpenAI::Models::Chat::ChatCompletionContentPartInputAudio
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Chat::ChatCompletionContentPartInputAudio
- Defined in:
- lib/openai/models/chat/chat_completion_content_part_input_audio.rb,
sig/openai/models/chat/chat_completion_content_part_input_audio.rbs
Defined Under Namespace
Classes: InputAudio, PromptCacheBreakpoint
Instance Attribute Summary collapse
- #input_audio ⇒ OpenAI::Models::Chat::ChatCompletionContentPartInputAudio::InputAudio
-
#prompt_cache_breakpoint ⇒ OpenAI::Models::Chat::ChatCompletionContentPartInputAudio::PromptCacheBreakpoint?
Marks the exact end of a reusable prompt prefix.
-
#type ⇒ Symbol, :input_audio
The type of the content part.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(input_audio:, prompt_cache_breakpoint: nil, type: :input_audio) ⇒ Object
constructor
Some parameter documentations has been truncated, see ChatCompletionContentPartInputAudio for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(input_audio:, prompt_cache_breakpoint: nil, type: :input_audio) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Chat::ChatCompletionContentPartInputAudio for more details.
Learn about audio inputs.
|
|
# File 'lib/openai/models/chat/chat_completion_content_part_input_audio.rb', line 27
|
Instance Attribute Details
#input_audio ⇒ OpenAI::Models::Chat::ChatCompletionContentPartInputAudio::InputAudio
10 |
# File 'lib/openai/models/chat/chat_completion_content_part_input_audio.rb', line 10 required :input_audio, -> { OpenAI::Chat::ChatCompletionContentPartInputAudio::InputAudio } |
#prompt_cache_breakpoint ⇒ OpenAI::Models::Chat::ChatCompletionContentPartInputAudio::PromptCacheBreakpoint?
Marks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL
from the request's prompt_cache_options.ttl; the boundary is not rounded to a
token block.
24 25 |
# File 'lib/openai/models/chat/chat_completion_content_part_input_audio.rb', line 24 optional :prompt_cache_breakpoint, -> { OpenAI::Chat::ChatCompletionContentPartInputAudio::PromptCacheBreakpoint } |
#type ⇒ Symbol, :input_audio
The type of the content part. Always input_audio.
16 |
# File 'lib/openai/models/chat/chat_completion_content_part_input_audio.rb', line 16 required :type, const: :input_audio |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/chat/chat_completion_content_part_input_audio.rb', line 73
|
Instance Method Details
#to_hash ⇒ {
30 |
# File 'sig/openai/models/chat/chat_completion_content_part_input_audio.rbs', line 30
def to_hash: -> {
|