Class: OpenAI::Models::Chat::ChatCompletionContentPartText

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/chat/chat_completion_content_part_text.rb,
sig/openai/models/chat/chat_completion_content_part_text.rbs

Defined Under Namespace

Classes: PromptCacheBreakpoint

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(text:, prompt_cache_breakpoint: nil, type: :text) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Chat::ChatCompletionContentPartText for more details.

Learn about text inputs.

Parameters:



# File 'lib/openai/models/chat/chat_completion_content_part_text.rb', line 28

Instance Attribute Details

#prompt_cache_breakpointOpenAI::Models::Chat::ChatCompletionContentPartText::PromptCacheBreakpoint?

Marks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL from the request's prompt_cache_options.ttl; the boundary is not rounded to a token block.



25
26
# File 'lib/openai/models/chat/chat_completion_content_part_text.rb', line 25

optional :prompt_cache_breakpoint,
-> { OpenAI::Chat::ChatCompletionContentPartText::PromptCacheBreakpoint }

#textString

The text content.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/openai/models/chat/chat_completion_content_part_text.rb', line 11

required :text, String

#typeSymbol, :text

The type of the content part.

Parameters:

  • value (:text)

Returns:

  • (Symbol, :text)


17
# File 'lib/openai/models/chat/chat_completion_content_part_text.rb', line 17

required :type, const: :text

Instance Method Details

#to_hash{

Returns:

  • ({)


30
# File 'sig/openai/models/chat/chat_completion_content_part_text.rbs', line 30

def to_hash: -> {