Class: OpenAI::Models::Chat::ChatCompletionMessage::Annotation::URLCitation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/chat/chat_completion_message.rb,
sig/openai/models/chat/chat_completion_message.rbs

Overview

See Also:

  • OpenAI::Models::Chat::ChatCompletionMessage::Annotation#url_citation

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Parameters:

  • end_index

    The index of the last character of the URL citation in the message.

  • start_index

    The index of the first character of the URL citation in the message.

  • title

    The title of the web resource.

  • url

    The URL of the web resource.



154
# File 'sig/openai/models/chat/chat_completion_message.rbs', line 154

def initialize: (

Instance Attribute Details

#end_indexInteger

The index of the last character of the URL citation in the message.

Returns:

  • (Integer)


124
# File 'lib/openai/models/chat/chat_completion_message.rb', line 124

required :end_index, Integer

#start_indexInteger

The index of the first character of the URL citation in the message.

Returns:

  • (Integer)


130
# File 'lib/openai/models/chat/chat_completion_message.rb', line 130

required :start_index, Integer

#titleString

The title of the web resource.

Returns:

  • (String)


136
# File 'lib/openai/models/chat/chat_completion_message.rb', line 136

required :title, String

#urlString

The URL of the web resource.

Returns:

  • (String)


142
# File 'lib/openai/models/chat/chat_completion_message.rb', line 142

required :url, String

Instance Method Details

#to_hash{

Returns:

  • ({)


161
# File 'sig/openai/models/chat/chat_completion_message.rbs', line 161

def to_hash: -> {