Class: OpenAI::Models::Chat::ChatCompletionMessage::FunctionCall Deprecated

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/chat/chat_completion_message.rb,
sig/openai/models/chat/chat_completion_message.rbs

Overview

Deprecated.

See Also:

  • OpenAI::Models::Chat::ChatCompletionMessage#function_call

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ FunctionCall

Returns a new instance of FunctionCall.

Parameters:

  • arguments —

    The arguments to call the function with, as generated by the model in JSON format. Note that the model does not always generate valid JSON, and may hallucinate parameters not defined by your function schema. Validate the arguments in your code before calling your function.

  • name —

    The name of the function to call.

  • arguments: (String)
  • name: (String)


189
# File 'sig/openai/models/chat/chat_completion_message.rbs', line 189

def initialize: (arguments: String, name: String) -> void

Instance Attribute Details

#arguments ⇒ String

The arguments to call the function with, as generated by the model in JSON format. Note that the model does not always generate valid JSON, and may hallucinate parameters not defined by your function schema. Validate the arguments in your code before calling your function.

Returns:

  • (String)


172
# File 'lib/openai/models/chat/chat_completion_message.rb', line 172

required :arguments, String

#name ⇒ String

The name of the function to call.

Returns:

  • (String)


178
# File 'lib/openai/models/chat/chat_completion_message.rb', line 178

required :name, String

Instance Method Details

#to_hash ⇒ { arguments: String, name: String }

Returns:

  • ({ arguments: String, name: String })


191
# File 'sig/openai/models/chat/chat_completion_message.rbs', line 191

def to_hash: -> { arguments: String, name: String }