Module: OpenAI::Models::Chat::ChatCompletionPredictionContent::Content
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/chat/chat_completion_prediction_content.rb,
sig/openai/models/chat/chat_completion_prediction_content.rbs
Overview
The content that should be matched when generating a model response. If generated tokens would match this content, the entire model response can be returned much more quickly.
Constant Summary collapse
- ChatCompletionContentPartTextArray =
OpenAI::Internal::Type::ArrayOf[-> { OpenAI::Chat::ChatCompletionContentPartText }]
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(String, Array<OpenAI::Models::Chat::ChatCompletionContentPartText>)
|
|
# File 'lib/openai/models/chat/chat_completion_prediction_content.rb', line 48
|
Instance Method Details
#self?.variants ⇒ ::Array[OpenAI::Models::Chat::ChatCompletionPredictionContent::content]
33 |
# File 'sig/openai/models/chat/chat_completion_prediction_content.rbs', line 33
def self?.variants: -> ::Array[OpenAI::Models::Chat::ChatCompletionPredictionContent::content]
|