Class: OpenAI::Models::Chat::CompletionCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Chat::CompletionCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/chat/completion_create_params.rb,
sig/openai/models/chat/completion_create_params.rbs
Overview
Defined Under Namespace
Modules: FunctionCall, Modality, Model, PromptCacheRetention, ResponseFormat, ServiceTier, Stop, Verbosity Classes: Function, Moderation, PromptCacheOptions, WebSearchOptions
Constant Summary collapse
- OpenAI =
Instance Attribute Summary collapse
-
#audio ⇒ OpenAI::Chat::ChatCompletionAudioParam?
Parameters for audio output.
-
#frequency_penalty ⇒ Float?
Number between -2.0 and 2.0.
-
#function_call ⇒ OpenAI::Models::Chat::CompletionCreateParams::function_call?
Deprecated in favor of
tool_choice. -
#functions ⇒ ::Array[OpenAI::Chat::CompletionCreateParams::Function]?
Deprecated in favor of
tools. -
#logit_bias ⇒ ::Hash[Symbol, Integer]?
Modify the likelihood of specified tokens appearing in the completion.
-
#logprobs ⇒ Boolean?
Whether to return log probabilities of the output tokens or not.
-
#max_completion_tokens ⇒ Integer?
An upper bound for the number of tokens that can be generated for a completion, including visible output tokens and reasoning tokens.
-
#max_tokens ⇒ Integer?
The maximum number of tokens that can be generated in the chat completion.
-
#messages ⇒ ::Array[OpenAI::Models::Chat::chat_completion_message_param]
A list of messages comprising the conversation so far.
-
#metadata ⇒ OpenAI::Models::metadata?
Set of 16 key-value pairs that can be attached to an object.
-
#modalities ⇒ ::Array[OpenAI::Models::Chat::CompletionCreateParams::modality]?
Output types that you would like the model to generate.
-
#model ⇒ OpenAI::Models::Chat::CompletionCreateParams::model
Model ID used to generate the response, like
gpt-6-astraoro3. -
#moderation ⇒ OpenAI::Chat::CompletionCreateParams::Moderation?
Configuration for running moderation on the request input and generated output.
-
#n ⇒ Integer?
How many chat completion choices to generate for each input message.
-
#parallel_tool_calls ⇒ Boolean?
Whether to enable parallel function calling during tool use.
-
#prediction ⇒ OpenAI::Chat::ChatCompletionPredictionContent?
Configuration for a Predicted Output, which can greatly improve response times when large parts of the model response are known ahead of time.
-
#presence_penalty ⇒ Float?
Number between -2.0 and 2.0.
-
#prompt_cache_key ⇒ String?
Used by OpenAI to cache responses for similar requests to optimize your cache hit rates.
-
#prompt_cache_options ⇒ OpenAI::Chat::CompletionCreateParams::PromptCacheOptions?
Options for prompt caching.
-
#prompt_cache_retention ⇒ OpenAI::Models::Chat::CompletionCreateParams::prompt_cache_retention?
Deprecated.
-
#reasoning_effort ⇒ OpenAI::Models::reasoning_effort?
Constrains effort on reasoning for reasoning models.
-
#response_format ⇒ OpenAI::Models::Chat::CompletionCreateParams::response_format?
An object specifying the format that the model must output.
-
#safety_identifier ⇒ String?
A stable identifier used to help detect users of your application that may be violating OpenAI's usage policies.
-
#seed ⇒ Integer?
This feature is in Beta.
-
#service_tier ⇒ OpenAI::Models::Chat::CompletionCreateParams::service_tier?
Specifies the processing type used for serving the request.
-
#stop ⇒ OpenAI::Models::Chat::CompletionCreateParams::stop?
Not supported with latest reasoning models
o3ando4-mini. -
#store ⇒ Boolean?
Whether or not to store the output of this chat completion request for use in our model distillation or evals products.
-
#stream_options ⇒ OpenAI::Chat::ChatCompletionStreamOptions?
Options for streaming response.
-
#temperature ⇒ Float?
What sampling temperature to use, between 0 and 2.
-
#tool_choice ⇒ OpenAI::Models::Chat::chat_completion_tool_choice_option?
Controls which (if any) tool is called by the model.
-
#tools ⇒ ::Array[OpenAI::Models::Chat::chat_completion_tool]?
A list of tools the model may call.
-
#top_logprobs ⇒ Integer?
An integer between 0 and 20 specifying the maximum number of most likely tokens to return at each token position, each with an associated log probability.
-
#top_p ⇒ Float?
An alternative to sampling with temperature, called nucleus sampling, where the model considers the results of the tokens with top_p probability mass.
-
#user ⇒ String?
This field is being replaced by
safety_identifierandprompt_cache_key. -
#verbosity ⇒ OpenAI::Models::Chat::CompletionCreateParams::verbosity?
Constrains the verbosity of the model's response.
-
#web_search_options ⇒ OpenAI::Chat::CompletionCreateParams::WebSearchOptions?
This tool searches the web for relevant results to use in a response.
Attributes included from Internal::Type::RequestParameters
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(OpenAI::Models::ResponseFormatText, OpenAI::Models::ResponseFormatJSONSchema, OpenAI::Models::ResponseFormatJSONObject)
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, description: nil, parameters: nil) ⇒ Object
|
|
# File 'lib/openai/models/chat/completion_create_params.rb', line 442
|
Instance Attribute Details
#audio ⇒ OpenAI::Chat::ChatCompletionAudioParam?
Parameters for audio output. Required when audio output is requested with
modalities: ["audio"].
Learn more.
43 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 43 optional :audio, -> { OpenAI::Chat::ChatCompletionAudioParam }, nil?: true |
#frequency_penalty ⇒ Float?
Number between -2.0 and 2.0. Positive values penalize new tokens based on their existing frequency in the text so far, decreasing the model's likelihood to repeat the same line verbatim.
51 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 51 optional :frequency_penalty, Float, nil?: true |
#function_call ⇒ OpenAI::Models::Chat::CompletionCreateParams::function_call?
Deprecated in favor of tool_choice.
Controls which (if any) function is called by the model.
none means the model will not call a function and instead generates a message.
auto means the model can pick between generating a message or calling a
function.
Specifying a particular function via {"name": "my_function"} forces the model
to call that function.
none is the default when no functions are present. auto is the default if
functions are present.
72 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 72 optional :function_call, union: -> { OpenAI::Chat::CompletionCreateParams::FunctionCall } |
#functions ⇒ ::Array[OpenAI::Chat::CompletionCreateParams::Function]?
Deprecated in favor of tools.
A list of functions the model may generate JSON inputs for.
82 83 84 85 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 82 optional( :functions, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Chat::CompletionCreateParams::Function] } ) |
#logit_bias ⇒ ::Hash[Symbol, Integer]?
Modify the likelihood of specified tokens appearing in the completion.
Accepts a JSON object that maps tokens (specified by their token ID in the tokenizer) to an associated bias value from -100 to 100. Mathematically, the bias is added to the logits generated by the model prior to sampling. The exact effect will vary per model, but values between -1 and 1 should decrease or increase likelihood of selection; values like -100 or 100 should result in a ban or exclusive selection of the relevant token.
98 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 98 optional :logit_bias, OpenAI::Internal::Type::HashOf[Integer], nil?: true |
#logprobs ⇒ Boolean?
Whether to return log probabilities of the output tokens or not. If true,
returns the log probabilities of each output token returned in the content of
message.
106 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 106 optional :logprobs, OpenAI::Internal::Type::Boolean, nil?: true |
#max_completion_tokens ⇒ Integer?
An upper bound for the number of tokens that can be generated for a completion, including visible output tokens and reasoning tokens.
114 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 114 optional :max_completion_tokens, Integer, nil?: true |
#max_tokens ⇒ Integer?
The maximum number of tokens that can be generated in the chat completion. This value can be used to control costs for text generated via API.
This value is now deprecated in favor of max_completion_tokens, and is not
compatible with
o-series models.
128 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 128 optional :max_tokens, Integer, nil?: true |
#messages ⇒ ::Array[OpenAI::Models::Chat::chat_completion_message_param]
22 23 24 25 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 22 required( :messages, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Chat::ChatCompletionMessageParam] } ) |
#metadata ⇒ OpenAI::Models::metadata?
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
139 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 139 optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true |
#modalities ⇒ ::Array[OpenAI::Models::Chat::CompletionCreateParams::modality]?
Output types that you would like the model to generate. Most models are capable of generating text, which is the default:
["text"]
The gpt-4o-audio-preview model can also be used to
generate audio. To
request that this model generate both text and audio responses, you can use:
["text", "audio"]
154 155 156 157 158 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 154 optional( :modalities, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Chat::CompletionCreateParams::Modality] }, nil?: true ) |
#model ⇒ OpenAI::Models::Chat::CompletionCreateParams::model
Model ID used to generate the response, like gpt-6-astra or o3. OpenAI
offers a wide range of models with different capabilities, performance
characteristics, and price points. Refer to the
model guide to browse and
compare available models.
35 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 35 required :model, union: -> { OpenAI::Chat::CompletionCreateParams::Model } |
#moderation ⇒ OpenAI::Chat::CompletionCreateParams::Moderation?
Configuration for running moderation on the request input and generated output.
164 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 164 optional :moderation, -> { OpenAI::Chat::CompletionCreateParams::Moderation }, nil?: true |
#n ⇒ Integer?
How many chat completion choices to generate for each input message. Note that
you will be charged based on the number of generated tokens across all of the
choices. Keep n as 1 to minimize costs.
172 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 172 optional :n, Integer, nil?: true |
#parallel_tool_calls ⇒ Boolean?
Whether to enable parallel function calling during tool use.
180 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 180 optional :parallel_tool_calls, OpenAI::Internal::Type::Boolean |
#prediction ⇒ OpenAI::Chat::ChatCompletionPredictionContent?
Configuration for a Predicted Output, which can greatly improve response times when large parts of the model response are known ahead of time. This is most common when you are regenerating a file with only minor changes to most of the content.
190 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 190 optional :prediction, -> { OpenAI::Chat::ChatCompletionPredictionContent }, nil?: true |
#presence_penalty ⇒ Float?
Number between -2.0 and 2.0. Positive values penalize new tokens based on whether they appear in the text so far, increasing the model's likelihood to talk about new topics.
198 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 198 optional :presence_penalty, Float, nil?: true |
#prompt_cache_key ⇒ String?
Used by OpenAI to cache responses for similar requests to optimize your cache
hit rates. Replaces the user field.
Learn more.
206 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 206 optional :prompt_cache_key, String, nil?: true |
#prompt_cache_options ⇒ OpenAI::Chat::CompletionCreateParams::PromptCacheOptions?
Options for prompt caching. Supported for gpt-5.6 and later models. By
default, OpenAI automatically chooses one implicit cache breakpoint. You can add
explicit breakpoints to content blocks with prompt_cache_breakpoint. Each
request can write up to four breakpoints. For cache matching, OpenAI considers
up to the latest 80 breakpoints in the conversation, without a content-block
lookback limit. Set mode to explicit to disable the implicit breakpoint. The
ttl defaults to 30m, which is currently the only supported value. See the
prompt caching guide
for current details.
220 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 220 optional :prompt_cache_options, -> { OpenAI::Chat::CompletionCreateParams::PromptCacheOptions } |
#prompt_cache_retention ⇒ OpenAI::Models::Chat::CompletionCreateParams::prompt_cache_retention?
Deprecated. Use prompt_cache_options.ttl instead.
The retention policy for the prompt cache. Set to 24h to enable extended
prompt caching, which keeps cached prefixes active for longer, up to a maximum
of 24 hours.
Learn more.
This field expresses a maximum retention policy, while
prompt_cache_options.ttl expresses a minimum cache lifetime. The two fields
are independent and do not interact. For gpt-5.5, gpt-5.5-pro, and future
models, only 24h is supported.
For older models that support both in_memory and 24h, the default depends on
your organization's data retention policy:
- Organizations without ZDR enabled default to
24h. - Organizations with ZDR enabled default to
in_memorywhenprompt_cache_retentionis not specified.
244 245 246 247 248 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 244 optional( :prompt_cache_retention, enum: -> { OpenAI::Chat::CompletionCreateParams::PromptCacheRetention }, nil?: true ) |
#reasoning_effort ⇒ OpenAI::Models::reasoning_effort?
Constrains effort on reasoning for reasoning models. Currently supported values
are none, minimal, low, medium, high, xhigh, and max. Reducing
reasoning effort can result in faster responses and fewer tokens used on
reasoning in a response. Not all reasoning models support every value. See the
reasoning guide for
model-specific support.
259 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 259 optional :reasoning_effort, enum: -> { OpenAI::ReasoningEffort }, nil?: true |
#response_format ⇒ OpenAI::Models::Chat::CompletionCreateParams::response_format?
An object specifying the format that the model must output.
Setting to { "type": "json_schema", "json_schema": {...} } enables Structured
Outputs which ensures the model will match your supplied JSON schema. Learn more
in the
Structured Outputs guide.
Setting to { "type": "json_object" } enables the older JSON mode, which
ensures the message the model generates is valid JSON. Using json_schema is
preferred for models that support it.
274 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 274 optional :response_format, union: -> { OpenAI::Chat::CompletionCreateParams::ResponseFormat } |
#safety_identifier ⇒ String?
A stable identifier used to help detect users of your application that may be violating OpenAI's usage policies. The IDs should be a string that uniquely identifies each user, with a maximum length of 64 characters. We recommend hashing their username or email address, in order to avoid sending us any identifying information. Learn more.
285 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 285 optional :safety_identifier, String, nil?: true |
#seed ⇒ Integer?
This feature is in Beta. If specified, our system will make a best effort to
sample deterministically, such that repeated requests with the same seed and
parameters should return the same result. Determinism is not guaranteed, and you
should refer to the system_fingerprint response parameter to monitor changes
in the backend.
297 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 297 optional :seed, Integer, nil?: true |
#service_tier ⇒ OpenAI::Models::Chat::CompletionCreateParams::service_tier?
Specifies the processing type used for serving the request.
- If set to 'auto', then the request will be processed with the service tier configured in the Project settings. Unless otherwise configured, the Project will use 'default'.
- If set to 'default', then the request will be processed with the standard pricing and performance for the selected model.
- If set to 'flex', then the request will be processed with the Flex Processing service tier.
- To opt-in to
Fast mode at the
request level, include the
service_tier=fastorservice_tier=priorityparameter for Responses or Chat Completions. The response will showservice_tier=priorityregardless of if you specifyservice_tier=fastorpriorityin your request. - When not set, the default behavior is 'auto'.
When the service_tier parameter is set, the response body will include the
service_tier value based on the processing mode actually used to serve the
request. This response value may be different from the value set in the
parameter.
324 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 324 optional :service_tier, enum: -> { OpenAI::Chat::CompletionCreateParams::ServiceTier }, nil?: true |
#stop ⇒ OpenAI::Models::Chat::CompletionCreateParams::stop?
Not supported with latest reasoning models o3 and o4-mini.
Up to 4 sequences where the API will stop generating further tokens. The returned text will not contain the stop sequence.
333 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 333 optional :stop, union: -> { OpenAI::Chat::CompletionCreateParams::Stop }, nil?: true |
#store ⇒ Boolean?
Whether or not to store the output of this chat completion request for use in our model distillation or evals products.
Supports text and image inputs. Note: image inputs over 8MB will be dropped.
344 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 344 optional :store, OpenAI::Internal::Type::Boolean, nil?: true |
#stream_options ⇒ OpenAI::Chat::ChatCompletionStreamOptions?
Options for streaming response. Only set this when you set stream: true.
350 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 350 optional :stream_options, -> { OpenAI::Chat::ChatCompletionStreamOptions }, nil?: true |
#temperature ⇒ Float?
What sampling temperature to use, between 0 and 2. Higher values like 0.8 will
make the output more random, while lower values like 0.2 will make it more
focused and deterministic. We generally recommend altering this or top_p but
not both.
359 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 359 optional :temperature, Float, nil?: true |
#tool_choice ⇒ OpenAI::Models::Chat::chat_completion_tool_choice_option?
Controls which (if any) tool is called by the model. none means the model will
not call any tool and instead generates a message. auto means the model can
pick between generating a message or calling one or more tools. required means
the model must call one or more tools. Specifying a particular tool via
{"type": "function", "function": {"name": "my_function"}} forces the model to
call that tool.
none is the default when no tools are present. auto is the default if tools
are present.
373 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 373 optional :tool_choice, union: -> { OpenAI::Chat::ChatCompletionToolChoiceOption } |
#tools ⇒ ::Array[OpenAI::Models::Chat::chat_completion_tool]?
A list of tools the model may call. You can provide either custom tools or function tools.
382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 382 optional( :tools, -> { OpenAI::Internal::Type::ArrayOf[ union: OpenAI::UnionOf[ OpenAI::Chat::ChatCompletionTool, OpenAI::StructuredOutput::JsonSchemaConverter ] ] } ) |
#top_logprobs ⇒ Integer?
An integer between 0 and 20 specifying the maximum number of most likely tokens
to return at each token position, each with an associated log probability. In
some cases, the number of returned tokens may be fewer than requested.
logprobs must be set to true if this parameter is used.
401 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 401 optional :top_logprobs, Integer, nil?: true |
#top_p ⇒ Float?
An alternative to sampling with temperature, called nucleus sampling, where the model considers the results of the tokens with top_p probability mass. So 0.1 means only the tokens comprising the top 10% probability mass are considered.
We generally recommend altering this or temperature but not both.
411 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 411 optional :top_p, Float, nil?: true |
#user ⇒ String?
This field is being replaced by safety_identifier and prompt_cache_key. Use
prompt_cache_key instead to maintain caching optimizations. A stable
identifier for your end-users. Used to boost cache hit rates by better bucketing
similar requests and to help OpenAI detect and prevent abuse.
Learn more.
423 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 423 optional :user, String |
#verbosity ⇒ OpenAI::Models::Chat::CompletionCreateParams::verbosity?
Constrains the verbosity of the model's response. Lower values will result in
more concise responses, while higher values will result in more verbose
responses. Currently supported values are low, medium, and high. The
default is medium.
432 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 432 optional :verbosity, enum: -> { OpenAI::Chat::CompletionCreateParams::Verbosity }, nil?: true |
#web_search_options ⇒ OpenAI::Chat::CompletionCreateParams::WebSearchOptions?
This tool searches the web for relevant results to use in a response. Learn more about the web search tool.
440 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 440 optional :web_search_options, -> { OpenAI::Chat::CompletionCreateParams::WebSearchOptions } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/chat/completion_create_params.rb', line 784
|
.variants ⇒ Array(OpenAI::Models::ResponseFormatText, OpenAI::Models::ResponseFormatJSONSchema, OpenAI::Models::ResponseFormatJSONObject)
|
|
# File 'lib/openai/models/chat/completion_create_params.rb', line 746
|
Instance Method Details
#to_hash ⇒ {
715 |
# File 'sig/openai/models/chat/completion_create_params.rbs', line 715
def to_hash: -> {
|