Module: OpenAI::Models::Chat::CompletionCreateParams::FunctionCall::FunctionCallMode
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/chat/completion_create_params.rb,
sig/openai/models/chat/completion_create_params.rbs
Overview
none means the model will not call a function and instead generates a message.
auto means the model can pick between generating a message or calling a
function.
Constant Summary collapse
- NONE =
:none- AUTO =
:auto
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[OpenAI::Models::Chat::CompletionCreateParams::FunctionCall::function_call_mode]
260 |
# File 'sig/openai/models/chat/completion_create_params.rbs', line 260
def self?.values: -> ::Array[OpenAI::Models::Chat::CompletionCreateParams::FunctionCall::function_call_mode]
|