Class: OpenAI::Models::Chat::CompletionCreateParams::Moderation::Policy
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Chat::CompletionCreateParams::Moderation::Policy
- Defined in:
- lib/openai/models/chat/completion_create_params.rb,
sig/openai/models/chat/completion_create_params.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#input ⇒ OpenAI::Models::Chat::CompletionCreateParams::Moderation::Policy::Input?
The moderation policy for the response input.
-
#output ⇒ OpenAI::Models::Chat::CompletionCreateParams::Moderation::Policy::Output?
The moderation policy for the response output.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(input: nil, output: nil) ⇒ Object
constructor
The policy to apply to moderated response input and output.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(input: nil, output: nil) ⇒ Object
The policy to apply to moderated response input and output.
|
|
# File 'lib/openai/models/chat/completion_create_params.rb', line 652
|
Instance Attribute Details
#input ⇒ OpenAI::Models::Chat::CompletionCreateParams::Moderation::Policy::Input?
The moderation policy for the response input.
636 637 638 639 640 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 636 optional :input, -> { OpenAI::Chat::CompletionCreateParams::Moderation::Policy::Input }, nil?: true |
#output ⇒ OpenAI::Models::Chat::CompletionCreateParams::Moderation::Policy::Output?
The moderation policy for the response output.
646 647 648 649 650 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 646 optional :output, -> { OpenAI::Chat::CompletionCreateParams::Moderation::Policy::Output }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/chat/completion_create_params.rb', line 678
|
Instance Method Details
#to_hash ⇒ {
347 |
# File 'sig/openai/models/chat/completion_create_params.rbs', line 347
def to_hash: -> {
|