Class: OpenAI::Models::Chat::CompletionCreateParams::PromptCacheOptions
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Chat::CompletionCreateParams::PromptCacheOptions
- Defined in:
- lib/openai/models/chat/completion_create_params.rb,
sig/openai/models/chat/completion_create_params.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#mode ⇒ OpenAI::Models::Chat::CompletionCreateParams::PromptCacheOptions::mode?
Controls whether OpenAI automatically creates an implicit cache breakpoint.
-
#ttl ⇒ OpenAI::Models::Chat::CompletionCreateParams::PromptCacheOptions::ttl?
The minimum lifetime applied to every implicit and explicit cache breakpoint written by the request.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(mode: nil, ttl: nil) ⇒ Object
|
|
# File 'lib/openai/models/chat/completion_create_params.rb', line 978
|
Instance Attribute Details
#mode ⇒ OpenAI::Models::Chat::CompletionCreateParams::PromptCacheOptions::mode?
Controls whether OpenAI automatically creates an implicit cache breakpoint.
Defaults to implicit. With implicit, OpenAI creates one implicit breakpoint
and writes up to the latest three explicit breakpoints in the request. With
explicit, OpenAI does not create an implicit breakpoint and writes up to the
latest four explicit breakpoints. If there are no explicit breakpoints, the
request does not use prompt caching.
968 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 968 optional :mode, enum: -> { OpenAI::Chat::CompletionCreateParams::PromptCacheOptions::Mode } |
#ttl ⇒ OpenAI::Models::Chat::CompletionCreateParams::PromptCacheOptions::ttl?
The minimum lifetime applied to every implicit and explicit cache breakpoint
written by the request. Defaults to 30m, which is currently the only supported
value. The backend may retain cache entries for longer.
976 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 976 optional :ttl, enum: -> { OpenAI::Chat::CompletionCreateParams::PromptCacheOptions::Ttl } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/chat/completion_create_params.rb', line 1016
|
Instance Method Details
#to_hash ⇒ {
1029 |
# File 'sig/openai/models/chat/completion_create_params.rbs', line 1029
def to_hash: -> {
|