Module: OpenAI::Models::Chat::CompletionCreateParams::PromptCacheOptions::Mode

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/chat/completion_create_params.rb,
sig/openai/models/chat/completion_create_params.rbs

Overview

Controls whether OpenAI automatically creates an implicit cache breakpoint. Defaults to implicit. With implicit, OpenAI creates one implicit breakpoint and writes up to the latest three explicit breakpoints in the request. With explicit, OpenAI does not create an implicit breakpoint and writes up to the latest four explicit breakpoints. If there are no explicit breakpoints, the request does not use prompt caching.

See Also:

  • OpenAI::Models::Chat::CompletionCreateParams::PromptCacheOptions#mode

Constant Summary collapse

IMPLICIT =

Returns:

  • (:implicit)
:implicit
EXPLICIT =

Returns:

  • (:explicit)
:explicit

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[OpenAI::Models::Chat::CompletionCreateParams::PromptCacheOptions::mode]

Returns:

  • (::Array[OpenAI::Models::Chat::CompletionCreateParams::PromptCacheOptions::mode])


447
# File 'sig/openai/models/chat/completion_create_params.rbs', line 447

def self?.values: -> ::Array[OpenAI::Models::Chat::CompletionCreateParams::PromptCacheOptions::mode]