Module: OpenAI::Models::Chat::CompletionCreateParams::Verbosity

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/chat/completion_create_params.rb

Overview

Constrains the verbosity of the model’s response. Lower values will result in more concise responses, while higher values will result in more verbose responses. Currently supported values are low, medium, and high.

Constant Summary collapse

LOW =
:low
MEDIUM =
:medium
HIGH =
:high

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info