Class: OpenAI::Models::Chat::CompletionCreateParams::WebSearchOptions
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Chat::CompletionCreateParams::WebSearchOptions
- Defined in:
- lib/openai/models/chat/completion_create_params.rb,
sig/openai/models/chat/completion_create_params.rbs
Defined Under Namespace
Modules: SearchContextSize Classes: UserLocation
Instance Attribute Summary collapse
-
#search_context_size ⇒ OpenAI::Models::Chat::CompletionCreateParams::WebSearchOptions::search_context_size?
High level guidance for the amount of context window space to use for the search.
-
#user_location ⇒ OpenAI::Chat::CompletionCreateParams::WebSearchOptions::UserLocation?
Approximate location parameters for the search.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(search_context_size: nil, user_location: nil) ⇒ Object
|
|
# File 'lib/openai/models/chat/completion_create_params.rb', line 1192
|
Instance Attribute Details
#search_context_size ⇒ OpenAI::Models::Chat::CompletionCreateParams::WebSearchOptions::search_context_size?
High level guidance for the amount of context window space to use for the
search. One of low, medium, or high. medium is the default.
1177 1178 1179 1180 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 1177 optional( :search_context_size, enum: -> { OpenAI::Chat::CompletionCreateParams::WebSearchOptions::SearchContextSize } ) |
#user_location ⇒ OpenAI::Chat::CompletionCreateParams::WebSearchOptions::UserLocation?
Approximate location parameters for the search.
1186 1187 1188 1189 1190 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 1186 optional( :user_location, -> { OpenAI::Chat::CompletionCreateParams::WebSearchOptions::UserLocation }, nil?: true ) |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/chat/completion_create_params.rb', line 1215
|
Instance Method Details
#to_hash ⇒ {
1146 |
# File 'sig/openai/models/chat/completion_create_params.rbs', line 1146
def to_hash: -> {
|