Class: OpenAI::Models::ComparisonFilter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::ComparisonFilter
- Defined in:
- lib/openai/models/comparison_filter.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#key ⇒ String
The key to compare against the value.
-
#type ⇒ Symbol, OpenAI::Models::ComparisonFilter::Type
Specifies the comparison operator:
eq,ne,gt,gte,lt,lte,in,nin. -
#value ⇒ String, ...
The value to compare against the attribute key; supports string, number, or boolean types.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(key:, type:, value:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ComparisonFilter for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(key:, type:, value:) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::ComparisonFilter for more details.
A filter used to compare a specified attribute key to a given value using a defined comparison operation.
|
|
# File 'lib/openai/models/comparison_filter.rb', line 35
|
Instance Attribute Details
#key ⇒ String
The key to compare against the value.
10 |
# File 'lib/openai/models/comparison_filter.rb', line 10 required :key, String |
#type ⇒ Symbol, OpenAI::Models::ComparisonFilter::Type
Specifies the comparison operator: eq, ne, gt, gte, lt, lte, in, nin.
-
eq: equals -
ne: not equal -
gt: greater than -
gte: greater than or equal -
lt: less than -
lte: less than or equal -
in: in -
nin: not in
26 |
# File 'lib/openai/models/comparison_filter.rb', line 26 required :type, enum: -> { OpenAI::ComparisonFilter::Type } |
#value ⇒ String, ...
The value to compare against the attribute key; supports string, number, or boolean types.
33 |
# File 'lib/openai/models/comparison_filter.rb', line 33 required :value, union: -> { OpenAI::ComparisonFilter::Value } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/comparison_filter.rb', line 71
|