Module: OpenAI::Models::CompletionChoice::FinishReason

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/completion_choice.rb,
sig/openai/models/completion_choice.rbs

Overview

The reason the model stopped generating tokens. This will be stop if the model hit a natural stop point or a provided stop sequence, length if the maximum number of tokens specified in the request was reached, or content_filter if content was omitted due to a flag from our content filters.

See Also:

  • OpenAI::Models::CompletionChoice#finish_reason

Constant Summary collapse

STOP =

Returns:

  • (:stop)
:stop
LENGTH =

Returns:

  • (:length)
:length
CONTENT_FILTER =

Returns:

  • (:content_filter)
:content_filter

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[OpenAI::Models::CompletionChoice::finish_reason]

Returns:

  • (::Array[OpenAI::Models::CompletionChoice::finish_reason])


43
# File 'sig/openai/models/completion_choice.rbs', line 43

def self?.values: -> ::Array[OpenAI::Models::CompletionChoice::finish_reason]