Module: OpenAI::Models::CompletionCreateParams::Model
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/completion_create_params.rb,
sig/openai/models/completion_create_params.rbs
Overview
ID of the model to use. You can use the List models API to see all of your available models, or see our Model overview for descriptions of them.
collapse
- GPT_3_5_TURBO_INSTRUCT =
:"gpt-3.5-turbo-instruct"- DAVINCI_002 =
:"davinci-002"- BABBAGE_002 =
:"babbage-002"
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(String, Symbol)
331 332 333 |
# File 'lib/openai/models/completion_create_params.rb', line 331 define_sorbet_constant!(:Variants) do T.type_alias { T.any(String, OpenAI::CompletionCreateParams::Model::TaggedSymbol) } end |
Instance Method Details
#self?.variants ⇒ ::Array[OpenAI::Models::CompletionCreateParams::model]
311 |
# File 'sig/openai/models/completion_create_params.rbs', line 311
def self?.variants: -> ::Array[OpenAI::Models::CompletionCreateParams::model]
|