Class: OpenAI::Models::ContainerRetrieveResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/container_retrieve_response.rb,
sig/openai/models/container_retrieve_response.rbs

Overview

See Also:

  • OpenAI::Resources::Containers#retrieve

Defined Under Namespace

Modules: MemoryLimit Classes: ExpiresAfter, NetworkPolicy

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, name:, object:, status:, expires_after: nil, last_active_at: nil, memory_limit: nil, network_policy: nil) ⇒ Object

Parameters:

  • id

    Unique identifier for the container.

  • created_at

    Unix timestamp (in seconds) when the container was created.

  • name

    Name of the container.

  • object

    The type of this object.

  • status

    Status of the container (e.g., active, deleted).

  • expires_after (defaults to: nil)

    The container will expire after this time period. The anchor is the reference point for the expiration. The minutes is the number of minutes after the anchor before the container expires.

  • last_active_at (defaults to: nil)

    Unix timestamp (in seconds) when the container was last active.

  • memory_limit (defaults to: nil)

    The memory limit configured for the container.

  • network_policy (defaults to: nil)

    Network access policy for the container.



# File 'lib/openai/models/container_retrieve_response.rb', line 63

Instance Attribute Details

#created_atInteger

Unix timestamp (in seconds) when the container was created.

Returns:

  • (Integer)


17
# File 'lib/openai/models/container_retrieve_response.rb', line 17

required :created_at, Integer

#expires_afterOpenAI::Models::ContainerRetrieveResponse::ExpiresAfter?

The container will expire after this time period. The anchor is the reference point for the expiration. The minutes is the number of minutes after the anchor before the container expires.



43
# File 'lib/openai/models/container_retrieve_response.rb', line 43

optional :expires_after, -> { OpenAI::Models::ContainerRetrieveResponse::ExpiresAfter }

#idString

Unique identifier for the container.

Returns:

  • (String)


11
# File 'lib/openai/models/container_retrieve_response.rb', line 11

required :id, String

#last_active_atInteger?

Unix timestamp (in seconds) when the container was last active.

Returns:

  • (Integer, nil)


49
# File 'lib/openai/models/container_retrieve_response.rb', line 49

optional :last_active_at, Integer

#memory_limitOpenAI::Models::ContainerRetrieveResponse::memory_limit?

The memory limit configured for the container.

Returns:

  • (OpenAI::Models::ContainerRetrieveResponse::memory_limit, nil)


55
# File 'lib/openai/models/container_retrieve_response.rb', line 55

optional :memory_limit, enum: -> { OpenAI::Models::ContainerRetrieveResponse::MemoryLimit }

#nameString

Name of the container.

Returns:

  • (String)


23
# File 'lib/openai/models/container_retrieve_response.rb', line 23

required :name, String

#network_policyOpenAI::Models::ContainerRetrieveResponse::NetworkPolicy?

Network access policy for the container.



61
# File 'lib/openai/models/container_retrieve_response.rb', line 61

optional :network_policy, -> { OpenAI::Models::ContainerRetrieveResponse::NetworkPolicy }

#objectString

The type of this object.

Returns:

  • (String)


29
# File 'lib/openai/models/container_retrieve_response.rb', line 29

required :object, String

#statusString

Status of the container (e.g., active, deleted).

Returns:

  • (String)


35
# File 'lib/openai/models/container_retrieve_response.rb', line 35

required :status, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/container_retrieve_response.rb', line 126

Instance Method Details

#to_hash{

Returns:

  • ({)


98
# File 'sig/openai/models/container_retrieve_response.rbs', line 98

def to_hash: -> {