Class: OpenAI::Models::ContainerRetrieveResponse::ExpiresAfter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/container_retrieve_response.rb

Overview

See Also:

Defined Under Namespace

Modules: Anchor

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(anchor: nil, minutes: nil) ⇒ Object

The container will expire after this time period. The anchor is the reference point for the expiration. The minutes is the number of minutes after the anchor before the container expires.

Parameters:

  • (defaults to: nil)

    The reference point for the expiration.

  • (defaults to: nil)

    The number of minutes after the anchor before the container expires.



# File 'lib/openai/models/container_retrieve_response.rb', line 99


Instance Attribute Details

#anchorSymbol, ...

The reference point for the expiration.

Returns:



91
# File 'lib/openai/models/container_retrieve_response.rb', line 91

optional :anchor, enum: -> { OpenAI::Models::ContainerRetrieveResponse::ExpiresAfter::Anchor }

#minutesInteger?

The number of minutes after the anchor before the container expires.

Returns:



97
# File 'lib/openai/models/container_retrieve_response.rb', line 97

optional :minutes, Integer