Class: OpenAI::Models::ContentProvenanceCheck::Result::SynthID

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/content_provenance_check.rb,
sig/openai/models/content_provenance_check.rbs

Defined Under Namespace

Modules: Outcome

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(generated_at:, model:, outcome:, type: :synthid) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::ContentProvenanceCheck::Result::SynthID for more details.

Parameters:

  • generated_at (String, nil)

    The UTC RFC 3339 timestamp recorded by the provenance signal for when the asset

  • model (String, nil)

    The OpenAI model recorded by the provenance signal, when available.

  • outcome (Symbol, OpenAI::Models::ContentProvenanceCheck::Result::SynthID::Outcome)

    Whether a supported OpenAI SynthID watermark was detected.

  • type (Symbol, :synthid) (defaults to: :synthid)

    The provenance signal type. Always synthid.



# File 'lib/openai/models/content_provenance_check.rb', line 184

Instance Attribute Details

#generated_atString?

The UTC RFC 3339 timestamp recorded by the provenance signal for when the asset was generated, when available.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


158
# File 'lib/openai/models/content_provenance_check.rb', line 158

required :generated_at, String, nil?: true

#modelString?

The OpenAI model recorded by the provenance signal, when available.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


164
# File 'lib/openai/models/content_provenance_check.rb', line 164

required :model, String, nil?: true

#outcomeSymbol, OpenAI::Models::ContentProvenanceCheck::Result::SynthID::Outcome

Whether a supported OpenAI SynthID watermark was detected. If not_detected, it means the tool did not find supported signals in the uploaded file. The content could still have been generated by OpenAI if the metadata was stripped or has evidence of tampering, the watermark was degraded, it comes from a legacy generation model, or it was created before provenance signals were available. Content could also still be AI-generated by another company's model, which the tool currently does not detect.

Parameters:

  • value (OpenAI::Models::ContentProvenanceCheck::Result::SynthID::outcome)

Returns:



176
# File 'lib/openai/models/content_provenance_check.rb', line 176

required :outcome, enum: -> { OpenAI::ContentProvenanceCheck::Result::SynthID::Outcome }

#typeSymbol, :synthid

The provenance signal type. Always synthid.

Parameters:

  • value (:synthid)

Returns:

  • (Symbol, :synthid)


182
# File 'lib/openai/models/content_provenance_check.rb', line 182

required :type, const: :synthid

Instance Method Details

#to_hash{

Returns:

  • ({)


136
# File 'sig/openai/models/content_provenance_check.rbs', line 136

def to_hash: -> {