Class: OpenAI::Models::Conversations::ContainerFileCitationBody

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/conversations/container_file_citation_body.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(container_id: , end_index: , file_id: , filename: , start_index: , type: :container_file_citation) ⇒ Object

Parameters:

  • container_id (String) (defaults to: )

    The ID of the container file.

  • end_index (Integer) (defaults to: )

    The index of the last character of the container file citation in the message.

  • file_id (String) (defaults to: )

    The ID of the file.

  • filename (String) (defaults to: )

    The filename of the container file cited.

  • start_index (Integer) (defaults to: )

    The index of the first character of the container file citation in the message.

  • type (Symbol, :container_file_citation) (defaults to: :container_file_citation)

    The type of the container file citation. Always ‘container_file_citation`.



# File 'lib/openai/models/conversations/container_file_citation_body.rb', line 43

Instance Attribute Details

#container_idString

The ID of the container file.

Returns:

  • (String)


11
# File 'lib/openai/models/conversations/container_file_citation_body.rb', line 11

required :container_id, String

#end_indexInteger

The index of the last character of the container file citation in the message.

Returns:

  • (Integer)


17
# File 'lib/openai/models/conversations/container_file_citation_body.rb', line 17

required :end_index, Integer

#file_idString

The ID of the file.

Returns:

  • (String)


23
# File 'lib/openai/models/conversations/container_file_citation_body.rb', line 23

required :file_id, String

#filenameString

The filename of the container file cited.

Returns:

  • (String)


29
# File 'lib/openai/models/conversations/container_file_citation_body.rb', line 29

required :filename, String

#start_indexInteger

The index of the first character of the container file citation in the message.

Returns:

  • (Integer)


35
# File 'lib/openai/models/conversations/container_file_citation_body.rb', line 35

required :start_index, Integer

#typeSymbol, :container_file_citation

The type of the container file citation. Always ‘container_file_citation`.

Returns:

  • (Symbol, :container_file_citation)


41
# File 'lib/openai/models/conversations/container_file_citation_body.rb', line 41

required :type, const: :container_file_citation