Class: OpenAI::Models::Conversations::ConversationCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/conversations/conversation_create_params.rb,
sig/openai/models/conversations/conversation_create_params.rbs

Overview

See Also:

  • OpenAI::Resources::Conversations#create

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(items: nil, metadata: nil, request_options: {}) ⇒ Object

Parameters:

  • items (defaults to: nil) —

    Initial items to include in the conversation context. You may add up to 20 items at a time.

  • metadata (defaults to: nil) —

    Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

    Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.



# File 'lib/openai/models/conversations/conversation_create_params.rb', line 33

Instance Attribute Details

#items ⇒ ::Array[OpenAI::Models::Responses::response_input_item]?

Initial items to include in the conversation context. You may add up to 20 items at a time.

Returns:

  • (::Array[OpenAI::Models::Responses::response_input_item], nil)


16
17
18
19
20
# File 'lib/openai/models/conversations/conversation_create_params.rb', line 16

optional(
  :items,
  -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Responses::ResponseInputItem] },
  nil?: true
)

#metadata ⇒ OpenAI::Models::metadata?

Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

Returns:

  • (OpenAI::Models::metadata, nil)


31
# File 'lib/openai/models/conversations/conversation_create_params.rb', line 31

optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


43
# File 'sig/openai/models/conversations/conversation_create_params.rbs', line 43

def to_hash: -> {