Class: OpenAI::Models::Conversations::ConversationItem::ImageGenerationCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Conversations::ConversationItem::ImageGenerationCall
- Defined in:
- lib/openai/models/conversations/conversation_item.rb
Defined Under Namespace
Modules: Action, Background, OutputFormat, Quality, Size, Status
Instance Attribute Summary collapse
-
#action ⇒ Symbol, ...
The action used for image generation.
-
#background ⇒ Symbol, ...
The background setting used for generation.
-
#id ⇒ String
The unique ID of the image generation call.
-
#output_format ⇒ Symbol, ...
The output format used for generation.
-
#quality ⇒ Symbol, ...
The quality of the image generated by the image generation tool call.
-
#result ⇒ String?
The generated image encoded in base64.
-
#revised_prompt ⇒ String?
The prompt that was used after any model prompt rewriting.
-
#size ⇒ String, ...
The image dimensions as a
WIDTHxHEIGHTstring, for example1536x864. -
#status ⇒ Symbol, OpenAI::Models::Conversations::ConversationItem::ImageGenerationCall::Status
The status of the image generation call.
-
#type ⇒ Symbol, :image_generation_call
The type of the image generation call.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, result:, status:, action: nil, background: nil, output_format: nil, quality: nil, revised_prompt: nil, size: nil, type: :image_generation_call) ⇒ Object
constructor
An image generation request made by the model.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, result:, status:, action: nil, background: nil, output_format: nil, quality: nil, revised_prompt: nil, size: nil, type: :image_generation_call) ⇒ Object
An image generation request made by the model.
|
|
# File 'lib/openai/models/conversations/conversation_item.rb', line 186
|
Instance Attribute Details
#action ⇒ Symbol, ...
The action used for image generation.
133 134 135 136 137 |
# File 'lib/openai/models/conversations/conversation_item.rb', line 133 optional( :action, enum: -> { OpenAI::Conversations::ConversationItem::ImageGenerationCall::Action }, nil?: true ) |
#background ⇒ Symbol, ...
The background setting used for generation.
143 144 145 146 147 |
# File 'lib/openai/models/conversations/conversation_item.rb', line 143 optional( :background, enum: -> { OpenAI::Conversations::ConversationItem::ImageGenerationCall::Background }, nil?: true ) |
#id ⇒ String
The unique ID of the image generation call.
109 |
# File 'lib/openai/models/conversations/conversation_item.rb', line 109 required :id, String |
#output_format ⇒ Symbol, ...
The output format used for generation.
153 154 155 156 157 |
# File 'lib/openai/models/conversations/conversation_item.rb', line 153 optional( :output_format, enum: -> { OpenAI::Conversations::ConversationItem::ImageGenerationCall::OutputFormat }, nil?: true ) |
#quality ⇒ Symbol, ...
The quality of the image generated by the image generation tool call. One of
low, medium, high, xhigh, max, or auto.
164 165 166 167 168 |
# File 'lib/openai/models/conversations/conversation_item.rb', line 164 optional( :quality, enum: -> { OpenAI::Conversations::ConversationItem::ImageGenerationCall::Quality }, nil?: true ) |
#result ⇒ String?
The generated image encoded in base64.
115 |
# File 'lib/openai/models/conversations/conversation_item.rb', line 115 required :result, String, nil?: true |
#revised_prompt ⇒ String?
The prompt that was used after any model prompt rewriting.
174 |
# File 'lib/openai/models/conversations/conversation_item.rb', line 174 optional :revised_prompt, String, nil?: true |
#size ⇒ String, ...
The image dimensions as a WIDTHxHEIGHT string, for example 1536x864.
180 181 182 183 184 |
# File 'lib/openai/models/conversations/conversation_item.rb', line 180 optional( :size, union: -> { OpenAI::Conversations::ConversationItem::ImageGenerationCall::Size }, nil?: true ) |
#status ⇒ Symbol, OpenAI::Models::Conversations::ConversationItem::ImageGenerationCall::Status
The status of the image generation call.
121 |
# File 'lib/openai/models/conversations/conversation_item.rb', line 121 required :status, enum: -> { OpenAI::Conversations::ConversationItem::ImageGenerationCall::Status } |
#type ⇒ Symbol, :image_generation_call
The type of the image generation call. Always image_generation_call.
127 |
# File 'lib/openai/models/conversations/conversation_item.rb', line 127 required :type, const: :image_generation_call |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/conversations/conversation_item.rb', line 231
|