Class: OpenAI::Models::Conversations::ConversationItem::LocalShellCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/conversations/conversation_item.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, output:, status: nil, type: :local_shell_call_output) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Conversations::ConversationItem::LocalShellCallOutput for more details.

The output of a local shell tool call.

Parameters:

  • The unique ID of the local shell tool call generated by the model.

  • A JSON string of the output of the local shell tool call.

  • (defaults to: nil)

    The status of the item. One of in_progress, completed, or incomplete.

  • (defaults to: :local_shell_call_output)

    The type of the local shell tool call output. Always local_shell_call_output.



# File 'lib/openai/models/conversations/conversation_item.rb', line 291


Instance Attribute Details

#idString

The unique ID of the local shell tool call generated by the model.

Returns:



269
# File 'lib/openai/models/conversations/conversation_item.rb', line 269

required :id, String

#outputString

A JSON string of the output of the local shell tool call.

Returns:



275
# File 'lib/openai/models/conversations/conversation_item.rb', line 275

required :output, String

#statusSymbol, ...

The status of the item. One of in_progress, completed, or incomplete.

Returns:



287
288
289
# File 'lib/openai/models/conversations/conversation_item.rb', line 287

optional :status,
enum: -> { OpenAI::Conversations::ConversationItem::LocalShellCallOutput::Status },
nil?: true

#typeSymbol, :local_shell_call_output

The type of the local shell tool call output. Always local_shell_call_output.

Returns:



281
# File 'lib/openai/models/conversations/conversation_item.rb', line 281

required :type, const: :local_shell_call_output