Class: OpenAI::Models::Conversations::ConversationItem::McpListTools
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Conversations::ConversationItem::McpListTools
- Defined in:
- lib/openai/models/conversations/conversation_item.rb
Defined Under Namespace
Classes: Tool
Instance Attribute Summary collapse
-
#error ⇒ String?
Error message if the server could not list tools.
-
#id ⇒ String
The unique ID of the list.
-
#server_label ⇒ String
The label of the MCP server.
-
#tools ⇒ Array<OpenAI::Models::Conversations::ConversationItem::McpListTools::Tool>
The tools available on the server.
-
#type ⇒ Symbol, :mcp_list_tools
The type of the item.
Attributes inherited from Internal::Type::BaseModel
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#error ⇒ String?
Error message if the server could not list tools.
517 |
# File 'lib/openai/models/conversations/conversation_item.rb', line 517 optional :error, String, nil?: true |
#id ⇒ String
The unique ID of the list.
490 |
# File 'lib/openai/models/conversations/conversation_item.rb', line 490 required :id, String |
#server_label ⇒ String
The label of the MCP server.
496 |
# File 'lib/openai/models/conversations/conversation_item.rb', line 496 required :server_label, String |
#tools ⇒ Array<OpenAI::Models::Conversations::ConversationItem::McpListTools::Tool>
The tools available on the server.
502 503 504 505 |
# File 'lib/openai/models/conversations/conversation_item.rb', line 502 required( :tools, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Conversations::ConversationItem::McpListTools::Tool] } ) |
#type ⇒ Symbol, :mcp_list_tools
The type of the item. Always mcp_list_tools.
511 |
# File 'lib/openai/models/conversations/conversation_item.rb', line 511 required :type, const: :mcp_list_tools |