Class: OpenAI::Models::Conversations::FileCitationBody

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/conversations/file_citation_body.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(file_id: , filename: , index: , type: :file_citation) ⇒ Object

Parameters:

  • file_id (String) (defaults to: )

    The ID of the file.

  • filename (String) (defaults to: )

    The filename of the file cited.

  • index (Integer) (defaults to: )

    The index of the file in the list of files.

  • type (Symbol, :file_citation) (defaults to: :file_citation)

    The type of the file citation. Always ‘file_citation`.



# File 'lib/openai/models/conversations/file_citation_body.rb', line 31

Instance Attribute Details

#file_idString

The ID of the file.

Returns:

  • (String)


11
# File 'lib/openai/models/conversations/file_citation_body.rb', line 11

required :file_id, String

#filenameString

The filename of the file cited.

Returns:

  • (String)


17
# File 'lib/openai/models/conversations/file_citation_body.rb', line 17

required :filename, String

#indexInteger

The index of the file in the list of files.

Returns:

  • (Integer)


23
# File 'lib/openai/models/conversations/file_citation_body.rb', line 23

required :index, Integer

#typeSymbol, :file_citation

The type of the file citation. Always ‘file_citation`.

Returns:

  • (Symbol, :file_citation)


29
# File 'lib/openai/models/conversations/file_citation_body.rb', line 29

required :type, const: :file_citation