Class: OpenAI::Models::Conversations::InputFileContent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/conversations/input_file_content.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(file_id: , file_url: nil, filename: nil, type: :input_file) ⇒ Object

Parameters:

  • file_id (String, nil) (defaults to: )

    The ID of the file to be sent to the model.

  • file_url (String) (defaults to: nil)

    The URL of the file to be sent to the model.

  • filename (String) (defaults to: nil)

    The name of the file to be sent to the model.

  • type (Symbol, :input_file) (defaults to: :input_file)

    The type of the input item. Always ‘input_file`.



# File 'lib/openai/models/conversations/input_file_content.rb', line 31

Instance Attribute Details

#file_idString?

The ID of the file to be sent to the model.

Returns:

  • (String, nil)


11
# File 'lib/openai/models/conversations/input_file_content.rb', line 11

required :file_id, String, nil?: true

#file_urlString?

The URL of the file to be sent to the model.

Returns:

  • (String, nil)


23
# File 'lib/openai/models/conversations/input_file_content.rb', line 23

optional :file_url, String

#filenameString?

The name of the file to be sent to the model.

Returns:

  • (String, nil)


29
# File 'lib/openai/models/conversations/input_file_content.rb', line 29

optional :filename, String

#typeSymbol, :input_file

The type of the input item. Always ‘input_file`.

Returns:

  • (Symbol, :input_file)


17
# File 'lib/openai/models/conversations/input_file_content.rb', line 17

required :type, const: :input_file