Class: OpenAI::Models::Conversations::InputImageContent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Conversations::InputImageContent
- Defined in:
- lib/openai/models/conversations/input_image_content.rb
Defined Under Namespace
Modules: Detail
Instance Attribute Summary collapse
-
#detail ⇒ Symbol, OpenAI::Models::Conversations::InputImageContent::Detail
The detail level of the image to be sent to the model.
-
#file_id ⇒ String?
The ID of the file to be sent to the model.
-
#image_url ⇒ String?
The URL of the image to be sent to the model.
-
#type ⇒ Symbol, :input_image
The type of the input item.
Instance Method Summary collapse
-
#initialize(detail: , file_id: , image_url: , type: :input_image) ⇒ Object
constructor
Some parameter documentations has been truncated, see InputImageContent for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(detail: , file_id: , image_url: , type: :input_image) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Conversations::InputImageContent for more details.
|
|
# File 'lib/openai/models/conversations/input_image_content.rb', line 33
|
Instance Attribute Details
#detail ⇒ Symbol, OpenAI::Models::Conversations::InputImageContent::Detail
The detail level of the image to be sent to the model. One of ‘high`, `low`, or `auto`. Defaults to `auto`.
12 |
# File 'lib/openai/models/conversations/input_image_content.rb', line 12 required :detail, enum: -> { OpenAI::Conversations::InputImageContent::Detail } |
#file_id ⇒ String?
The ID of the file to be sent to the model.
18 |
# File 'lib/openai/models/conversations/input_image_content.rb', line 18 required :file_id, String, nil?: true |
#image_url ⇒ String?
The URL of the image to be sent to the model. A fully qualified URL or base64 encoded image in a data URL.
25 |
# File 'lib/openai/models/conversations/input_image_content.rb', line 25 required :image_url, String, nil?: true |
#type ⇒ Symbol, :input_image
The type of the input item. Always ‘input_image`.
31 |
# File 'lib/openai/models/conversations/input_image_content.rb', line 31 required :type, const: :input_image |