Class: OpenAI::Models::Conversations::SummaryTextContent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/conversations/summary_text_content.rb,
sig/openai/models/conversations/summary_text_content.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(text:, type: :summary_text) ⇒ SummaryTextContent

Returns a new instance of SummaryTextContent.

Parameters:

  • text —

    A summary of the reasoning output from the model so far.

  • type (defaults to: :summary_text) —

    The type of the object. Always summary_text.

  • text: (String)
  • type: (:summary_text) (defaults to: :summary_text)


# File 'lib/openai/models/conversations/summary_text_content.rb', line 19

Instance Attribute Details

#text ⇒ String

A summary of the reasoning output from the model so far.

Returns:

  • (String)


11
# File 'lib/openai/models/conversations/summary_text_content.rb', line 11

required :text, String

#type ⇒ :summary_text

The type of the object. Always summary_text.

Returns:

  • (:summary_text)


17
# File 'lib/openai/models/conversations/summary_text_content.rb', line 17

required :type, const: :summary_text

Instance Method Details

#to_hash ⇒ { text: String, ?type: :summary_text }

Returns:

  • ({ text: String, ?type: :summary_text })


19
# File 'sig/openai/models/conversations/summary_text_content.rbs', line 19

def to_hash: -> { text: String, ?type: :summary_text }