Class: OpenAI::Models::Conversations::URLCitationBody

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/conversations/url_citation_body.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(end_index: , start_index: , title: , url: , type: :url_citation) ⇒ Object

Parameters:

  • end_index (Integer) (defaults to: )

    The index of the last character of the URL citation in the message.

  • start_index (Integer) (defaults to: )

    The index of the first character of the URL citation in the message.

  • title (String) (defaults to: )

    The title of the web resource.

  • url (String) (defaults to: )

    The URL of the web resource.

  • type (Symbol, :url_citation) (defaults to: :url_citation)

    The type of the URL citation. Always ‘url_citation`.



# File 'lib/openai/models/conversations/url_citation_body.rb', line 37

Instance Attribute Details

#end_indexInteger

The index of the last character of the URL citation in the message.

Returns:

  • (Integer)


11
# File 'lib/openai/models/conversations/url_citation_body.rb', line 11

required :end_index, Integer

#start_indexInteger

The index of the first character of the URL citation in the message.

Returns:

  • (Integer)


17
# File 'lib/openai/models/conversations/url_citation_body.rb', line 17

required :start_index, Integer

#titleString

The title of the web resource.

Returns:

  • (String)


23
# File 'lib/openai/models/conversations/url_citation_body.rb', line 23

required :title, String

#typeSymbol, :url_citation

The type of the URL citation. Always ‘url_citation`.

Returns:

  • (Symbol, :url_citation)


29
# File 'lib/openai/models/conversations/url_citation_body.rb', line 29

required :type, const: :url_citation

#urlString

The URL of the web resource.

Returns:

  • (String)


35
# File 'lib/openai/models/conversations/url_citation_body.rb', line 35

required :url, String