Class: OpenAI::Models::EvalCreateParams::DataSourceConfig::Custom

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/eval_create_params.rb,
sig/openai/models/eval_create_params.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Parameters:

  • item_schema

    The json schema for each row in the data source.

  • include_sample_schema

    Whether the eval should expect you to populate the sample namespace (ie, by generating responses off of your data source)

  • type

    The type of data source. Always custom.



110
# File 'sig/openai/models/eval_create_params.rbs', line 110

def initialize: (

Instance Attribute Details

#include_sample_schemaBoolean?

Whether the eval should expect you to populate the sample namespace (ie, by generating responses off of your data source)

Returns:



108
# File 'lib/openai/models/eval_create_params.rb', line 108

optional :include_sample_schema, OpenAI::Internal::Type::Boolean

#item_schema::Hash[Symbol, top]

The json schema for each row in the data source.

Returns:

  • (::Hash[Symbol, top])


95
# File 'lib/openai/models/eval_create_params.rb', line 95

required :item_schema, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Unknown]

#type:custom

The type of data source. Always custom.

Returns:

  • (:custom)


101
# File 'lib/openai/models/eval_create_params.rb', line 101

required :type, const: :custom

Instance Method Details

#to_hash{

Returns:

  • ({)


116
# File 'sig/openai/models/eval_create_params.rbs', line 116

def to_hash: -> {