Class: OpenAI::Models::EvalCreateParams::TestingCriterion::LabelModel::Input::EvalItem::Content::InputImage

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/eval_create_params.rb,
sig/openai/models/eval_create_params.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Parameters:

  • image_url

    The URL of the image input.

  • detail

    The detail level of the image to be sent to the model. One of high, low, or auto. Defaults to auto.

  • type

    The type of the image input. Always input_image.



369
# File 'sig/openai/models/eval_create_params.rbs', line 369

def initialize: (

Instance Attribute Details

#detailString?

The detail level of the image to be sent to the model. One of high, low, or auto. Defaults to auto.

Returns:

  • (String, nil)


424
# File 'lib/openai/models/eval_create_params.rb', line 424

optional :detail, String

#image_urlString

The URL of the image input.

Returns:

  • (String)


411
# File 'lib/openai/models/eval_create_params.rb', line 411

required :image_url, String

#type:input_image

The type of the image input. Always input_image.

Returns:

  • (:input_image)


417
# File 'lib/openai/models/eval_create_params.rb', line 417

required :type, const: :input_image

Instance Method Details

#to_hash{

Returns:

  • ({)


375
# File 'sig/openai/models/eval_create_params.rbs', line 375

def to_hash: -> {