Class: OpenAI::Models::EvalCreateResponse::DataSourceConfig::Logs

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/eval_create_response.rb,
sig/openai/models/eval_create_response.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Parameters:

  • schema

    The json schema for the run data source items. Learn how to build JSON schemas here.

  • metadata

    Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

    Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

  • type

    The type of data source. Always logs.



123
# File 'sig/openai/models/eval_create_response.rbs', line 123

def initialize: (

Instance Attribute Details

#metadataOpenAI::Models::metadata?

Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

Returns:

  • (OpenAI::Models::metadata, nil)


137
# File 'lib/openai/models/eval_create_response.rb', line 137

optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true

#schema::Hash[Symbol, top]

The json schema for the run data source items. Learn how to build JSON schemas here.

Returns:

  • (::Hash[Symbol, top])


120
# File 'lib/openai/models/eval_create_response.rb', line 120

required :schema, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Unknown]

#type:logs

The type of data source. Always logs.

Returns:

  • (:logs)


126
# File 'lib/openai/models/eval_create_response.rb', line 126

required :type, const: :logs

Instance Method Details

#to_hash{

Returns:

  • ({)


129
# File 'sig/openai/models/eval_create_response.rbs', line 129

def to_hash: -> {