Module: OpenAI::Models::EvalRetrieveResponse::TestingCriterion

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/eval_retrieve_response.rb,
sig/openai/models/eval_retrieve_response.rbs

Overview

A LabelModelGrader object which uses a model to assign labels to each item in the evaluation.

Defined Under Namespace

Classes: EvalGraderPython, EvalGraderScoreModel, EvalGraderTextSimilarity

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(name:, source:, image_tag: nil, pass_threshold: nil, type: :python) ⇒ Object

A PythonGrader object that runs a python script on the input.

Parameters:

  • name (String)

    The name of the grader.

  • source (String)

    The source code of the python script.

  • image_tag (String) (defaults to: nil)

    The image tag to use for the python script.

  • pass_threshold (Float) (defaults to: nil)

    The threshold for the score.

  • type (Symbol, :python) (defaults to: :python)

    The object type, which is always python.



# File 'lib/openai/models/eval_retrieve_response.rb', line 179

#self?.variants::Array[OpenAI::Models::EvalRetrieveResponse::testing_criterion]

Returns:

  • (::Array[OpenAI::Models::EvalRetrieveResponse::testing_criterion])


199
# File 'sig/openai/models/eval_retrieve_response.rbs', line 199

def self?.variants: -> ::Array[OpenAI::Models::EvalRetrieveResponse::testing_criterion]