Class: OpenAI::Models::Evals::CreateEvalJSONLRunDataSource

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/evals/create_eval_jsonl_run_data_source.rb,
sig/openai/models/evals/create_eval_jsonl_run_data_source.rbs

Defined Under Namespace

Modules: Source

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(source:, type: :jsonl) ⇒ Object

Parameters:

  • source —

    Determines what populates the item namespace in the data source.

  • type (defaults to: :jsonl) —

    The type of data source. Always jsonl.



# File 'lib/openai/models/evals/create_eval_jsonl_run_data_source.rb', line 19

Instance Attribute Details

#source ⇒ OpenAI::Models::Evals::CreateEvalJSONLRunDataSource::source

Determines what populates the item namespace in the data source.

Returns:

  • (OpenAI::Models::Evals::CreateEvalJSONLRunDataSource::source)


11
# File 'lib/openai/models/evals/create_eval_jsonl_run_data_source.rb', line 11

required :source, union: -> { OpenAI::Evals::CreateEvalJSONLRunDataSource::Source }

#type ⇒ :jsonl

The type of data source. Always jsonl.

Returns:

  • (:jsonl)


17
# File 'lib/openai/models/evals/create_eval_jsonl_run_data_source.rb', line 17

required :type, const: :jsonl

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


26
# File 'sig/openai/models/evals/create_eval_jsonl_run_data_source.rbs', line 26

def to_hash: -> {