Module: OpenAI::Models::Evals::RunCancelResponse::DataSource::Responses::InputMessages

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/evals/run_cancel_response.rb,
sig/openai/models/evals/run_cancel_response.rbs

Overview

Used when sampling from a model. Dictates the structure of the messages passed into the model. Can either be a reference to a prebuilt trajectory (ie, item.input_trajectory), or a template with variable references to the item namespace.

See Also:

  • OpenAI::Models::Evals::RunCancelResponse::DataSource::Responses#input_messages

Defined Under Namespace

Classes: ItemReference, Template

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.variants::Array[OpenAI::Models::Evals::RunCancelResponse::DataSource::Responses::input_messages]

Returns:

  • (::Array[OpenAI::Models::Evals::RunCancelResponse::DataSource::Responses::input_messages])


454
# File 'sig/openai/models/evals/run_cancel_response.rbs', line 454

def self?.variants: -> ::Array[OpenAI::Models::Evals::RunCancelResponse::DataSource::Responses::input_messages]