Class: OpenAI::Models::Evals::RunCancelResponse::DataSource::Responses::InputMessages::ItemReference

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/evals/run_cancel_response.rb,
sig/openai/models/evals/run_cancel_response.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Parameters:

  • item_reference

    A reference to a variable in the item namespace. Ie, "item.name"

  • type

    The type of input messages. Always item_reference.



636
# File 'sig/openai/models/evals/run_cancel_response.rbs', line 636

def initialize: (

Instance Attribute Details

#item_referenceString

A reference to a variable in the item namespace. Ie, "item.name"

Returns:

  • (String)


726
# File 'lib/openai/models/evals/run_cancel_response.rb', line 726

required :item_reference, String

#type:item_reference

The type of input messages. Always item_reference.

Returns:

  • (:item_reference)


732
# File 'lib/openai/models/evals/run_cancel_response.rb', line 732

required :type, const: :item_reference

Instance Method Details

#to_hash{

Returns:

  • ({)


641
# File 'sig/openai/models/evals/run_cancel_response.rbs', line 641

def to_hash: -> {