Class: OpenAI::Models::Evals::RunCancelResponse::DataSource::Responses::InputMessages::Template::Template::EvalItem::Content::InputImage

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/evals/run_cancel_response.rb,
sig/openai/models/evals/run_cancel_response.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • image_url —

    The URL of the image input.

  • detail —

    The detail level of the image to be sent to the model. One of high, low, or auto. Defaults to auto.

  • type —

    The type of the image input. Always input_image.



578
# File 'sig/openai/models/evals/run_cancel_response.rbs', line 578

def initialize: (

Instance Attribute Details

#detail ⇒ String?

The detail level of the image to be sent to the model. One of high, low, or auto. Defaults to auto.

Returns:

  • (String, nil)


667
# File 'lib/openai/models/evals/run_cancel_response.rb', line 667

optional :detail, String

#image_url ⇒ String

The URL of the image input.

Returns:

  • (String)


654
# File 'lib/openai/models/evals/run_cancel_response.rb', line 654

required :image_url, String

#type ⇒ :input_image

The type of the image input. Always input_image.

Returns:

  • (:input_image)


660
# File 'lib/openai/models/evals/run_cancel_response.rb', line 660

required :type, const: :input_image

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


584
# File 'sig/openai/models/evals/run_cancel_response.rbs', line 584

def to_hash: -> {