Class: OpenAI::Models::Evals::RunCancelResponse::ResultCounts
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Evals::RunCancelResponse::ResultCounts
- Defined in:
- lib/openai/models/evals/run_cancel_response.rb,
sig/openai/models/evals/run_cancel_response.rbs
Overview
Instance Attribute Summary collapse
-
#errored ⇒ Integer
Number of output items that resulted in an error.
-
#failed ⇒ Integer
Number of output items that failed to pass the evaluation.
-
#passed ⇒ Integer
Number of output items that passed the evaluation.
-
#total ⇒ Integer
Total number of executed output items.
Instance Method Summary collapse
-
#initialize(errored:, failed:, passed:, total:) ⇒ Object
constructor
Counters summarizing the outcomes of the evaluation run.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(errored:, failed:, passed:, total:) ⇒ Object
Counters summarizing the outcomes of the evaluation run.
|
|
# File 'lib/openai/models/evals/run_cancel_response.rb', line 883
|
Instance Attribute Details
#errored ⇒ Integer
Number of output items that resulted in an error.
863 |
# File 'lib/openai/models/evals/run_cancel_response.rb', line 863 required :errored, Integer |
#failed ⇒ Integer
Number of output items that failed to pass the evaluation.
869 |
# File 'lib/openai/models/evals/run_cancel_response.rb', line 869 required :failed, Integer |
#passed ⇒ Integer
Number of output items that passed the evaluation.
875 |
# File 'lib/openai/models/evals/run_cancel_response.rb', line 875 required :passed, Integer |
#total ⇒ Integer
Total number of executed output items.
881 |
# File 'lib/openai/models/evals/run_cancel_response.rb', line 881 required :total, Integer |
Instance Method Details
#to_hash ⇒ {
629 |
# File 'sig/openai/models/evals/run_cancel_response.rbs', line 629
def to_hash: -> {
|