Class: OpenAI::Models::Evals::RunCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/evals/run_create_params.rb,
sig/openai/models/evals/run_create_params.rbs

Overview

See Also:

  • OpenAI::Resources::Evals::Runs#create

Defined Under Namespace

Modules: DataSource

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(eval_id:, data_source:, metadata: nil, name: nil, request_options: {}) ⇒ Object

Parameters:

  • data_source

    Details about the run's data source.

  • metadata (defaults to: nil)

    Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

    Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

  • name (defaults to: nil)

    The name of the run.



# File 'lib/openai/models/evals/run_create_params.rb', line 39

Instance Attribute Details

#data_sourceOpenAI::Models::Evals::RunCreateParams::data_source

Details about the run's data source.

Returns:

  • (OpenAI::Models::Evals::RunCreateParams::data_source)


20
# File 'lib/openai/models/evals/run_create_params.rb', line 20

required :data_source, union: -> { OpenAI::Evals::RunCreateParams::DataSource }

#eval_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/openai/models/evals/run_create_params.rb', line 14

required :eval_id, String

#metadataOpenAI::Models::metadata?

Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

Returns:

  • (OpenAI::Models::metadata, nil)


31
# File 'lib/openai/models/evals/run_create_params.rb', line 31

optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true

#nameString?

The name of the run.

Returns:

  • (String, nil)


37
# File 'lib/openai/models/evals/run_create_params.rb', line 37

optional :name, String

Instance Method Details

#to_hash{

Returns:

  • ({)


55
# File 'sig/openai/models/evals/run_create_params.rbs', line 55

def to_hash: -> {