Class: OpenAI::Models::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::InputMessages::Template

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/evals/run_create_params.rb,
sig/openai/models/evals/run_create_params.rbs

Defined Under Namespace

Modules: Template

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(template:, type: :template) ⇒ Object

Parameters:

  • template —

    A list of chat messages forming the prompt or context. May include variable references to the item namespace, ie OpenAI::Models::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::InputMessages::Template.{item{item.name}.

  • type (defaults to: :template) —

    The type of input messages. Always template.



# File 'lib/openai/models/evals/run_create_params.rb', line 412

Instance Attribute Details

#template ⇒ ::Array[OpenAI::Models::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::InputMessages::Template::template]

A list of chat messages forming the prompt or context. May include variable references to the item namespace, ie OpenAI::Models::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::InputMessages::Template.{item{item.name}.

Returns:

  • (::Array[OpenAI::Models::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::InputMessages::Template::template])


397
398
399
400
401
402
403
404
# File 'lib/openai/models/evals/run_create_params.rb', line 397

required(
  :template,
  -> do
    OpenAI::Internal::Type::ArrayOf[
      union: OpenAI::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::InputMessages::Template::Template
    ]
  end
)

#type ⇒ :template

The type of input messages. Always template.

Returns:

  • (:template)


410
# File 'lib/openai/models/evals/run_create_params.rb', line 410

required :type, const: :template

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


379
# File 'sig/openai/models/evals/run_create_params.rbs', line 379

def to_hash: -> {