Class: OpenAI::Models::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::SamplingParams::Text
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::SamplingParams::Text
- Defined in:
- lib/openai/models/evals/run_create_params.rb,
sig/openai/models/evals/run_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#format_ ⇒ OpenAI::Models::ResponseFormatText, ...
An object specifying the format that the model must output.
Instance Method Summary collapse
-
#initialize(format_: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Text for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(format_: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::SamplingParams::Text for more details.
Configuration options for a text response from the model. Can be plain text or structured JSON data. Learn more:
|
|
# File 'lib/openai/models/evals/run_create_params.rb', line 694
|
Instance Attribute Details
#format_ ⇒ OpenAI::Models::ResponseFormatText, ...
An object specifying the format that the model must output.
Configuring { "type": "json_schema" } enables Structured Outputs, which
ensures the model will match your supplied JSON schema. Learn more in the
Structured Outputs guide.
The default format is { "type": "text" } with no additional options.
Not recommended for gpt-4o and newer models:
Setting to { "type": "json_object" } enables the older JSON mode, which
ensures the message the model generates is valid JSON. Using json_schema is
preferred for models that support it.
688 689 690 691 692 |
# File 'lib/openai/models/evals/run_create_params.rb', line 688 optional :format_, union: -> { OpenAI::Responses::ResponseFormatTextConfig }, api_name: :format |
Instance Method Details
#to_hash ⇒ {
503 |
# File 'sig/openai/models/evals/run_create_params.rbs', line 503
def to_hash: -> {
|