Class: OpenAI::Models::Evals::RunCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/evals/run_create_response.rb,
sig/openai/models/evals/run_create_response.rbs

Overview

See Also:

  • OpenAI::Resources::Evals::Runs#create

Defined Under Namespace

Modules: DataSource Classes: PerModelUsage, PerTestingCriteriaResult, ResultCounts

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(failed:, passed:, testing_criteria:) ⇒ Object

Parameters:

  • id —

    Unique identifier for the evaluation run.

  • created_at —

    Unix timestamp (in seconds) when the evaluation run was created.

  • data_source —

    Information about the run's data source.

  • error —

    An object representing an error response from the Eval API.

  • eval_id —

    The identifier of the associated evaluation.

  • metadata —

    Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

    Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

  • model —

    The model that is evaluated, if applicable.

  • name —

    The name of the evaluation run.

  • per_model_usage —

    Usage statistics for each model during the evaluation run.

  • per_testing_criteria_results —

    Results per testing criteria applied during the evaluation run.

  • report_url —

    The URL to the rendered evaluation run report on the UI dashboard.

  • result_counts —

    Counters summarizing the outcomes of the evaluation run.

  • status —

    The status of the evaluation run.

  • object —

    The type of the object. Always "eval.run".



# File 'lib/openai/models/evals/run_create_response.rb', line 103

Instance Attribute Details

#created_at ⇒ Integer

Unix timestamp (in seconds) when the evaluation run was created.

Returns:

  • (Integer)


18
# File 'lib/openai/models/evals/run_create_response.rb', line 18

required :created_at, Integer

#data_source ⇒ OpenAI::Models::Evals::RunCreateResponse::data_source

Information about the run's data source.

Returns:

  • (OpenAI::Models::Evals::RunCreateResponse::data_source)


24
# File 'lib/openai/models/evals/run_create_response.rb', line 24

required :data_source, union: -> { OpenAI::Models::Evals::RunCreateResponse::DataSource }

#error ⇒ OpenAI::Evals::EvalAPIError

An object representing an error response from the Eval API.

Returns:

  • (OpenAI::Evals::EvalAPIError)


30
# File 'lib/openai/models/evals/run_create_response.rb', line 30

required :error, -> { OpenAI::Evals::EvalAPIError }

#eval_id ⇒ String

The identifier of the associated evaluation.

Returns:

  • (String)


36
# File 'lib/openai/models/evals/run_create_response.rb', line 36

required :eval_id, String

#id ⇒ String

Unique identifier for the evaluation run.

Returns:

  • (String)


12
# File 'lib/openai/models/evals/run_create_response.rb', line 12

required :id, String

#metadata ⇒ OpenAI::Models::metadata?

Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

Returns:

  • (OpenAI::Models::metadata, nil)


47
# File 'lib/openai/models/evals/run_create_response.rb', line 47

required :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true

#model ⇒ String

The model that is evaluated, if applicable.

Returns:

  • (String)


53
# File 'lib/openai/models/evals/run_create_response.rb', line 53

required :model, String

#name ⇒ String

The name of the evaluation run.

Returns:

  • (String)


59
# File 'lib/openai/models/evals/run_create_response.rb', line 59

required :name, String

#object ⇒ :"eval.run"

The type of the object. Always "eval.run".

Returns:

  • (:"eval.run")


65
# File 'lib/openai/models/evals/run_create_response.rb', line 65

required :object, const: :"eval.run"

#per_model_usage ⇒ ::Array[OpenAI::Models::Evals::RunCreateResponse::PerModelUsage]

Usage statistics for each model during the evaluation run.



71
72
73
74
# File 'lib/openai/models/evals/run_create_response.rb', line 71

required(
  :per_model_usage,
  -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Models::Evals::RunCreateResponse::PerModelUsage] }
)

#per_testing_criteria_results ⇒ ::Array[OpenAI::Models::Evals::RunCreateResponse::PerTestingCriteriaResult]

Results per testing criteria applied during the evaluation run.



80
81
82
83
# File 'lib/openai/models/evals/run_create_response.rb', line 80

required(
  :per_testing_criteria_results,
  -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Models::Evals::RunCreateResponse::PerTestingCriteriaResult] }
)

#report_url ⇒ String

The URL to the rendered evaluation run report on the UI dashboard.

Returns:

  • (String)


89
# File 'lib/openai/models/evals/run_create_response.rb', line 89

required :report_url, String

#result_counts ⇒ OpenAI::Models::Evals::RunCreateResponse::ResultCounts

Counters summarizing the outcomes of the evaluation run.



95
# File 'lib/openai/models/evals/run_create_response.rb', line 95

required :result_counts, -> { OpenAI::Models::Evals::RunCreateResponse::ResultCounts }

#status ⇒ String

The status of the evaluation run.

Returns:

  • (String)


101
# File 'lib/openai/models/evals/run_create_response.rb', line 101

required :status, String

Class Method Details

.variants ⇒ Array(OpenAI::Models::Evals::CreateEvalJSONLRunDataSource, OpenAI::Models::Evals::CreateEvalCompletionsRunDataSource, OpenAI::Models::Evals::RunCreateResponse::DataSource::Responses)



# File 'lib/openai/models/evals/run_create_response.rb', line 912

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


120
# File 'sig/openai/models/evals/run_create_response.rbs', line 120

def to_hash: -> {