Class: OpenAI::Models::Evals::RunCreateResponse::DataSource::Responses::InputMessages::Template

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/evals/run_create_response.rb,
sig/openai/models/evals/run_create_response.rbs

Defined Under Namespace

Modules: Template

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(template:, type: :template) ⇒ Object

Parameters:

  • template

    A list of chat messages forming the prompt or context. May include variable references to the item namespace, ie OpenAI::Models::Evals::RunCreateResponse::DataSource::Responses::InputMessages::Template.{item{item.name}.

  • type (defaults to: :template)

    The type of input messages. Always template.



# File 'lib/openai/models/evals/run_create_response.rb', line 484

Instance Attribute Details

#template::Array[OpenAI::Models::Evals::RunCreateResponse::DataSource::Responses::InputMessages::Template::template]

A list of chat messages forming the prompt or context. May include variable references to the item namespace, ie OpenAI::Models::Evals::RunCreateResponse::DataSource::Responses::InputMessages::Template.{item{item.name}.

Returns:

  • (::Array[OpenAI::Models::Evals::RunCreateResponse::DataSource::Responses::InputMessages::Template::template])


469
470
471
472
473
474
475
476
# File 'lib/openai/models/evals/run_create_response.rb', line 469

required(
  :template,
  -> {
    OpenAI::Internal::Type::ArrayOf[
      union: OpenAI::Models::Evals::RunCreateResponse::DataSource::Responses::InputMessages::Template::Template
    ]
  }
)

#type:template

The type of input messages. Always template.

Returns:

  • (:template)


482
# File 'lib/openai/models/evals/run_create_response.rb', line 482

required :type, const: :template

Instance Method Details

#to_hash{

Returns:

  • ({)


443
# File 'sig/openai/models/evals/run_create_response.rbs', line 443

def to_hash: -> {