Module: OpenAI::Models::Evals::RunCreateResponse::DataSource::Responses::InputMessages::Template::Template
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/evals/run_create_response.rb
Overview
A message input to the model with a role indicating instruction following hierarchy. Instructions given with the developer or system role take precedence over instructions given with the user role. Messages with the assistant role are presumed to have been generated by the model in previous interactions.
Defined Under Namespace
Classes: ChatMessage, EvalItem
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(content:, role:) ⇒ Object
|
|
# File 'lib/openai/models/evals/run_create_response.rb', line 463
|