Class: OpenAI::Models::Evals::RunListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/evals/run_list_params.rb

Overview

Defined Under Namespace

Modules: Order, Status

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(eval_id:, after: nil, limit: nil, order: nil, status: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Evals::RunListParams for more details.



# File 'lib/openai/models/evals/run_list_params.rb', line 42


Instance Attribute Details

#afterString?

Identifier for the last run from the previous pagination request.



20
# File 'lib/openai/models/evals/run_list_params.rb', line 20

optional :after, String

#eval_idString



14
# File 'lib/openai/models/evals/run_list_params.rb', line 14

required :eval_id, String

#limitInteger?

Number of runs to retrieve.



26
# File 'lib/openai/models/evals/run_list_params.rb', line 26

optional :limit, Integer

#orderSymbol, ...

Sort order for runs by timestamp. Use asc for ascending order or desc for descending order. Defaults to asc.



33
# File 'lib/openai/models/evals/run_list_params.rb', line 33

optional :order, enum: -> { OpenAI::Evals::RunListParams::Order }

#statusSymbol, ...

Filter runs by status. One of queued | in_progress | failed | completed | canceled.



40
# File 'lib/openai/models/evals/run_list_params.rb', line 40

optional :status, enum: -> { OpenAI::Evals::RunListParams::Status }

Class Method Details

.valuesArray<Symbol>



# File 'lib/openai/models/evals/run_list_params.rb', line 66