Class: OpenAI::Models::Evals::Runs::OutputItemRetrieveResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/evals/runs/output_item_retrieve_response.rb,
sig/openai/models/evals/runs/output_item_retrieve_response.rbs

Overview

See Also:

  • OpenAI::Resources::Evals::Runs::OutputItems#retrieve

Defined Under Namespace

Classes: Result, Sample

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, passed:, score:, sample: nil, type: nil) ⇒ Object

Parameters:

  • id —

    Unique identifier for the evaluation run output item.

  • created_at —

    Unix timestamp (in seconds) when the evaluation run was created.

  • datasource_item —

    Details of the input data source item.

  • datasource_item_id —

    The identifier for the data source item.

  • eval_id —

    The identifier of the evaluation group.

  • results —

    A list of grader results for this output item.

  • run_id —

    The identifier of the evaluation run associated with this output item.

  • sample (defaults to: nil) —

    A sample containing the input and output of the evaluation run.

  • status —

    The status of the evaluation run.

  • object —

    The type of the object. Always "eval.run.output_item".



# File 'lib/openai/models/evals/runs/output_item_retrieve_response.rb', line 135

Instance Attribute Details

#created_at ⇒ Integer

Unix timestamp (in seconds) when the evaluation run was created.

Returns:

  • (Integer)


19
# File 'lib/openai/models/evals/runs/output_item_retrieve_response.rb', line 19

required :created_at, Integer

#datasource_item ⇒ ::Hash[Symbol, top]

Details of the input data source item.

Returns:

  • (::Hash[Symbol, top])


25
# File 'lib/openai/models/evals/runs/output_item_retrieve_response.rb', line 25

required :datasource_item, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Unknown]

#datasource_item_id ⇒ Integer

The identifier for the data source item.

Returns:

  • (Integer)


31
# File 'lib/openai/models/evals/runs/output_item_retrieve_response.rb', line 31

required :datasource_item_id, Integer

#eval_id ⇒ String

The identifier of the evaluation group.

Returns:

  • (String)


37
# File 'lib/openai/models/evals/runs/output_item_retrieve_response.rb', line 37

required :eval_id, String

#id ⇒ String

Unique identifier for the evaluation run output item.

Returns:

  • (String)


13
# File 'lib/openai/models/evals/runs/output_item_retrieve_response.rb', line 13

required :id, String

#object ⇒ :"eval.run.output_item"

The type of the object. Always "eval.run.output_item".

Returns:

  • (:"eval.run.output_item")


43
# File 'lib/openai/models/evals/runs/output_item_retrieve_response.rb', line 43

required :object, const: :"eval.run.output_item"

#results ⇒ ::Array[OpenAI::Models::Evals::Runs::OutputItemRetrieveResponse::Result]

A list of grader results for this output item.



49
50
51
52
# File 'lib/openai/models/evals/runs/output_item_retrieve_response.rb', line 49

required(
  :results,
  -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Models::Evals::Runs::OutputItemRetrieveResponse::Result] }
)

#run_id ⇒ String

The identifier of the evaluation run associated with this output item.

Returns:

  • (String)


58
# File 'lib/openai/models/evals/runs/output_item_retrieve_response.rb', line 58

required :run_id, String

#sample ⇒ OpenAI::Models::Evals::Runs::OutputItemRetrieveResponse::Sample

A sample containing the input and output of the evaluation run.



64
# File 'lib/openai/models/evals/runs/output_item_retrieve_response.rb', line 64

required :sample, -> { OpenAI::Models::Evals::Runs::OutputItemRetrieveResponse::Sample }

#status ⇒ String

The status of the evaluation run.

Returns:

  • (String)


70
# File 'lib/openai/models/evals/runs/output_item_retrieve_response.rb', line 70

required :status, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


83
# File 'sig/openai/models/evals/runs/output_item_retrieve_response.rbs', line 83

def to_hash: -> {