Class: OpenAI::Models::FineTuning::FineTuningJob::Error

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/fine_tuning/fine_tuning_job.rb,
sig/openai/models/fine_tuning/fine_tuning_job.rbs

Overview

See Also:

  • OpenAI::Models::FineTuning::FineTuningJob#error

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • code —

    A machine-readable error code.

  • message —

    A human-readable error message.

  • param —

    The parameter that was invalid, usually training_file or validation_file. This field will be null if the failure was not parameter-specific.



228
# File 'sig/openai/models/fine_tuning/fine_tuning_job.rbs', line 228

def initialize: (

Instance Attribute Details

#code ⇒ String

A machine-readable error code.

Returns:

  • (String)


229
# File 'lib/openai/models/fine_tuning/fine_tuning_job.rb', line 229

required :code, String

#message ⇒ String

A human-readable error message.

Returns:

  • (String)


235
# File 'lib/openai/models/fine_tuning/fine_tuning_job.rb', line 235

required :message, String

#param ⇒ String?

The parameter that was invalid, usually training_file or validation_file. This field will be null if the failure was not parameter-specific.

Returns:

  • (String, nil)


242
# File 'lib/openai/models/fine_tuning/fine_tuning_job.rb', line 242

required :param, String, nil?: true

Instance Method Details

#to_hash ⇒ { code: String, message: String, param: String? }

Returns:

  • ({ code: String, message: String, param: String? })


234
# File 'sig/openai/models/fine_tuning/fine_tuning_job.rbs', line 234

def to_hash: -> { code: String, message: String, param: String? }