Class: OpenAI::Models::FineTuning::FineTuningJobWandbIntegration

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/fine_tuning/fine_tuning_job_wandb_integration.rb,
sig/openai/models/fine_tuning/fine_tuning_job_wandb_integration.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • project —

    The name of the project that the new run will be created under.

  • entity —

    The entity to use for the run. This allows you to set the team or username of the WandB user that you would like associated with the run. If not set, the default entity for the registered WandB API key is used.

  • name —

    A display name to set for the run. If not set, we will use the Job ID as the name.

  • tags —

    A list of tags to be attached to the newly created run. These tags are passed through directly to WandB. Some default tags are generated by OpenAI: "openai/finetune", "openai/base-model", "openai/ftjob-abcdef".



50
# File 'sig/openai/models/fine_tuning/fine_tuning_job_wandb_integration.rbs', line 50

def initialize: (

Instance Attribute Details

#entity ⇒ String?

The entity to use for the run. This allows you to set the team or username of the WandB user that you would like associated with the run. If not set, the default entity for the registered WandB API key is used.

Returns:

  • (String, nil)


19
# File 'lib/openai/models/fine_tuning/fine_tuning_job_wandb_integration.rb', line 19

optional :entity, String, nil?: true

#name ⇒ String?

A display name to set for the run. If not set, we will use the Job ID as the name.

Returns:

  • (String, nil)


26
# File 'lib/openai/models/fine_tuning/fine_tuning_job_wandb_integration.rb', line 26

optional :name, String, nil?: true

#project ⇒ String

The name of the project that the new run will be created under.

Returns:

  • (String)


11
# File 'lib/openai/models/fine_tuning/fine_tuning_job_wandb_integration.rb', line 11

required :project, String

#tags ⇒ ::Array[String]?

A list of tags to be attached to the newly created run. These tags are passed through directly to WandB. Some default tags are generated by OpenAI: "openai/finetune", "openai/base-model", "openai/ftjob-abcdef".

Returns:

  • (::Array[String], nil)


34
# File 'lib/openai/models/fine_tuning/fine_tuning_job_wandb_integration.rb', line 34

optional :tags, OpenAI::Internal::Type::ArrayOf[String]

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


57
# File 'sig/openai/models/fine_tuning/fine_tuning_job_wandb_integration.rbs', line 57

def to_hash: -> {