Class: OpenAI::Models::FineTuning::JobCreateParams::Hyperparameters Deprecated

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/fine_tuning/job_create_params.rb,
sig/openai/models/fine_tuning/job_create_params.rbs

Overview

Deprecated.

Defined Under Namespace

Modules: BatchSize, LearningRateMultiplier, NEpochs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(batch_size: nil, learning_rate_multiplier: nil, n_epochs: nil) ⇒ Object

Parameters:

  • batch_size (defaults to: nil) —

    Number of examples in each batch. A larger batch size means that model parameters are updated less frequently, but with lower variance.

  • learning_rate_multiplier (defaults to: nil) —

    Scaling factor for the learning rate. A smaller learning rate may be useful to avoid overfitting.

  • n_epochs (defaults to: nil) —

    The number of epochs to train the model for. An epoch refers to one full cycle through the training dataset.



# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 245


Instance Attribute Details

#batch_size ⇒ OpenAI::Models::FineTuning::JobCreateParams::Hyperparameters::batch_size?

Number of examples in each batch. A larger batch size means that model parameters are updated less frequently, but with lower variance.

Returns:

  • (OpenAI::Models::FineTuning::JobCreateParams::Hyperparameters::batch_size, nil)


226
# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 226

optional :batch_size, union: -> { OpenAI::FineTuning::JobCreateParams::Hyperparameters::BatchSize }

#learning_rate_multiplier ⇒ OpenAI::Models::FineTuning::JobCreateParams::Hyperparameters::learning_rate_multiplier?

Scaling factor for the learning rate. A smaller learning rate may be useful to avoid overfitting.

Returns:

  • (OpenAI::Models::FineTuning::JobCreateParams::Hyperparameters::learning_rate_multiplier, nil)


233
234
235
236
# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 233

optional(
  :learning_rate_multiplier,
  union: -> { OpenAI::FineTuning::JobCreateParams::Hyperparameters::LearningRateMultiplier }
)

#n_epochs ⇒ OpenAI::Models::FineTuning::JobCreateParams::Hyperparameters::n_epochs?

The number of epochs to train the model for. An epoch refers to one full cycle through the training dataset.

Returns:

  • (OpenAI::Models::FineTuning::JobCreateParams::Hyperparameters::n_epochs, nil)


243
# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 243

optional :n_epochs, union: -> { OpenAI::FineTuning::JobCreateParams::Hyperparameters::NEpochs }

Class Method Details

.variants ⇒ Array(Symbol, :auto, Float)

Returns:

  • (Array(Symbol, :auto, Float))


# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 272


Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


261
# File 'sig/openai/models/fine_tuning/job_create_params.rbs', line 261

def to_hash: -> {