Class: OpenAI::Models::FineTuning::JobCreateParams::Integration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::FineTuning::JobCreateParams::Integration
- Defined in:
- lib/openai/models/fine_tuning/job_create_params.rb,
sig/openai/models/fine_tuning/job_create_params.rbs
Defined Under Namespace
Classes: Wandb
Instance Attribute Summary collapse
-
#type ⇒ :wandb
The type of integration to enable.
-
#wandb ⇒ OpenAI::FineTuning::JobCreateParams::Integration::Wandb
The settings for your integration with Weights and Biases.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(wandb:, type: :wandb) ⇒ Object
|
|
# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 324
|
Instance Attribute Details
#type ⇒ :wandb
The type of integration to enable. Currently, only "wandb" (Weights and Biases) is supported.
313 |
# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 313 required :type, const: :wandb |
#wandb ⇒ OpenAI::FineTuning::JobCreateParams::Integration::Wandb
The settings for your integration with Weights and Biases. This payload specifies the project that metrics will be sent to. Optionally, you can set an explicit display name for your run, add tags to your run, and set a default entity (team, username, etc) to be associated with your run.
322 |
# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 322 required :wandb, -> { OpenAI::FineTuning::JobCreateParams::Integration::Wandb } |
Instance Method Details
#to_hash ⇒ {
322 |
# File 'sig/openai/models/fine_tuning/job_create_params.rbs', line 322 def to_hash: -> { |