Class: OpenAI::Models::FineTuning::JobCreateParams::Integration::Wandb
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::FineTuning::JobCreateParams::Integration::Wandb
- Defined in:
- lib/openai/models/fine_tuning/job_create_params.rb,
sig/openai/models/fine_tuning/job_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#entity ⇒ String?
The entity to use for the run.
-
#name ⇒ String?
A display name to set for the run.
-
#project ⇒ String
The name of the project that the new run will be created under.
-
#tags ⇒ ::Array[String]?
A list of tags to be attached to the newly created run.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
371 |
# File 'sig/openai/models/fine_tuning/job_create_params.rbs', line 371
def initialize: (
|
Instance Attribute Details
#entity ⇒ String?
The entity to use for the run. This allows you to set the team or username of the WandB user that you would like associated with the run. If not set, the default entity for the registered WandB API key is used.
349 |
# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 349 optional :entity, String, nil?: true |
#name ⇒ String?
A display name to set for the run. If not set, we will use the Job ID as the name.
356 |
# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 356 optional :name, String, nil?: true |
#project ⇒ String
The name of the project that the new run will be created under.
341 |
# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 341 required :project, String |
#tags ⇒ ::Array[String]?
A list of tags to be attached to the newly created run. These tags are passed through directly to WandB. Some default tags are generated by OpenAI: "openai/finetune", "openai/base-model", "openai/ftjob-abcdef".
364 |
# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 364 optional :tags, OpenAI::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
378 |
# File 'sig/openai/models/fine_tuning/job_create_params.rbs', line 378
def to_hash: -> {
|