Class: OpenAI::Models::Graders::GraderInputItem::InputImage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/graders/grader_input_item.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(image_url:, detail: nil, type: :input_image) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Graders::GraderInputItem::InputImage for more details.

An image input block used within EvalItem content arrays.

Parameters:

  • The URL of the image input.

  • (defaults to: nil)

    The detail level of the image to be sent to the model. One of high, low, or

  • (defaults to: :input_image)

    The type of the image input. Always input_image.



# File 'lib/openai/models/graders/grader_input_item.rb', line 69


Instance Attribute Details

#detailString?

The detail level of the image to be sent to the model. One of high, low, or auto. Defaults to auto.

Returns:



67
# File 'lib/openai/models/graders/grader_input_item.rb', line 67

optional :detail, String

#image_urlString

The URL of the image input.

Returns:



54
# File 'lib/openai/models/graders/grader_input_item.rb', line 54

required :image_url, String

#typeSymbol, :input_image

The type of the image input. Always input_image.

Returns:



60
# File 'lib/openai/models/graders/grader_input_item.rb', line 60

required :type, const: :input_image