Class: OpenAI::Models::Graders::PythonGrader

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/graders/python_grader.rb,
sig/openai/models/graders/python_grader.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • name —

    The name of the grader.

  • source —

    The source code of the python script.

  • image_tag —

    The image tag to use for the python script.

  • type —

    The object type, which is always python.



33
# File 'sig/openai/models/graders/python_grader.rbs', line 33

def initialize: (

Instance Attribute Details

#image_tag ⇒ String?

The image tag to use for the python script.

Returns:

  • (String, nil)


29
# File 'lib/openai/models/graders/python_grader.rb', line 29

optional :image_tag, String

#name ⇒ String

The name of the grader.

Returns:

  • (String)


11
# File 'lib/openai/models/graders/python_grader.rb', line 11

required :name, String

#source ⇒ String

The source code of the python script.

Returns:

  • (String)


17
# File 'lib/openai/models/graders/python_grader.rb', line 17

required :source, String

#type ⇒ :python

The object type, which is always python.

Returns:

  • (:python)


23
# File 'lib/openai/models/graders/python_grader.rb', line 23

required :type, const: :python

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


40
# File 'sig/openai/models/graders/python_grader.rbs', line 40

def to_hash: -> {