Class: OpenAI::Models::Graders::ScoreModelGrader

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/graders/score_model_grader.rb,
sig/openai/models/graders/score_model_grader.rbs

Defined Under Namespace

Classes: Input, SamplingParams

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • input —

    The input messages evaluated by the grader. Supports text, output text, input image, and input audio content blocks, and may include template strings.

  • model —

    The model to use for the evaluation.

  • name —

    The name of the grader.

  • range —

    The range of the score. Defaults to [0, 1].

  • sampling_params —

    The sampling parameters for the model.

  • type —

    The object type, which is always score_model.



57
# File 'sig/openai/models/graders/score_model_grader.rbs', line 57

def initialize: (

Instance Attribute Details

#input ⇒ ::Array[OpenAI::Graders::ScoreModelGrader::Input]

The input messages evaluated by the grader. Supports text, output text, input image, and input audio content blocks, and may include template strings.

Returns:

  • (::Array[OpenAI::Graders::ScoreModelGrader::Input])


12
# File 'lib/openai/models/graders/score_model_grader.rb', line 12

required :input, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Graders::ScoreModelGrader::Input] }

#model ⇒ String

The model to use for the evaluation.

Returns:

  • (String)


18
# File 'lib/openai/models/graders/score_model_grader.rb', line 18

required :model, String

#name ⇒ String

The name of the grader.

Returns:

  • (String)


24
# File 'lib/openai/models/graders/score_model_grader.rb', line 24

required :name, String

#range ⇒ ::Array[Float]?

The range of the score. Defaults to [0, 1].

Returns:

  • (::Array[Float], nil)


36
# File 'lib/openai/models/graders/score_model_grader.rb', line 36

optional :range, OpenAI::Internal::Type::ArrayOf[Float]

#sampling_params ⇒ OpenAI::Graders::ScoreModelGrader::SamplingParams?

The sampling parameters for the model.

Returns:

  • (OpenAI::Graders::ScoreModelGrader::SamplingParams, nil)


42
# File 'lib/openai/models/graders/score_model_grader.rb', line 42

optional :sampling_params, -> { OpenAI::Graders::ScoreModelGrader::SamplingParams }

#type ⇒ :score_model

The object type, which is always score_model.

Returns:

  • (:score_model)


30
# File 'lib/openai/models/graders/score_model_grader.rb', line 30

required :type, const: :score_model

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/graders/score_model_grader.rb', line 215

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


66
# File 'sig/openai/models/graders/score_model_grader.rbs', line 66

def to_hash: -> {