Class: OpenAI::Models::Graders::ScoreModelGrader::SamplingParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/graders/score_model_grader.rb,
sig/openai/models/graders/score_model_grader.rbs

Overview

See Also:

  • OpenAI::Models::Graders::ScoreModelGrader#sampling_params

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Parameters:

  • max_completions_tokens

    The maximum number of tokens the grader model may generate in its response.

  • reasoning_effort

    Constrains effort on reasoning for reasoning models. Currently supported values are none, minimal, low, medium, high, xhigh, and max. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response. Not all reasoning models support every value. See the reasoning guide for model-specific support.

  • seed

    A seed value to initialize the randomness, during sampling.

  • temperature

    A higher temperature increases randomness in the outputs.

  • top_p

    An alternative to temperature for nucleus sampling; 1.0 includes all tokens.



258
# File 'sig/openai/models/graders/score_model_grader.rbs', line 258

def initialize: (

Instance Attribute Details

#max_completions_tokensInteger?

The maximum number of tokens the grader model may generate in its response.

Returns:

  • (Integer, nil)


226
# File 'lib/openai/models/graders/score_model_grader.rb', line 226

optional :max_completions_tokens, Integer, nil?: true

#reasoning_effortOpenAI::Models::reasoning_effort?

Constrains effort on reasoning for reasoning models. Currently supported values are none, minimal, low, medium, high, xhigh, and max. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response. Not all reasoning models support every value. See the reasoning guide for model-specific support.

Returns:

  • (OpenAI::Models::reasoning_effort, nil)


237
# File 'lib/openai/models/graders/score_model_grader.rb', line 237

optional :reasoning_effort, enum: -> { OpenAI::ReasoningEffort }, nil?: true

#seedInteger?

A seed value to initialize the randomness, during sampling.

Returns:

  • (Integer, nil)


243
# File 'lib/openai/models/graders/score_model_grader.rb', line 243

optional :seed, Integer, nil?: true

#temperatureFloat?

A higher temperature increases randomness in the outputs.

Returns:

  • (Float, nil)


249
# File 'lib/openai/models/graders/score_model_grader.rb', line 249

optional :temperature, Float, nil?: true

#top_pFloat?

An alternative to temperature for nucleus sampling; 1.0 includes all tokens.

Returns:

  • (Float, nil)


255
# File 'lib/openai/models/graders/score_model_grader.rb', line 255

optional :top_p, Float, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


266
# File 'sig/openai/models/graders/score_model_grader.rbs', line 266

def to_hash: -> {