Module: OpenAI::Models::ImageEditParams::Image
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/image_edit_params.rb,
sig/openai/models/image_edit_params.rbs
Overview
The image(s) to edit. Must be a supported image file or an array of images.
For the GPT image models (gpt-image-1, gpt-image-1-mini, gpt-image-1.5,
gpt-image-2, gpt-image-2-2026-04-21, and chatgpt-image-latest), each image
should be a png, webp, or jpg file less than 50MB. You can provide up to
16 images.
For dall-e-2, you can only provide one image, and it should be a square png
file less than 4MB.
Constant Summary collapse
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(StringIO, Array<StringIO>)
|
|
# File 'lib/openai/models/image_edit_params.rb', line 200
|
Instance Method Details
#self?.variants ⇒ ::Array[OpenAI::Models::ImageEditParams::image]
100 |
# File 'sig/openai/models/image_edit_params.rbs', line 100
def self?.variants: -> ::Array[OpenAI::Models::ImageEditParams::image]
|