Module: OpenAI::Models::ImageGenCompletedEvent::Size
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/image_gen_completed_event.rb,
sig/openai/models/image_gen_completed_event.rbs
Overview
The image dimensions as a WIDTHxHEIGHT string, for example 1536x864.
collapse
- SIZE_1024X1024 =
:"1024x1024"- SIZE_1024X1536 =
:"1024x1536"- SIZE_1536X1024 =
:"1536x1024"- AUTO =
:auto
Class Method Summary collapse
-
.values ⇒ Array<Symbol>
Preserve the enum helper available before custom dimensions were supported.
- .variants ⇒ Array(String, Symbol)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
Preserve the enum helper available before custom dimensions were supported.
164 |
# File 'lib/openai/models/image_gen_completed_event.rb', line 164 def self.values = [SIZE_1024X1024, SIZE_1024X1536, SIZE_1536X1024, AUTO] |
.variants ⇒ Array(String, Symbol)
148 149 150 |
# File 'lib/openai/models/image_gen_completed_event.rb', line 148 define_sorbet_constant!(:Variants) do T.type_alias { T.any(String, OpenAI::ImageGenCompletedEvent::Size::TaggedSymbol) } end |
Instance Method Details
#self? ⇒ ::Array[(:"1024x1024"] #self? ⇒ void #self? ⇒ void #self? ⇒ void
131 132 133 134 |
# File 'sig/openai/models/image_gen_completed_event.rbs', line 131 def self?.values: -> ::Array[(:"1024x1024" | :"1024x1536" | :"1536x1024" | :auto)] |
#self?.variants ⇒ ::Array[OpenAI::Models::ImageGenCompletedEvent::size]
124 |
# File 'sig/openai/models/image_gen_completed_event.rbs', line 124 def self?.variants: -> ::Array[OpenAI::Models::ImageGenCompletedEvent::size] |