Module: OpenAI::Models::ImagesResponse::Size
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/images_response.rb,
sig/openai/models/images_response.rbs
Overview
The image dimensions as a WIDTHxHEIGHT string, for example 1536x864.
collapse
- SIZE_1024X1024 =
:"1024x1024"- SIZE_1024X1536 =
:"1024x1536"- SIZE_1536X1024 =
:"1536x1024"
Class Method Summary collapse
-
.values ⇒ Array<Symbol>
Preserve the enum helper available before custom dimensions were supported.
- .variants ⇒ Array(String, Symbol)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
Preserve the enum helper available before custom dimensions were supported.
155 |
# File 'lib/openai/models/images_response.rb', line 155 def self.values = [SIZE_1024X1024, SIZE_1024X1536, SIZE_1536X1024] |
.variants ⇒ Array(String, Symbol)
140 141 142 |
# File 'lib/openai/models/images_response.rb', line 140 define_sorbet_constant!(:Variants) do T.type_alias { T.any(String, OpenAI::ImagesResponse::Size::TaggedSymbol) } end |
Instance Method Details
#self? ⇒ ::Array[(:"1024x1024"] #self? ⇒ void #self? ⇒ void
152 153 154 |
# File 'sig/openai/models/images_response.rbs', line 152
def self?.values: -> ::Array[(:"1024x1024"
| :"1024x1536"
| :"1536x1024")]
|
#self?.variants ⇒ ::Array[OpenAI::Models::ImagesResponse::size]
146 |
# File 'sig/openai/models/images_response.rbs', line 146
def self?.variants: -> ::Array[OpenAI::Models::ImagesResponse::size]
|