Class: OpenAI::Models::Live::CommentaryAppendEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/commentary_append_event.rb,
sig/openai/models/live/commentary_append_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content:, delegation_id:, event_id: nil, type: :"session.commentary.append") ⇒ Object

Provide context the Live model can communicate to the user, optionally for an existing client delegation.

Parameters:

  • content (String)

    Speakable context for the Live model, limited to 500 tokens. Use this for a result the model should communicate; use session.thinking.append for silent context.

  • delegation_id (String, nil)

    Required, nullable. Set null for general session context, or use the ID from session.delegation.created for an existing client delegation. Non-null IDs are not accepted with Responses delegation.

  • event_id (String, nil) (defaults to: nil)

    Optional client identifier for correlating this command with a server event's client_event_id or error.client_event_id.

  • type (Symbol, :"session.commentary.append") (defaults to: :"session.commentary.append")

    The Live client event type. Always session.commentary.append.



# File 'lib/openai/models/live/commentary_append_event.rb', line 36

Instance Attribute Details

#contentString

Speakable context for the Live model, limited to 500 tokens. Use this for a result the model should communicate; use session.thinking.append for silent context.

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/openai/models/live/commentary_append_event.rb', line 13

required :content, String

#delegation_idString?

Required, nullable. Set null for general session context, or use the ID from session.delegation.created for an existing client delegation. Non-null IDs are not accepted with Responses delegation.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


21
# File 'lib/openai/models/live/commentary_append_event.rb', line 21

required :delegation_id, String, nil?: true

#event_idString?

Optional client identifier for correlating this command with a server event's client_event_id or error.client_event_id.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


34
# File 'lib/openai/models/live/commentary_append_event.rb', line 34

optional :event_id, String, nil?: true

#typeSymbol, :"session.commentary.append"

The Live client event type. Always session.commentary.append.

Parameters:

  • value (:"session.commentary.append")

Returns:

  • (Symbol, :"session.commentary.append")


27
# File 'lib/openai/models/live/commentary_append_event.rb', line 27

required :type, const: :"session.commentary.append"

Instance Method Details

#to_hash{

Returns:

  • ({)


28
# File 'sig/openai/models/live/commentary_append_event.rbs', line 28

def to_hash: -> {