Class: OpenAI::Models::Live::CommentaryAppendedEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::CommentaryAppendedEvent
- Defined in:
- lib/openai/models/live/commentary_appended_event.rb,
sig/openai/models/live/commentary_appended_event.rbs
Instance Attribute Summary collapse
-
#client_event_id ⇒ String?
The event_id of the client command associated with this server event, when supplied.
-
#end_ms ⇒ Integer
The end of this event on the Live session timeline, in milliseconds from the beginning of the session.
-
#event_id ⇒ String
The unique ID of the Live server event.
-
#start_ms ⇒ Integer
The start of this event on the Live session timeline, in milliseconds from the beginning of the session.
-
#type ⇒ Symbol, :"session.commentary.appended"
The event type, always
session.commentary.appended.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(end_ms:, event_id:, start_ms:, client_event_id: nil, type: :"session.commentary.appended") ⇒ Object
constructor
Returned when a session.commentary.append command is accepted into the Live session timeline.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_ms:, event_id:, start_ms:, client_event_id: nil, type: :"session.commentary.appended") ⇒ Object
Returned when a session.commentary.append command is accepted into the Live session timeline. Acknowledges the added commentary without guaranteeing exact wording or completed audio playback.
|
|
# File 'lib/openai/models/live/commentary_appended_event.rb', line 40
|
Instance Attribute Details
#client_event_id ⇒ String?
The event_id of the client command associated with this server event, when supplied.
38 |
# File 'lib/openai/models/live/commentary_appended_event.rb', line 38 optional :client_event_id, String |
#end_ms ⇒ Integer
The end of this event on the Live session timeline, in milliseconds from the beginning of the session. For appended context, this can equal start_ms.
12 |
# File 'lib/openai/models/live/commentary_appended_event.rb', line 12 required :end_ms, Integer |
#event_id ⇒ String
The unique ID of the Live server event.
18 |
# File 'lib/openai/models/live/commentary_appended_event.rb', line 18 required :event_id, String |
#start_ms ⇒ Integer
The start of this event on the Live session timeline, in milliseconds from the beginning of the session.
25 |
# File 'lib/openai/models/live/commentary_appended_event.rb', line 25 required :start_ms, Integer |
#type ⇒ Symbol, :"session.commentary.appended"
The event type, always session.commentary.appended.
31 |
# File 'lib/openai/models/live/commentary_appended_event.rb', line 31 required :type, const: :"session.commentary.appended" |
Instance Method Details
#to_hash ⇒ {
34 |
# File 'sig/openai/models/live/commentary_appended_event.rbs', line 34
def to_hash: -> {
|