Class: OpenAI::Models::Live::DelegationCreatedEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/delegation_created_event.rb,
sig/openai/models/live/delegation_created_event.rbs

Defined Under Namespace

Classes: Delegation

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(delegation:, event_id:, offset_ms:, client_event_id: nil, type: :"session.delegation.created") ⇒ Object

Returned when the Live model delegates work to your application or a Responses backend. Contains delegation metadata and the position on the session timeline where the work was delegated.

Parameters:

  • delegation (OpenAI::Models::Live::DelegationCreatedEvent::Delegation)

    The delegated work identifier and destination. This object contains metadata, not the task text.

  • event_id (String)

    The unique ID of the Live server event.

  • offset_ms (Integer)

    The position on the Live session timeline where the delegation was created, in milliseconds from the beginning of the session.

  • client_event_id (String) (defaults to: nil)

    The event_id of the client command associated with this server event, when supplied.

  • type (Symbol, :"session.delegation.created") (defaults to: :"session.delegation.created")

    The event type, always session.delegation.created.



# File 'lib/openai/models/live/delegation_created_event.rb', line 40

Instance Attribute Details

#client_event_idString?

The event_id of the client command associated with this server event, when supplied.

Parameters:

  • (String)

Returns:

  • (String, nil)


38
# File 'lib/openai/models/live/delegation_created_event.rb', line 38

optional :client_event_id, String

#delegationOpenAI::Models::Live::DelegationCreatedEvent::Delegation

The delegated work identifier and destination. This object contains metadata, not the task text.

Parameters:

  • value (OpenAI::Live::DelegationCreatedEvent::Delegation)

Returns:



12
# File 'lib/openai/models/live/delegation_created_event.rb', line 12

required :delegation, -> { OpenAI::Live::DelegationCreatedEvent::Delegation }

#event_idString

The unique ID of the Live server event.

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/openai/models/live/delegation_created_event.rb', line 18

required :event_id, String

#offset_msInteger

The position on the Live session timeline where the delegation was created, in milliseconds from the beginning of the session.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


25
# File 'lib/openai/models/live/delegation_created_event.rb', line 25

required :offset_ms, Integer

#typeSymbol, :"session.delegation.created"

The event type, always session.delegation.created.

Parameters:

Returns:



31
# File 'lib/openai/models/live/delegation_created_event.rb', line 31

required :type, const: :"session.delegation.created"

Instance Method Details

#to_hash{

Returns:

  • ({)


34
# File 'sig/openai/models/live/delegation_created_event.rbs', line 34

def to_hash: -> {