Class: OpenAI::Models::Live::ErrorEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::ErrorEvent
- Defined in:
- lib/openai/models/live/error_event.rb,
sig/openai/models/live/error_event.rbs
Instance Attribute Summary collapse
-
#client_event_id ⇒ String?
The event_id of the client command associated with this server event, when supplied.
-
#error ⇒ OpenAI::Models::Live::Error
Details of the Live error and the client command that caused it, when known.
-
#event_id ⇒ String
The unique ID of the Live server event.
-
#type ⇒ Symbol, :error
The event type, always
error.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(error:, event_id:, client_event_id: nil, type: :error) ⇒ Object
constructor
Reports an error in the Live session, such as an invalid client command.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(error:, event_id:, client_event_id: nil, type: :error) ⇒ Object
Reports an error in the Live session, such as an invalid client command. Use error.client_event_id, when present, to identify the command that caused the error.
|
|
# File 'lib/openai/models/live/error_event.rb', line 32
|
Instance Attribute Details
#client_event_id ⇒ String?
The event_id of the client command associated with this server event, when supplied.
30 |
# File 'lib/openai/models/live/error_event.rb', line 30 optional :client_event_id, String |
#error ⇒ OpenAI::Models::Live::Error
Details of the Live error and the client command that caused it, when known.
11 |
# File 'lib/openai/models/live/error_event.rb', line 11 required :error, -> { OpenAI::Live::Error } |
#event_id ⇒ String
The unique ID of the Live server event.
17 |
# File 'lib/openai/models/live/error_event.rb', line 17 required :event_id, String |
#type ⇒ Symbol, :error
The event type, always error.
23 |
# File 'lib/openai/models/live/error_event.rb', line 23 required :type, const: :error |
Instance Method Details
#to_hash ⇒ {
30 |
# File 'sig/openai/models/live/error_event.rbs', line 30
def to_hash: -> {
|