Class: OpenAI::Models::Live::ForkSessionConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/fork_session_config.rb,
sig/openai/models/live/fork_session_config.rbs

Defined Under Namespace

Classes: Audio, Delegation

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(format_: nil) ⇒ Object

Audio format for a WebSocket fork. WebRTC forks negotiate their audio format and must omit this field.

Parameters:



# File 'lib/openai/models/live/fork_session_config.rb', line 36

Instance Attribute Details

#audioOpenAI::Models::Live::ForkSessionConfig::Audio?

Audio format for a WebSocket fork. WebRTC forks negotiate their audio format and must omit this field.



12
# File 'lib/openai/models/live/fork_session_config.rb', line 12

optional :audio, -> { OpenAI::Live::ForkSessionConfig::Audio }

#clientOpenAI::Models::Live::ClientConfig?

Frontend data-channel permissions for a WebRTC fork. Omitted permissions inherit the stored values. Not supported for WebSocket forks.

Parameters:

  • (OpenAI::Live::ClientConfig)

Returns:



19
# File 'lib/openai/models/live/fork_session_config.rb', line 19

optional :client, -> { OpenAI::Live::ClientConfig }

#delegationOpenAI::Models::Live::ForkSessionConfig::Delegation?

Overrides for the stored session’s Responses backend. Only supported when the stored session already uses Responses delegation; the delegation type cannot change.



27
# File 'lib/openai/models/live/fork_session_config.rb', line 27

optional :delegation, -> { OpenAI::Live::ForkSessionConfig::Delegation }

#storeBoolean?

Whether to store the forked session. Omission inherits the stored session's setting.

Parameters:

Returns:



34
# File 'lib/openai/models/live/fork_session_config.rb', line 34

optional :store, OpenAI::Internal::Type::Boolean

Instance Method Details

#to_hash{

Returns:

  • ({)


40
# File 'sig/openai/models/live/fork_session_config.rbs', line 40

def to_hash: -> {