Class: OpenAI::Models::Live::ForkSessionStartEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::ForkSessionStartEvent
- Defined in:
- lib/openai/models/live/fork_session_start_event.rb,
sig/openai/models/live/fork_session_start_event.rbs
Instance Attribute Summary collapse
-
#event_id ⇒ String?
Optional client identifier for correlating this command with a server event's client_event_id or error.client_event_id.
-
#session ⇒ OpenAI::Models::Live::ForkSessionConfig
Overrides for a stored session after connecting to the fork WebSocket.
-
#type ⇒ Symbol, :"session.start"
The Live client event type.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(session:, event_id: nil, type: :"session.start") ⇒ Object
constructor
Start a Live session after connecting to a stored session’s fork WebSocket.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(session:, event_id: nil, type: :"session.start") ⇒ Object
Start a Live session after connecting to a stored session’s fork WebSocket. Send
an empty session object to use the stored configuration.
|
|
# File 'lib/openai/models/live/fork_session_start_event.rb', line 29
|
Instance Attribute Details
#event_id ⇒ String?
Optional client identifier for correlating this command with a server event's client_event_id or error.client_event_id.
27 |
# File 'lib/openai/models/live/fork_session_start_event.rb', line 27 optional :event_id, String, nil?: true |
#session ⇒ OpenAI::Models::Live::ForkSessionConfig
Overrides for a stored session after connecting to the fork WebSocket. An empty object inherits the stored configuration; do not supply a new model. audio.format applies only to the new WebSocket connection. client overrides are only supported for WebRTC forks.
14 |
# File 'lib/openai/models/live/fork_session_start_event.rb', line 14 required :session, -> { OpenAI::Live::ForkSessionConfig } |
#type ⇒ Symbol, :"session.start"
The Live client event type. Always session.start.
20 |
# File 'lib/openai/models/live/fork_session_start_event.rb', line 20 required :type, const: :"session.start" |
Instance Method Details
#to_hash ⇒ {
24 |
# File 'sig/openai/models/live/fork_session_start_event.rbs', line 24
def to_hash: -> {
|