Class: OpenAI::Models::Live::InfoEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/info_event.rb,
sig/openai/models/live/info_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(code:, event_id:, message:, client_event_id: nil, type: :info) ⇒ Object

An informational notice about the Live session, such as the event permissions applied to a frontend data channel.

Parameters:

  • code (String)

    A machine-readable code for the notice, such as data_channel_permissions.

  • event_id (String)

    The unique ID of the Live server event.

  • message (String)

    A human-readable explanation of the Live session notice.

  • client_event_id (String) (defaults to: nil)

    The event_id of the client command associated with this server event, when supplied.

  • type (Symbol, :info) (defaults to: :info)

    The event type, always info.



# File 'lib/openai/models/live/info_event.rb', line 38

Instance Attribute Details

#client_event_idString?

The event_id of the client command associated with this server event, when supplied.

Parameters:

  • (String)

Returns:

  • (String, nil)


36
# File 'lib/openai/models/live/info_event.rb', line 36

optional :client_event_id, String

#codeString

A machine-readable code for the notice, such as data_channel_permissions.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/openai/models/live/info_event.rb', line 11

required :code, String

#event_idString

The unique ID of the Live server event.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/openai/models/live/info_event.rb', line 17

required :event_id, String

#messageString

A human-readable explanation of the Live session notice.

Parameters:

  • value (String)

Returns:

  • (String)


23
# File 'lib/openai/models/live/info_event.rb', line 23

required :message, String

#typeSymbol, :info

The event type, always info.

Parameters:

  • value (:info)

Returns:

  • (Symbol, :info)


29
# File 'lib/openai/models/live/info_event.rb', line 29

required :type, const: :info

Instance Method Details

#to_hash{

Returns:

  • ({)


34
# File 'sig/openai/models/live/info_event.rbs', line 34

def to_hash: -> {