Class: OpenAI::Models::Live::InitialItem::Assistant::Content::Text
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::InitialItem::Assistant::Content::Text
- Defined in:
- lib/openai/models/live/initial_item.rb,
sig/openai/models/live/initial_item.rbs
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#text ⇒ String
The message text to include in the Live session’s initial conversation history.
-
#type ⇒ Symbol, ...
The text content type.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(text:, type: nil) ⇒ Object
constructor
Assistant text supplied as conversation history when starting a Live session.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(text:, type: nil) ⇒ Object
Assistant text supplied as conversation history when starting a Live session.
|
|
# File 'lib/openai/models/live/initial_item.rb', line 337
|
Instance Attribute Details
#text ⇒ String
The message text to include in the Live session’s initial conversation history.
329 |
# File 'lib/openai/models/live/initial_item.rb', line 329 required :text, String |
#type ⇒ Symbol, ...
The text content type. Always text.
335 |
# File 'lib/openai/models/live/initial_item.rb', line 335 optional :type, enum: -> { OpenAI::Live::InitialItem::Assistant::Content::Text::Type } |
Instance Method Details
#to_hash ⇒ {
275 |
# File 'sig/openai/models/live/initial_item.rbs', line 275
def to_hash: -> {
|