Class: OpenAI::Models::Live::InputAudioMuteEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/input_audio_mute_event.rb,
sig/openai/models/live/input_audio_mute_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_id: nil, type: :"session.input_audio.mute") ⇒ Object

Mute audio input to the Live model without closing the session. The server acknowledges with session.input_audio.muted.

Parameters:

  • event_id (String, nil) (defaults to: nil)

    Optional client identifier for correlating this command with a server event's client_event_id or error.client_event_id.

  • type (Symbol, :"session.input_audio.mute") (defaults to: :"session.input_audio.mute")

    The Live client event type. Always session.input_audio.mute.



# File 'lib/openai/models/live/input_audio_mute_event.rb', line 20

Instance Attribute Details

#event_idString?

Optional client identifier for correlating this command with a server event's client_event_id or error.client_event_id.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


18
# File 'lib/openai/models/live/input_audio_mute_event.rb', line 18

optional :event_id, String, nil?: true

#typeSymbol, :"session.input_audio.mute"

The Live client event type. Always session.input_audio.mute.

Parameters:

  • value (:"session.input_audio.mute")

Returns:

  • (Symbol, :"session.input_audio.mute")


11
# File 'lib/openai/models/live/input_audio_mute_event.rb', line 11

required :type, const: :"session.input_audio.mute"

Instance Method Details

#to_hash{

Returns:

  • ({)


17
# File 'sig/openai/models/live/input_audio_mute_event.rbs', line 17

def to_hash: -> {