Class: OpenAI::Models::Live::InputAudioMutedEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/input_audio_muted_event.rb,
sig/openai/models/live/input_audio_muted_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_id:, client_event_id: nil, type: :"session.input_audio.muted") ⇒ Object

Returned when a session.input_audio.mute command is accepted. Input audio is no longer sent to the model; sideband audio reflection continues.

Parameters:

  • event_id (String)

    The unique ID of the Live server event.

  • client_event_id (String) (defaults to: nil)

    The event_id of the client command associated with this server event, when supplied.

  • type (Symbol, :"session.input_audio.muted") (defaults to: :"session.input_audio.muted")

    The event type, always session.input_audio.muted.



# File 'lib/openai/models/live/input_audio_muted_event.rb', line 26

Instance Attribute Details

#client_event_idString?

The event_id of the client command associated with this server event, when supplied.

Parameters:

  • (String)

Returns:

  • (String, nil)


24
# File 'lib/openai/models/live/input_audio_muted_event.rb', line 24

optional :client_event_id, String

#event_idString

The unique ID of the Live server event.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/openai/models/live/input_audio_muted_event.rb', line 11

required :event_id, String

#typeSymbol, :"session.input_audio.muted"

The event type, always session.input_audio.muted.

Parameters:

  • value (:"session.input_audio.muted")

Returns:

  • (Symbol, :"session.input_audio.muted")


17
# File 'lib/openai/models/live/input_audio_muted_event.rb', line 17

required :type, const: :"session.input_audio.muted"

Instance Method Details

#to_hash{

Returns:

  • ({)


26
# File 'sig/openai/models/live/input_audio_muted_event.rbs', line 26

def to_hash: -> {