Class: OpenAI::Models::Live::InputTranscriptDeltaEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::InputTranscriptDeltaEvent
- Defined in:
- lib/openai/models/live/input_transcript_delta_event.rb,
sig/openai/models/live/input_transcript_delta_event.rbs
Instance Attribute Summary collapse
-
#client_event_id ⇒ String?
The event_id of the client command associated with this server event, when supplied.
-
#delta ⇒ String
The transcript text fragment for the audio in this time range.
-
#end_ms ⇒ Integer
The end of this event on the Live session timeline, in milliseconds from the beginning of the session.
-
#event_id ⇒ String
The unique ID of the Live server event.
-
#start_ms ⇒ Integer
The start of this event on the Live session timeline, in milliseconds from the beginning of the session.
-
#type ⇒ Symbol, :"session.input_transcript.delta"
The event type, always
session.input_transcript.delta.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(delta:, end_ms:, event_id:, start_ms:, client_event_id: nil, type: :"session.input_transcript.delta") ⇒ Object
constructor
A transcript fragment for user input audio in the Live session.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(delta:, end_ms:, event_id:, start_ms:, client_event_id: nil, type: :"session.input_transcript.delta") ⇒ Object
A transcript fragment for user input audio in the Live session. Accumulate fragments in delivery order; these events do not define complete turns or include a transcript-done event.
|
|
# File 'lib/openai/models/live/input_transcript_delta_event.rb', line 47
|
Instance Attribute Details
#client_event_id ⇒ String?
The event_id of the client command associated with this server event, when supplied.
45 |
# File 'lib/openai/models/live/input_transcript_delta_event.rb', line 45 optional :client_event_id, String |
#delta ⇒ String
The transcript text fragment for the audio in this time range. Append fragments in delivery order to build the transcript.
12 |
# File 'lib/openai/models/live/input_transcript_delta_event.rb', line 12 required :delta, String |
#end_ms ⇒ Integer
The end of this event on the Live session timeline, in milliseconds from the beginning of the session. For appended context, this can equal start_ms.
19 |
# File 'lib/openai/models/live/input_transcript_delta_event.rb', line 19 required :end_ms, Integer |
#event_id ⇒ String
The unique ID of the Live server event.
25 |
# File 'lib/openai/models/live/input_transcript_delta_event.rb', line 25 required :event_id, String |
#start_ms ⇒ Integer
The start of this event on the Live session timeline, in milliseconds from the beginning of the session.
32 |
# File 'lib/openai/models/live/input_transcript_delta_event.rb', line 32 required :start_ms, Integer |
#type ⇒ Symbol, :"session.input_transcript.delta"
The event type, always session.input_transcript.delta.
38 |
# File 'lib/openai/models/live/input_transcript_delta_event.rb', line 38 required :type, const: :"session.input_transcript.delta" |
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/openai/models/live/input_transcript_delta_event.rbs', line 38
def to_hash: -> {
|