Class: OpenAI::Models::Live::InstructionsAppendedEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/instructions_appended_event.rb,
sig/openai/models/live/instructions_appended_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(end_ms:, event_id:, start_ms:, client_event_id: nil, type: :"session.instructions.appended") ⇒ Object

Returned when a session.instructions.append command is accepted into the Live session timeline. Acknowledges the appended instructions without guaranteeing that the model has acted on them.

Parameters:

  • end_ms (Integer)

    The end of this event on the Live session timeline, in milliseconds from the beginning of the session. For appended context, this can equal start_ms.

  • event_id (String)

    The unique ID of the Live server event.

  • start_ms (Integer)

    The start of this event on the Live session timeline, in milliseconds from the beginning of the session.

  • client_event_id (String) (defaults to: nil)

    The event_id of the client command associated with this server event, when supplied.

  • type (Symbol, :"session.instructions.appended") (defaults to: :"session.instructions.appended")

    The event type, always session.instructions.appended.



# File 'lib/openai/models/live/instructions_appended_event.rb', line 40

Instance Attribute Details

#client_event_idString?

The event_id of the client command associated with this server event, when supplied.

Parameters:

  • (String)

Returns:

  • (String, nil)


38
# File 'lib/openai/models/live/instructions_appended_event.rb', line 38

optional :client_event_id, String

#end_msInteger

The end of this event on the Live session timeline, in milliseconds from the beginning of the session. For appended context, this can equal start_ms.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


12
# File 'lib/openai/models/live/instructions_appended_event.rb', line 12

required :end_ms, Integer

#event_idString

The unique ID of the Live server event.

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/openai/models/live/instructions_appended_event.rb', line 18

required :event_id, String

#start_msInteger

The start of this event on the Live session timeline, in milliseconds from the beginning of the session.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


25
# File 'lib/openai/models/live/instructions_appended_event.rb', line 25

required :start_ms, Integer

#typeSymbol, :"session.instructions.appended"

The event type, always session.instructions.appended.

Parameters:

  • value (:"session.instructions.appended")

Returns:

  • (Symbol, :"session.instructions.appended")


31
# File 'lib/openai/models/live/instructions_appended_event.rb', line 31

required :type, const: :"session.instructions.appended"

Instance Method Details

#to_hash{

Returns:

  • ({)


34
# File 'sig/openai/models/live/instructions_appended_event.rbs', line 34

def to_hash: -> {