Class: OpenAI::Models::Live::MediaSessionConfig::Audio::Output

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/media_session_config.rb,
sig/openai/models/live/media_session_config.rbs

Overview

See Also:

  • OpenAI::Models::Live::MediaSessionConfig::Audio#output

Defined Under Namespace

Modules: Voice

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(voice: nil) ⇒ Object

Settings for speech generated by the Live model. Choose the voice before starting the session.

Parameters:



# File 'lib/openai/models/live/media_session_config.rb', line 153

Instance Attribute Details

#voiceString, ...

The voice used for Live speech, as a built-in voice name or a custom voice object containing its ID. Defaults to marin and cannot change after startup.



151
# File 'lib/openai/models/live/media_session_config.rb', line 151

optional :voice, union: -> { OpenAI::Live::MediaSessionConfig::Audio::Output::Voice }

Instance Method Details

#to_hash{

Returns:

  • ({)


106
# File 'sig/openai/models/live/media_session_config.rbs', line 106

def to_hash: -> {