Class: OpenAI::Models::Live::MediaSessionConfig::Delegation::Responses
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::MediaSessionConfig::Delegation::Responses
- Defined in:
- lib/openai/models/live/media_session_config.rb,
sig/openai/models/live/media_session_config.rbs
Instance Attribute Summary collapse
-
#responses ⇒ OpenAI::Models::Live::ResponsesDelegationConfig
Backend model, prompt, and tools used when the Live session delegates a task to Responses.
-
#type ⇒ Symbol, :responses
The delegation owner.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(responses:, type: :responses) ⇒ Object
constructor
Delegate tasks to a Responses model managed by the Live session.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(responses:, type: :responses) ⇒ Object
Delegate tasks to a Responses model managed by the Live session.
|
|
# File 'lib/openai/models/live/media_session_config.rb', line 210
|
Instance Attribute Details
#responses ⇒ OpenAI::Models::Live::ResponsesDelegationConfig
Backend model, prompt, and tools used when the Live session delegates a task to Responses.
202 |
# File 'lib/openai/models/live/media_session_config.rb', line 202 required :responses, -> { OpenAI::Live::ResponsesDelegationConfig } |
#type ⇒ Symbol, :responses
The delegation owner. Always responses for tasks handled by the Responses API.
208 |
# File 'lib/openai/models/live/media_session_config.rb', line 208 required :type, const: :responses |
Instance Method Details
#to_hash ⇒ {
146 |
# File 'sig/openai/models/live/media_session_config.rbs', line 146
def to_hash: -> {
|