Class: OpenAI::Models::Live::MediaSessionForkConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/media_session_fork_config.rb,
sig/openai/models/live/media_session_fork_config.rbs

Defined Under Namespace

Classes: Delegation

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(client: nil, delegation: nil, store: nil) ⇒ Object

Optional overrides for a stored Live session. Omitted settings are inherited. The model, voice, frontend instructions, and prior conversation come from the stored session. WebRTC negotiates its audio format; audio.format is only supported on WebSocket forks.

Parameters:

  • client (OpenAI::Models::Live::ClientConfig) (defaults to: nil)

    Startup-only capabilities for an untrusted frontend attached to a unified WebRTC session. Trusted sideband connections are unaffected.

  • delegation (OpenAI::Models::Live::MediaSessionForkConfig::Delegation) (defaults to: nil)

    Update the Responses backend for an existing Live session without changing delegation ownership.

  • store (Boolean) (defaults to: nil)

    Whether to store the forked session. Omission inherits the stored session's setting.



# File 'lib/openai/models/live/media_session_fork_config.rb', line 28

Instance Attribute Details

#clientOpenAI::Models::Live::ClientConfig?

Startup-only capabilities for an untrusted frontend attached to a unified WebRTC session. Trusted sideband connections are unaffected.

Parameters:

  • (OpenAI::Live::ClientConfig)

Returns:



12
# File 'lib/openai/models/live/media_session_fork_config.rb', line 12

optional :client, -> { OpenAI::Live::ClientConfig }

#delegationOpenAI::Models::Live::MediaSessionForkConfig::Delegation?

Update the Responses backend for an existing Live session without changing delegation ownership.



19
# File 'lib/openai/models/live/media_session_fork_config.rb', line 19

optional :delegation, -> { OpenAI::Live::MediaSessionForkConfig::Delegation }

#storeBoolean?

Whether to store the forked session. Omission inherits the stored session's setting.

Parameters:

Returns:



26
# File 'lib/openai/models/live/media_session_fork_config.rb', line 26

optional :store, OpenAI::Internal::Type::Boolean

Instance Method Details

#to_hash{

Returns:

  • ({)


32
# File 'sig/openai/models/live/media_session_fork_config.rbs', line 32

def to_hash: -> {