Class: OpenAI::Models::Live::MediaSessionForkConfig::Delegation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::MediaSessionForkConfig::Delegation
- Defined in:
- lib/openai/models/live/media_session_fork_config.rb,
sig/openai/models/live/media_session_fork_config.rbs
Overview
Instance Attribute Summary collapse
-
#responses ⇒ OpenAI::Models::Live::ResponsesDelegationUpdateConfig?
Responses backend settings to update.
-
#type ⇒ Symbol, :responses
The delegation owner.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(responses: nil, type: :responses) ⇒ Object
constructor
Update the Responses backend for an existing Live session without changing delegation ownership.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(responses: nil, type: :responses) ⇒ Object
Update the Responses backend for an existing Live session without changing delegation ownership.
|
|
# File 'lib/openai/models/live/media_session_fork_config.rb', line 61
|
Instance Attribute Details
#responses ⇒ OpenAI::Models::Live::ResponsesDelegationUpdateConfig?
Responses backend settings to update. Omitted settings keep their existing values.
59 |
# File 'lib/openai/models/live/media_session_fork_config.rb', line 59 optional :responses, -> { OpenAI::Live::ResponsesDelegationUpdateConfig } |
#type ⇒ Symbol, :responses
The delegation owner. Always responses for tasks handled by the Responses API.
52 |
# File 'lib/openai/models/live/media_session_fork_config.rb', line 52 required :type, const: :responses |
Instance Method Details
#to_hash ⇒ {
58 |
# File 'sig/openai/models/live/media_session_fork_config.rbs', line 58
def to_hash: -> {
|