Class: OpenAI::Models::Live::ResponseCreateEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/response_create_event.rb,
sig/openai/models/live/response_create_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_id: nil, type: :"response.create") ⇒ ResponseCreateEvent

Request a response from the Live session’s Responses backend, or continue a delegated response waiting for tool results. Requires Responses delegation.

Parameters:

  • event_id (String, nil) (defaults to: nil)

    Optional client identifier for correlating this command with a server event's client_event_id or error.client_event_id.

  • type (Symbol, :"response.create") (defaults to: :"response.create")

    The Live client event type. Always response.create.

  • event_id: (String, nil) (defaults to: nil)
  • type: (:"response.create") (defaults to: :"response.create")


# File 'lib/openai/models/live/response_create_event.rb', line 20

Instance Attribute Details

#event_idString?

Optional client identifier for correlating this command with a server event's client_event_id or error.client_event_id.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


18
# File 'lib/openai/models/live/response_create_event.rb', line 18

optional :event_id, String, nil?: true

#typeSymbol, :"response.create"

The Live client event type. Always response.create.

Parameters:

  • value (:"response.create")

Returns:

  • (Symbol, :"response.create")


11
# File 'lib/openai/models/live/response_create_event.rb', line 11

required :type, const: :"response.create"

Instance Method Details

#to_hash{ ?type: :"response.create", ?event_id: String? }

Returns:

  • ({ ?type: :"response.create", ?event_id: String? })


14
# File 'sig/openai/models/live/response_create_event.rbs', line 14

def to_hash: -> { ?type: :"response.create", ?event_id: String? }