Class: OpenAI::Models::Live::ResponsesDelegationUpdateConfig::Reasoning
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::ResponsesDelegationUpdateConfig::Reasoning
- Defined in:
- lib/openai/models/live/responses_delegation_update_config.rb,
sig/openai/models/live/responses_delegation_update_config.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#effort ⇒ Symbol, ...
How much reasoning effort the delegated Responses model should use.
-
#summary ⇒ Symbol, ...
The reasoning summary to request from the delegated Responses model, when supported.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(effort: nil, summary: nil) ⇒ Object
constructor
Reasoning settings passed to each delegated Responses request.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(effort: nil, summary: nil) ⇒ Object
Reasoning settings passed to each delegated Responses request.
|
|
# File 'lib/openai/models/live/responses_delegation_update_config.rb', line 135
|
Instance Attribute Details
#effort ⇒ Symbol, ...
How much reasoning effort the delegated Responses model should use. Supported values depend on the backend model.
118 119 120 121 122 |
# File 'lib/openai/models/live/responses_delegation_update_config.rb', line 118 optional( :effort, enum: -> { OpenAI::Live::ResponsesDelegationUpdateConfig::Reasoning::Effort }, nil?: true ) |
#summary ⇒ Symbol, ...
The reasoning summary to request from the delegated Responses model, when supported.
129 130 131 132 133 |
# File 'lib/openai/models/live/responses_delegation_update_config.rb', line 129 optional( :summary, enum: -> { OpenAI::Live::ResponsesDelegationUpdateConfig::Reasoning::Summary }, nil?: true ) |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/live/responses_delegation_update_config.rb', line 160
|
Instance Method Details
#to_hash ⇒ {
86 |
# File 'sig/openai/models/live/responses_delegation_update_config.rbs', line 86
def to_hash: -> {
|