Class: OpenAI::Models::Live::ServerEvent::SessionInputAudioAppend

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/server_event.rb,
sig/openai/models/live/server_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



39
# File 'sig/openai/models/live/server_event.rbs', line 39

def initialize: (

Instance Attribute Details

#audioString

Base64-encoded raw mono PCM16LE at 24 kHz received from the primary transport, reflected to the sideband before model-input muting. This server event uses the same audio key as the client command, but is not an acknowledgment of it.

Parameters:

  • value (String)

Returns:

  • (String)


89
# File 'lib/openai/models/live/server_event.rb', line 89

required :audio, String

#typeSymbol, :"session.input_audio.append"

The event type, always session.input_audio.append.

Parameters:

  • value (:"session.input_audio.append")

Returns:

  • (Symbol, :"session.input_audio.append")


95
# File 'lib/openai/models/live/server_event.rb', line 95

required :type, const: :"session.input_audio.append"

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/openai/models/live/server_event.rbs', line 44

def to_hash: -> {