Class: OpenAI::Models::Live::SessionConfig::Audio::Output
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::SessionConfig::Audio::Output
- Defined in:
- lib/openai/models/live/session_config.rb,
sig/openai/models/live/session_config.rbs
Overview
Defined Under Namespace
Modules: Voice
Instance Attribute Summary collapse
-
#voice ⇒ String, ...
The voice used for Live speech, as a built-in voice name or a custom voice object containing its ID.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(voice: nil) ⇒ Object
constructor
The voice used for speech generated by the Live model.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(voice: nil) ⇒ Object
The voice used for speech generated by the Live model.
|
|
# File 'lib/openai/models/live/session_config.rb', line 163
|
Instance Attribute Details
#voice ⇒ String, ...
The voice used for Live speech, as a built-in voice name or a custom voice
object containing its ID. Defaults to marin and cannot change after startup.
161 |
# File 'lib/openai/models/live/session_config.rb', line 161 optional :voice, union: -> { OpenAI::Live::SessionConfig::Audio::Output::Voice } |
Instance Method Details
#to_hash ⇒ {
117 |
# File 'sig/openai/models/live/session_config.rbs', line 117
def to_hash: -> {
|