Class: OpenAI::Models::Live::SessionForkParams::Transport

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/session_fork_params.rb,
sig/openai/models/live/session_fork_params.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(sdp:, type: :webrtc) ⇒ Transport

WebRTC transport with an SDP offer for the new connection to the forked session.

Parameters:

  • sdp (String)

    Session Description Protocol message for the WebRTC connection.

  • type (Symbol, :webrtc) (defaults to: :webrtc)

    The transport used for the Live session. Always webrtc.

  • sdp: (String)
  • type: (:webrtc) (defaults to: :webrtc)


41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/openai/models/live/session_fork_params.rb', line 41

class Transport < OpenAI::Internal::Type::BaseModel
  # @!attribute sdp
  #   Session Description Protocol message for the WebRTC connection.
  #
  #   @return [String]
  required :sdp, String

  # @!attribute type
  #   The transport used for the Live session. Always `webrtc`.
  #
  #   @return [Symbol, :webrtc]
  required :type, const: :webrtc

  # @!method initialize(sdp:, type: :webrtc)
  #   WebRTC transport with an SDP offer for the new connection to the forked session.
  #
  #   @param sdp [String]
  #     Session Description Protocol message for the WebRTC connection.
  #
  #   @param type [Symbol, :webrtc]
  #     The transport used for the Live session. Always `webrtc`.
end

Instance Attribute Details

#sdpString

Session Description Protocol message for the WebRTC connection.

Parameters:

  • value (String)

Returns:

  • (String)


46
# File 'lib/openai/models/live/session_fork_params.rb', line 46

required :sdp, String

#typeSymbol, :webrtc

The transport used for the Live session. Always webrtc.

Parameters:

  • value (:webrtc)

Returns:

  • (Symbol, :webrtc)


52
# File 'lib/openai/models/live/session_fork_params.rb', line 52

required :type, const: :webrtc

Instance Method Details

#to_hash{ sdp: String, ?type: :webrtc }

Returns:

  • ({ sdp: String, ?type: :webrtc })


49
# File 'sig/openai/models/live/session_fork_params.rbs', line 49

def to_hash: -> { sdp: String, ?type: :webrtc }