Class: OpenAI::Models::Live::SessionStartEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/session_start_event.rb,
sig/openai/models/live/session_start_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(session:, event_id: nil, type: :"session.start") ⇒ Object

Start a Live session on a primary WebSocket. Send this event before other commands and wait for session.started.

Parameters:

  • session (OpenAI::Models::Live::SessionConfig)

    Initial configuration for a primary WebSocket. Send session.start first and wait for session.started before application commands. WebRTC creation already starts the session; do not send this event again on its data channel.

  • event_id (String, nil) (defaults to: nil)

    Optional client identifier for correlating this command with a server event's client_event_id or error.client_event_id.

  • type (Symbol, :"session.start") (defaults to: :"session.start")

    The Live client event type. Always session.start.



# File 'lib/openai/models/live/session_start_event.rb', line 28

Instance Attribute Details

#event_idString?

Optional client identifier for correlating this command with a server event's client_event_id or error.client_event_id.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


26
# File 'lib/openai/models/live/session_start_event.rb', line 26

optional :event_id, String, nil?: true

#sessionOpenAI::Models::Live::SessionConfig

Initial configuration for a primary WebSocket. Send session.start first and wait for session.started before application commands. WebRTC creation already starts the session; do not send this event again on its data channel.

Parameters:

  • value (OpenAI::Live::SessionConfig)

Returns:



13
# File 'lib/openai/models/live/session_start_event.rb', line 13

required :session, -> { OpenAI::Live::SessionConfig }

#typeSymbol, :"session.start"

The Live client event type. Always session.start.

Parameters:

Returns:



19
# File 'lib/openai/models/live/session_start_event.rb', line 19

required :type, const: :"session.start"

Instance Method Details

#to_hash{

Returns:

  • ({)


24
# File 'sig/openai/models/live/session_start_event.rbs', line 24

def to_hash: -> {