Class: OpenAI::Models::Live::SessionStartedEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/session_started_event.rb,
sig/openai/models/live/session_started_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_id:, session:, client_event_id: nil, type: :"session.started") ⇒ Object

Returned when a Live session has started. Contains the resolved session configuration, including server defaults.

Parameters:

  • event_id (String)

    The unique ID of the Live server event.

  • session (OpenAI::Models::Live::SessionResource)

    The resolved Live session configuration and server-assigned session metadata.

  • client_event_id (String) (defaults to: nil)

    The event_id of the client command associated with this server event, when supplied.

  • type (Symbol, :"session.started") (defaults to: :"session.started")

    The event type, always session.started.



# File 'lib/openai/models/live/session_started_event.rb', line 32

Instance Attribute Details

#client_event_idString?

The event_id of the client command associated with this server event, when supplied.

Parameters:

  • (String)

Returns:

  • (String, nil)


30
# File 'lib/openai/models/live/session_started_event.rb', line 30

optional :client_event_id, String

#event_idString

The unique ID of the Live server event.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/openai/models/live/session_started_event.rb', line 11

required :event_id, String

#sessionOpenAI::Models::Live::SessionResource

The resolved Live session configuration and server-assigned session metadata.

Parameters:

  • value (OpenAI::Live::SessionResource)

Returns:



17
# File 'lib/openai/models/live/session_started_event.rb', line 17

required :session, -> { OpenAI::Live::SessionResource }

#typeSymbol, :"session.started"

The event type, always session.started.

Parameters:

Returns:



23
# File 'lib/openai/models/live/session_started_event.rb', line 23

required :type, const: :"session.started"

Instance Method Details

#to_hash{

Returns:

  • ({)


30
# File 'sig/openai/models/live/session_started_event.rbs', line 30

def to_hash: -> {