Class: OpenAI::Models::Live::SessionUpdateConfig::Delegation::Responses

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/session_update_config.rb,
sig/openai/models/live/session_update_config.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(responses: nil, type: :responses) ⇒ Object

Update the Responses backend for an existing Live session without changing delegation ownership.

Parameters:

  • responses (OpenAI::Models::Live::ResponsesDelegationUpdateConfig) (defaults to: nil)

    Responses backend settings to update. Omitted settings keep their existing values.

  • type (Symbol, :responses) (defaults to: :responses)

    The delegation owner. Always responses for tasks handled by the Responses API.



# File 'lib/openai/models/live/session_update_config.rb', line 51

Instance Attribute Details

#responsesOpenAI::Models::Live::ResponsesDelegationUpdateConfig?

Responses backend settings to update. Omitted settings keep their existing values.



49
# File 'lib/openai/models/live/session_update_config.rb', line 49

optional :responses, -> { OpenAI::Live::ResponsesDelegationUpdateConfig }

#typeSymbol, :responses

The delegation owner. Always responses for tasks handled by the Responses API.

Parameters:

  • value (:responses)

Returns:

  • (Symbol, :responses)


42
# File 'lib/openai/models/live/session_update_config.rb', line 42

required :type, const: :responses

Instance Method Details

#to_hash{

Returns:

  • ({)


45
# File 'sig/openai/models/live/session_update_config.rbs', line 45

def to_hash: -> {