Class: OpenAI::Models::Live::SessionUpdateEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/session_update_event.rb,
sig/openai/models/live/session_update_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(session:, event_id: nil, type: :"session.update") ⇒ Object

Update the delegation settings of an active Live session. The server acknowledges accepted changes with session.updated.

Parameters:

  • session (OpenAI::Models::Live::SessionUpdateConfig)

    Sparse delegation updates. Omitted settings retain their values. The delegation type cannot change, including resetting Responses delegation to null or client. Model, frontend instructions, audio, and startup input are immutable.

  • event_id (String, nil) (defaults to: nil)

    Optional client identifier for correlating this command with a server event's client_event_id or error.client_event_id.

  • type (Symbol, :"session.update") (defaults to: :"session.update")

    The Live client event type. Always session.update.



# File 'lib/openai/models/live/session_update_event.rb', line 28

Instance Attribute Details

#event_idString?

Optional client identifier for correlating this command with a server event's client_event_id or error.client_event_id.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


26
# File 'lib/openai/models/live/session_update_event.rb', line 26

optional :event_id, String, nil?: true

#sessionOpenAI::Models::Live::SessionUpdateConfig

Sparse delegation updates. Omitted settings retain their values. The delegation type cannot change, including resetting Responses delegation to null or client. Model, frontend instructions, audio, and startup input are immutable.

Parameters:

  • value (OpenAI::Live::SessionUpdateConfig)

Returns:



13
# File 'lib/openai/models/live/session_update_event.rb', line 13

required :session, -> { OpenAI::Live::SessionUpdateConfig }

#typeSymbol, :"session.update"

The Live client event type. Always session.update.

Parameters:

Returns:



19
# File 'lib/openai/models/live/session_update_event.rb', line 19

required :type, const: :"session.update"

Instance Method Details

#to_hash{

Returns:

  • ({)


24
# File 'sig/openai/models/live/session_update_event.rbs', line 24

def to_hash: -> {