Class: OpenAI::Models::Live::SessionUsageUpdatedEvent::ContextWindow

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/live/session_usage_updated_event.rb,
sig/openai/models/live/session_usage_updated_event.rbs

Overview

See Also:

  • OpenAI::Models::Live::SessionUsageUpdatedEvent#context_window

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(usage_ratio:) ⇒ ContextWindow

The latest measured Live context-window usage. Omitted when the context limit is unknown.

Parameters:

  • usage_ratio (Float)

    The latest active context token count divided by the Live model context limit. Can decrease after compaction and may lag between measured audio frames.

  • usage_ratio: (Float)


# File 'lib/openai/models/live/session_usage_updated_event.rb', line 70

Instance Attribute Details

#usage_ratioFloat

The latest active context token count divided by the Live model context limit. Can decrease after compaction and may lag between measured audio frames.

Parameters:

  • value (Float)

Returns:

  • (Float)


68
# File 'lib/openai/models/live/session_usage_updated_event.rb', line 68

required :usage_ratio, Float

Instance Method Details

#to_hash{ usage_ratio: Float }

Returns:

  • ({ usage_ratio: Float })


53
# File 'sig/openai/models/live/session_usage_updated_event.rbs', line 53

def to_hash: -> { usage_ratio: Float }