Class: OpenAI::Models::Moderation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/moderation.rb,
sig/openai/models/moderation.rbs

Defined Under Namespace

Classes: Categories, CategoryAppliedInputTypes, CategoryScores

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(harassment:, harassment_threatening:, hate:, hate_threatening:, illicit:, illicit_violent:, self_harm:, self_harm_instructions:, self_harm_intent:, sexual:, sexual_minors:, violence:, violence_graphic:) ⇒ Object

Parameters:

  • categories

    A list of the categories, and whether they are flagged or not.

  • category_applied_input_types

    A list of the categories along with the input type(s) that the score applies to.

  • category_scores

    A list of the categories along with their scores as predicted by model.

  • flagged

    Whether any of the below categories are flagged.



# File 'lib/openai/models/moderation.rb', line 30

Instance Attribute Details

#categoriesOpenAI::Moderation::Categories

A list of the categories, and whether they are flagged or not.

Returns:

  • (OpenAI::Moderation::Categories)


10
# File 'lib/openai/models/moderation.rb', line 10

required :categories, -> { OpenAI::Moderation::Categories }

#category_applied_input_typesOpenAI::Moderation::CategoryAppliedInputTypes

A list of the categories along with the input type(s) that the score applies to.

Returns:

  • (OpenAI::Moderation::CategoryAppliedInputTypes)


16
# File 'lib/openai/models/moderation.rb', line 16

required :category_applied_input_types, -> { OpenAI::Moderation::CategoryAppliedInputTypes }

#category_scoresOpenAI::Moderation::CategoryScores

A list of the categories along with their scores as predicted by model.

Returns:

  • (OpenAI::Moderation::CategoryScores)


22
# File 'lib/openai/models/moderation.rb', line 22

required :category_scores, -> { OpenAI::Moderation::CategoryScores }

#flaggedBoolean

Whether any of the below categories are flagged.

Returns:



28
# File 'lib/openai/models/moderation.rb', line 28

required :flagged, OpenAI::Internal::Type::Boolean

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/moderation.rb', line 503

Instance Method Details

#to_hash{

Returns:

  • ({)


39
# File 'sig/openai/models/moderation.rbs', line 39

def to_hash: -> {