Class: OpenAI::Models::ModerationCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/moderation_create_params.rb,
sig/openai/models/moderation_create_params.rbs

Overview

See Also:

  • OpenAI::Resources::Moderations#create

Defined Under Namespace

Modules: Input, Model

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(input:, model: nil, request_options: {}) ⇒ Object

Parameters:

  • input —

    Input (or inputs) to classify. Can be a single string, an array of strings, or an array of multi-modal input objects similar to other models.

  • model (defaults to: nil) —

    The content moderation model you would like to use. Learn more in the moderation guide, and learn about available models here.



# File 'lib/openai/models/moderation_create_params.rb', line 26

Instance Attribute Details

#input ⇒ OpenAI::Models::ModerationCreateParams::input

Input (or inputs) to classify. Can be a single string, an array of strings, or an array of multi-modal input objects similar to other models.

Returns:

  • (OpenAI::Models::ModerationCreateParams::input)


15
# File 'lib/openai/models/moderation_create_params.rb', line 15

required :input, union: -> { OpenAI::ModerationCreateParams::Input }

#model ⇒ OpenAI::Models::ModerationCreateParams::model?

The content moderation model you would like to use. Learn more in the moderation guide, and learn about available models here.

Returns:

  • (OpenAI::Models::ModerationCreateParams::model, nil)


24
# File 'lib/openai/models/moderation_create_params.rb', line 24

optional :model, union: -> { OpenAI::ModerationCreateParams::Model }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


46
# File 'sig/openai/models/moderation_create_params.rbs', line 46

def to_hash: -> {