Module: OpenAI::Models::ModerationCreateParams::Model
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/moderation_create_params.rb,
sig/openai/models/moderation_create_params.rbs
Overview
The content moderation model you would like to use. Learn more in the moderation guide, and learn about available models here.
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(String, Symbol, OpenAI::Models::ModerationModel)
|
|
# File 'lib/openai/models/moderation_create_params.rb', line 75
|
Instance Method Details
#self?.variants ⇒ ::Array[OpenAI::Models::ModerationCreateParams::model]
54 |
# File 'sig/openai/models/moderation_create_params.rbs', line 54
def self?.variants: -> ::Array[OpenAI::Models::ModerationCreateParams::model]
|