Module: OpenAI::Models::Realtime::AudioTranscription::Delay

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/realtime/audio_transcription.rb,
sig/openai/models/realtime/audio_transcription.rbs

Overview

Controls how long the model waits before emitting transcription text. Higher values can improve transcription accuracy at the cost of latency. Only supported with gpt-realtime-whisper in GA Realtime sessions.

See Also:

  • OpenAI::Models::Realtime::AudioTranscription#delay

Constant Summary collapse

MINIMAL =

Returns:

  • (:minimal)
:minimal
LOW =

Returns:

  • (:low)
:low
MEDIUM =

Returns:

  • (:medium)
:medium
HIGH =

Returns:

  • (:high)
:high
XHIGH =

Returns:

  • (:xhigh)
:xhigh

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[OpenAI::Models::Realtime::AudioTranscription::delay]

Returns:

  • (::Array[OpenAI::Models::Realtime::AudioTranscription::delay])


58
# File 'sig/openai/models/realtime/audio_transcription.rbs', line 58

def self?.values: -> ::Array[OpenAI::Models::Realtime::AudioTranscription::delay]