Module: OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter::Anchor

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/realtime/client_secret_create_params.rb,
sig/openai/models/realtime/client_secret_create_params.rbs

Overview

The anchor point for the client secret expiration, meaning that seconds will be added to the created_at time of the client secret to produce an expiration timestamp. Only created_at is currently supported.

See Also:

  • OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter#anchor

Constant Summary collapse

CREATED_AT =

Returns:

  • (:created_at)
:created_at

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter::anchor]

Returns:

  • (::Array[OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter::anchor])


73
# File 'sig/openai/models/realtime/client_secret_create_params.rbs', line 73

def self?.values: -> ::Array[OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter::anchor]