Class: OpenAI::Models::Realtime::ConversationItemCreatedEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/conversation_item_created_event.rb,
sig/openai/models/realtime/conversation_item_created_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_id:, item:, previous_item_id: nil, type: :"conversation.item.created") ⇒ Object

Parameters:

  • event_id

    The unique ID of the server event.

  • item

    A single item within a Realtime conversation.

  • previous_item_id (defaults to: nil)

    The ID of the preceding item in the Conversation context, allows the client to understand the order of the conversation. Can be null if the item has no predecessor.

  • type (defaults to: :"conversation.item.created")

    The event type, must be conversation.item.created.



# File 'lib/openai/models/realtime/conversation_item_created_event.rb', line 33

Instance Attribute Details

#event_idString

The unique ID of the server event.

Returns:

  • (String)


11
# File 'lib/openai/models/realtime/conversation_item_created_event.rb', line 11

required :event_id, String

#itemOpenAI::Models::Realtime::conversation_item

A single item within a Realtime conversation.

Returns:

  • (OpenAI::Models::Realtime::conversation_item)


17
# File 'lib/openai/models/realtime/conversation_item_created_event.rb', line 17

required :item, union: -> { OpenAI::Realtime::ConversationItem }

#previous_item_idString?

The ID of the preceding item in the Conversation context, allows the client to understand the order of the conversation. Can be null if the item has no predecessor.

Returns:

  • (String, nil)


31
# File 'lib/openai/models/realtime/conversation_item_created_event.rb', line 31

optional :previous_item_id, String, nil?: true

#type:"conversation.item.created"

The event type, must be conversation.item.created.

Returns:

  • (:"conversation.item.created")


23
# File 'lib/openai/models/realtime/conversation_item_created_event.rb', line 23

required :type, const: :"conversation.item.created"

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/openai/models/realtime/conversation_item_created_event.rbs', line 44

def to_hash: -> {