Class: OpenAI::Models::Realtime::ConversationItemDeleteEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/conversation_item_delete_event.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(item_id:, event_id: nil, type: :"conversation.item.delete") ⇒ Object

Send this event when you want to remove any item from the conversation history. The server will respond with a conversation.item.deleted event, unless the item does not exist in the conversation history, in which case the server will respond with an error.

Parameters:

  • The ID of the item to delete.

  • (defaults to: nil)

    Optional client-generated ID used to identify this event.

  • (defaults to: :"conversation.item.delete")

    The event type, must be conversation.item.delete.



# File 'lib/openai/models/realtime/conversation_item_delete_event.rb', line 25


Instance Attribute Details

#event_idString?

Optional client-generated ID used to identify this event.

Returns:



23
# File 'lib/openai/models/realtime/conversation_item_delete_event.rb', line 23

optional :event_id, String

#item_idString

The ID of the item to delete.

Returns:



11
# File 'lib/openai/models/realtime/conversation_item_delete_event.rb', line 11

required :item_id, String

#typeSymbol, :"conversation.item.delete"

The event type, must be conversation.item.delete.

Returns:



17
# File 'lib/openai/models/realtime/conversation_item_delete_event.rb', line 17

required :type, const: :"conversation.item.delete"