Class: OpenAI::Models::Realtime::ConversationItemInputAudioTranscriptionCompletedEvent::Usage::TranscriptTextUsageTokens
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::ConversationItemInputAudioTranscriptionCompletedEvent::Usage::TranscriptTextUsageTokens
- Defined in:
- lib/openai/models/realtime/conversation_item_input_audio_transcription_completed_event.rb,
sig/openai/models/realtime/conversation_item_input_audio_transcription_completed_event.rbs
Defined Under Namespace
Classes: InputTokenDetails
Instance Attribute Summary collapse
-
#input_token_details ⇒ OpenAI::Models::Realtime::ConversationItemInputAudioTranscriptionCompletedEvent::Usage::TranscriptTextUsageTokens::InputTokenDetails?
Details about the input tokens billed for this request.
-
#input_tokens ⇒ Integer
Number of input tokens billed for this request.
-
#output_tokens ⇒ Integer
Number of output tokens generated.
-
#total_tokens ⇒ Integer
Total number of tokens used (input + output).
-
#type ⇒ Symbol, :tokens
The type of the usage object.
Instance Method Summary collapse
-
#initialize(input_tokens:, output_tokens:, total_tokens:, input_token_details: nil, type: :tokens) ⇒ Object
constructor
Usage statistics for models billed by token usage.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(input_tokens:, output_tokens:, total_tokens:, input_token_details: nil, type: :tokens) ⇒ Object
Usage statistics for models billed by token usage.
|
|
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_completed_event.rb', line 137
|
Instance Attribute Details
#input_token_details ⇒ OpenAI::Models::Realtime::ConversationItemInputAudioTranscriptionCompletedEvent::Usage::TranscriptTextUsageTokens::InputTokenDetails?
Details about the input tokens billed for this request.
134 135 |
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_completed_event.rb', line 134 optional :input_token_details, -> { OpenAI::Realtime::ConversationItemInputAudioTranscriptionCompletedEvent::Usage::TranscriptTextUsageTokens::InputTokenDetails } |
#input_tokens ⇒ Integer
Number of input tokens billed for this request.
110 |
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_completed_event.rb', line 110 required :input_tokens, Integer |
#output_tokens ⇒ Integer
Number of output tokens generated.
116 |
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_completed_event.rb', line 116 required :output_tokens, Integer |
#total_tokens ⇒ Integer
Total number of tokens used (input + output).
122 |
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_completed_event.rb', line 122 required :total_tokens, Integer |
#type ⇒ Symbol, :tokens
The type of the usage object. Always tokens for this variant.
128 |
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_completed_event.rb', line 128 required :type, const: :tokens |
Instance Method Details
#to_hash ⇒ {
98 |
# File 'sig/openai/models/realtime/conversation_item_input_audio_transcription_completed_event.rbs', line 98
def to_hash: -> {
|