Class: OpenAI::Models::Realtime::ConversationItemInputAudioTranscriptionFailedEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/conversation_item_input_audio_transcription_failed_event.rb,
sig/openai/models/realtime/conversation_item_input_audio_transcription_failed_event.rbs

Defined Under Namespace

Classes: Error

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content_index:, error:, event_id:, item_id:, type: :"conversation.item.input_audio_transcription.failed") ⇒ Object

Parameters:

  • content_index —

    The index of the content part containing the audio.

  • error —

    Details of the transcription error.

  • event_id —

    The unique ID of the server event.

  • item_id —

    The ID of the user message item.

  • type (defaults to: :"conversation.item.input_audio_transcription.failed") —

    The event type, must be conversation.item.input_audio_transcription.failed.



# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_failed_event.rb', line 37

Instance Attribute Details

#content_index ⇒ Integer

The index of the content part containing the audio.

Returns:

  • (Integer)


11
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_failed_event.rb', line 11

required :content_index, Integer

#error ⇒ OpenAI::Realtime::ConversationItemInputAudioTranscriptionFailedEvent::Error

Details of the transcription error.

Returns:

  • (OpenAI::Realtime::ConversationItemInputAudioTranscriptionFailedEvent::Error)


17
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_failed_event.rb', line 17

required :error, -> { OpenAI::Realtime::ConversationItemInputAudioTranscriptionFailedEvent::Error }

#event_id ⇒ String

The unique ID of the server event.

Returns:

  • (String)


23
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_failed_event.rb', line 23

required :event_id, String

#item_id ⇒ String

The ID of the user message item.

Returns:

  • (String)


29
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_failed_event.rb', line 29

required :item_id, String

#type ⇒ :"conversation.item.input_audio_transcription.failed"

The event type, must be conversation.item.input_audio_transcription.failed.

Returns:

  • (:"conversation.item.input_audio_transcription.failed")


35
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_failed_event.rb', line 35

required :type, const: :"conversation.item.input_audio_transcription.failed"

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


47
# File 'sig/openai/models/realtime/conversation_item_input_audio_transcription_failed_event.rbs', line 47

def to_hash: -> {