Class: OpenAI::Models::Realtime::ConversationItemInputAudioTranscriptionSegment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/conversation_item_input_audio_transcription_segment.rb,
sig/openai/models/realtime/conversation_item_input_audio_transcription_segment.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, content_index:, end_:, event_id:, item_id:, speaker:, start:, text:, type: :"conversation.item.input_audio_transcription.segment") ⇒ Object

Parameters:

  • id —

    The segment identifier.

  • content_index —

    The index of the input audio content part within the item.

  • end_ —

    End time of the segment in seconds.

  • event_id —

    The unique ID of the server event.

  • item_id —

    The ID of the item containing the input audio content.

  • speaker —

    The detected speaker label for this segment.

  • start —

    Start time of the segment in seconds.

  • text —

    The text for this segment.

  • type (defaults to: :"conversation.item.input_audio_transcription.segment") —

    The event type, must be conversation.item.input_audio_transcription.segment.



# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_segment.rb', line 61

Instance Attribute Details

#content_index ⇒ Integer

The index of the input audio content part within the item.

Returns:

  • (Integer)


17
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_segment.rb', line 17

required :content_index, Integer

#end_ ⇒ Float

End time of the segment in seconds.

Returns:

  • (Float)


23
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_segment.rb', line 23

required :end_, Float, api_name: :end

#event_id ⇒ String

The unique ID of the server event.

Returns:

  • (String)


29
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_segment.rb', line 29

required :event_id, String

#id ⇒ String

The segment identifier.

Returns:

  • (String)


11
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_segment.rb', line 11

required :id, String

#item_id ⇒ String

The ID of the item containing the input audio content.

Returns:

  • (String)


35
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_segment.rb', line 35

required :item_id, String

#speaker ⇒ String

The detected speaker label for this segment.

Returns:

  • (String)


41
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_segment.rb', line 41

required :speaker, String

#start ⇒ Float

Start time of the segment in seconds.

Returns:

  • (Float)


47
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_segment.rb', line 47

required :start, Float

#text ⇒ String

The text for this segment.

Returns:

  • (String)


53
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_segment.rb', line 53

required :text, String

#type ⇒ :"conversation.item.input_audio_transcription.segment"

The event type, must be conversation.item.input_audio_transcription.segment.

Returns:

  • (:"conversation.item.input_audio_transcription.segment")


59
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_segment.rb', line 59

required :type, const: :"conversation.item.input_audio_transcription.segment"

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


75
# File 'sig/openai/models/realtime/conversation_item_input_audio_transcription_segment.rbs', line 75

def to_hash: -> {