Class: OpenAI::Models::Realtime::InputAudioBufferAppendEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/input_audio_buffer_append_event.rb,
sig/openai/models/realtime/input_audio_buffer_append_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(audio:, event_id: nil, type: :"input_audio_buffer.append") ⇒ Object

Parameters:

  • audio —

    Base64-encoded audio bytes. This must be in the format specified by the input_audio_format field in the session configuration.

  • event_id (defaults to: nil) —

    Optional client-generated ID used to identify this event.

  • type (defaults to: :"input_audio_buffer.append") —

    The event type, must be input_audio_buffer.append.



# File 'lib/openai/models/realtime/input_audio_buffer_append_event.rb', line 26

Instance Attribute Details

#audio ⇒ String

Base64-encoded audio bytes. This must be in the format specified by the input_audio_format field in the session configuration.

Returns:

  • (String)


12
# File 'lib/openai/models/realtime/input_audio_buffer_append_event.rb', line 12

required :audio, String

#event_id ⇒ String?

Optional client-generated ID used to identify this event.

Returns:

  • (String, nil)


24
# File 'lib/openai/models/realtime/input_audio_buffer_append_event.rb', line 24

optional :event_id, String

#type ⇒ :"input_audio_buffer.append"

The event type, must be input_audio_buffer.append.

Returns:

  • (:"input_audio_buffer.append")


18
# File 'lib/openai/models/realtime/input_audio_buffer_append_event.rb', line 18

required :type, const: :"input_audio_buffer.append"

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


38
# File 'sig/openai/models/realtime/input_audio_buffer_append_event.rbs', line 38

def to_hash: -> {