Class: OpenAI::Models::Realtime::InputAudioBufferCommitEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::InputAudioBufferCommitEvent
- Defined in:
- lib/openai/models/realtime/input_audio_buffer_commit_event.rb
Instance Attribute Summary collapse
-
#event_id ⇒ String?
Optional client-generated ID used to identify this event.
-
#type ⇒ Symbol, :"input_audio_buffer.commit"
The event type, must be
input_audio_buffer.commit.
Instance Method Summary collapse
-
#initialize(event_id: nil, type: :"input_audio_buffer.commit") ⇒ Object
constructor
Send this event to commit the user input audio buffer, which will create a new user message item in the conversation.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(event_id: nil, type: :"input_audio_buffer.commit") ⇒ Object
Send this event to commit the user input audio buffer, which will create a new user message item in the conversation. This event will produce an error if the input audio buffer is empty. When in Server VAD mode, the client does not need to send this event, the server will commit the audio buffer automatically.
Committing the input audio buffer will trigger input audio transcription (if enabled in session configuration), but it will not create a response from the model. The server will respond with an input_audio_buffer.committed event.
|
|
# File 'lib/openai/models/realtime/input_audio_buffer_commit_event.rb', line 19
|
Instance Attribute Details
#event_id ⇒ String?
Optional client-generated ID used to identify this event.
17 |
# File 'lib/openai/models/realtime/input_audio_buffer_commit_event.rb', line 17 optional :event_id, String |
#type ⇒ Symbol, :"input_audio_buffer.commit"
The event type, must be input_audio_buffer.commit.
11 |
# File 'lib/openai/models/realtime/input_audio_buffer_commit_event.rb', line 11 required :type, const: :"input_audio_buffer.commit" |