Class: OpenAI::Models::Realtime::InputAudioBufferCommittedEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/input_audio_buffer_committed_event.rb,
sig/openai/models/realtime/input_audio_buffer_committed_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_id:, item_id:, previous_item_id: nil, type: :"input_audio_buffer.committed") ⇒ Object

Parameters:

  • event_id —

    The unique ID of the server event.

  • item_id —

    The ID of the user message item that will be created.

  • previous_item_id (defaults to: nil) —

    The ID of the preceding item after which the new item will be inserted. Can be null if the item has no predecessor.

  • type (defaults to: :"input_audio_buffer.committed") —

    The event type, must be input_audio_buffer.committed.



# File 'lib/openai/models/realtime/input_audio_buffer_committed_event.rb', line 32

Instance Attribute Details

#event_id ⇒ String

The unique ID of the server event.

Returns:

  • (String)


11
# File 'lib/openai/models/realtime/input_audio_buffer_committed_event.rb', line 11

required :event_id, String

#item_id ⇒ String

The ID of the user message item that will be created.

Returns:

  • (String)


17
# File 'lib/openai/models/realtime/input_audio_buffer_committed_event.rb', line 17

required :item_id, String

#previous_item_id ⇒ String?

The ID of the preceding item after which the new item will be inserted. Can be null if the item has no predecessor.

Returns:

  • (String, nil)


30
# File 'lib/openai/models/realtime/input_audio_buffer_committed_event.rb', line 30

optional :previous_item_id, String, nil?: true

#type ⇒ :"input_audio_buffer.committed"

The event type, must be input_audio_buffer.committed.

Returns:

  • (:"input_audio_buffer.committed")


23
# File 'lib/openai/models/realtime/input_audio_buffer_committed_event.rb', line 23

required :type, const: :"input_audio_buffer.committed"

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


42
# File 'sig/openai/models/realtime/input_audio_buffer_committed_event.rbs', line 42

def to_hash: -> {