Class: OpenAI::Models::Realtime::LogProbProperties
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::LogProbProperties
- Defined in:
- lib/openai/models/realtime/log_prob_properties.rb,
sig/openai/models/realtime/log_prob_properties.rbs
Instance Attribute Summary collapse
-
#bytes ⇒ ::Array[Integer]
The bytes that were used to generate the log probability.
-
#logprob ⇒ Float
The log probability of the token.
-
#token ⇒ String
The token that was used to generate the log probability.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(token:, bytes:, logprob:) ⇒ Object
|
|
# File 'lib/openai/models/realtime/log_prob_properties.rb', line 25
|
Instance Attribute Details
#bytes ⇒ ::Array[Integer]
The bytes that were used to generate the log probability.
17 |
# File 'lib/openai/models/realtime/log_prob_properties.rb', line 17 required :bytes, OpenAI::Internal::Type::ArrayOf[Integer] |
#logprob ⇒ Float
The log probability of the token.
23 |
# File 'lib/openai/models/realtime/log_prob_properties.rb', line 23 required :logprob, Float |
#token ⇒ String
The token that was used to generate the log probability.
11 |
# File 'lib/openai/models/realtime/log_prob_properties.rb', line 11 required :token, String |
Instance Method Details
#to_hash ⇒ {
29 |
# File 'sig/openai/models/realtime/log_prob_properties.rbs', line 29
def to_hash: -> {
|