Class: OpenAI::Models::Realtime::RealtimeAudioConfig::Input::TurnDetection

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_audio_config.rb

Overview

See Also:

Defined Under Namespace

Modules: Eagerness, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(create_response: nil, eagerness: nil, idle_timeout_ms: nil, interrupt_response: nil, prefix_padding_ms: nil, silence_duration_ms: nil, threshold: nil, type: nil) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeAudioConfig::Input::TurnDetection for more details.

Configuration for turn detection, ether Server VAD or Semantic VAD. This can be set to ‘null` to turn off, in which case the client must manually trigger model response. Server VAD means that the model will detect the start and end of speech based on audio volume and respond at the end of user speech. Semantic VAD is more advanced and uses a turn detection model (in conjunction with VAD) to semantically estimate whether the user has finished speaking, then dynamically sets a timeout based on this probability. For example, if user audio trails off with “uhhm”, the model will score a low probability of turn end and wait longer for the user to continue speaking. This can be useful for more natural conversations, but may have a higher latency.

Parameters:

  • create_response (Boolean) (defaults to: nil)

    Whether or not to automatically generate a response when a VAD stop event occurs

  • eagerness (Symbol, OpenAI::Models::Realtime::RealtimeAudioConfig::Input::TurnDetection::Eagerness) (defaults to: nil)

    Used only for ‘semantic_vad` mode. The eagerness of the model to respond. `low`

  • idle_timeout_ms (Integer, nil) (defaults to: nil)

    Optional idle timeout after which turn detection will auto-timeout when

  • interrupt_response (Boolean) (defaults to: nil)

    Whether or not to automatically interrupt any ongoing response with output to th

  • prefix_padding_ms (Integer) (defaults to: nil)

    Used only for ‘server_vad` mode. Amount of audio to include before the VAD detec

  • silence_duration_ms (Integer) (defaults to: nil)

    Used only for ‘server_vad` mode. Duration of silence to detect speech stop (in m

  • threshold (Float) (defaults to: nil)

    Used only for ‘server_vad` mode. Activation threshold for VAD (0.0 to 1.0), this

  • type (Symbol, OpenAI::Models::Realtime::RealtimeAudioConfig::Input::TurnDetection::Type) (defaults to: nil)

    Type of turn detection.



# File 'lib/openai/models/realtime/realtime_audio_config.rb', line 270

Instance Attribute Details

#create_responseBoolean?

Whether or not to automatically generate a response when a VAD stop event occurs.

Returns:



216
# File 'lib/openai/models/realtime/realtime_audio_config.rb', line 216

optional :create_response, OpenAI::Internal::Type::Boolean

#eagernessSymbol, ...

Used only for ‘semantic_vad` mode. The eagerness of the model to respond. `low` will wait longer for the user to continue speaking, `high` will respond more quickly. `auto` is the default and is equivalent to `medium`.



224
# File 'lib/openai/models/realtime/realtime_audio_config.rb', line 224

optional :eagerness, enum: -> { OpenAI::Realtime::RealtimeAudioConfig::Input::TurnDetection::Eagerness }

#idle_timeout_msInteger?

Optional idle timeout after which turn detection will auto-timeout when no additional audio is received.

Returns:

  • (Integer, nil)


231
# File 'lib/openai/models/realtime/realtime_audio_config.rb', line 231

optional :idle_timeout_ms, Integer, nil?: true

#interrupt_responseBoolean?

Whether or not to automatically interrupt any ongoing response with output to the default conversation (i.e. ‘conversation` of `auto`) when a VAD start event occurs.

Returns:



239
# File 'lib/openai/models/realtime/realtime_audio_config.rb', line 239

optional :interrupt_response, OpenAI::Internal::Type::Boolean

#prefix_padding_msInteger?

Used only for ‘server_vad` mode. Amount of audio to include before the VAD detected speech (in milliseconds). Defaults to 300ms.

Returns:

  • (Integer, nil)


246
# File 'lib/openai/models/realtime/realtime_audio_config.rb', line 246

optional :prefix_padding_ms, Integer

#silence_duration_msInteger?

Used only for ‘server_vad` mode. Duration of silence to detect speech stop (in milliseconds). Defaults to 500ms. With shorter values the model will respond more quickly, but may jump in on short pauses from the user.

Returns:

  • (Integer, nil)


254
# File 'lib/openai/models/realtime/realtime_audio_config.rb', line 254

optional :silence_duration_ms, Integer

#thresholdFloat?

Used only for ‘server_vad` mode. Activation threshold for VAD (0.0 to 1.0), this defaults to 0.5. A higher threshold will require louder audio to activate the model, and thus might perform better in noisy environments.

Returns:

  • (Float, nil)


262
# File 'lib/openai/models/realtime/realtime_audio_config.rb', line 262

optional :threshold, Float

#typeSymbol, ...

Type of turn detection.



268
# File 'lib/openai/models/realtime/realtime_audio_config.rb', line 268

optional :type, enum: -> { OpenAI::Realtime::RealtimeAudioConfig::Input::TurnDetection::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/realtime/realtime_audio_config.rb', line 315