Class: OpenAI::Models::Realtime::RealtimeAudioConfig::Output

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_audio_config.rb

Overview

See Also:

Defined Under Namespace

Modules: Format, Voice

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(format_: nil, speed: nil, voice: nil) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeAudioConfig::Output for more details.

Parameters:



# File 'lib/openai/models/realtime/realtime_audio_config.rb', line 364

Instance Attribute Details

#format_Symbol, ...

The format of output audio. Options are ‘pcm16`, `g711_ulaw`, or `g711_alaw`. For `pcm16`, output audio is sampled at a rate of 24kHz.



341
342
343
344
345
# File 'lib/openai/models/realtime/realtime_audio_config.rb', line 341

optional :format_,
enum: -> {
  OpenAI::Realtime::RealtimeAudioConfig::Output::Format
},
api_name: :format

#speedFloat?

The speed of the model’s spoken response. 1.0 is the default speed. 0.25 is the minimum speed. 1.5 is the maximum speed. This value can only be changed in between model turns, not while a response is in progress.

Returns:

  • (Float, nil)


353
# File 'lib/openai/models/realtime/realtime_audio_config.rb', line 353

optional :speed, Float

#voiceString, ...

The voice the model uses to respond. Voice cannot be changed during the session once the model has responded with audio at least once. Current voice options are ‘alloy`, `ash`, `ballad`, `coral`, `echo`, `sage`, `shimmer`, `verse`, `marin`, and `cedar`.



362
# File 'lib/openai/models/realtime/realtime_audio_config.rb', line 362

optional :voice, union: -> { OpenAI::Realtime::RealtimeAudioConfig::Output::Voice }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/realtime/realtime_audio_config.rb', line 385