Class: OpenAI::Models::Realtime::RealtimeAudioConfigInput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeAudioConfigInput
- Defined in:
- lib/openai/models/realtime/realtime_audio_config_input.rb,
sig/openai/models/realtime/realtime_audio_config_input.rbs
Defined Under Namespace
Classes: NoiseReduction
Instance Attribute Summary collapse
-
#format_ ⇒ OpenAI::Models::Realtime::RealtimeAudioFormats::AudioPCM, ...
The format of the input audio.
-
#noise_reduction ⇒ OpenAI::Models::Realtime::RealtimeAudioConfigInput::NoiseReduction?
Configuration for input audio noise reduction.
-
#transcription ⇒ OpenAI::Models::Realtime::AudioTranscription?
Configuration for input audio transcription, defaults to off and can be set to
nullto turn off once on. -
#turn_detection ⇒ OpenAI::Models::Realtime::RealtimeAudioInputTurnDetection::ServerVad, ...
Configuration for turn detection, ether Server VAD or Semantic VAD.
Instance Method Summary collapse
-
#initialize(format_: nil, noise_reduction: nil, transcription: nil, turn_detection: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RealtimeAudioConfigInput for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(format_: nil, noise_reduction: nil, transcription: nil, turn_detection: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeAudioConfigInput for more details.
|
|
# File 'lib/openai/models/realtime/realtime_audio_config_input.rb', line 57
|
Instance Attribute Details
#format_ ⇒ OpenAI::Models::Realtime::RealtimeAudioFormats::AudioPCM, ...
The format of the input audio.
11 |
# File 'lib/openai/models/realtime/realtime_audio_config_input.rb', line 11 optional :format_, union: -> { OpenAI::Realtime::RealtimeAudioFormats }, api_name: :format |
#noise_reduction ⇒ OpenAI::Models::Realtime::RealtimeAudioConfigInput::NoiseReduction?
Configuration for input audio noise reduction. This can be set to null to turn
off. Noise reduction filters audio added to the input audio buffer before it is
sent to VAD and the model. Filtering the audio can improve VAD and turn
detection accuracy (reducing false positives) and model performance by improving
perception of the input audio.
21 |
# File 'lib/openai/models/realtime/realtime_audio_config_input.rb', line 21 optional :noise_reduction, -> { OpenAI::Realtime::RealtimeAudioConfigInput::NoiseReduction } |
#transcription ⇒ OpenAI::Models::Realtime::AudioTranscription?
Configuration for input audio transcription, defaults to off and can be set to
null to turn off once on. Input audio transcription is not native to the
model, since the model consumes audio directly. Transcription runs
asynchronously through
the /audio/transcriptions endpoint
and should be treated as guidance of input audio content rather than precisely
what the model heard. The client can optionally set the language and prompt for
transcription, these offer additional guidance to the transcription service.
34 |
# File 'lib/openai/models/realtime/realtime_audio_config_input.rb', line 34 optional :transcription, -> { OpenAI::Realtime::AudioTranscription } |
#turn_detection ⇒ OpenAI::Models::Realtime::RealtimeAudioInputTurnDetection::ServerVad, ...
Configuration for turn detection, ether Server VAD or Semantic VAD. This can be
set to null to turn off, in which case the client must manually trigger model
response.
Server VAD means that the model will detect the start and end of speech based on audio volume and respond at the end of user speech.
Semantic VAD is more advanced and uses a turn detection model (in conjunction with VAD) to semantically estimate whether the user has finished speaking, then dynamically sets a timeout based on this probability. For example, if user audio trails off with "uhhm", the model will score a low probability of turn end and wait longer for the user to continue speaking. This can be useful for more natural conversations, but may have a higher latency.
For gpt-realtime-whisper transcription sessions, turn detection must be set to
null; VAD is not supported.
55 |
# File 'lib/openai/models/realtime/realtime_audio_config_input.rb', line 55 optional :turn_detection, union: -> { OpenAI::Realtime::RealtimeAudioInputTurnDetection }, nil?: true |
Instance Method Details
#to_hash ⇒ {
40 |
# File 'sig/openai/models/realtime/realtime_audio_config_input.rbs', line 40
def to_hash: -> {
|