Class: OpenAI::Models::Realtime::RealtimeAudioConfigInput::NoiseReduction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_audio_config_input.rb,
sig/openai/models/realtime/realtime_audio_config_input.rbs

Overview

See Also:

  • OpenAI::Models::Realtime::RealtimeAudioConfigInput#noise_reduction

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type: nil) ⇒ Object

Parameters:

  • type (defaults to: nil) —

    Type of noise reduction. near_field is for close-talking microphones such as headphones, far_field is for far-field microphones such as laptop or conference room microphones.



# File 'lib/openai/models/realtime/realtime_audio_config_input.rb', line 106

Instance Attribute Details

#type ⇒ OpenAI::Models::Realtime::noise_reduction_type?

Type of noise reduction. near_field is for close-talking microphones such as headphones, far_field is for far-field microphones such as laptop or conference room microphones.

Returns:

  • (OpenAI::Models::Realtime::noise_reduction_type, nil)


104
# File 'lib/openai/models/realtime/realtime_audio_config_input.rb', line 104

optional :type, enum: -> { OpenAI::Realtime::NoiseReductionType }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


149
# File 'sig/openai/models/realtime/realtime_audio_config_input.rbs', line 149

def to_hash: -> {