Module: OpenAI::Models::Realtime::RealtimeAudioInputTurnDetection

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/realtime/realtime_audio_input_turn_detection.rb

Overview

Configuration for turn detection, ether Server VAD or Semantic VAD. This can be set to null to turn off, in which case the client must manually trigger model response.

Server VAD means that the model will detect the start and end of speech based on audio volume and respond at the end of user speech.

Semantic VAD is more advanced and uses a turn detection model (in conjunction with VAD) to semantically estimate whether the user has finished speaking, then dynamically sets a timeout based on this probability. For example, if user audio trails off with “uhhm”, the model will score a low probability of turn end and wait longer for the user to continue speaking. This can be useful for more natural conversations, but may have a higher latency.

Defined Under Namespace

Classes: SemanticVad, ServerVad

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.variantsArray(OpenAI::Models::Realtime::RealtimeAudioInputTurnDetection::ServerVad, OpenAI::Models::Realtime::RealtimeAudioInputTurnDetection::SemanticVad)



# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 190


Instance Method Details

#initialize(create_response: nil, idle_timeout_ms: nil, interrupt_response: nil, prefix_padding_ms: nil, silence_duration_ms: nil, threshold: nil, type: :server_vad) ⇒ Object

Some parameter documentations has been truncated, see ServerVad for more details.

Server-side voice activity detection (VAD) which flips on when user speech is detected and off after a period of silence.



# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 100