Class: OpenAI::Models::Realtime::RealtimeAudioInputTurnDetection::SemanticVad

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_audio_input_turn_detection.rb

Defined Under Namespace

Modules: Eagerness

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(create_response: nil, eagerness: nil, interrupt_response: nil, type: :semantic_vad) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeAudioInputTurnDetection::SemanticVad for more details.

Server-side semantic turn detection which uses a model to determine when the user has finished speaking.

Parameters:

  • (defaults to: nil)

    Whether or not to automatically generate a response when a VAD stop event occurs

  • (defaults to: nil)

    Used only for semantic_vad mode. The eagerness of the model to respond. low

  • (defaults to: nil)

    Whether or not to automatically interrupt any ongoing response with output to th

  • (defaults to: :semantic_vad)

    Type of turn detection, semantic_vad to turn on Semantic VAD.



# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 155


Instance Attribute Details

#create_responseBoolean?

Whether or not to automatically generate a response when a VAD stop event occurs.

Returns:



135
# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 135

optional :create_response, OpenAI::Internal::Type::Boolean

#eagernessSymbol, ...

Used only for semantic_vad mode. The eagerness of the model to respond. low will wait longer for the user to continue speaking, high will respond more quickly. auto is the default and is equivalent to medium. low, medium, and high have max timeouts of 8s, 4s, and 2s respectively.

Returns:



144
145
# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 144

optional :eagerness,
enum: -> { OpenAI::Realtime::RealtimeAudioInputTurnDetection::SemanticVad::Eagerness }

#interrupt_responseBoolean?

Whether or not to automatically interrupt any ongoing response with output to the default conversation (i.e. conversation of auto) when a VAD start event occurs.

Returns:



153
# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 153

optional :interrupt_response, OpenAI::Internal::Type::Boolean

#typeSymbol, :semantic_vad

Type of turn detection, semantic_vad to turn on Semantic VAD.

Returns:



128
# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 128

required :type, const: :semantic_vad