Module: OpenAI::Models::Realtime::RealtimeAudioInputTurnDetection::SemanticVad::Eagerness

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/realtime/realtime_audio_input_turn_detection.rb

Overview

Used only for semantic_vad mode. The eagerness of the model to respond. low will wait longer for the user to continue speaking, high will respond more quickly. auto is the default and is equivalent to medium. low, medium, and high have max timeouts of 8s, 4s, and 2s respectively.

See Also:

Constant Summary collapse

LOW =
:low
MEDIUM =
:medium
HIGH =
:high
AUTO =
:auto

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:



# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 185