Class: OpenAI::Models::Realtime::RealtimeClientSecretConfig::ExpiresAfter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeClientSecretConfig::ExpiresAfter
- Defined in:
- lib/openai/models/realtime/realtime_client_secret_config.rb
Overview
Defined Under Namespace
Modules: Anchor
Instance Attribute Summary collapse
-
#anchor ⇒ Symbol, OpenAI::Models::Realtime::RealtimeClientSecretConfig::ExpiresAfter::Anchor
The anchor point for the ephemeral token expiration.
-
#seconds ⇒ Integer?
The number of seconds from the anchor point to the expiration.
Instance Method Summary collapse
-
#initialize(anchor: , seconds: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExpiresAfter for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(anchor: , seconds: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeClientSecretConfig::ExpiresAfter for more details.
Configuration for the ephemeral token expiration.
|
|
# File 'lib/openai/models/realtime/realtime_client_secret_config.rb', line 37
|
Instance Attribute Details
#anchor ⇒ Symbol, OpenAI::Models::Realtime::RealtimeClientSecretConfig::ExpiresAfter::Anchor
The anchor point for the ephemeral token expiration. Only ‘created_at` is currently supported.
28 |
# File 'lib/openai/models/realtime/realtime_client_secret_config.rb', line 28 required :anchor, enum: -> { OpenAI::Realtime::RealtimeClientSecretConfig::ExpiresAfter::Anchor } |
#seconds ⇒ Integer?
The number of seconds from the anchor point to the expiration. Select a value between ‘10` and `7200`.
35 |
# File 'lib/openai/models/realtime/realtime_client_secret_config.rb', line 35 optional :seconds, Integer |