Class: OpenAI::Models::Realtime::RealtimeConversationItemFunctionCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb,
sig/openai/models/realtime/realtime_conversation_item_function_call_output.rbs

Defined Under Namespace

Modules: Object, Status

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_id:, output:, id: nil, object: nil, status: nil, type: :function_call_output) ⇒ Object

Parameters:

  • call_id —

    The ID of the function call this output is for.

  • output —

    The output of the function call, this is free text and can contain any information or simply be empty.

  • id (defaults to: nil) —

    The unique ID of the item. This may be provided by the client or generated by the server.

  • object (defaults to: nil) —

    Identifier for the API object being returned - always realtime.item. Optional when creating a new item.

  • status (defaults to: nil) —

    The status of the item. Has no effect on the conversation.

  • type (defaults to: :function_call_output) —

    The type of the item. Always function_call_output.



# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 46

Instance Attribute Details

#call_id ⇒ String

The ID of the function call this output is for.

Returns:

  • (String)


11
# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 11

required :call_id, String

#id ⇒ String?

The unique ID of the item. This may be provided by the client or generated by the server.

Returns:

  • (String, nil)


31
# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 31

optional :id, String

#object ⇒ OpenAI::Models::Realtime::RealtimeConversationItemFunctionCallOutput::object?

Identifier for the API object being returned - always realtime.item. Optional when creating a new item.

Returns:

  • (OpenAI::Models::Realtime::RealtimeConversationItemFunctionCallOutput::object, nil)


38
# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 38

optional :object, enum: -> { OpenAI::Realtime::RealtimeConversationItemFunctionCallOutput::Object }

#output ⇒ String

The output of the function call, this is free text and can contain any information or simply be empty.

Returns:

  • (String)


18
# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 18

required :output, String

#status ⇒ OpenAI::Models::Realtime::RealtimeConversationItemFunctionCallOutput::status?

The status of the item. Has no effect on the conversation.

Returns:

  • (OpenAI::Models::Realtime::RealtimeConversationItemFunctionCallOutput::status, nil)


44
# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 44

optional :status, enum: -> { OpenAI::Realtime::RealtimeConversationItemFunctionCallOutput::Status }

#type ⇒ :function_call_output

The type of the item. Always function_call_output.

Returns:

  • (:function_call_output)


24
# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 24

required :type, const: :function_call_output

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 79

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


75
# File 'sig/openai/models/realtime/realtime_conversation_item_function_call_output.rbs', line 75

def to_hash: -> {