Module: OpenAI::Models::Realtime::RealtimeResponseCreateParams::Conversation

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/realtime/realtime_response_create_params.rb

Overview

Controls which conversation the response is added to. Currently supports auto and none, with auto as the default value. The auto value means that the contents of the response will be added to the default conversation. Set this to none to create an out-of-band response which will not add items to default conversation.

See Also:

collapse

AUTO =
:auto
NONE =
:none

Class Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.variantsArray(String, Symbol)

Returns:

  • (Array(String, Symbol))


142
143
144
# File 'lib/openai/models/realtime/realtime_response_create_params.rb', line 142

define_sorbet_constant!(:Variants) do
  T.type_alias { T.any(String, OpenAI::Realtime::RealtimeResponseCreateParams::Conversation::TaggedSymbol) }
end