Module: OpenAI::Models::Realtime::RealtimeSession::Include

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/realtime/realtime_session.rb

Constant Summary collapse

ITEM_INPUT_AUDIO_TRANSCRIPTION_LOGPROBS =
:"item.input_audio_transcription.logprobs"

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(id: nil, expires_at: nil, include: nil, input_audio_format: nil, input_audio_noise_reduction: nil, input_audio_transcription: nil, instructions: nil, max_response_output_tokens: nil, modalities: nil, model: nil, object: nil, output_audio_format: nil, prompt: nil, speed: nil, temperature: nil, tool_choice: nil, tools: nil, tracing: nil, turn_detection: nil, voice: nil) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeSession for more details.

Realtime session object for the beta interface.

Parameters:

  • (defaults to: nil)

    Unique identifier for the session that looks like sess_1234567890abcdef.

  • (defaults to: nil)

    Expiration timestamp for the session, in seconds since epoch.

  • (defaults to: nil)

    Additional fields to include in server outputs.

  • (defaults to: nil)

    The format of input audio. Options are pcm16, g711_ulaw, or g711_alaw.

  • (defaults to: nil)

    Configuration for input audio noise reduction. This can be set to null to turn

  • (defaults to: nil)

    Configuration for input audio transcription, defaults to off and can be set to ‘

  • (defaults to: nil)

    The default system instructions (i.e. system message) prepended to model

  • (defaults to: nil)

    Maximum number of output tokens for a single assistant response,

  • (defaults to: nil)

    The set of modalities the model can respond with. To disable audio,

  • (defaults to: nil)

    The Realtime model used for this session.

  • (defaults to: nil)

    The object type. Always realtime.session.

  • (defaults to: nil)

    The format of output audio. Options are pcm16, g711_ulaw, or g711_alaw.

  • (defaults to: nil)

    Reference to a prompt template and its variables.

  • (defaults to: nil)

    The speed of the model’s spoken response. 1.0 is the default speed. 0.25 is

  • (defaults to: nil)

    Sampling temperature for the model, limited to [0.6, 1.2]. For audio models a te

  • (defaults to: nil)

    How the model chooses tools. Options are auto, none, required, or

  • (defaults to: nil)

    Tools (functions) available to the model.

  • (defaults to: nil)

    Configuration options for tracing. Set to null to disable tracing. Once

  • (defaults to: nil)

    Configuration for turn detection, ether Server VAD or Semantic VAD. This can be

  • (defaults to: nil)

    The voice the model uses to respond. Voice cannot be changed during the



230
231
232
233
234
235
236
237
# File 'lib/openai/models/realtime/realtime_session.rb', line 230

module Include
  extend OpenAI::Internal::Type::Enum

  ITEM_INPUT_AUDIO_TRANSCRIPTION_LOGPROBS = :"item.input_audio_transcription.logprobs"

  # @!method self.values
  #   @return [Array<Symbol>]
end