Module: OpenAI::Models::Realtime::RealtimeSession::Tracing

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/realtime/realtime_session.rb,
sig/openai/models/realtime/realtime_session.rbs

Overview

Configuration options for tracing. Set to null to disable tracing. Once tracing is enabled for a session, the configuration cannot be modified.

auto will create a trace for the session with default values for the workflow name, group id, and metadata.

See Also:

  • OpenAI::Models::Realtime::RealtimeSession#tracing

Defined Under Namespace

Classes: TracingConfiguration

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.variants::Array[OpenAI::Models::Realtime::RealtimeSession::tracing]

Returns:

  • (::Array[OpenAI::Models::Realtime::RealtimeSession::tracing])


323
# File 'sig/openai/models/realtime/realtime_session.rbs', line 323

def self?.variants: -> ::Array[OpenAI::Models::Realtime::RealtimeSession::tracing]