Class: OpenAI::Models::Realtime::RealtimeSession::Tracing::TracingConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeSession::Tracing::TracingConfiguration
- Defined in:
- lib/openai/models/realtime/realtime_session.rb,
sig/openai/models/realtime/realtime_session.rbs
Instance Attribute Summary collapse
-
#group_id ⇒ String?
The group id to attach to this trace to enable filtering and grouping in the traces dashboard.
-
#metadata ⇒ Object?
The arbitrary metadata to attach to this trace to enable filtering in the traces dashboard.
-
#workflow_name ⇒ String?
The name of the workflow to attach to this trace.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
310 |
# File 'sig/openai/models/realtime/realtime_session.rbs', line 310
def initialize: (
|
Instance Attribute Details
#group_id ⇒ String?
The group id to attach to this trace to enable filtering and grouping in the traces dashboard.
426 |
# File 'lib/openai/models/realtime/realtime_session.rb', line 426 optional :group_id, String |
#metadata ⇒ Object?
The arbitrary metadata to attach to this trace to enable filtering in the traces dashboard.
433 |
# File 'lib/openai/models/realtime/realtime_session.rb', line 433 optional :metadata, OpenAI::Internal::Type::Unknown |
#workflow_name ⇒ String?
The name of the workflow to attach to this trace. This is used to name the trace in the traces dashboard.
440 |
# File 'lib/openai/models/realtime/realtime_session.rb', line 440 optional :workflow_name, String |
Instance Method Details
#to_hash ⇒ {
316 |
# File 'sig/openai/models/realtime/realtime_session.rbs', line 316
def to_hash: -> {
|