Module: OpenAI::Models::Realtime::RealtimeSession::TurnDetection::SemanticVad::Eagerness
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/realtime/realtime_session.rb,
sig/openai/models/realtime/realtime_session.rbs
Overview
Used only for semantic_vad mode. The eagerness of the model to respond. low
will wait longer for the user to continue speaking, high will respond more
quickly. auto is the default and is equivalent to medium. low, medium,
and high have max timeouts of 8s, 4s, and 2s respectively.
Constant Summary collapse
- LOW =
:low- MEDIUM =
:medium- HIGH =
:high- AUTO =
:auto
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[OpenAI::Models::Realtime::RealtimeSession::TurnDetection::SemanticVad::eagerness]
439 |
# File 'sig/openai/models/realtime/realtime_session.rbs', line 439
def self?.values: -> ::Array[OpenAI::Models::Realtime::RealtimeSession::TurnDetection::SemanticVad::eagerness]
|