Class: OpenAI::Models::Realtime::RealtimeSession::TurnDetection::ServerVad
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeSession::TurnDetection::ServerVad
- Defined in:
- lib/openai/models/realtime/realtime_session.rb
Instance Attribute Summary collapse
-
#create_response ⇒ Boolean?
Whether or not to automatically generate a response when a VAD stop event occurs.
-
#idle_timeout_ms ⇒ Integer?
Optional timeout after which a model response will be triggered automatically.
-
#interrupt_response ⇒ Boolean?
Whether or not to automatically interrupt (cancel) any ongoing response with output to the default conversation (i.e.
conversationofauto) when a VAD start event occurs. -
#prefix_padding_ms ⇒ Integer?
Used only for
server_vadmode. -
#silence_duration_ms ⇒ Integer?
Used only for
server_vadmode. -
#threshold ⇒ Float?
Used only for
server_vadmode. -
#type ⇒ Symbol, :server_vad
Type of turn detection,
server_vadto turn on simple Server VAD.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#create_response ⇒ Boolean?
Whether or not to automatically generate a response when a VAD stop event occurs. If interrupt_response is set to false this may fail to create a response if the model is already responding.
If both create_response and interrupt_response are set to false, the model will never respond automatically but VAD events will still be emitted.
499 |
# File 'lib/openai/models/realtime/realtime_session.rb', line 499 optional :create_response, OpenAI::Internal::Type::Boolean |
#idle_timeout_ms ⇒ Integer?
Optional timeout after which a model response will be triggered automatically. This is useful for situations in which a long pause from the user is unexpected, such as a phone call. The model will effectively prompt the user to continue the conversation based on the current context.
The timeout value will be applied after the last model response’s audio has finished playing, i.e. it’s set to the response.done time plus audio playback duration.
An input_audio_buffer.timeout_triggered event (plus events associated with the Response) will be emitted when the timeout is reached. Idle timeout is currently only supported for server_vad mode.
516 |
# File 'lib/openai/models/realtime/realtime_session.rb', line 516 optional :idle_timeout_ms, Integer, nil?: true |
#interrupt_response ⇒ Boolean?
Whether or not to automatically interrupt (cancel) any ongoing response with output to the default conversation (i.e. conversation of auto) when a VAD start event occurs. If true then the response will be cancelled, otherwise it will continue until complete.
If both create_response and interrupt_response are set to false, the model will never respond automatically but VAD events will still be emitted.
528 |
# File 'lib/openai/models/realtime/realtime_session.rb', line 528 optional :interrupt_response, OpenAI::Internal::Type::Boolean |
#prefix_padding_ms ⇒ Integer?
Used only for server_vad mode. Amount of audio to include before the VAD detected speech (in milliseconds). Defaults to 300ms.
535 |
# File 'lib/openai/models/realtime/realtime_session.rb', line 535 optional :prefix_padding_ms, Integer |
#silence_duration_ms ⇒ Integer?
Used only for server_vad mode. Duration of silence to detect speech stop (in milliseconds). Defaults to 500ms. With shorter values the model will respond more quickly, but may jump in on short pauses from the user.
543 |
# File 'lib/openai/models/realtime/realtime_session.rb', line 543 optional :silence_duration_ms, Integer |
#threshold ⇒ Float?
Used only for server_vad mode. Activation threshold for VAD (0.0 to 1.0), this defaults to 0.5. A higher threshold will require louder audio to activate the model, and thus might perform better in noisy environments.
551 |
# File 'lib/openai/models/realtime/realtime_session.rb', line 551 optional :threshold, Float |
#type ⇒ Symbol, :server_vad
Type of turn detection, server_vad to turn on simple Server VAD.
488 |
# File 'lib/openai/models/realtime/realtime_session.rb', line 488 required :type, const: :server_vad |