Class: OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio::Input::TurnDetection::SemanticVad

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/realtime/realtime_session_create_response.rb,
sig/openai/models/realtime/realtime_session_create_response.rbs

Defined Under Namespace

Modules: Eagerness

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(create_response: nil, eagerness: nil, interrupt_response: nil, type: :semantic_vad) ⇒ Object

Server-side semantic turn detection which uses a model to determine when the user has finished speaking.

Parameters:

  • create_response (Boolean) (defaults to: nil)

    Whether or not to automatically generate a response when a VAD stop event occurs.

  • eagerness (Symbol, OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio::Input::TurnDetection::SemanticVad::Eagerness) (defaults to: nil)

    Used only for semantic_vad mode. The eagerness of the model to respond. low will wait longer for the user to continue speaking, high will respond more quickly. auto is the default and is equivalent to medium. low, medium, and high have max timeouts of 8s, 4s, and 2s respectively.

  • interrupt_response (Boolean) (defaults to: nil)

    Whether or not to automatically interrupt any ongoing response with output to the default conversation (i.e. conversation of auto) when a VAD start event occurs.

  • type (Symbol, :semantic_vad) (defaults to: :semantic_vad)

    Type of turn detection, semantic_vad to turn on Semantic VAD.



# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 571

Instance Attribute Details

#create_responseBoolean?

Whether or not to automatically generate a response when a VAD stop event occurs.

Parameters:

Returns:



547
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 547

optional :create_response, OpenAI::Internal::Type::Boolean

#eagernessSymbol, ...

Used only for semantic_vad mode. The eagerness of the model to respond. low will wait longer for the user to continue speaking, high will respond more quickly. auto is the default and is equivalent to medium. low, medium, and high have max timeouts of 8s, 4s, and 2s respectively.



556
557
558
559
560
561
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 556

optional(
  :eagerness,
  enum: -> {
    OpenAI::Realtime::RealtimeSessionCreateResponse::Audio::Input::TurnDetection::SemanticVad::Eagerness
  }
)

#interrupt_responseBoolean?

Whether or not to automatically interrupt any ongoing response with output to the default conversation (i.e. conversation of auto) when a VAD start event occurs.

Parameters:

Returns:



569
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 569

optional :interrupt_response, OpenAI::Internal::Type::Boolean

#typeSymbol, :semantic_vad

Type of turn detection, semantic_vad to turn on Semantic VAD.

Parameters:

  • value (:semantic_vad)

Returns:

  • (Symbol, :semantic_vad)


540
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 540

required :type, const: :semantic_vad

Instance Method Details

#to_hash{

Returns:

  • ({)


324
# File 'sig/openai/models/realtime/realtime_session_create_response.rbs', line 324

def to_hash: -> {