Module: OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio::Output::Voice

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/realtime/realtime_session_create_response.rb

Overview

The voice the model uses to respond. Voice cannot be changed during the session once the model has responded with audio at least once. Current voice options are alloy, ash, ballad, coral, echo, sage, shimmer, verse, marin, and cedar. We recommend marin and cedar for best quality.

See Also:

collapse

ALLOY =
:alloy
ASH =
:ash
BALLAD =
:ballad
CORAL =
:coral
ECHO =
:echo
SAGE =
:sage
SHIMMER =
:shimmer
VERSE =
:verse
MARIN =
:marin
CEDAR =
:cedar

Class Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.variantsArray(String, Symbol)

Returns:

  • (Array(String, Symbol))


540
541
542
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 540

define_sorbet_constant!(:Variants) do
  T.type_alias { T.any(String, OpenAI::Realtime::RealtimeSessionCreateResponse::Audio::Output::Voice::TaggedSymbol) }
end