Class: OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Tool::McpTool
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Tool::McpTool
- Defined in:
- lib/openai/models/realtime/realtime_session_create_response.rb,
sig/openai/models/realtime/realtime_session_create_response.rbs
Defined Under Namespace
Modules: AllowedCaller, AllowedTools, ConnectorID, RequireApproval
Instance Attribute Summary collapse
-
#allowed_callers ⇒ ::Array[OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Tool::McpTool::allowed_caller]?
The tool invocation context(s).
-
#allowed_tools ⇒ OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Tool::McpTool::allowed_tools?
List of allowed tool names or a filter object.
-
#authorization ⇒ String?
An OAuth access token that can be used with a remote MCP server, either with a custom MCP server URL or a service connector.
-
#connector_id ⇒ OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Tool::McpTool::connector_id?
Identifier for service connectors, like those available in ChatGPT.
-
#defer_loading ⇒ Boolean?
Whether this MCP tool is deferred and discovered via tool search.
-
#headers ⇒ ::Hash[Symbol, String]?
Optional HTTP headers to send to the MCP server.
-
#require_approval ⇒ OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Tool::McpTool::require_approval?
Specify which of the MCP server's tools require approval.
-
#server_description ⇒ String?
Optional description of the MCP server, used to provide more context.
-
#server_label ⇒ String
A label for this MCP server, used to identify it in tool calls.
-
#server_url ⇒ String?
The URL for the MCP server.
-
#tunnel_id ⇒ String?
The Secure MCP Tunnel ID to use instead of a direct server URL.
-
#type ⇒ :mcp
The type of the MCP tool.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1089 |
# File 'sig/openai/models/realtime/realtime_session_create_response.rbs', line 1089 def initialize: ( |
Instance Attribute Details
#allowed_callers ⇒ ::Array[OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Tool::McpTool::allowed_caller]?
The tool invocation context(s).
932 933 934 935 936 937 938 939 940 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 932 optional( :allowed_callers, -> { OpenAI::Internal::Type::ArrayOf[ enum: OpenAI::Realtime::RealtimeSessionCreateResponse::Tool::McpTool::AllowedCaller ] }, nil?: true ) |
#allowed_tools ⇒ OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Tool::McpTool::allowed_tools?
List of allowed tool names or a filter object.
946 947 948 949 950 951 952 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 946 optional( :allowed_tools, union: -> { OpenAI::Realtime::RealtimeSessionCreateResponse::Tool::McpTool::AllowedTools }, nil?: true ) |
#authorization ⇒ String?
An OAuth access token that can be used with a remote MCP server, either with a custom MCP server URL or a service connector. Your application must handle the OAuth authorization flow and provide the token here.
960 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 960 optional :authorization, String |
#connector_id ⇒ OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Tool::McpTool::connector_id?
Identifier for service connectors, like those available in ChatGPT. One of
server_url, connector_id, or tunnel_id must be provided. Learn more about
service connectors
here.
This field is deprecated for models released after September 1, 2026. Use
server_url to connect to a remote MCP server, or tunnel_id to connect
through a Secure MCP Tunnel.
Currently supported connector_id values are:
- Dropbox:
connector_dropbox - Gmail:
connector_gmail - Google Calendar:
connector_googlecalendar - Google Drive:
connector_googledrive - Microsoft Teams:
connector_microsoftteams - Outlook Calendar:
connector_outlookcalendar - Outlook Email:
connector_outlookemail - SharePoint:
connector_sharepoint
986 987 988 989 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 986 optional( :connector_id, enum: -> { OpenAI::Realtime::RealtimeSessionCreateResponse::Tool::McpTool::ConnectorID } ) |
#defer_loading ⇒ Boolean?
Whether this MCP tool is deferred and discovered via tool search.
995 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 995 optional :defer_loading, OpenAI::Internal::Type::Boolean |
#headers ⇒ ::Hash[Symbol, String]?
Optional HTTP headers to send to the MCP server. Use for authentication or other purposes.
1002 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 1002 optional :headers, OpenAI::Internal::Type::HashOf[String], nil?: true |
#require_approval ⇒ OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Tool::McpTool::require_approval?
Specify which of the MCP server's tools require approval.
1008 1009 1010 1011 1012 1013 1014 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 1008 optional( :require_approval, union: -> { OpenAI::Realtime::RealtimeSessionCreateResponse::Tool::McpTool::RequireApproval }, nil?: true ) |
#server_description ⇒ String?
Optional description of the MCP server, used to provide more context.
1020 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 1020 optional :server_description, String |
#server_label ⇒ String
A label for this MCP server, used to identify it in tool calls.
920 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 920 required :server_label, String |
#server_url ⇒ String?
The URL for the MCP server. One of server_url, connector_id, or tunnel_id
must be provided.
1027 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 1027 optional :server_url, String |
#tunnel_id ⇒ String?
The Secure MCP Tunnel ID to use instead of a direct server URL. One of
server_url, connector_id, or tunnel_id must be provided.
1034 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 1034 optional :tunnel_id, String |
#type ⇒ :mcp
The type of the MCP tool. Always mcp.
926 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 926 required :type, const: :mcp |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 1105
|
Instance Method Details
#to_hash ⇒ {
1104 |
# File 'sig/openai/models/realtime/realtime_session_create_response.rbs', line 1104 def to_hash: -> { |