Module: OpenAI::Models::Realtime::RealtimeTracingConfig
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/realtime/realtime_tracing_config.rb,
sig/openai/models/realtime/realtime_tracing_config.rbs
Overview
Realtime API can write session traces to the Traces Dashboard. Set to null to disable tracing. Once tracing is enabled for a session, the configuration cannot be modified.
auto will create a trace for the session with default values for the workflow
name, group id, and metadata.
Defined Under Namespace
Classes: TracingConfiguration
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Symbol, :auto, OpenAI::Models::Realtime::RealtimeTracingConfig::TracingConfiguration)
|
|
# File 'lib/openai/models/realtime/realtime_tracing_config.rb', line 58
|
Instance Method Details
#self?.variants ⇒ ::Array[OpenAI::Models::Realtime::realtime_tracing_config]
39 |
# File 'sig/openai/models/realtime/realtime_tracing_config.rbs', line 39
def self?.variants: -> ::Array[OpenAI::Models::Realtime::realtime_tracing_config]
|