Class: OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateRequest::InputAudioTranscription

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/realtime/realtime_transcription_session_create_request.rb

Overview

Defined Under Namespace

Modules: Model

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(language: nil, model: nil, prompt: nil) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateRequest::InputAudioTranscription for more details.

Configuration for input audio transcription. The client can optionally set the language and prompt for transcription, these offer additional guidance to the transcription service.

Parameters:



# File 'lib/openai/models/realtime/realtime_transcription_session_create_request.rb', line 215

Instance Attribute Details

#languageString?

The language of the input audio. Supplying the input language in [ISO-639-1](en.wikipedia.org/wiki/List_of_ISO_639-1_codes) (e.g. ‘en`) format will improve accuracy and latency.

Returns:

  • (String, nil)


195
# File 'lib/openai/models/realtime/realtime_transcription_session_create_request.rb', line 195

optional :language, String

#modelSymbol, ...

The model to use for transcription, current options are ‘gpt-4o-transcribe`, `gpt-4o-mini-transcribe`, and `whisper-1`.



202
203
# File 'lib/openai/models/realtime/realtime_transcription_session_create_request.rb', line 202

optional :model,
enum: -> { OpenAI::Realtime::RealtimeTranscriptionSessionCreateRequest::InputAudioTranscription::Model }

#promptString?

An optional text to guide the model’s style or continue a previous audio segment. For ‘whisper-1`, the [prompt is a list of keywords](platform.openai.com/docs/guides/speech-to-text#prompting). For `gpt-4o-transcribe` models, the prompt is a free text string, for example “expect words related to technology”.

Returns:

  • (String, nil)


213
# File 'lib/openai/models/realtime/realtime_transcription_session_create_request.rb', line 213

optional :prompt, String