Class: OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_transcription_session_create_response.rb

Defined Under Namespace

Modules: Modality

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from OpenAI::Internal::Type::BaseModel

Instance Attribute Details

#client_secretOpenAI::Models::Realtime::RealtimeTranscriptionSessionClientSecret

Ephemeral key returned by the API. Only present when the session is created on the server via REST API.



12
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 12

required :client_secret, -> { OpenAI::Realtime::RealtimeTranscriptionSessionClientSecret }

#input_audio_formatString?

The format of input audio. Options are ‘pcm16`, `g711_ulaw`, or `g711_alaw`.

Returns:

  • (String, nil)


18
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 18

optional :input_audio_format, String

#input_audio_transcriptionOpenAI::Models::Realtime::RealtimeTranscriptionSessionInputAudioTranscription?

Configuration of the transcription model.



24
25
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 24

optional :input_audio_transcription,
-> { OpenAI::Realtime::RealtimeTranscriptionSessionInputAudioTranscription }

#modalitiesArray<Symbol, OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse::Modality>?

The set of modalities the model can respond with. To disable audio, set this to [“text”].



32
33
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 32

optional :modalities,
-> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Realtime::RealtimeTranscriptionSessionCreateResponse::Modality] }

#turn_detectionOpenAI::Models::Realtime::RealtimeTranscriptionSessionTurnDetection?

Configuration for turn detection. Can be set to ‘null` to turn off. Server VAD means that the model will detect the start and end of speech based on audio volume and respond at the end of user speech.



41
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 41

optional :turn_detection, -> { OpenAI::Realtime::RealtimeTranscriptionSessionTurnDetection }