Class: OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio::Input

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_transcription_session_create_response.rb,
sig/openai/models/realtime/realtime_transcription_session_create_response.rbs

Overview

See Also:

  • OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio#input

Defined Under Namespace

Classes: NoiseReduction

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(format_: nil, noise_reduction: nil, transcription: nil, turn_detection: nil) ⇒ Object

Parameters:

  • format_ (defaults to: nil)

    The PCM audio format. Only a 24kHz sample rate is supported.

  • noise_reduction (defaults to: nil)

    Configuration for input audio noise reduction.

  • turn_detection (defaults to: nil)

    Configuration for turn detection. Can be set to null to turn off. Server VAD means that the model will detect the start and end of speech based on audio volume and respond at the end of user speech. For gpt-realtime-whisper, this must be null; VAD is not supported.



# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 124

Instance Attribute Details

#format_OpenAI::Models::Realtime::realtime_audio_formats?

The PCM audio format. Only a 24kHz sample rate is supported.

Returns:

  • (OpenAI::Models::Realtime::realtime_audio_formats, nil)


93
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 93

optional :format_, union: -> { OpenAI::Realtime::RealtimeAudioFormats }, api_name: :format

#noise_reductionOpenAI::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio::Input::NoiseReduction?

Configuration for input audio noise reduction.

Returns:

  • (OpenAI::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio::Input::NoiseReduction, nil)


99
100
101
102
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 99

optional(
  :noise_reduction,
  -> { OpenAI::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio::Input::NoiseReduction }
)

#transcriptionOpenAI::Models::Realtime::AudioTranscription?



107
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 107

optional :transcription, -> { OpenAI::Realtime::AudioTranscription }

#turn_detectionOpenAI::Realtime::RealtimeTranscriptionSessionTurnDetection?

Configuration for turn detection. Can be set to null to turn off. Server VAD means that the model will detect the start and end of speech based on audio volume and respond at the end of user speech. For gpt-realtime-whisper, this must be null; VAD is not supported.

Returns:

  • (OpenAI::Realtime::RealtimeTranscriptionSessionTurnDetection, nil)


116
117
118
119
120
121
122
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 116

optional(
  :turn_detection,
  -> {
    OpenAI::Realtime::RealtimeTranscriptionSessionTurnDetection
  },
  nil?: true
)

Instance Method Details

#to_hash{

Returns:

  • ({)


160
# File 'sig/openai/models/realtime/realtime_transcription_session_create_response.rbs', line 160

def to_hash: -> {