Class: OpenAI::Models::Realtime::RealtimeTranscriptionSessionTurnDetection

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_transcription_session_turn_detection.rb,
sig/openai/models/realtime/realtime_transcription_session_turn_detection.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



31
# File 'sig/openai/models/realtime/realtime_transcription_session_turn_detection.rbs', line 31

def initialize: (

Instance Attribute Details

#prefix_padding_msInteger?

Amount of audio to include before the VAD detected speech (in milliseconds). Defaults to 300ms.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


12
# File 'lib/openai/models/realtime/realtime_transcription_session_turn_detection.rb', line 12

optional :prefix_padding_ms, Integer

#silence_duration_msInteger?

Duration of silence to detect speech stop (in milliseconds). Defaults to 500ms. With shorter values the model will respond more quickly, but may jump in on short pauses from the user.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


20
# File 'lib/openai/models/realtime/realtime_transcription_session_turn_detection.rb', line 20

optional :silence_duration_ms, Integer

#thresholdFloat?

Activation threshold for VAD (0.0 to 1.0), this defaults to 0.5. A higher threshold will require louder audio to activate the model, and thus might perform better in noisy environments.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


28
# File 'lib/openai/models/realtime/realtime_transcription_session_turn_detection.rb', line 28

optional :threshold, Float

#typeString?

Type of turn detection, only server_vad is currently supported.

Parameters:

  • (String)

Returns:

  • (String, nil)


34
# File 'lib/openai/models/realtime/realtime_transcription_session_turn_detection.rb', line 34

optional :type, String

Instance Method Details

#to_hash{

Returns:

  • ({)


38
# File 'sig/openai/models/realtime/realtime_transcription_session_turn_detection.rbs', line 38

def to_hash: -> {