Class: OpenAI::Models::Realtime::RealtimeTranslationClientSecretCreateRequest::ExpiresAfter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_translation_client_secret_create_request.rb,
sig/openai/models/realtime/realtime_translation_client_secret_create_request.rbs

Overview

See Also:

  • OpenAI::Models::Realtime::RealtimeTranslationClientSecretCreateRequest#expires_after

Defined Under Namespace

Modules: Anchor

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(anchor: nil, seconds: nil) ⇒ Object

Parameters:

  • anchor (defaults to: nil)

    The anchor point for the client secret expiration, meaning that seconds will be added to the created_at time of the client secret to produce an expiration timestamp. Only created_at is currently supported.

  • seconds (defaults to: nil)

    The number of seconds from the anchor point to the expiration. Select a value between 10 and 7200 (2 hours). This default to 600 seconds (10 minutes) if not specified.



# File 'lib/openai/models/realtime/realtime_translation_client_secret_create_request.rb', line 60

Instance Attribute Details

#anchorOpenAI::Models::Realtime::RealtimeTranslationClientSecretCreateRequest::ExpiresAfter::anchor?

The anchor point for the client secret expiration, meaning that seconds will be added to the created_at time of the client secret to produce an expiration timestamp. Only created_at is currently supported.

Returns:

  • (OpenAI::Models::Realtime::RealtimeTranslationClientSecretCreateRequest::ExpiresAfter::anchor, nil)


47
48
49
50
# File 'lib/openai/models/realtime/realtime_translation_client_secret_create_request.rb', line 47

optional(
  :anchor,
  enum: -> { OpenAI::Realtime::RealtimeTranslationClientSecretCreateRequest::ExpiresAfter::Anchor }
)

#secondsInteger?

The number of seconds from the anchor point to the expiration. Select a value between 10 and 7200 (2 hours). This default to 600 seconds (10 minutes) if not specified.

Returns:

  • (Integer, nil)


58
# File 'lib/openai/models/realtime/realtime_translation_client_secret_create_request.rb', line 58

optional :seconds, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


89
# File 'sig/openai/models/realtime/realtime_translation_client_secret_create_request.rbs', line 89

def to_hash: -> {