Class: OpenAI::Models::Realtime::RealtimeTranslationInputTranscriptDeltaEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeTranslationInputTranscriptDeltaEvent
- Defined in:
- lib/openai/models/realtime/realtime_translation_input_transcript_delta_event.rb
Instance Attribute Summary collapse
-
#delta ⇒ String
Append-only source-language transcript text.
-
#elapsed_ms ⇒ Integer?
Timing metadata for stream alignment, derived from the translation frame when available.
-
#event_id ⇒ String
The unique ID of the server event.
-
#type ⇒ Symbol, :"session.input_transcript.delta"
The event type, must be ‘session.input_transcript.delta`.
Instance Method Summary collapse
-
#initialize(delta:, event_id:, elapsed_ms: nil, type: :"session.input_transcript.delta") ⇒ Object
constructor
Some parameter documentations has been truncated, see RealtimeTranslationInputTranscriptDeltaEvent for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(delta:, event_id:, elapsed_ms: nil, type: :"session.input_transcript.delta") ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeTranslationInputTranscriptDeltaEvent for more details.
Returned when optional source-language transcript text is available. This event is emitted only when ‘audio.input.transcription` is configured.
Transcript deltas are append-only text fragments. Clients should not insert unconditional spaces between deltas.
|
|
# File 'lib/openai/models/realtime/realtime_translation_input_transcript_delta_event.rb', line 34
|
Instance Attribute Details
#delta ⇒ String
Append-only source-language transcript text.
11 |
# File 'lib/openai/models/realtime/realtime_translation_input_transcript_delta_event.rb', line 11 required :delta, String |
#elapsed_ms ⇒ Integer?
Timing metadata for stream alignment, derived from the translation frame when available. It advances in 200 ms increments, but multiple transcript deltas may share the same ‘elapsed_ms`. Treat it as alignment metadata, not a unique transcript-delta identifier.
32 |
# File 'lib/openai/models/realtime/realtime_translation_input_transcript_delta_event.rb', line 32 optional :elapsed_ms, Integer, nil?: true |
#event_id ⇒ String
The unique ID of the server event.
17 |
# File 'lib/openai/models/realtime/realtime_translation_input_transcript_delta_event.rb', line 17 required :event_id, String |
#type ⇒ Symbol, :"session.input_transcript.delta"
The event type, must be ‘session.input_transcript.delta`.
23 |
# File 'lib/openai/models/realtime/realtime_translation_input_transcript_delta_event.rb', line 23 required :type, const: :"session.input_transcript.delta" |