Class: OpenAI::Models::Realtime::RealtimeTranslationSessionCreateRequest::Audio::Output

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_translation_session_create_request.rb,
sig/openai/models/realtime/realtime_translation_session_create_request.rbs

Overview

See Also:

  • OpenAI::Models::Realtime::RealtimeTranslationSessionCreateRequest::Audio#output

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(language: nil) ⇒ Output

Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeTranslationSessionCreateRequest::Audio::Output for more details.

Parameters:

  • language (String) (defaults to: nil)

    Target language for translated output audio and transcript deltas.

  • language: (String) (defaults to: nil)


# File 'lib/openai/models/realtime/realtime_translation_session_create_request.rb', line 127

Instance Attribute Details

#languageString?

Target language for translated output audio and transcript deltas.

Parameters:

  • (String)

Returns:

  • (String, nil)


125
# File 'lib/openai/models/realtime/realtime_translation_session_create_request.rb', line 125

optional :language, String

Instance Method Details

#to_hash{ language: String }

Returns:

  • ({ language: String })


114
# File 'sig/openai/models/realtime/realtime_translation_session_create_request.rbs', line 114

def to_hash: -> { language: String }