Class: OpenAI::Models::Realtime::RealtimeTranslationSessionUpdateEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_translation_session_update_event.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(session:, event_id: nil, type: :"session.update") ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeTranslationSessionUpdateEvent for more details.

Send this event to update the translation session configuration. Translation sessions support updates to ‘audio.output.language`, `audio.input.transcription`, and `audio.input.noise_reduction`.

Parameters:

  • session (OpenAI::Models::Realtime::RealtimeTranslationSessionUpdateRequest)

    Translation session fields to update. The session ‘type` and `model` are set

  • event_id (String) (defaults to: nil)

    Optional client-generated ID used to identify this event.

  • type (Symbol, :"session.update") (defaults to: :"session.update")

    The event type, must be ‘session.update`.



# File 'lib/openai/models/realtime/realtime_translation_session_update_event.rb', line 26

Instance Attribute Details

#event_idString?

Optional client-generated ID used to identify this event.

Returns:

  • (String, nil)


24
# File 'lib/openai/models/realtime/realtime_translation_session_update_event.rb', line 24

optional :event_id, String

#sessionOpenAI::Models::Realtime::RealtimeTranslationSessionUpdateRequest

Translation session fields to update. The session ‘type` and `model` are set at creation and cannot be changed with `session.update`.



12
# File 'lib/openai/models/realtime/realtime_translation_session_update_event.rb', line 12

required :session, -> { OpenAI::Realtime::RealtimeTranslationSessionUpdateRequest }

#typeSymbol, :"session.update"

The event type, must be ‘session.update`.

Returns:



18
# File 'lib/openai/models/realtime/realtime_translation_session_update_event.rb', line 18

required :type, const: :"session.update"