Class: OpenAI::Models::Realtime::RealtimeTranslationSessionUpdateRequest::Audio::Input::Transcription
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeTranslationSessionUpdateRequest::Audio::Input::Transcription
- Defined in:
- lib/openai/models/realtime/realtime_translation_session_update_request.rb,
sig/openai/models/realtime/realtime_translation_session_update_request.rbs
Overview
Instance Attribute Summary collapse
-
#model ⇒ String
The transcription model to use for source transcript deltas.
Instance Method Summary collapse
-
#initialize ⇒ Transcription
constructor
A new instance of Transcription.
- #to_hash ⇒ { model: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Transcription
Returns a new instance of Transcription.
94 |
# File 'sig/openai/models/realtime/realtime_translation_session_update_request.rbs', line 94
def initialize: (model: String) -> void
|
Instance Attribute Details
#model ⇒ String
The transcription model to use for source transcript deltas.
99 |
# File 'lib/openai/models/realtime/realtime_translation_session_update_request.rb', line 99 required :model, String |
Instance Method Details
#to_hash ⇒ { model: String }
96 |
# File 'sig/openai/models/realtime/realtime_translation_session_update_request.rbs', line 96
def to_hash: -> { model: String }
|