Class: OpenAI::Models::Realtime::RealtimeTranslationSessionUpdateRequest::Audio::Output
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeTranslationSessionUpdateRequest::Audio::Output
- Defined in:
- lib/openai/models/realtime/realtime_translation_session_update_request.rb,
sig/openai/models/realtime/realtime_translation_session_update_request.rbs
Overview
Instance Attribute Summary collapse
-
#language ⇒ String?
Target language for translated output audio and transcript deltas.
Instance Method Summary collapse
-
#initialize(language: nil) ⇒ Output
constructor
Some parameter documentations has been truncated, see Output for more details.
- #to_hash ⇒ { language: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(language: nil) ⇒ Output
Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeTranslationSessionUpdateRequest::Audio::Output for more details.
|
|
# File 'lib/openai/models/realtime/realtime_translation_session_update_request.rb', line 118
|
Instance Attribute Details
#language ⇒ String?
Target language for translated output audio and transcript deltas.
116 |
# File 'lib/openai/models/realtime/realtime_translation_session_update_request.rb', line 116 optional :language, String |
Instance Method Details
#to_hash ⇒ { language: String }
109 |
# File 'sig/openai/models/realtime/realtime_translation_session_update_request.rbs', line 109
def to_hash: -> { language: String }
|