Class: OpenAI::Models::Realtime::RealtimeTranslationSessionUpdatedEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeTranslationSessionUpdatedEvent
- Defined in:
- lib/openai/models/realtime/realtime_translation_session_updated_event.rb
Instance Attribute Summary collapse
-
#event_id ⇒ String
The unique ID of the server event.
-
#session ⇒ OpenAI::Models::Realtime::RealtimeTranslationSession
The translation session configuration.
-
#type ⇒ Symbol, :"session.updated"
The event type, must be ‘session.updated`.
Instance Method Summary collapse
-
#initialize(event_id:, session:, type: :"session.updated") ⇒ Object
constructor
Returned when a translation session is updated with a ‘session.update` event, unless there is an error.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(event_id:, session:, type: :"session.updated") ⇒ Object
Returned when a translation session is updated with a ‘session.update` event, unless there is an error.
|
|
# File 'lib/openai/models/realtime/realtime_translation_session_updated_event.rb', line 25
|
Instance Attribute Details
#event_id ⇒ String
The unique ID of the server event.
11 |
# File 'lib/openai/models/realtime/realtime_translation_session_updated_event.rb', line 11 required :event_id, String |
#session ⇒ OpenAI::Models::Realtime::RealtimeTranslationSession
The translation session configuration.
17 |
# File 'lib/openai/models/realtime/realtime_translation_session_updated_event.rb', line 17 required :session, -> { OpenAI::Realtime::RealtimeTranslationSession } |
#type ⇒ Symbol, :"session.updated"
The event type, must be ‘session.updated`.
23 |
# File 'lib/openai/models/realtime/realtime_translation_session_updated_event.rb', line 23 required :type, const: :"session.updated" |