Class: OpenAI::Models::Realtime::ResponseCreateEvent::Response::Tool

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/response_create_event.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(description: nil, name: nil, parameters: nil, type: nil) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Realtime::ResponseCreateEvent::Response::Tool for more details.

Parameters:

  • description (String) (defaults to: nil)

    The description of the function, including guidance on when and how

  • name (String) (defaults to: nil)

    The name of the function.

  • parameters (Object) (defaults to: nil)

    Parameters of the function in JSON Schema.

  • type (Symbol, OpenAI::Models::Realtime::ResponseCreateEvent::Response::Tool::Type) (defaults to: nil)

    The type of the tool, i.e. ‘function`.



# File 'lib/openai/models/realtime/response_create_event.rb', line 309

Instance Attribute Details

#descriptionString?

The description of the function, including guidance on when and how to call it, and guidance about what to tell the user when calling (if anything).

Returns:

  • (String, nil)


289
# File 'lib/openai/models/realtime/response_create_event.rb', line 289

optional :description, String

#nameString?

The name of the function.

Returns:

  • (String, nil)


295
# File 'lib/openai/models/realtime/response_create_event.rb', line 295

optional :name, String

#parametersObject?

Parameters of the function in JSON Schema.

Returns:

  • (Object, nil)


301
# File 'lib/openai/models/realtime/response_create_event.rb', line 301

optional :parameters, OpenAI::Internal::Type::Unknown

#typeSymbol, ...

The type of the tool, i.e. ‘function`.



307
# File 'lib/openai/models/realtime/response_create_event.rb', line 307

optional :type, enum: -> { OpenAI::Realtime::ResponseCreateEvent::Response::Tool::Type }