Class: OpenAI::Models::Realtime::ResponseDoneEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/response_done_event.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_id:, response:, type: :"response.done") ⇒ Object

Returned when a Response is done streaming. Always emitted, no matter the final state. The Response object included in the response.done event will include all output Items in the Response but will omit the raw audio data.

Clients should check the status field of the Response to determine if it was successful (completed) or if there was another outcome: cancelled, failed, or incomplete.

A response will contain all output items that were generated during the response, excluding any audio content.

Parameters:

  • The unique ID of the server event.

  • The response resource.

  • (defaults to: :"response.done")

    The event type, must be response.done.



# File 'lib/openai/models/realtime/response_done_event.rb', line 25


Instance Attribute Details

#event_idString

The unique ID of the server event.

Returns:



11
# File 'lib/openai/models/realtime/response_done_event.rb', line 11

required :event_id, String

#responseOpenAI::Models::Realtime::RealtimeResponse

The response resource.

Returns:



17
# File 'lib/openai/models/realtime/response_done_event.rb', line 17

required :response, -> { OpenAI::Realtime::RealtimeResponse }

#typeSymbol, :"response.done"

The event type, must be response.done.

Returns:



23
# File 'lib/openai/models/realtime/response_done_event.rb', line 23

required :type, const: :"response.done"