Class: OpenAI::Models::Realtime::ResponseMcpCallCompleted

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/response_mcp_call_completed.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_id:, item_id:, output_index:, type: :"response.mcp_call.completed") ⇒ Object

Returned when an MCP tool call has completed successfully.

Parameters:

  • The unique ID of the server event.

  • The ID of the MCP tool call item.

  • The index of the output item in the response.

  • (defaults to: :"response.mcp_call.completed")

    The event type, must be response.mcp_call.completed.



# File 'lib/openai/models/realtime/response_mcp_call_completed.rb', line 31


Instance Attribute Details

#event_idString

The unique ID of the server event.

Returns:



11
# File 'lib/openai/models/realtime/response_mcp_call_completed.rb', line 11

required :event_id, String

#item_idString

The ID of the MCP tool call item.

Returns:



17
# File 'lib/openai/models/realtime/response_mcp_call_completed.rb', line 17

required :item_id, String

#output_indexInteger

The index of the output item in the response.

Returns:



23
# File 'lib/openai/models/realtime/response_mcp_call_completed.rb', line 23

required :output_index, Integer

#typeSymbol, :"response.mcp_call.completed"

The event type, must be response.mcp_call.completed.

Returns:



29
# File 'lib/openai/models/realtime/response_mcp_call_completed.rb', line 29

required :type, const: :"response.mcp_call.completed"