Class: OpenAI::Models::Realtime::TranscriptionSessionUpdatedEvent::Session::ClientSecret
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::TranscriptionSessionUpdatedEvent::Session::ClientSecret
- Defined in:
- lib/openai/models/realtime/transcription_session_updated_event.rb,
sig/openai/models/realtime/transcription_session_updated_event.rbs
Overview
Instance Attribute Summary collapse
-
#expires_at ⇒ Integer
Timestamp for when the token expires.
-
#value ⇒ String
Ephemeral key usable in client environments to authenticate connections to the Realtime API.
Instance Method Summary collapse
-
#initialize ⇒ ClientSecret
constructor
A new instance of ClientSecret.
- #to_hash ⇒ { expires_at: Integer, value: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ ClientSecret
Returns a new instance of ClientSecret.
87 |
# File 'sig/openai/models/realtime/transcription_session_updated_event.rbs', line 87
def initialize: (expires_at: Integer, value: String) -> void
|
Instance Attribute Details
#expires_at ⇒ Integer
Timestamp for when the token expires. Currently, all tokens expire after one minute.
107 |
# File 'lib/openai/models/realtime/transcription_session_updated_event.rb', line 107 required :expires_at, Integer |
#value ⇒ String
Ephemeral key usable in client environments to authenticate connections to the Realtime API. Use this in client-side environments rather than a standard API token, which should only be used server-side.
115 |
# File 'lib/openai/models/realtime/transcription_session_updated_event.rb', line 115 required :value, String |
Instance Method Details
#to_hash ⇒ { expires_at: Integer, value: String }
89 |
# File 'sig/openai/models/realtime/transcription_session_updated_event.rbs', line 89
def to_hash: -> { expires_at: Integer, value: String }
|