Module: OpenAI::Models::Reasoning::Context
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/reasoning.rb
Overview
Controls which reasoning items are rendered back to the model on later turns. When returned on a response, this is the effective reasoning context mode used for the response.
Constant Summary collapse
- AUTO =
:auto- CURRENT_TURN =
:current_turn- ALL_TURNS =
:all_turns
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info