Module: OpenAI::Models::ReasoningEffort

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/reasoning_effort.rb

Overview

Constrains effort on reasoning for [reasoning models](platform.openai.com/docs/guides/reasoning). Currently supported values are none, minimal, low, medium, high, and xhigh. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response.

  • gpt-5.1 defaults to none, which does not perform reasoning. The supported reasoning values for gpt-5.1 are none, low, medium, and high. Tool calls are supported for all reasoning values in gpt-5.1.

  • All models before gpt-5.1 default to medium reasoning effort, and do not support none.

  • The gpt-5-pro model defaults to (and only supports) high reasoning effort.

  • xhigh is supported for all models after gpt-5.1-codex-max.

Constant Summary collapse

NONE =
:none
MINIMAL =
:minimal
LOW =
:low
MEDIUM =
:medium
HIGH =
:high
XHIGH =
:xhigh

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/reasoning_effort.rb', line 28