Class: OpenAI::Models::ResponseFormatTextGrammar
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::ResponseFormatTextGrammar
- Defined in:
- lib/openai/models/response_format_text_grammar.rb,
sig/openai/models/response_format_text_grammar.rbs
Instance Attribute Summary collapse
-
#grammar ⇒ String
The custom grammar for the model to follow.
-
#type ⇒ Symbol, :grammar
The type of response format being defined.
Instance Method Summary collapse
-
#initialize(grammar:, type: :grammar) ⇒ ResponseFormatTextGrammar
constructor
A custom grammar for the model to follow when generating text.
- #to_hash ⇒ { grammar: String, type: :grammar }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(grammar:, type: :grammar) ⇒ ResponseFormatTextGrammar
A custom grammar for the model to follow when generating text. Learn more in the custom grammars guide.
|
|
# File 'lib/openai/models/response_format_text_grammar.rb', line 18
|
Instance Attribute Details
#grammar ⇒ String
The custom grammar for the model to follow.
10 |
# File 'lib/openai/models/response_format_text_grammar.rb', line 10 required :grammar, String |
#type ⇒ Symbol, :grammar
The type of response format being defined. Always grammar.
16 |
# File 'lib/openai/models/response_format_text_grammar.rb', line 16 required :type, const: :grammar |
Instance Method Details
#to_hash ⇒ { grammar: String, type: :grammar }
12 |
# File 'sig/openai/models/response_format_text_grammar.rbs', line 12
def to_hash: -> { grammar: String, type: :grammar }
|