Class: OpenAI::Models::Responses::ComputerAction::Click

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/computer_action.rb

Defined Under Namespace

Modules: Button

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(button:, x:, y_:, type: :click) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Responses::ComputerAction::Click for more details.

A click action.

Parameters:

  • Indicates which mouse button was pressed during the click. One of left, ‘right

  • The x-coordinate where the click occurred.

  • The y-coordinate where the click occurred.

  • (defaults to: :click)

    Specifies the event type. For a click action, this property is always click.



# File 'lib/openai/models/responses/computer_action.rb', line 65


Instance Attribute Details

#buttonSymbol, OpenAI::Models::Responses::ComputerAction::Click::Button

Indicates which mouse button was pressed during the click. One of left, right, wheel, back, or forward.

Returns:



45
# File 'lib/openai/models/responses/computer_action.rb', line 45

required :button, enum: -> { OpenAI::Responses::ComputerAction::Click::Button }

#typeSymbol, :click

Specifies the event type. For a click action, this property is always click.

Returns:



51
# File 'lib/openai/models/responses/computer_action.rb', line 51

required :type, const: :click

#xInteger

The x-coordinate where the click occurred.

Returns:



57
# File 'lib/openai/models/responses/computer_action.rb', line 57

required :x, Integer

#y_Integer

The y-coordinate where the click occurred.

Returns:



63
# File 'lib/openai/models/responses/computer_action.rb', line 63

required :y_, Integer, api_name: :y