Class: OpenAI::Models::Responses::ComputerAction::Scroll

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/computer_action.rb,
sig/openai/models/responses/computer_action.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • scroll_x —

    The horizontal scroll distance.

  • scroll_y —

    The vertical scroll distance.

  • x —

    The x-coordinate where the scroll occurred.

  • y_ —

    The y-coordinate where the scroll occurred.

  • keys —

    The keys being held while scrolling.

  • type —

    Specifies the event type. For a scroll action, this property is always set to scroll.



325
# File 'sig/openai/models/responses/computer_action.rbs', line 325

def initialize: (

Instance Attribute Details

#keys ⇒ ::Array[String]?

The keys being held while scrolling.

Returns:

  • (::Array[String], nil)


345
# File 'lib/openai/models/responses/computer_action.rb', line 345

optional :keys, OpenAI::Internal::Type::ArrayOf[String], nil?: true

#scroll_x ⇒ Integer

The horizontal scroll distance.

Returns:

  • (Integer)


314
# File 'lib/openai/models/responses/computer_action.rb', line 314

required :scroll_x, Integer

#scroll_y ⇒ Integer

The vertical scroll distance.

Returns:

  • (Integer)


320
# File 'lib/openai/models/responses/computer_action.rb', line 320

required :scroll_y, Integer

#type ⇒ :scroll

Specifies the event type. For a scroll action, this property is always set to scroll.

Returns:

  • (:scroll)


327
# File 'lib/openai/models/responses/computer_action.rb', line 327

required :type, const: :scroll

#x ⇒ Integer

The x-coordinate where the scroll occurred.

Returns:

  • (Integer)


333
# File 'lib/openai/models/responses/computer_action.rb', line 333

required :x, Integer

#y_ ⇒ Integer

The y-coordinate where the scroll occurred.

Returns:

  • (Integer)


339
# File 'lib/openai/models/responses/computer_action.rb', line 339

required :y_, Integer, api_name: :y

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


334
# File 'sig/openai/models/responses/computer_action.rbs', line 334

def to_hash: -> {