Class: OpenAI::Models::Responses::ContainerAuto

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/container_auto.rb,
sig/openai/models/responses/container_auto.rbs

Defined Under Namespace

Modules: MemoryLimit, NetworkPolicy, Skill

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(file_ids: nil, memory_limit: nil, network_policy: nil, skills: nil, type: :container_auto) ⇒ Object

Parameters:

  • file_ids (defaults to: nil) —

    An optional list of uploaded files to make available to your code.

  • memory_limit (defaults to: nil) —

    The memory limit for the container.

  • network_policy (defaults to: nil) —

    Network access policy for the container.

  • skills (defaults to: nil) —

    An optional list of skills referenced by id or inline data.

  • type (defaults to: :container_auto) —

    Automatically creates a container for this request



# File 'lib/openai/models/responses/container_auto.rb', line 37

Instance Attribute Details

#file_ids ⇒ ::Array[String]?

An optional list of uploaded files to make available to your code.

Returns:

  • (::Array[String], nil)


17
# File 'lib/openai/models/responses/container_auto.rb', line 17

optional :file_ids, OpenAI::Internal::Type::ArrayOf[String]

#memory_limit ⇒ OpenAI::Models::Responses::ContainerAuto::memory_limit?

The memory limit for the container.

Returns:

  • (OpenAI::Models::Responses::ContainerAuto::memory_limit, nil)


23
# File 'lib/openai/models/responses/container_auto.rb', line 23

optional :memory_limit, enum: -> { OpenAI::Responses::ContainerAuto::MemoryLimit }, nil?: true

#network_policy ⇒ OpenAI::Models::Responses::ContainerAuto::network_policy?

Network access policy for the container.

Returns:

  • (OpenAI::Models::Responses::ContainerAuto::network_policy, nil)


29
# File 'lib/openai/models/responses/container_auto.rb', line 29

optional :network_policy, union: -> { OpenAI::Responses::ContainerAuto::NetworkPolicy }

#skills ⇒ ::Array[OpenAI::Models::Responses::ContainerAuto::skill]?

An optional list of skills referenced by id or inline data.

Returns:

  • (::Array[OpenAI::Models::Responses::ContainerAuto::skill], nil)


35
# File 'lib/openai/models/responses/container_auto.rb', line 35

optional :skills, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Responses::ContainerAuto::Skill] }

#type ⇒ :container_auto

Automatically creates a container for this request

Returns:

  • (:container_auto)


11
# File 'lib/openai/models/responses/container_auto.rb', line 11

required :type, const: :container_auto

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/responses/container_auto.rb', line 64

.variants ⇒ Array(OpenAI::Models::Responses::ContainerNetworkPolicyDisabled, OpenAI::Models::Responses::ContainerNetworkPolicyAllowlist)



# File 'lib/openai/models/responses/container_auto.rb', line 80

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


60
# File 'sig/openai/models/responses/container_auto.rbs', line 60

def to_hash: -> {