Class: OpenAI::Models::Responses::ContainerNetworkPolicyDomainSecret

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/container_network_policy_domain_secret.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(domain:, name:, value:) ⇒ Object

Parameters:

  • The domain associated with the secret.

  • The name of the secret to inject for the domain.

  • The secret value to inject for the domain.



# File 'lib/openai/models/responses/container_network_policy_domain_secret.rb', line 25


Instance Attribute Details

#domainString

The domain associated with the secret.

Returns:



11
# File 'lib/openai/models/responses/container_network_policy_domain_secret.rb', line 11

required :domain, String

#nameString

The name of the secret to inject for the domain.

Returns:



17
# File 'lib/openai/models/responses/container_network_policy_domain_secret.rb', line 17

required :name, String

#valueString

The secret value to inject for the domain.

Returns:



23
# File 'lib/openai/models/responses/container_network_policy_domain_secret.rb', line 23

required :value, String