Module: OpenAI::Models::Responses::FunctionShellTool::AllowedCaller
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/responses/function_shell_tool.rb,
sig/openai/models/responses/function_shell_tool.rbs
Constant Summary collapse
- DIRECT =
:direct- PROGRAMMATIC =
:programmatic
Instance Method Summary collapse
-
#initialize(allowed_callers: nil, environment: nil, type: :shell) ⇒ Object
A tool that allows the model to execute shell commands.
- #self?.values ⇒ ::Array[OpenAI::Models::Responses::FunctionShellTool::allowed_caller]
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(allowed_callers: nil, environment: nil, type: :shell) ⇒ Object
A tool that allows the model to execute shell commands.
37 38 39 40 41 42 43 44 45 |
# File 'lib/openai/models/responses/function_shell_tool.rb', line 37 module AllowedCaller extend OpenAI::Internal::Type::Enum DIRECT = :direct PROGRAMMATIC = :programmatic # @!method self.values # @return [Array<Symbol>] end |
#self?.values ⇒ ::Array[OpenAI::Models::Responses::FunctionShellTool::allowed_caller]
38 |
# File 'sig/openai/models/responses/function_shell_tool.rbs', line 38
def self?.values: -> ::Array[OpenAI::Models::Responses::FunctionShellTool::allowed_caller]
|