Class: OpenAI::Models::Responses::Response::Moderation::Output::ModerationResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::Response::Moderation::Output::ModerationResult
- Defined in:
- lib/openai/models/responses/response.rb,
sig/openai/models/responses/response.rbs
Defined Under Namespace
Modules: CategoryAppliedInputType
Instance Attribute Summary collapse
-
#categories ⇒ Hash{Symbol=>Boolean}
A dictionary of moderation categories to booleans, True if the input is flagged under this category.
-
#category_applied_input_types ⇒ Hash{Symbol=>Array<Symbol, OpenAI::Models::Responses::Response::Moderation::Output::ModerationResult::CategoryAppliedInputType>}
Which modalities of input are reflected by the score for each category.
-
#category_scores ⇒ Hash{Symbol=>Float}
A dictionary of moderation categories to scores.
-
#flagged ⇒ Boolean
A boolean indicating whether the content was flagged by any category.
-
#model ⇒ String
The moderation model that produced this result.
-
#type ⇒ Symbol, :moderation_result
The object type, which was always
moderation_resultfor successful moderation results.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
420 |
# File 'sig/openai/models/responses/response.rbs', line 420
def initialize: (
|
Instance Attribute Details
#categories ⇒ Hash{Symbol=>Boolean}
A dictionary of moderation categories to booleans, True if the input is flagged under this category.
|
|
# File 'lib/openai/models/responses/response.rb', line 719
|
#category_applied_input_types ⇒ Hash{Symbol=>Array<Symbol, OpenAI::Models::Responses::Response::Moderation::Output::ModerationResult::CategoryAppliedInputType>}
Which modalities of input are reflected by the score for each category.
725 726 727 728 729 730 |
# File 'lib/openai/models/responses/response.rb', line 725 required :category_applied_input_types, -> do OpenAI::Internal::Type::HashOf[ OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Responses::Response::Moderation::Output::ModerationResult::CategoryAppliedInputType] ] end |
#category_scores ⇒ Hash{Symbol=>Float}
A dictionary of moderation categories to scores.
|
|
# File 'lib/openai/models/responses/response.rb', line 736
|
#flagged ⇒ Boolean
A boolean indicating whether the content was flagged by any category.
742 |
# File 'lib/openai/models/responses/response.rb', line 742 required :flagged, OpenAI::Internal::Type::Boolean |
#model ⇒ String
The moderation model that produced this result.
748 |
# File 'lib/openai/models/responses/response.rb', line 748 required :model, String |
#type ⇒ Symbol, :moderation_result
The object type, which was always moderation_result for successful moderation
results.
755 |
# File 'lib/openai/models/responses/response.rb', line 755 required :type, const: :moderation_result |
Instance Method Details
#to_hash ⇒ {
429 |
# File 'sig/openai/models/responses/response.rbs', line 429
def to_hash: -> {
|