Class: OpenAI::Models::Responses::ResponseApplyPatchToolCall::Caller::Program
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseApplyPatchToolCall::Caller::Program
- Defined in:
- lib/openai/models/responses/response_apply_patch_tool_call.rb,
sig/openai/models/responses/response_apply_patch_tool_call.rbs
Instance Attribute Summary collapse
-
#caller_id ⇒ String
The call ID of the program item that produced this tool call.
- #type ⇒ Symbol, :program
Instance Method Summary collapse
-
#initialize(caller_id:, type: :program) ⇒ Program
constructor
A new instance of Program.
- #to_hash ⇒ { caller_id: String, type: :program }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caller_id:, type: :program) ⇒ Program
Returns a new instance of Program.
|
|
# File 'lib/openai/models/responses/response_apply_patch_tool_call.rb', line 222
|
Instance Attribute Details
#caller_id ⇒ String
The call ID of the program item that produced this tool call.
215 |
# File 'lib/openai/models/responses/response_apply_patch_tool_call.rb', line 215 required :caller_id, String |
#type ⇒ Symbol, :program
220 |
# File 'lib/openai/models/responses/response_apply_patch_tool_call.rb', line 220 required :type, const: :program |
Instance Method Details
#to_hash ⇒ { caller_id: String, type: :program }
148 |
# File 'sig/openai/models/responses/response_apply_patch_tool_call.rbs', line 148
def to_hash: -> { caller_id: String, type: :program }
|