Class: OpenAI::Models::Responses::ResponseApplyPatchToolCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_apply_patch_tool_call_output.rb,
sig/openai/models/responses/response_apply_patch_tool_call_output.rbs

Defined Under Namespace

Modules: Caller, Status

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, call_id:, status:, caller_: nil, created_by: nil, output: nil, type: :apply_patch_call_output) ⇒ Object

Parameters:

  • id —

    The unique ID of the apply patch tool call output. Populated when this item is returned via API.

  • call_id —

    The unique ID of the apply patch tool call generated by the model.

  • status —

    The status of the apply patch tool call output. One of completed or failed.

  • caller_ (defaults to: nil) —

    The execution context that produced this tool call.

  • created_by (defaults to: nil) —

    The ID of the entity that created this tool call output.

  • output (defaults to: nil) —

    Optional textual output returned by the apply patch tool.

  • type (defaults to: :apply_patch_call_output) —

    The type of the item. Always apply_patch_call_output.



# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 55

Instance Attribute Details

#call_id ⇒ String

The unique ID of the apply patch tool call generated by the model.

Returns:

  • (String)


18
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 18

required :call_id, String

#caller_ ⇒ OpenAI::Models::Responses::ResponseApplyPatchToolCallOutput::caller_?

The execution context that produced this tool call.

Returns:

  • (OpenAI::Models::Responses::ResponseApplyPatchToolCallOutput::caller_, nil)


36
37
38
39
40
41
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 36

optional(
  :caller_,
  union: -> { OpenAI::Responses::ResponseApplyPatchToolCallOutput::Caller },
  api_name: :caller,
  nil?: true
)

#created_by ⇒ String?

The ID of the entity that created this tool call output.

Returns:

  • (String, nil)


47
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 47

optional :created_by, String

#id ⇒ String

The unique ID of the apply patch tool call output. Populated when this item is returned via API.

Returns:

  • (String)


12
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 12

required :id, String

#output ⇒ String?

Optional textual output returned by the apply patch tool.

Returns:

  • (String, nil)


53
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 53

optional :output, String, nil?: true

#status ⇒ OpenAI::Models::Responses::ResponseApplyPatchToolCallOutput::status

The status of the apply patch tool call output. One of completed or failed.

Returns:

  • (OpenAI::Models::Responses::ResponseApplyPatchToolCallOutput::status)


24
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 24

required :status, enum: -> { OpenAI::Responses::ResponseApplyPatchToolCallOutput::Status }

#type ⇒ :apply_patch_call_output

The type of the item. Always apply_patch_call_output.

Returns:

  • (:apply_patch_call_output)


30
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 30

required :type, const: :apply_patch_call_output

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 89

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


66
# File 'sig/openai/models/responses/response_apply_patch_tool_call_output.rbs', line 66

def to_hash: -> {