Class: OpenAI::Models::Responses::ResponseApplyPatchToolCallOutput::Caller::Program

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_apply_patch_tool_call_output.rb,
sig/openai/models/responses/response_apply_patch_tool_call_output.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(caller_id:, type: :program) ⇒ Program

Returns a new instance of Program.

Parameters:

  • caller_id —

    The call ID of the program item that produced this tool call.

  • caller_id: (String)
  • type: (:program) (defaults to: :program)


# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 127


Instance Attribute Details

#caller_id ⇒ String

The call ID of the program item that produced this tool call.

Returns:

  • (String)


120
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 120

required :caller_id, String

#type ⇒ Symbol, :program

Parameters:

  • value (:program)

Returns:

  • (Symbol, :program)


125
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 125

required :type, const: :program

Instance Method Details

#to_hash ⇒ { caller_id: String, ?type: :program }

Returns:

  • ({ caller_id: String, ?type: :program })


116
# File 'sig/openai/models/responses/response_apply_patch_tool_call_output.rbs', line 116

def to_hash: -> { caller_id: String, ?type: :program }