Class: OpenAI::Models::Responses::ResponseCompactParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/responses/response_compact_params.rb,
sig/openai/models/responses/response_compact_params.rbs

Overview

See Also:

  • OpenAI::Resources::Responses#compact

Defined Under Namespace

Modules: Input, Model, PromptCacheRetention, ServiceTier Classes: PromptCacheOptions

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(model:, input: nil, instructions: nil, previous_response_id: nil, prompt_cache_key: nil, prompt_cache_options: nil, prompt_cache_retention: nil, service_tier: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseCompactParams for more details.

Parameters:



# File 'lib/openai/models/responses/response_compact_params.rb', line 83

Instance Attribute Details

#inputString, ...

Text, image, or file inputs to the model, used to generate a response

Parameters:

  • value (OpenAI::Models::Responses::ResponseCompactParams::input, nil)

Returns:



25
# File 'lib/openai/models/responses/response_compact_params.rb', line 25

optional :input, union: -> { OpenAI::Responses::ResponseCompactParams::Input }, nil?: true

#instructionsString?

A system (or developer) message inserted into the model's context. When used along with previous_response_id, the instructions from a previous response will not be carried over to the next response. This makes it simple to swap out system (or developer) messages in new responses.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


34
# File 'lib/openai/models/responses/response_compact_params.rb', line 34

optional :instructions, String, nil?: true

#modelSymbol, ...

Model ID used to generate the response, like gpt-5 or o3. OpenAI offers a wide range of models with different capabilities, performance characteristics, and price points. Refer to the model guide to browse and compare available models.

Parameters:

  • value (OpenAI::Models::Responses::ResponseCompactParams::model, nil)

Returns:



19
# File 'lib/openai/models/responses/response_compact_params.rb', line 19

required :model, union: -> { OpenAI::Responses::ResponseCompactParams::Model }, nil?: true

#previous_response_idString?

The unique ID of the previous response to the model. Use this to create multi-turn conversations. Learn more about conversation state. Cannot be used in conjunction with conversation.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


43
# File 'lib/openai/models/responses/response_compact_params.rb', line 43

optional :previous_response_id, String, nil?: true

#prompt_cache_keyString?

A key to use when reading from or writing to the prompt cache.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


49
# File 'lib/openai/models/responses/response_compact_params.rb', line 49

optional :prompt_cache_key, String, nil?: true

#prompt_cache_optionsOpenAI::Models::Responses::ResponseCompactParams::PromptCacheOptions?

Options for prompt caching. Supported for gpt-5.6 and later models. By default, OpenAI automatically chooses one implicit cache breakpoint. You can add explicit breakpoints to content blocks with prompt_cache_breakpoint. Each request can write up to four breakpoints. For cache matching, OpenAI considers up to the latest 80 breakpoints in the conversation, without a content-block lookback limit. Set mode to explicit to disable the implicit breakpoint. The ttl defaults to 30m, which is currently the only supported value. See the prompt caching guide for current details.

Parameters:

  • value (OpenAI::Responses::ResponseCompactParams::PromptCacheOptions, nil)

Returns:



63
64
65
# File 'lib/openai/models/responses/response_compact_params.rb', line 63

optional :prompt_cache_options,
-> { OpenAI::Responses::ResponseCompactParams::PromptCacheOptions },
nil?: true

#prompt_cache_retentionSymbol, ...

Deprecated.

How long to retain a prompt cache entry created by this request.

Parameters:

  • value (OpenAI::Models::Responses::ResponseCompactParams::prompt_cache_retention, nil)

Returns:



73
74
75
# File 'lib/openai/models/responses/response_compact_params.rb', line 73

optional :prompt_cache_retention,
enum: -> { OpenAI::Responses::ResponseCompactParams::PromptCacheRetention },
nil?: true

#service_tierSymbol, ...

The service tier to use for this request.

Parameters:

  • value (OpenAI::Models::Responses::ResponseCompactParams::service_tier, nil)

Returns:



81
# File 'lib/openai/models/responses/response_compact_params.rb', line 81

optional :service_tier, enum: -> { OpenAI::Responses::ResponseCompactParams::ServiceTier }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/responses/response_compact_params.rb', line 498

Instance Method Details

#to_hash{

Returns:

  • ({)


49
# File 'sig/openai/models/responses/response_compact_params.rbs', line 49

def to_hash: -> {