Module: OpenAI::Models::Responses::ResponseCompactParams::ServiceTier

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/responses/response_compact_params.rb,
sig/openai/models/responses/response_compact_params.rbs

Overview

Specifies the processing type used for serving the request. - If set to 'auto', then the request will be processed with the service tier configured in the Project settings. Unless otherwise configured, the Project will use 'default'. - If set to 'default', then the request will be processed with the standard pricing and performance for the selected model. - If set to 'flex', then the request will be processed with the Flex Processing service tier. - To opt-in to Fast mode at the request level, include the service_tier=fast or service_tier=priority parameter for Responses or Chat Completions. The response will show service_tier=priority regardless of if you specify service_tier=fast or priority in your request. - When not set, the default behavior is 'auto'. When the service_tier parameter is set, the response body will include the service_tier value based on the processing mode actually used to serve the request. This response value may be different from the value set in the parameter.

Constant Summary collapse

AUTO =

Returns:

  • (:auto)
:auto
DEFAULT =

Returns:

  • (:default)
:default
FAST =

Returns:

  • (:fast)
:fast
FLEX =

Returns:

  • (:flex)
:flex
PRIORITY =

Returns:

  • (:priority)
:priority

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/responses/response_compact_params.rb', line 554

Instance Method Details

#self?.values::Array[OpenAI::Models::Responses::ResponseCompactParams::service_tier]

Returns:

  • (::Array[OpenAI::Models::Responses::ResponseCompactParams::service_tier])


345
# File 'sig/openai/models/responses/response_compact_params.rbs', line 345

def self?.values: -> ::Array[OpenAI::Models::Responses::ResponseCompactParams::service_tier]