Class: OpenAI::Models::Responses::ResponseCompactionItem

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_compaction_item.rb,
sig/openai/models/responses/response_compaction_item.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, encrypted_content:, created_by: nil, type: :compaction) ⇒ Object

Parameters:

  • id —

    The unique ID of the compaction item.

  • encrypted_content —

    The encrypted content that was produced by compaction.

  • created_by (defaults to: nil) —

    The identifier of the actor that created the item.

  • type (defaults to: :compaction) —

    The type of the item. Always compaction.



# File 'lib/openai/models/responses/response_compaction_item.rb', line 31

Instance Attribute Details

#created_by ⇒ String?

The identifier of the actor that created the item.

Returns:

  • (String, nil)


29
# File 'lib/openai/models/responses/response_compaction_item.rb', line 29

optional :created_by, String

#encrypted_content ⇒ String

The encrypted content that was produced by compaction.

Returns:

  • (String)


17
# File 'lib/openai/models/responses/response_compaction_item.rb', line 17

required :encrypted_content, String

#id ⇒ String

The unique ID of the compaction item.

Returns:

  • (String)


11
# File 'lib/openai/models/responses/response_compaction_item.rb', line 11

required :id, String

#type ⇒ :compaction

The type of the item. Always compaction.

Returns:

  • (:compaction)


23
# File 'lib/openai/models/responses/response_compaction_item.rb', line 23

required :type, const: :compaction

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


43
# File 'sig/openai/models/responses/response_compaction_item.rbs', line 43

def to_hash: -> {