Class: OpenAI::Models::Responses::ResponseComputerToolCall::Action::Keypress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_computer_tool_call.rb,
sig/openai/models/responses/response_computer_tool_call.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Keypress

Returns a new instance of Keypress.

Parameters:

  • keys —

    The combination of keys the model is requesting to be pressed. This is an array of strings, each representing a key.

  • type —

    Specifies the event type. For a keypress action, this property is always set to keypress.

  • keys: (::Array[String])
  • type: (:keypress)


353
# File 'sig/openai/models/responses/response_computer_tool_call.rbs', line 353

def initialize: (keys: ::Array[String], ?type: :keypress) -> void

Instance Attribute Details

#keys ⇒ ::Array[String]

The combination of keys the model is requesting to be pressed. This is an array of strings, each representing a key.

Returns:

  • (::Array[String])


368
# File 'lib/openai/models/responses/response_computer_tool_call.rb', line 368

required :keys, OpenAI::Internal::Type::ArrayOf[String]

#type ⇒ :keypress

Specifies the event type. For a keypress action, this property is always set to keypress.

Returns:

  • (:keypress)


375
# File 'lib/openai/models/responses/response_computer_tool_call.rb', line 375

required :type, const: :keypress

Instance Method Details

#to_hash ⇒ { keys: ::Array[String], ?type: :keypress }

Returns:

  • ({ keys: ::Array[String], ?type: :keypress })


355
# File 'sig/openai/models/responses/response_computer_tool_call.rbs', line 355

def to_hash: -> { keys: ::Array[String], ?type: :keypress }