Class: OpenAI::Models::Responses::ResponseComputerToolCall::Action::Move

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_computer_tool_call.rb,
sig/openai/models/responses/response_computer_tool_call.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • x —

    The x-coordinate to move to.

  • y_ —

    The y-coordinate to move to.

  • keys —

    The keys being held while moving the mouse.

  • type —

    Specifies the event type. For a move action, this property is always set to move.



384
# File 'sig/openai/models/responses/response_computer_tool_call.rbs', line 384

def initialize: (

Instance Attribute Details

#keys ⇒ ::Array[String]?

The keys being held while moving the mouse.

Returns:

  • (::Array[String], nil)


413
# File 'lib/openai/models/responses/response_computer_tool_call.rb', line 413

optional :keys, OpenAI::Internal::Type::ArrayOf[String], nil?: true

#type ⇒ :move

Specifies the event type. For a move action, this property is always set to move.

Returns:

  • (:move)


395
# File 'lib/openai/models/responses/response_computer_tool_call.rb', line 395

required :type, const: :move

#x ⇒ Integer

The x-coordinate to move to.

Returns:

  • (Integer)


401
# File 'lib/openai/models/responses/response_computer_tool_call.rb', line 401

required :x, Integer

#y_ ⇒ Integer

The y-coordinate to move to.

Returns:

  • (Integer)


407
# File 'lib/openai/models/responses/response_computer_tool_call.rb', line 407

required :y_, Integer, api_name: :y

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


391
# File 'sig/openai/models/responses/response_computer_tool_call.rbs', line 391

def to_hash: -> {