Class: OpenAI::Models::Responses::ResponseComputerToolCall::Action::Scroll

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_computer_tool_call.rb,
sig/openai/models/responses/response_computer_tool_call.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • scroll_x —

    The horizontal scroll distance.

  • scroll_y —

    The vertical scroll distance.

  • x —

    The x-coordinate where the scroll occurred.

  • y_ —

    The y-coordinate where the scroll occurred.

  • keys —

    The keys being held while scrolling.

  • type —

    Specifies the event type. For a scroll action, this property is always set to scroll.



457
# File 'sig/openai/models/responses/response_computer_tool_call.rbs', line 457

def initialize: (

Instance Attribute Details

#keys ⇒ ::Array[String]?

The keys being held while scrolling.

Returns:

  • (::Array[String], nil)


484
# File 'lib/openai/models/responses/response_computer_tool_call.rb', line 484

optional :keys, OpenAI::Internal::Type::ArrayOf[String], nil?: true

#scroll_x ⇒ Integer

The horizontal scroll distance.

Returns:

  • (Integer)


453
# File 'lib/openai/models/responses/response_computer_tool_call.rb', line 453

required :scroll_x, Integer

#scroll_y ⇒ Integer

The vertical scroll distance.

Returns:

  • (Integer)


459
# File 'lib/openai/models/responses/response_computer_tool_call.rb', line 459

required :scroll_y, Integer

#type ⇒ :scroll

Specifies the event type. For a scroll action, this property is always set to scroll.

Returns:

  • (:scroll)


466
# File 'lib/openai/models/responses/response_computer_tool_call.rb', line 466

required :type, const: :scroll

#x ⇒ Integer

The x-coordinate where the scroll occurred.

Returns:

  • (Integer)


472
# File 'lib/openai/models/responses/response_computer_tool_call.rb', line 472

required :x, Integer

#y_ ⇒ Integer

The y-coordinate where the scroll occurred.

Returns:

  • (Integer)


478
# File 'lib/openai/models/responses/response_computer_tool_call.rb', line 478

required :y_, Integer, api_name: :y

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


466
# File 'sig/openai/models/responses/response_computer_tool_call.rbs', line 466

def to_hash: -> {