Class: OpenAI::Models::Responses::ResponseConfigurationUpdateItemParam::Reasoning

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_configuration_update_item_param.rb,
sig/openai/models/responses/response_configuration_update_item_param.rbs

Overview

See Also:

  • OpenAI::Models::Responses::ResponseConfigurationUpdateItemParam#reasoning

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(effort: nil) ⇒ Reasoning

Updates to reasoning configuration. Only effort is supported.

Parameters:

  • effort (Symbol, OpenAI::Models::ReasoningEffort, nil) (defaults to: nil)

    The reasoning effort to use for subsequent responses until another configuration update replaces it.

  • effort: (OpenAI::Models::reasoning_effort, nil) (defaults to: nil)


# File 'lib/openai/models/responses/response_configuration_update_item_param.rb', line 48

Instance Attribute Details

#effortSymbol, ...

The reasoning effort to use for subsequent responses until another configuration update replaces it.

Parameters:

  • value (OpenAI::Models::reasoning_effort, nil)

Returns:



46
# File 'lib/openai/models/responses/response_configuration_update_item_param.rb', line 46

optional :effort, enum: -> { OpenAI::ReasoningEffort }, nil?: true

Instance Method Details

#to_hash{ ?effort: OpenAI::Models::reasoning_effort? }

Returns:

  • ({ ?effort: OpenAI::Models::reasoning_effort? })


41
# File 'sig/openai/models/responses/response_configuration_update_item_param.rbs', line 41

def to_hash: -> { ?effort: OpenAI::Models::reasoning_effort? }