Class: OpenAI::Models::Responses::ResponseCreateParams::AccessPrograms
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseCreateParams::AccessPrograms
- Defined in:
- lib/openai/models/responses/response_create_params.rb,
sig/openai/models/responses/response_create_params.rbs
Defined Under Namespace
Modules: Cyber
Instance Attribute Summary collapse
-
#cyber ⇒ OpenAI::Models::Responses::ResponseCreateParams::AccessPrograms::cyber?
The Cyber access program to use for this request.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(cyber: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cyber: nil) ⇒ Object
639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/openai/models/responses/response_create_params.rb', line 639 class AccessPrograms < OpenAI::Internal::Type::BaseModel # @!attribute cyber # The Cyber access program to use for this request. Supported values are # `standard`, `daybreak_blue`, and `daybreak_red`. If omitted, the API resolves # the program from the model's Cyber tier and your organization and project # access, subject to model-specific eligibility restrictions. By default, models # without a Cyber tier use Standard. Blue-tier models use Daybreak Blue when # authorized; otherwise they fall back to Standard unless the model requires # Daybreak access. Red-tier models use Daybreak Red and require authorization. # Requests that require unavailable Daybreak access return 403. An implicit # Standard fallback is represented by null in the response's access_programs # field, rather than an explicit Standard selection. # # @return [Symbol, OpenAI::Models::Responses::ResponseCreateParams::AccessPrograms::Cyber, nil] optional :cyber, enum: -> { OpenAI::Responses::ResponseCreateParams::AccessPrograms::Cyber } # @!method initialize(cyber: nil) # Domain-specific access programs to use for this request. # # @param cyber [Symbol, OpenAI::Models::Responses::ResponseCreateParams::AccessPrograms::Cyber] # The Cyber access program to use for this request. Supported values are # `standard`, `daybreak_blue`, and `daybreak_red`. If omitted, the API resolves # the program from the model's Cyber tier and your organization and project # access, subject to model-specific eligibility restrictions. By default, models # without a Cyber tier use Standard. Blue-tier models use Daybreak Blue when # authorized; otherwise they fall back to Standard unless the model requires # Daybreak access. Red-tier models use Daybreak Red and require authorization. # Requests that require unavailable Daybreak access return 403. An implicit # Standard fallback is represented by null in the response's access_programs # field, rather than an explicit Standard selection. # The Cyber access program to use for this request. Supported values are # `standard`, `daybreak_blue`, and `daybreak_red`. If omitted, the API resolves # the program from the model's Cyber tier and your organization and project # access, subject to model-specific eligibility restrictions. By default, models # without a Cyber tier use Standard. Blue-tier models use Daybreak Blue when # authorized; otherwise they fall back to Standard unless the model requires # Daybreak access. Red-tier models use Daybreak Red and require authorization. # Requests that require unavailable Daybreak access return 403. An implicit # Standard fallback is represented by null in the response's access_programs # field, rather than an explicit Standard selection. # # @see OpenAI::Models::Responses::ResponseCreateParams::AccessPrograms#cyber module Cyber extend OpenAI::Internal::Type::Enum STANDARD = :standard DAYBREAK_BLUE = :daybreak_blue DAYBREAK_RED = :daybreak_red # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#cyber ⇒ OpenAI::Models::Responses::ResponseCreateParams::AccessPrograms::cyber?
The Cyber access program to use for this request. Supported values are
standard, daybreak_blue, and daybreak_red. If omitted, the API resolves
the program from the model's Cyber tier and your organization and project
access, subject to model-specific eligibility restrictions. By default, models
without a Cyber tier use Standard. Blue-tier models use Daybreak Blue when
authorized; otherwise they fall back to Standard unless the model requires
Daybreak access. Red-tier models use Daybreak Red and require authorization.
Requests that require unavailable Daybreak access return 403. An implicit
Standard fallback is represented by null in the response's access_programs
field, rather than an explicit Standard selection.
653 |
# File 'lib/openai/models/responses/response_create_params.rb', line 653 optional :cyber, enum: -> { OpenAI::Responses::ResponseCreateParams::AccessPrograms::Cyber } |
Instance Method Details
#to_hash ⇒ {
713 |
# File 'sig/openai/models/responses/response_create_params.rbs', line 713
def to_hash: -> {
|