Class: OpenAI::Models::Responses::ResponseCustomToolCallInputDoneEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_custom_tool_call_input_done_event.rb,
sig/openai/models/responses/response_custom_tool_call_input_done_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(input:, item_id:, output_index:, sequence_number:, type: :"response.custom_tool_call_input.done") ⇒ Object

Parameters:

  • input —

    The complete input data for the custom tool call.

  • item_id —

    Unique identifier for the API item associated with this event.

  • output_index —

    The index of the output this event applies to.

  • sequence_number —

    The sequence number of this event.

  • type (defaults to: :"response.custom_tool_call_input.done") —

    The event type identifier.



# File 'lib/openai/models/responses/response_custom_tool_call_input_done_event.rb', line 37

Instance Attribute Details

#input ⇒ String

The complete input data for the custom tool call.

Returns:

  • (String)


11
# File 'lib/openai/models/responses/response_custom_tool_call_input_done_event.rb', line 11

required :input, String

#item_id ⇒ String

Unique identifier for the API item associated with this event.

Returns:

  • (String)


17
# File 'lib/openai/models/responses/response_custom_tool_call_input_done_event.rb', line 17

required :item_id, String

#output_index ⇒ Integer

The index of the output this event applies to.

Returns:

  • (Integer)


23
# File 'lib/openai/models/responses/response_custom_tool_call_input_done_event.rb', line 23

required :output_index, Integer

#sequence_number ⇒ Integer

The sequence number of this event.

Returns:

  • (Integer)


29
# File 'lib/openai/models/responses/response_custom_tool_call_input_done_event.rb', line 29

required :sequence_number, Integer

#type ⇒ :"response.custom_tool_call_input.done"

The event type identifier.

Returns:

  • (:"response.custom_tool_call_input.done")


35
# File 'lib/openai/models/responses/response_custom_tool_call_input_done_event.rb', line 35

required :type, const: :"response.custom_tool_call_input.done"

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


47
# File 'sig/openai/models/responses/response_custom_tool_call_input_done_event.rbs', line 47

def to_hash: -> {