Class: OpenAI::Models::Responses::ResponseCustomToolCallItem

Inherits:
ResponseCustomToolCall show all
Defined in:
lib/openai/models/responses/response_custom_tool_call_item.rb,
sig/openai/models/responses/response_custom_tool_call_item.rbs

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Attributes inherited from ResponseCustomToolCall

#call_id, #caller_, #input, #name, #namespace, #type

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_id:, input:, name:, id:, status:, caller_: nil, namespace: nil, created_by: nil, type: :custom_tool_call) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseCustomToolCallItem for more details.

A call to a custom tool created by the model.

Parameters:

  • call_id (String)

    An identifier used to map this custom tool call to a tool call output.

  • input (String)

    The input for the custom tool call generated by the model.

  • name (String)

    The name of the custom tool being called.

  • id (String)

    The unique ID of the custom tool call item.

  • status (Symbol, OpenAI::Models::Responses::ResponseCustomToolCallItem::Status)

    The status of the item. One of in_progress, completed, or

  • caller_ (OpenAI::Models::Responses::ResponseCustomToolCall::Caller::Direct, OpenAI::Models::Responses::ResponseCustomToolCall::Caller::Program, nil) (defaults to: nil)

    The execution context that produced this tool call.

  • namespace (String) (defaults to: nil)

    The namespace of the custom tool being called.

  • created_by (String) (defaults to: nil)

    The identifier of the actor that created the item.

  • type (Symbol, :custom_tool_call) (defaults to: :custom_tool_call)

    The type of the custom tool call. Always custom_tool_call.



# File 'lib/openai/models/responses/response_custom_tool_call_item.rb', line 26

Instance Attribute Details

#created_byString?

The identifier of the actor that created the item.

Parameters:

  • _ (String)

Returns:

  • (String, nil)


24
# File 'lib/openai/models/responses/response_custom_tool_call_item.rb', line 24

optional :created_by, String

#idString

The unique ID of the custom tool call item.

Parameters:

  • _ (String)

Returns:

  • (String)


11
# File 'lib/openai/models/responses/response_custom_tool_call_item.rb', line 11

required :id, String

#statusSymbol, OpenAI::Models::Responses::ResponseCustomToolCallItem::Status

The status of the item. One of in_progress, completed, or incomplete. Populated when items are returned via API.



18
# File 'lib/openai/models/responses/response_custom_tool_call_item.rb', line 18

required :status, enum: -> { OpenAI::Responses::ResponseCustomToolCallItem::Status }

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/openai/models/responses/response_custom_tool_call_item.rbs', line 44

def to_hash: -> {