Class: OpenAI::Models::Responses::ResponseCustomToolCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_custom_tool_call_output.rb,
sig/openai/models/responses/response_custom_tool_call_output.rbs

Direct Known Subclasses

ResponseCustomToolCallOutputItem

Defined Under Namespace

Modules: Caller, Output

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_id:, output:, id: nil, caller_: nil, type: :custom_tool_call_output) ⇒ Object

Parameters:

  • call_id —

    The call ID, used to map this custom tool call output to a custom tool call.

  • output —

    The output from the custom tool call generated by your code. Can be a string or an list of output content.

  • id (defaults to: nil) —

    The unique ID of the custom tool call output in the OpenAI platform.

  • caller_ (defaults to: nil) —

    The execution context that produced this tool call.

  • type (defaults to: :custom_tool_call_output) —

    The type of the custom tool call output. Always custom_tool_call_output.



# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 43

Instance Attribute Details

#call_id ⇒ String

The call ID, used to map this custom tool call output to a custom tool call.

Returns:

  • (String)


11
# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 11

required :call_id, String

#caller_ ⇒ OpenAI::Models::Responses::ResponseCustomToolCallOutput::caller_?

The execution context that produced this tool call.

Returns:

  • (OpenAI::Models::Responses::ResponseCustomToolCallOutput::caller_, nil)


36
37
38
39
40
41
# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 36

optional(
  :caller_,
  union: -> { OpenAI::Responses::ResponseCustomToolCallOutput::Caller },
  api_name: :caller,
  nil?: true
)

#id ⇒ String?

The unique ID of the custom tool call output in the OpenAI platform.

Returns:

  • (String, nil)


30
# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 30

optional :id, String

#output ⇒ OpenAI::Models::Responses::ResponseCustomToolCallOutput::output

The output from the custom tool call generated by your code. Can be a string or an list of output content.

Returns:

  • (OpenAI::Models::Responses::ResponseCustomToolCallOutput::output)


18
# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 18

required :output, union: -> { OpenAI::Responses::ResponseCustomToolCallOutput::Output }

#type ⇒ :custom_tool_call_output

The type of the custom tool call output. Always custom_tool_call_output.

Returns:

  • (:custom_tool_call_output)


24
# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 24

required :type, const: :custom_tool_call_output

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


52
# File 'sig/openai/models/responses/response_custom_tool_call_output.rbs', line 52

def to_hash: -> {