Module: OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent::Outcome
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/responses/response_function_shell_call_output_content.rb,
sig/openai/models/responses/response_function_shell_call_output_content.rbs
Overview
The exit or timeout outcome associated with this shell call.
Defined Under Namespace
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(type: :timeout) ⇒ Object
Indicates that the shell call exceeded its configured time limit.
- #self?.variants ⇒ ::Array[OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent::outcome]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent::Outcome::Timeout, OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent::Outcome::Exit)
|
|
# File 'lib/openai/models/responses/response_function_shell_call_output_content.rb', line 82
|
Instance Method Details
#initialize(type: :timeout) ⇒ Object
Indicates that the shell call exceeded its configured time limit.
|
|
# File 'lib/openai/models/responses/response_function_shell_call_output_content.rb', line 55
|
#self?.variants ⇒ ::Array[OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent::outcome]
59 |
# File 'sig/openai/models/responses/response_function_shell_call_output_content.rbs', line 59
def self?.variants: -> ::Array[OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent::outcome]
|