Class: OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent::Outcome::Exit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent::Outcome::Exit
- Defined in:
- lib/openai/models/responses/response_function_shell_call_output_content.rb,
sig/openai/models/responses/response_function_shell_call_output_content.rbs
Instance Attribute Summary collapse
-
#exit_code ⇒ Integer
The exit code returned by the shell process.
-
#type ⇒ Symbol, :exit
The outcome type.
Instance Method Summary collapse
-
#initialize(exit_code:, type: :exit) ⇒ Exit
constructor
Indicates that the shell commands finished and returned an exit code.
- #to_hash ⇒ { exit_code: Integer, type: :exit }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(exit_code:, type: :exit) ⇒ Exit
Indicates that the shell commands finished and returned an exit code.
|
|
# File 'lib/openai/models/responses/response_function_shell_call_output_content.rb', line 74
|
Instance Attribute Details
#exit_code ⇒ Integer
The exit code returned by the shell process.
66 |
# File 'lib/openai/models/responses/response_function_shell_call_output_content.rb', line 66 required :exit_code, Integer |
#type ⇒ Symbol, :exit
The outcome type. Always exit.
72 |
# File 'lib/openai/models/responses/response_function_shell_call_output_content.rb', line 72 required :type, const: :exit |
Instance Method Details
#to_hash ⇒ { exit_code: Integer, type: :exit }
56 |
# File 'sig/openai/models/responses/response_function_shell_call_output_content.rbs', line 56
def to_hash: -> { exit_code: Integer, type: :exit }
|