Class: OpenAI::Models::Responses::ResponseFunctionShellToolCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_function_shell_tool_call.rb

Defined Under Namespace

Modules: Environment, Status Classes: Action

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(commands:, max_output_length:, timeout_ms:) ⇒ Object

The shell commands and limits that describe how to run the tool call.

Parameters:

  • Optional maximum number of characters to return from each command.

  • Optional timeout in milliseconds for the commands.



# File 'lib/openai/models/responses/response_function_shell_tool_call.rb', line 53


Instance Attribute Details

#actionOpenAI::Models::Responses::ResponseFunctionShellToolCall::Action

The shell commands and limits that describe how to run the tool call.

Returns:



18
# File 'lib/openai/models/responses/response_function_shell_tool_call.rb', line 18

required :action, -> { OpenAI::Responses::ResponseFunctionShellToolCall::Action }

#call_idString

The unique ID of the shell tool call generated by the model.

Returns:



24
# File 'lib/openai/models/responses/response_function_shell_tool_call.rb', line 24

required :call_id, String

#created_byString?

The ID of the entity that created this tool call.

Returns:



51
# File 'lib/openai/models/responses/response_function_shell_tool_call.rb', line 51

optional :created_by, String

#environmentOpenAI::Models::Responses::ResponseLocalEnvironment, ...

Represents the use of a local environment to perform shell actions.

Returns:



30
31
32
# File 'lib/openai/models/responses/response_function_shell_tool_call.rb', line 30

required :environment,
union: -> { OpenAI::Responses::ResponseFunctionShellToolCall::Environment },
nil?: true

#idString

The unique ID of the shell tool call. Populated when this item is returned via API.

Returns:



12
# File 'lib/openai/models/responses/response_function_shell_tool_call.rb', line 12

required :id, String

#statusSymbol, OpenAI::Models::Responses::ResponseFunctionShellToolCall::Status

The status of the shell call. One of in_progress, completed, or incomplete.

Returns:



39
# File 'lib/openai/models/responses/response_function_shell_tool_call.rb', line 39

required :status, enum: -> { OpenAI::Responses::ResponseFunctionShellToolCall::Status }

#typeSymbol, :shell_call

The type of the item. Always shell_call.

Returns:



45
# File 'lib/openai/models/responses/response_function_shell_tool_call.rb', line 45

required :type, const: :shell_call

Class Method Details

.variantsArray(OpenAI::Models::Responses::ResponseLocalEnvironment, OpenAI::Models::Responses::ResponseContainerReference)

Returns:



# File 'lib/openai/models/responses/response_function_shell_tool_call.rb', line 116