Class: OpenAI::Models::Responses::ResponseFunctionShellToolCall::Action

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_function_shell_tool_call.rb,
sig/openai/models/responses/response_function_shell_tool_call.rbs

Overview

See Also:

  • OpenAI::Models::Responses::ResponseFunctionShellToolCall#action

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Parameters:

  • Optional maximum number of characters to return from each command.

  • Optional timeout in milliseconds for the commands.



106
# File 'sig/openai/models/responses/response_function_shell_tool_call.rbs', line 106

def initialize: (

Instance Attribute Details

#commandsArray<String>

Parameters:

Returns:



100
# File 'lib/openai/models/responses/response_function_shell_tool_call.rb', line 100

required :commands, OpenAI::Internal::Type::ArrayOf[String]

#max_output_lengthInteger?

Optional maximum number of characters to return from each command.

Returns:



106
# File 'lib/openai/models/responses/response_function_shell_tool_call.rb', line 106

required :max_output_length, Integer, nil?: true

#timeout_msInteger?

Optional timeout in milliseconds for the commands.

Returns:



112
# File 'lib/openai/models/responses/response_function_shell_tool_call.rb', line 112

required :timeout_ms, Integer, nil?: true

Instance Method Details

#to_hash{

Returns:



112
# File 'sig/openai/models/responses/response_function_shell_tool_call.rbs', line 112

def to_hash: -> {