Module: OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Output::Outcome
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/responses/response_function_shell_tool_call_output.rb
Overview
Represents either an exit outcome (with an exit code) or a timeout outcome for a shell call output chunk.
Defined Under Namespace
Instance Method Summary collapse
-
#initialize(type: :timeout) ⇒ Object
Indicates that the shell call exceeded its configured time limit.
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(type: :timeout) ⇒ Object
Indicates that the shell call exceeded its configured time limit.
|
|
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 137
|