Class: OpenAI::Models::Responses::ResponseFunctionToolCallItem

Inherits:
ResponseFunctionToolCall show all
Defined in:
lib/openai/models/responses/response_function_tool_call_item.rb,
sig/openai/models/responses/response_function_tool_call_item.rbs

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Attributes inherited from ResponseFunctionToolCall

#arguments, #async, #call_id, #caller_, #name, #namespace, #type

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from ResponseFunctionToolCall

variants

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(arguments:, call_id:, name:, id:, status:, async: nil, caller_: nil, namespace: nil, created_by: nil, type: :function_call) ⇒ Object

Parameters:

  • arguments —

    A JSON string of the arguments to pass to the function.

  • call_id —

    The unique ID of the function tool call generated by the model.

  • name —

    The name of the function to run.

  • id —

    The unique ID of the function tool call.

  • status —

    The status of the item. One of in_progress, completed, or incomplete. Populated when items are returned via API.

  • async (defaults to: nil) —

    Whether the function tool call runs asynchronously.

  • caller_ (defaults to: nil) —

    The execution context that produced this tool call.

  • namespace (defaults to: nil) —

    The namespace of the function to run.

  • created_by (defaults to: nil) —

    The identifier of the actor that created the item.

  • type (defaults to: :function_call) —

    The type of the function tool call. Always function_call.



# File 'lib/openai/models/responses/response_function_tool_call_item.rb', line 26

Instance Attribute Details

#created_by ⇒ String?

The identifier of the actor that created the item.

Returns:

  • (String, nil)


24
# File 'lib/openai/models/responses/response_function_tool_call_item.rb', line 24

optional :created_by, String

#id ⇒ String

The unique ID of the function tool call.

Returns:

  • (String)


11
# File 'lib/openai/models/responses/response_function_tool_call_item.rb', line 11

required :id, String

#status ⇒ OpenAI::Models::Responses::ResponseFunctionToolCallItem::status

The status of the item. One of in_progress, completed, or incomplete. Populated when items are returned via API.

Returns:

  • (OpenAI::Models::Responses::ResponseFunctionToolCallItem::status)


18
# File 'lib/openai/models/responses/response_function_tool_call_item.rb', line 18

required :status, enum: -> { OpenAI::Responses::ResponseFunctionToolCallItem::Status }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


75
# File 'sig/openai/models/responses/response_function_tool_call_item.rbs', line 75

def to_hash: -> {