Class: OpenAI::Models::Responses::ResponseFunctionWebSearch

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_function_web_search.rb

Defined Under Namespace

Modules: Action, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(pattern:, url:, type: :find_in_page) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseFunctionWebSearch::Action::Find for more details.

Action type “find_in_page”: Searches for a pattern within a loaded page.

Parameters:

  • The pattern or text to search for within the page.

  • The URL of the page searched for the pattern.

  • (defaults to: :find_in_page)

    The action type.



# File 'lib/openai/models/responses/response_function_web_search.rb', line 32

Instance Attribute Details

#actionOpenAI::Models::Responses::ResponseFunctionWebSearch::Action::Search, ...

An object describing the specific action taken in this web search call. Includes details on how the model used the web (search, open_page, find_in_page).

Returns:



18
# File 'lib/openai/models/responses/response_function_web_search.rb', line 18

required :action, union: -> { OpenAI::Responses::ResponseFunctionWebSearch::Action }

#idString

The unique ID of the web search tool call.

Returns:



11
# File 'lib/openai/models/responses/response_function_web_search.rb', line 11

required :id, String

#statusSymbol, OpenAI::Models::Responses::ResponseFunctionWebSearch::Status

The status of the web search tool call.

Returns:



24
# File 'lib/openai/models/responses/response_function_web_search.rb', line 24

required :status, enum: -> { OpenAI::Responses::ResponseFunctionWebSearch::Status }

#typeSymbol, :web_search_call

The type of the web search tool call. Always web_search_call.

Returns:



30
# File 'lib/openai/models/responses/response_function_web_search.rb', line 30

required :type, const: :web_search_call

Class Method Details

.variantsArray(OpenAI::Models::Responses::ResponseFunctionWebSearch::Action::Search, OpenAI::Models::Responses::ResponseFunctionWebSearch::Action::OpenPage, OpenAI::Models::Responses::ResponseFunctionWebSearch::Action::Find)

Returns:



# File 'lib/openai/models/responses/response_function_web_search.rb', line 191