Module: OpenAI::Models::Responses::ResponseFunctionWebSearch::Action
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/responses/response_function_web_search.rb,
sig/openai/models/responses/response_function_web_search.rbs
Overview
An object describing the specific action taken in this web search call. Includes details on how the model used the web (search, open_page, find_in_page).
Defined Under Namespace
Classes: Find, OpenPage, Search
Instance Method Summary collapse
-
#initialize(url: nil, type: :open_page) ⇒ Object
Some parameter documentations has been truncated, see OpenPage for more details.
- #self?.variants ⇒ ::Array[OpenAI::Models::Responses::ResponseFunctionWebSearch::action]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(url: nil, type: :open_page) ⇒ Object
Some parameter documentations has been truncated, see OpenPage for more details.
Action type "open_page" - Opens a specific URL from search results.
|
|
# File 'lib/openai/models/responses/response_function_web_search.rb', line 122
|
#self?.variants ⇒ ::Array[OpenAI::Models::Responses::ResponseFunctionWebSearch::action]
130 |
# File 'sig/openai/models/responses/response_function_web_search.rbs', line 130
def self?.variants: -> ::Array[OpenAI::Models::Responses::ResponseFunctionWebSearch::action]
|