Class: OpenAI::Models::Responses::ResponseFunctionWebSearch::Action::Find

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_function_web_search.rb,
sig/openai/models/responses/response_function_web_search.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • pattern —

    The pattern or text to search for within the page.

  • url —

    The URL of the page searched for the pattern.

  • type —

    The action type.



167
# File 'sig/openai/models/responses/response_function_web_search.rbs', line 167

def initialize: (

Instance Attribute Details

#pattern ⇒ String

The pattern or text to search for within the page.

Returns:

  • (String)


166
# File 'lib/openai/models/responses/response_function_web_search.rb', line 166

required :pattern, String

#type ⇒ :find_in_page

The action type.

Returns:

  • (:find_in_page)


172
# File 'lib/openai/models/responses/response_function_web_search.rb', line 172

required :type, const: :find_in_page

#url ⇒ String

The URL of the page searched for the pattern.

Returns:

  • (String)


178
# File 'lib/openai/models/responses/response_function_web_search.rb', line 178

required :url, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


173
# File 'sig/openai/models/responses/response_function_web_search.rbs', line 173

def to_hash: -> {