Class: OpenAI::Models::Responses::ResponseInputFile
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputFile
- Defined in:
- lib/openai/models/responses/response_input_file.rb,
sig/openai/models/responses/response_input_file.rbs
Defined Under Namespace
Modules: Detail Classes: PromptCacheBreakpoint
Instance Attribute Summary collapse
-
#detail ⇒ Symbol, ...
The detail level of the file to be sent to the model.
-
#file_data ⇒ String?
The content of the file to be sent to the model.
-
#file_id ⇒ String?
The ID of the file to be sent to the model.
-
#file_url ⇒ String?
The URL of the file to be sent to the model.
-
#filename ⇒ String?
The name of the file to be sent to the model.
-
#prompt_cache_breakpoint ⇒ OpenAI::Models::Responses::ResponseInputFile::PromptCacheBreakpoint?
Marks the exact end of a reusable prompt prefix.
-
#type ⇒ Symbol, :input_file
The type of the input item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(detail: nil, file_data: nil, file_id: nil, file_url: nil, filename: nil, prompt_cache_breakpoint: nil, type: :input_file) ⇒ Object
constructor
Some parameter documentations has been truncated, see ResponseInputFile for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(detail: nil, file_data: nil, file_id: nil, file_url: nil, filename: nil, prompt_cache_breakpoint: nil, type: :input_file) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseInputFile for more details.
A file input to the model.
|
|
# File 'lib/openai/models/responses/response_input_file.rb', line 55
|
Instance Attribute Details
#detail ⇒ Symbol, ...
The detail level of the file to be sent to the model. Use auto to let the
system select the detail level; for GPT-5.6 and later models, auto uses
high-quality rendering, which may increase input token usage. Use low for
lower-cost rendering, or high to render the file at higher quality. Defaults
to auto.
21 |
# File 'lib/openai/models/responses/response_input_file.rb', line 21 optional :detail, enum: -> { OpenAI::Responses::ResponseInputFile::Detail } |
#file_data ⇒ String?
The content of the file to be sent to the model.
27 |
# File 'lib/openai/models/responses/response_input_file.rb', line 27 optional :file_data, String |
#file_id ⇒ String?
The ID of the file to be sent to the model.
33 |
# File 'lib/openai/models/responses/response_input_file.rb', line 33 optional :file_id, String, nil?: true |
#file_url ⇒ String?
The URL of the file to be sent to the model.
39 |
# File 'lib/openai/models/responses/response_input_file.rb', line 39 optional :file_url, String |
#filename ⇒ String?
The name of the file to be sent to the model.
45 |
# File 'lib/openai/models/responses/response_input_file.rb', line 45 optional :filename, String |
#prompt_cache_breakpoint ⇒ OpenAI::Models::Responses::ResponseInputFile::PromptCacheBreakpoint?
Marks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL
from the request's prompt_cache_options.ttl; the boundary is not rounded to a
token block.
53 |
# File 'lib/openai/models/responses/response_input_file.rb', line 53 optional :prompt_cache_breakpoint, -> { OpenAI::Responses::ResponseInputFile::PromptCacheBreakpoint } |
#type ⇒ Symbol, :input_file
The type of the input item. Always input_file.
11 |
# File 'lib/openai/models/responses/response_input_file.rb', line 11 required :type, const: :input_file |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/response_input_file.rb', line 89
|
Instance Method Details
#to_hash ⇒ {
54 |
# File 'sig/openai/models/responses/response_input_file.rbs', line 54
def to_hash: -> {
|