Class: OpenAI::Models::Responses::ResponseInputFileContent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_file_content.rb,
sig/openai/models/responses/response_input_file_content.rbs

Defined Under Namespace

Modules: Detail Classes: PromptCacheBreakpoint

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(detail: nil, file_data: nil, file_id: nil, file_url: nil, filename: nil, prompt_cache_breakpoint: nil, type: :input_file) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseInputFileContent for more details.

A file input to the model.

Parameters:

  • detail (Symbol, OpenAI::Models::Responses::ResponseInputFileContent::Detail) (defaults to: nil)

    The detail level of the file to be sent to the model. Use auto to let the syst

  • file_data (String, nil) (defaults to: nil)

    The base64-encoded data of the file to be sent to the model.

  • file_id (String, nil) (defaults to: nil)

    The ID of the file to be sent to the model.

  • file_url (String, nil) (defaults to: nil)

    The URL of the file to be sent to the model.

  • filename (String, nil) (defaults to: nil)

    The name of the file to be sent to the model.

  • prompt_cache_breakpoint (OpenAI::Models::Responses::ResponseInputFileContent::PromptCacheBreakpoint, nil) (defaults to: nil)

    Marks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL

  • type (Symbol, :input_file) (defaults to: :input_file)

    The type of the input item. Always input_file.



# File 'lib/openai/models/responses/response_input_file_content.rb', line 57

Instance Attribute Details

#detailSymbol, ...

The detail level of the file to be sent to the model. Use auto to let the system select the detail level; for GPT-5.6 and later models, auto uses high-quality rendering, which may increase input token usage. Use low for lower-cost rendering, or high to render the file at higher quality. Defaults to auto.



21
# File 'lib/openai/models/responses/response_input_file_content.rb', line 21

optional :detail, enum: -> { OpenAI::Responses::ResponseInputFileContent::Detail }

#file_dataString?

The base64-encoded data of the file to be sent to the model.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


27
# File 'lib/openai/models/responses/response_input_file_content.rb', line 27

optional :file_data, String, nil?: true

#file_idString?

The ID of the file to be sent to the model.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


33
# File 'lib/openai/models/responses/response_input_file_content.rb', line 33

optional :file_id, String, nil?: true

#file_urlString?

The URL of the file to be sent to the model.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


39
# File 'lib/openai/models/responses/response_input_file_content.rb', line 39

optional :file_url, String, nil?: true

#filenameString?

The name of the file to be sent to the model.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


45
# File 'lib/openai/models/responses/response_input_file_content.rb', line 45

optional :filename, String, nil?: true

#prompt_cache_breakpointOpenAI::Models::Responses::ResponseInputFileContent::PromptCacheBreakpoint?

Marks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL from the request's prompt_cache_options.ttl; the boundary is not rounded to a token block.

Parameters:

  • value (OpenAI::Responses::ResponseInputFileContent::PromptCacheBreakpoint, nil)

Returns:



53
54
55
# File 'lib/openai/models/responses/response_input_file_content.rb', line 53

optional :prompt_cache_breakpoint,
-> { OpenAI::Responses::ResponseInputFileContent::PromptCacheBreakpoint },
nil?: true

#typeSymbol, :input_file

The type of the input item. Always input_file.

Parameters:

  • value (:input_file)

Returns:

  • (Symbol, :input_file)


11
# File 'lib/openai/models/responses/response_input_file_content.rb', line 11

required :type, const: :input_file

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/responses/response_input_file_content.rb', line 91

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/openai/models/responses/response_input_file_content.rbs', line 44

def to_hash: -> {