Module: OpenAI::Models::Responses::ResponseInputFileContent::Detail
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/responses/response_input_file_content.rb,
sig/openai/models/responses/response_input_file_content.rbs
Overview
The detail level of the file to be sent to the model. Use low for the default
rendering behavior, or high to render the file at higher quality. Defaults to
low.
Constant Summary collapse
- LOW =
:low- HIGH =
:high
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/response_input_file_content.rb', line 74
|
Instance Method Details
#self?.values ⇒ ::Array[OpenAI::Models::Responses::ResponseInputFileContent::detail]
57 |
# File 'sig/openai/models/responses/response_input_file_content.rbs', line 57
def self?.values: -> ::Array[OpenAI::Models::Responses::ResponseInputFileContent::detail]
|