Class: OpenAI::Models::Responses::ResponseInputImage::PromptCacheBreakpoint

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_image.rb,
sig/openai/models/responses/response_input_image.rbs

Overview

See Also:

  • OpenAI::Models::Responses::ResponseInputImage#prompt_cache_breakpoint

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(mode: :explicit) ⇒ PromptCacheBreakpoint

Marks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL from the request's prompt_cache_options.ttl; the boundary is not rounded to a token block.

Parameters:

  • mode (Symbol, :explicit) (defaults to: :explicit)

    The breakpoint mode. Always explicit.

  • mode: (:explicit) (defaults to: :explicit)


# File 'lib/openai/models/responses/response_input_image.rb', line 82

Instance Attribute Details

#modeSymbol, :explicit

The breakpoint mode. Always explicit.

Parameters:

  • value (:explicit)

Returns:

  • (Symbol, :explicit)


80
# File 'lib/openai/models/responses/response_input_image.rb', line 80

required :mode, const: :explicit

Instance Method Details

#to_hash{ mode: :explicit }

Returns:

  • ({ mode: :explicit })


64
# File 'sig/openai/models/responses/response_input_image.rbs', line 64

def to_hash: -> { mode: :explicit }