Class: OpenAI::Models::Responses::ResponseInputImageContent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_image_content.rb

Defined Under Namespace

Modules: Detail

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(detail: nil, file_id: nil, image_url: nil, type: :input_image) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseInputImageContent for more details.

An image input to the model. Learn about [image inputs](platform.openai.com/docs/guides/vision)

Parameters:

  • (defaults to: nil)

    The detail level of the image to be sent to the model. One of high, low, ‘au

  • (defaults to: nil)

    The ID of the file to be sent to the model.

  • (defaults to: nil)

    The URL of the image to be sent to the model. A fully qualified URL or base64 en

  • (defaults to: :input_image)

    The type of the input item. Always input_image.



# File 'lib/openai/models/responses/response_input_image_content.rb', line 33


Instance Attribute Details

#detailSymbol, ...

The detail level of the image to be sent to the model. One of high, low, auto, or original. Defaults to auto.

Returns:



18
# File 'lib/openai/models/responses/response_input_image_content.rb', line 18

optional :detail, enum: -> { OpenAI::Responses::ResponseInputImageContent::Detail }, nil?: true

#file_idString?

The ID of the file to be sent to the model.

Returns:



24
# File 'lib/openai/models/responses/response_input_image_content.rb', line 24

optional :file_id, String, nil?: true

#image_urlString?

The URL of the image to be sent to the model. A fully qualified URL or base64 encoded image in a data URL.

Returns:



31
# File 'lib/openai/models/responses/response_input_image_content.rb', line 31

optional :image_url, String, nil?: true

#typeSymbol, :input_image

The type of the input item. Always input_image.

Returns:



11
# File 'lib/openai/models/responses/response_input_image_content.rb', line 11

required :type, const: :input_image