Module: OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Operation
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs
Overview
The specific create, delete, or update instruction for the apply_patch tool call.
Defined Under Namespace
Classes: CreateFile, DeleteFile, UpdateFile
Instance Method Summary collapse
-
#initialize(path:, type: :delete_file) ⇒ Object
Instruction for deleting an existing file via the apply_patch tool.
- #self?.variants ⇒ ::Array[OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::operation]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(path:, type: :delete_file) ⇒ Object
Instruction for deleting an existing file via the apply_patch tool.
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 1218
|
#self?.variants ⇒ ::Array[OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::operation]
883 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 883
def self?.variants: -> ::Array[OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::operation]
|