Class: OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Operation::DeleteFile
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Operation::DeleteFile
- Defined in:
- lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs
Instance Attribute Summary collapse
-
#path ⇒ String
Path of the file to delete relative to the workspace root.
-
#type ⇒ Symbol, :delete_file
The operation type.
Instance Method Summary collapse
-
#initialize ⇒ DeleteFile
constructor
A new instance of DeleteFile.
- #to_hash ⇒ { path: String, type: :delete_file }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ DeleteFile
Returns a new instance of DeleteFile.
859 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 859
def initialize: (path: String, ?type: :delete_file) -> void
|
Instance Attribute Details
#path ⇒ String
Path of the file to delete relative to the workspace root.
1233 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1233 required :path, String |
#type ⇒ Symbol, :delete_file
The operation type. Always delete_file.
1239 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1239 required :type, const: :delete_file |
Instance Method Details
#to_hash ⇒ { path: String, type: :delete_file }
861 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 861
def to_hash: -> { path: String, type: :delete_file }
|