Class: OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Operation::UpdateFile

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



874
# File 'sig/openai/models/responses/response_input_item.rbs', line 874

def initialize: (

Instance Attribute Details

#diffString

Unified diff content to apply to the existing file.

Parameters:

  • value (String)

Returns:

  • (String)


1254
# File 'lib/openai/models/responses/response_input_item.rb', line 1254

required :diff, String

#pathString

Path of the file to update relative to the workspace root.

Parameters:

  • value (String)

Returns:

  • (String)


1260
# File 'lib/openai/models/responses/response_input_item.rb', line 1260

required :path, String

#typeSymbol, :update_file

The operation type. Always update_file.

Parameters:

  • value (:update_file)

Returns:

  • (Symbol, :update_file)


1266
# File 'lib/openai/models/responses/response_input_item.rb', line 1266

required :type, const: :update_file

Instance Method Details

#to_hash{ diff: String, path: String, type: :update_file }

Returns:

  • ({ diff: String, path: String, type: :update_file })


880
# File 'sig/openai/models/responses/response_input_item.rbs', line 880

def to_hash: -> { diff: String, path: String, type: :update_file }