Class: OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs

Defined Under Namespace

Modules: Caller, Status

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_id:, status:, id: nil, caller_: nil, output: nil, type: :apply_patch_call_output) ⇒ Object

Parameters:

  • call_id —

    The unique ID of the apply patch tool call generated by the model.

  • status —

    The status of the apply patch tool call output. One of completed or failed.

  • id (defaults to: nil) —

    The unique ID of the apply patch tool call output. Populated when this item is returned via API.

  • caller_ (defaults to: nil) —

    The execution context that produced this tool call.

  • output (defaults to: nil) —

    Optional human-readable log text from the apply patch tool (e.g., patch results or errors).

  • type (defaults to: :apply_patch_call_output) —

    The type of the item. Always apply_patch_call_output.



# File 'lib/openai/models/responses/response_input_item.rb', line 1679

Instance Attribute Details

#call_id ⇒ String

The unique ID of the apply patch tool call generated by the model.

Returns:

  • (String)


1640
# File 'lib/openai/models/responses/response_input_item.rb', line 1640

required :call_id, String

#caller_ ⇒ OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput::caller_?

The execution context that produced this tool call.

Returns:

  • (OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput::caller_, nil)


1665
1666
1667
1668
1669
1670
# File 'lib/openai/models/responses/response_input_item.rb', line 1665

optional(
  :caller_,
  union: -> { OpenAI::Responses::ResponseInputItem::ApplyPatchCallOutput::Caller },
  api_name: :caller,
  nil?: true
)

#id ⇒ String?

The unique ID of the apply patch tool call output. Populated when this item is returned via API.

Returns:

  • (String, nil)


1659
# File 'lib/openai/models/responses/response_input_item.rb', line 1659

optional :id, String, nil?: true

#output ⇒ String?

Optional human-readable log text from the apply patch tool (e.g., patch results or errors).

Returns:

  • (String, nil)


1677
# File 'lib/openai/models/responses/response_input_item.rb', line 1677

optional :output, String, nil?: true

#status ⇒ OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput::status

The status of the apply patch tool call output. One of completed or failed.

Returns:

  • (OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput::status)


1646
# File 'lib/openai/models/responses/response_input_item.rb', line 1646

required :status, enum: -> { OpenAI::Responses::ResponseInputItem::ApplyPatchCallOutput::Status }

#type ⇒ :apply_patch_call_output

The type of the item. Always apply_patch_call_output.

Returns:

  • (:apply_patch_call_output)


1652
# File 'lib/openai/models/responses/response_input_item.rb', line 1652

required :type, const: :apply_patch_call_output

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/responses/response_input_item.rb', line 1711

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


1427
# File 'sig/openai/models/responses/response_input_item.rbs', line 1427

def to_hash: -> {