Class: OpenAI::Models::Responses::ResponseInputItem::ComputerCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs

Defined Under Namespace

Modules: Status Classes: AcknowledgedSafetyCheck

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, code: nil, message: nil) ⇒ Object

Parameters:

  • call_id

    The ID of the computer tool call that produced the output.

  • output

    A computer screenshot image used with the computer use tool.

  • id

    The ID of the computer tool call output.

  • acknowledged_safety_checks

    The safety checks reported by the API that have been acknowledged by the developer.

  • status

    The status of the message input. One of in_progress, completed, or incomplete. Populated when input items are returned via API.

  • type

    The type of the computer tool call output. Always computer_call_output.



# File 'lib/openai/models/responses/response_input_item.rb', line 305

Instance Attribute Details

#acknowledged_safety_checks::Array[OpenAI::Responses::ResponseInputItem::ComputerCallOutput::AcknowledgedSafetyCheck]?

The safety checks reported by the API that have been acknowledged by the developer.

Returns:

  • (::Array[OpenAI::Responses::ResponseInputItem::ComputerCallOutput::AcknowledgedSafetyCheck], nil)


243
244
245
246
247
248
249
250
251
# File 'lib/openai/models/responses/response_input_item.rb', line 243

optional(
  :acknowledged_safety_checks,
  -> {
    OpenAI::Internal::Type::ArrayOf[
      OpenAI::Responses::ResponseInputItem::ComputerCallOutput::AcknowledgedSafetyCheck
    ]
  },
  nil?: true
)

#call_idString

The ID of the computer tool call that produced the output.

Returns:

  • (String)


218
# File 'lib/openai/models/responses/response_input_item.rb', line 218

required :call_id, String

#idString?

The ID of the computer tool call output.

Returns:

  • (String, nil)


236
# File 'lib/openai/models/responses/response_input_item.rb', line 236

optional :id, String, nil?: true

#outputOpenAI::Responses::ResponseComputerToolCallOutputScreenshot

A computer screenshot image used with the computer use tool.

Returns:

  • (OpenAI::Responses::ResponseComputerToolCallOutputScreenshot)


224
# File 'lib/openai/models/responses/response_input_item.rb', line 224

required :output, -> { OpenAI::Responses::ResponseComputerToolCallOutputScreenshot }

#statusOpenAI::Models::Responses::ResponseInputItem::ComputerCallOutput::status?

The status of the message input. One of in_progress, completed, or incomplete. Populated when input items are returned via API.

Returns:

  • (OpenAI::Models::Responses::ResponseInputItem::ComputerCallOutput::status, nil)


258
259
260
261
262
# File 'lib/openai/models/responses/response_input_item.rb', line 258

optional(
  :status,
  enum: -> { OpenAI::Responses::ResponseInputItem::ComputerCallOutput::Status },
  nil?: true
)

#type:computer_call_output

The type of the computer tool call output. Always computer_call_output.

Returns:

  • (:computer_call_output)


230
# File 'lib/openai/models/responses/response_input_item.rb', line 230

required :type, const: :computer_call_output

Instance Method Details

#to_hash{

Returns:

  • ({)


189
# File 'sig/openai/models/responses/response_input_item.rbs', line 189

def to_hash: -> {