Class: OpenAI::Models::Responses::ResponseInputItem::ImageGenerationCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputItem::ImageGenerationCall
- Defined in:
- lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs
Defined Under Namespace
Modules: Action, Background, OutputFormat, Quality, Size, Status
Instance Attribute Summary collapse
-
#action ⇒ OpenAI::Models::Responses::ResponseInputItem::ImageGenerationCall::action?
The action used for image generation.
-
#background ⇒ OpenAI::Models::Responses::ResponseInputItem::ImageGenerationCall::background?
The background setting used for generation.
-
#id ⇒ String
The unique ID of the image generation call.
-
#output_format ⇒ OpenAI::Models::Responses::ResponseInputItem::ImageGenerationCall::output_format?
The output format used for generation.
-
#quality ⇒ OpenAI::Models::Responses::ResponseInputItem::ImageGenerationCall::quality?
The quality of the image generated by the image generation tool call.
-
#result ⇒ String?
The generated image encoded in base64.
-
#revised_prompt ⇒ String?
The prompt that was used after any model prompt rewriting.
-
#size ⇒ OpenAI::Models::Responses::ResponseInputItem::ImageGenerationCall::size?
The image dimensions as a
WIDTHxHEIGHTstring, for example1536x864. -
#status ⇒ OpenAI::Models::Responses::ResponseInputItem::ImageGenerationCall::status
The status of the image generation call.
-
#type ⇒ :image_generation_call
The type of the image generation call.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(id:, result:, status:, action: nil, background: nil, output_format: nil, quality: nil, revised_prompt: nil, size: nil, type: :image_generation_call) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, result:, status:, action: nil, background: nil, output_format: nil, quality: nil, revised_prompt: nil, size: nil, type: :image_generation_call) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 717
|
Instance Attribute Details
#action ⇒ OpenAI::Models::Responses::ResponseInputItem::ImageGenerationCall::action?
The action used for image generation.
662 663 664 665 666 |
# File 'lib/openai/models/responses/response_input_item.rb', line 662 optional( :action, enum: -> { OpenAI::Responses::ResponseInputItem::ImageGenerationCall::Action }, nil?: true ) |
#background ⇒ OpenAI::Models::Responses::ResponseInputItem::ImageGenerationCall::background?
The background setting used for generation.
672 673 674 675 676 |
# File 'lib/openai/models/responses/response_input_item.rb', line 672 optional( :background, enum: -> { OpenAI::Responses::ResponseInputItem::ImageGenerationCall::Background }, nil?: true ) |
#id ⇒ String
The unique ID of the image generation call.
638 |
# File 'lib/openai/models/responses/response_input_item.rb', line 638 required :id, String |
#output_format ⇒ OpenAI::Models::Responses::ResponseInputItem::ImageGenerationCall::output_format?
The output format used for generation.
682 683 684 685 686 |
# File 'lib/openai/models/responses/response_input_item.rb', line 682 optional( :output_format, enum: -> { OpenAI::Responses::ResponseInputItem::ImageGenerationCall::OutputFormat }, nil?: true ) |
#quality ⇒ OpenAI::Models::Responses::ResponseInputItem::ImageGenerationCall::quality?
The quality of the image generated by the image generation tool call. One of
low, medium, high, xhigh, max, or auto.
693 694 695 696 697 |
# File 'lib/openai/models/responses/response_input_item.rb', line 693 optional( :quality, enum: -> { OpenAI::Responses::ResponseInputItem::ImageGenerationCall::Quality }, nil?: true ) |
#result ⇒ String?
The generated image encoded in base64.
644 |
# File 'lib/openai/models/responses/response_input_item.rb', line 644 required :result, String, nil?: true |
#revised_prompt ⇒ String?
The prompt that was used after any model prompt rewriting.
703 |
# File 'lib/openai/models/responses/response_input_item.rb', line 703 optional :revised_prompt, String, nil?: true |
#size ⇒ OpenAI::Models::Responses::ResponseInputItem::ImageGenerationCall::size?
The image dimensions as a WIDTHxHEIGHT string, for example 1536x864.
709 710 711 712 713 714 715 |
# File 'lib/openai/models/responses/response_input_item.rb', line 709 optional( :size, union: -> { OpenAI::Responses::ResponseInputItem::ImageGenerationCall::Size }, nil?: true ) |
#status ⇒ OpenAI::Models::Responses::ResponseInputItem::ImageGenerationCall::status
The status of the image generation call.
650 |
# File 'lib/openai/models/responses/response_input_item.rb', line 650 required :status, enum: -> { OpenAI::Responses::ResponseInputItem::ImageGenerationCall::Status } |
#type ⇒ :image_generation_call
The type of the image generation call. Always image_generation_call.
656 |
# File 'lib/openai/models/responses/response_input_item.rb', line 656 required :type, const: :image_generation_call |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 762
|
Instance Method Details
#to_hash ⇒ {
594 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 594
def to_hash: -> {
|