Class: OpenAI::Models::Responses::ResponseInputItem::LocalShellCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs

Defined Under Namespace

Modules: Status Classes: Action

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(command:, env:, timeout_ms: nil, user: nil, working_directory: nil, type: :exec) ⇒ Object

Parameters:

  • id —

    The unique ID of the local shell call.

  • action —

    Execute a shell command on the server.

  • call_id —

    The unique ID of the local shell tool call generated by the model.

  • status —

    The status of the local shell call.

  • type (defaults to: :exec) —

    The type of the local shell call. Always local_shell_call.



# File 'lib/openai/models/responses/response_input_item.rb', line 896

Instance Attribute Details

#action ⇒ OpenAI::Responses::ResponseInputItem::LocalShellCall::Action

Execute a shell command on the server.

Returns:

  • (OpenAI::Responses::ResponseInputItem::LocalShellCall::Action)


876
# File 'lib/openai/models/responses/response_input_item.rb', line 876

required :action, -> { OpenAI::Responses::ResponseInputItem::LocalShellCall::Action }

#call_id ⇒ String

The unique ID of the local shell tool call generated by the model.

Returns:

  • (String)


882
# File 'lib/openai/models/responses/response_input_item.rb', line 882

required :call_id, String

#id ⇒ String

The unique ID of the local shell call.

Returns:

  • (String)


870
# File 'lib/openai/models/responses/response_input_item.rb', line 870

required :id, String

#status ⇒ OpenAI::Models::Responses::ResponseInputItem::LocalShellCall::status

The status of the local shell call.

Returns:

  • (OpenAI::Models::Responses::ResponseInputItem::LocalShellCall::status)


888
# File 'lib/openai/models/responses/response_input_item.rb', line 888

required :status, enum: -> { OpenAI::Responses::ResponseInputItem::LocalShellCall::Status }

#type ⇒ :local_shell_call

The type of the local shell call. Always local_shell_call.

Returns:

  • (:local_shell_call)


894
# File 'lib/openai/models/responses/response_input_item.rb', line 894

required :type, const: :local_shell_call

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


727
# File 'sig/openai/models/responses/response_input_item.rbs', line 727

def to_hash: -> {