Class: OpenAI::Models::Responses::ResponseInputItem::LocalShellCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, output:, status: nil, type: :local_shell_call_output) ⇒ Object

Parameters:

  • id —

    The unique ID of the local shell tool call generated by the model.

  • output —

    A JSON string of the output of the local shell tool call.

  • status (defaults to: nil) —

    The status of the item. One of in_progress, completed, or incomplete.

  • type (defaults to: :local_shell_call_output) —

    The type of the local shell tool call output. Always local_shell_call_output.



# File 'lib/openai/models/responses/response_input_item.rb', line 1018

Instance Attribute Details

#id ⇒ String

The unique ID of the local shell tool call generated by the model.

Returns:

  • (String)


994
# File 'lib/openai/models/responses/response_input_item.rb', line 994

required :id, String

#output ⇒ String

A JSON string of the output of the local shell tool call.

Returns:

  • (String)


1000
# File 'lib/openai/models/responses/response_input_item.rb', line 1000

required :output, String

#status ⇒ OpenAI::Models::Responses::ResponseInputItem::LocalShellCallOutput::status?

The status of the item. One of in_progress, completed, or incomplete.

Returns:

  • (OpenAI::Models::Responses::ResponseInputItem::LocalShellCallOutput::status, nil)


1012
1013
1014
1015
1016
# File 'lib/openai/models/responses/response_input_item.rb', line 1012

optional(
  :status,
  enum: -> { OpenAI::Responses::ResponseInputItem::LocalShellCallOutput::Status },
  nil?: true
)

#type ⇒ :local_shell_call_output

The type of the local shell tool call output. Always local_shell_call_output.

Returns:

  • (:local_shell_call_output)


1006
# File 'lib/openai/models/responses/response_input_item.rb', line 1006

required :type, const: :local_shell_call_output

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


844
# File 'sig/openai/models/responses/response_input_item.rbs', line 844

def to_hash: -> {