Class: OpenAI::Models::Responses::ResponseInputItem::McpListTools

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs

Defined Under Namespace

Classes: Tool

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • id —

    The unique ID of the list.

  • server_label —

    The label of the MCP server.

  • tools —

    The tools available on the server.

  • error —

    Error message if the server could not list tools.

  • type —

    The type of the item. Always mcp_list_tools.



1524
# File 'sig/openai/models/responses/response_input_item.rbs', line 1524

def initialize: (

Instance Attribute Details

#error ⇒ String?

Error message if the server could not list tools.

Returns:

  • (String, nil)


1797
# File 'lib/openai/models/responses/response_input_item.rb', line 1797

optional :error, String, nil?: true

#id ⇒ String

The unique ID of the list.

Returns:

  • (String)


1770
# File 'lib/openai/models/responses/response_input_item.rb', line 1770

required :id, String

#server_label ⇒ String

The label of the MCP server.

Returns:

  • (String)


1776
# File 'lib/openai/models/responses/response_input_item.rb', line 1776

required :server_label, String

#tools ⇒ ::Array[OpenAI::Responses::ResponseInputItem::McpListTools::Tool]

The tools available on the server.

Returns:

  • (::Array[OpenAI::Responses::ResponseInputItem::McpListTools::Tool])


1782
1783
1784
1785
# File 'lib/openai/models/responses/response_input_item.rb', line 1782

required(
  :tools,
  -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Responses::ResponseInputItem::McpListTools::Tool] }
)

#type ⇒ :mcp_list_tools

The type of the item. Always mcp_list_tools.

Returns:

  • (:mcp_list_tools)


1791
# File 'lib/openai/models/responses/response_input_item.rb', line 1791

required :type, const: :mcp_list_tools

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


1532
# File 'sig/openai/models/responses/response_input_item.rbs', line 1532

def to_hash: -> {