Class: OpenAI::Models::Responses::ResponseInputItem::ShellCall::Action

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs

Overview

See Also:

  • OpenAI::Models::Responses::ResponseInputItem::ShellCall#action

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • Ordered shell commands for the execution environment to run.

  • Maximum number of UTF-8 characters to capture from combined stdout and stderr output.

  • Maximum wall-clock time in milliseconds to allow the shell commands to run.



960
# File 'sig/openai/models/responses/response_input_item.rbs', line 960

def initialize: (

Instance Attribute Details

#commands ⇒ ::Array[String]

Ordered shell commands for the execution environment to run.

Returns:



1134
# File 'lib/openai/models/responses/response_input_item.rb', line 1134

required :commands, OpenAI::Internal::Type::ArrayOf[String]

#max_output_length ⇒ Integer?

Maximum number of UTF-8 characters to capture from combined stdout and stderr output.

Returns:



1141
# File 'lib/openai/models/responses/response_input_item.rb', line 1141

optional :max_output_length, Integer, nil?: true

#timeout_ms ⇒ Integer?

Maximum wall-clock time in milliseconds to allow the shell commands to run.

Returns:



1147
# File 'lib/openai/models/responses/response_input_item.rb', line 1147

optional :timeout_ms, Integer, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:



966
# File 'sig/openai/models/responses/response_input_item.rbs', line 966

def to_hash: -> {