Class: OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput
- Defined in:
- lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::caller_?
The execution context that produced this tool call.
-
#id ⇒ String?
The unique ID of the shell tool call output.
-
#max_output_length ⇒ Integer?
The maximum number of UTF-8 characters captured for this shell call's combined output.
-
#output ⇒ ::Array[OpenAI::Responses::ResponseFunctionShellCallOutputContent]
Captured chunks of stdout and stderr output, along with their associated outcomes.
-
#status ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::status?
The status of the shell call output.
-
#type ⇒ :shell_call_output
The type of the item.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caller_id:, type: :program) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 1304
|
Instance Attribute Details
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
1249 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1249 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::caller_?
The execution context that produced this tool call.
1278 1279 1280 1281 1282 1283 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1278 optional( :caller_, union: -> { OpenAI::Responses::ResponseInputItem::ShellCallOutput::Caller }, api_name: :caller, nil?: true ) |
#id ⇒ String?
The unique ID of the shell tool call output. Populated when this item is returned via API.
1272 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1272 optional :id, String, nil?: true |
#max_output_length ⇒ Integer?
The maximum number of UTF-8 characters captured for this shell call's combined output.
1290 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1290 optional :max_output_length, Integer, nil?: true |
#output ⇒ ::Array[OpenAI::Responses::ResponseFunctionShellCallOutputContent]
Captured chunks of stdout and stderr output, along with their associated outcomes.
1256 1257 1258 1259 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1256 required( :output, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Responses::ResponseFunctionShellCallOutputContent] } ) |
#status ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::status?
The status of the shell call output.
1296 1297 1298 1299 1300 1301 1302 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1296 optional( :status, enum: -> { OpenAI::Responses::ResponseInputItem::ShellCallOutput::Status }, nil?: true ) |
#type ⇒ :shell_call_output
The type of the item. Always shell_call_output.
1265 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1265 required :type, const: :shell_call_output |
Class Method Details
.variants ⇒ Array(OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::Caller::Direct, OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::Caller::Program)
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 1376
|
Instance Method Details
#to_hash ⇒ {
1100 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 1100
def to_hash: -> {
|