Class: OpenAI::Models::Responses::ResponseInputItem::ToolSearchCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs

Defined Under Namespace

Modules: Execution, Status

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(arguments:, id: nil, call_id: nil, execution: nil, status: nil, type: :tool_search_call) ⇒ Object

Parameters:

  • arguments —

    The arguments supplied to the tool search call.

  • id (defaults to: nil) —

    The unique ID of this tool search call.

  • call_id (defaults to: nil) —

    The unique ID of the tool search call generated by the model.

  • execution (defaults to: nil) —

    Whether tool search was executed by the server or by the client.

  • status (defaults to: nil) —

    The status of the tool search call.

  • type (defaults to: :tool_search_call) —

    The item type. Always tool_search_call.



# File 'lib/openai/models/responses/response_input_item.rb', line 547

Instance Attribute Details

#arguments ⇒ top

The arguments supplied to the tool search call.

Returns:

  • (top)


509
# File 'lib/openai/models/responses/response_input_item.rb', line 509

required :arguments, OpenAI::Internal::Type::Unknown

#call_id ⇒ String?

The unique ID of the tool search call generated by the model.

Returns:

  • (String, nil)


527
# File 'lib/openai/models/responses/response_input_item.rb', line 527

optional :call_id, String, nil?: true

#execution ⇒ OpenAI::Models::Responses::ResponseInputItem::ToolSearchCall::execution?

Whether tool search was executed by the server or by the client.

Returns:

  • (OpenAI::Models::Responses::ResponseInputItem::ToolSearchCall::execution, nil)


533
# File 'lib/openai/models/responses/response_input_item.rb', line 533

optional :execution, enum: -> { OpenAI::Responses::ResponseInputItem::ToolSearchCall::Execution }

#id ⇒ String?

The unique ID of this tool search call.

Returns:

  • (String, nil)


521
# File 'lib/openai/models/responses/response_input_item.rb', line 521

optional :id, String, nil?: true

#status ⇒ OpenAI::Models::Responses::ResponseInputItem::ToolSearchCall::status?

The status of the tool search call.

Returns:

  • (OpenAI::Models::Responses::ResponseInputItem::ToolSearchCall::status, nil)


539
540
541
542
543
544
545
# File 'lib/openai/models/responses/response_input_item.rb', line 539

optional(
  :status,
  enum: -> {
    OpenAI::Responses::ResponseInputItem::ToolSearchCall::Status
  },
  nil?: true
)

#type ⇒ :tool_search_call

The item type. Always tool_search_call.

Returns:

  • (:tool_search_call)


515
# File 'lib/openai/models/responses/response_input_item.rb', line 515

required :type, const: :tool_search_call

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/responses/response_input_item.rb', line 575

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


437
# File 'sig/openai/models/responses/response_input_item.rbs', line 437

def to_hash: -> {