Class: OpenAI::Models::Responses::ResponseInputTextContent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_text_content.rb,
sig/openai/models/responses/response_input_text_content.rbs

Defined Under Namespace

Classes: PromptCacheBreakpoint

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(text:, prompt_cache_breakpoint: nil, type: :input_text) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseInputTextContent for more details.

A text input to the model.

Parameters:



# File 'lib/openai/models/responses/response_input_text_content.rb', line 29

Instance Attribute Details

#prompt_cache_breakpointOpenAI::Models::Responses::ResponseInputTextContent::PromptCacheBreakpoint?

Marks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL from the request's prompt_cache_options.ttl; the boundary is not rounded to a token block.

Parameters:

  • value (OpenAI::Responses::ResponseInputTextContent::PromptCacheBreakpoint, nil)

Returns:



25
26
27
# File 'lib/openai/models/responses/response_input_text_content.rb', line 25

optional :prompt_cache_breakpoint,
-> { OpenAI::Responses::ResponseInputTextContent::PromptCacheBreakpoint },
nil?: true

#textString

The text input to the model.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/openai/models/responses/response_input_text_content.rb', line 11

required :text, String

#typeSymbol, :input_text

The type of the input item. Always input_text.

Parameters:

  • value (:input_text)

Returns:

  • (Symbol, :input_text)


17
# File 'lib/openai/models/responses/response_input_text_content.rb', line 17

required :type, const: :input_text

Instance Method Details

#to_hash{

Returns:

  • ({)


24
# File 'sig/openai/models/responses/response_input_text_content.rbs', line 24

def to_hash: -> {