Class: OpenAI::Models::Responses::ResponseItem::ImageGenerationCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseItem::ImageGenerationCall
- Defined in:
- lib/openai/models/responses/response_item.rb,
sig/openai/models/responses/response_item.rbs
Defined Under Namespace
Modules: Action, Background, OutputFormat, Quality, Size, Status
Instance Attribute Summary collapse
-
#action ⇒ OpenAI::Models::Responses::ResponseItem::ImageGenerationCall::action?
The action used for image generation.
-
#background ⇒ OpenAI::Models::Responses::ResponseItem::ImageGenerationCall::background?
The background setting used for generation.
-
#id ⇒ String
The unique ID of the image generation call.
-
#output_format ⇒ OpenAI::Models::Responses::ResponseItem::ImageGenerationCall::output_format?
The output format used for generation.
-
#quality ⇒ OpenAI::Models::Responses::ResponseItem::ImageGenerationCall::quality?
The quality of the image generated by the image generation tool call.
-
#result ⇒ String?
The generated image encoded in base64.
-
#revised_prompt ⇒ String?
The prompt that was used after any model prompt rewriting.
-
#size ⇒ OpenAI::Models::Responses::ResponseItem::ImageGenerationCall::size?
The image dimensions as a
WIDTHxHEIGHTstring, for example1536x864. -
#status ⇒ OpenAI::Models::Responses::ResponseItem::ImageGenerationCall::status
The status of the image generation call.
-
#type ⇒ :image_generation_call
The type of the image generation call.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(id:, result:, status:, action: nil, background: nil, output_format: nil, quality: nil, revised_prompt: nil, size: nil, type: :image_generation_call) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, result:, status:, action: nil, background: nil, output_format: nil, quality: nil, revised_prompt: nil, size: nil, type: :image_generation_call) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_item.rb', line 351
|
Instance Attribute Details
#action ⇒ OpenAI::Models::Responses::ResponseItem::ImageGenerationCall::action?
The action used for image generation.
298 299 300 301 302 303 304 |
# File 'lib/openai/models/responses/response_item.rb', line 298 optional( :action, enum: -> { OpenAI::Responses::ResponseItem::ImageGenerationCall::Action }, nil?: true ) |
#background ⇒ OpenAI::Models::Responses::ResponseItem::ImageGenerationCall::background?
The background setting used for generation.
310 311 312 313 314 |
# File 'lib/openai/models/responses/response_item.rb', line 310 optional( :background, enum: -> { OpenAI::Responses::ResponseItem::ImageGenerationCall::Background }, nil?: true ) |
#id ⇒ String
The unique ID of the image generation call.
274 |
# File 'lib/openai/models/responses/response_item.rb', line 274 required :id, String |
#output_format ⇒ OpenAI::Models::Responses::ResponseItem::ImageGenerationCall::output_format?
The output format used for generation.
320 321 322 323 324 |
# File 'lib/openai/models/responses/response_item.rb', line 320 optional( :output_format, enum: -> { OpenAI::Responses::ResponseItem::ImageGenerationCall::OutputFormat }, nil?: true ) |
#quality ⇒ OpenAI::Models::Responses::ResponseItem::ImageGenerationCall::quality?
The quality of the image generated by the image generation tool call. One of
low, medium, high, xhigh, max, or auto.
331 332 333 334 335 336 337 |
# File 'lib/openai/models/responses/response_item.rb', line 331 optional( :quality, enum: -> { OpenAI::Responses::ResponseItem::ImageGenerationCall::Quality }, nil?: true ) |
#result ⇒ String?
The generated image encoded in base64.
280 |
# File 'lib/openai/models/responses/response_item.rb', line 280 required :result, String, nil?: true |
#revised_prompt ⇒ String?
The prompt that was used after any model prompt rewriting.
343 |
# File 'lib/openai/models/responses/response_item.rb', line 343 optional :revised_prompt, String, nil?: true |
#size ⇒ OpenAI::Models::Responses::ResponseItem::ImageGenerationCall::size?
The image dimensions as a WIDTHxHEIGHT string, for example 1536x864.
349 |
# File 'lib/openai/models/responses/response_item.rb', line 349 optional :size, union: -> { OpenAI::Responses::ResponseItem::ImageGenerationCall::Size }, nil?: true |
#status ⇒ OpenAI::Models::Responses::ResponseItem::ImageGenerationCall::status
The status of the image generation call.
286 |
# File 'lib/openai/models/responses/response_item.rb', line 286 required :status, enum: -> { OpenAI::Responses::ResponseItem::ImageGenerationCall::Status } |
#type ⇒ :image_generation_call
The type of the image generation call. Always image_generation_call.
292 |
# File 'lib/openai/models/responses/response_item.rb', line 292 required :type, const: :image_generation_call |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/response_item.rb', line 396
|
Instance Method Details
#to_hash ⇒ {
303 |
# File 'sig/openai/models/responses/response_item.rbs', line 303
def to_hash: -> {
|