Class: OpenAI::Models::Responses::ResponseMcpCallArgumentsDeltaEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_mcp_call_arguments_delta_event.rb,
sig/openai/models/responses/response_mcp_call_arguments_delta_event.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(delta:, item_id:, output_index:, sequence_number:, type: :"response.mcp_call_arguments.delta") ⇒ Object

Parameters:

  • delta

    A JSON string containing the partial update to the arguments for the MCP tool call.

  • item_id

    The unique identifier of the MCP tool call item being processed.

  • output_index

    The index of the output item in the response's output array.

  • sequence_number

    The sequence number of this event.

  • type (defaults to: :"response.mcp_call_arguments.delta")

    The type of the event. Always 'response.mcp_call_arguments.delta'.



# File 'lib/openai/models/responses/response_mcp_call_arguments_delta_event.rb', line 38

Instance Attribute Details

#deltaString

A JSON string containing the partial update to the arguments for the MCP tool call.

Returns:

  • (String)


12
# File 'lib/openai/models/responses/response_mcp_call_arguments_delta_event.rb', line 12

required :delta, String

#item_idString

The unique identifier of the MCP tool call item being processed.

Returns:

  • (String)


18
# File 'lib/openai/models/responses/response_mcp_call_arguments_delta_event.rb', line 18

required :item_id, String

#output_indexInteger

The index of the output item in the response's output array.

Returns:

  • (Integer)


24
# File 'lib/openai/models/responses/response_mcp_call_arguments_delta_event.rb', line 24

required :output_index, Integer

#sequence_numberInteger

The sequence number of this event.

Returns:

  • (Integer)


30
# File 'lib/openai/models/responses/response_mcp_call_arguments_delta_event.rb', line 30

required :sequence_number, Integer

#type:"response.mcp_call_arguments.delta"

The type of the event. Always 'response.mcp_call_arguments.delta'.

Returns:

  • (:"response.mcp_call_arguments.delta")


36
# File 'lib/openai/models/responses/response_mcp_call_arguments_delta_event.rb', line 36

required :type, const: :"response.mcp_call_arguments.delta"

Instance Method Details

#to_hash{

Returns:

  • ({)


49
# File 'sig/openai/models/responses/response_mcp_call_arguments_delta_event.rbs', line 49

def to_hash: -> {