Class: OpenAI::Models::Responses::ResponseOutputText::Annotation::ContainerFileCitation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_output_text.rb,
sig/openai/models/responses/response_output_text.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • container_id —

    The ID of the container file.

  • end_index —

    The index of the last character of the container file citation in the message.

  • file_id —

    The ID of the file.

  • filename —

    The filename of the container file cited.

  • start_index —

    The index of the first character of the container file citation in the message.

  • type —

    The type of the container file citation. Always container_file_citation.



194
# File 'sig/openai/models/responses/response_output_text.rbs', line 194

def initialize: (

Instance Attribute Details

#container_id ⇒ String

The ID of the container file.

Returns:

  • (String)


172
# File 'lib/openai/models/responses/response_output_text.rb', line 172

required :container_id, String

#end_index ⇒ Integer

The index of the last character of the container file citation in the message.

Returns:

  • (Integer)


178
# File 'lib/openai/models/responses/response_output_text.rb', line 178

required :end_index, Integer

#file_id ⇒ String

The ID of the file.

Returns:

  • (String)


184
# File 'lib/openai/models/responses/response_output_text.rb', line 184

required :file_id, String

#filename ⇒ String

The filename of the container file cited.

Returns:

  • (String)


190
# File 'lib/openai/models/responses/response_output_text.rb', line 190

required :filename, String

#start_index ⇒ Integer

The index of the first character of the container file citation in the message.

Returns:

  • (Integer)


196
# File 'lib/openai/models/responses/response_output_text.rb', line 196

required :start_index, Integer

#type ⇒ :container_file_citation

The type of the container file citation. Always container_file_citation.

Returns:

  • (:container_file_citation)


202
# File 'lib/openai/models/responses/response_output_text.rb', line 202

required :type, const: :container_file_citation

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


203
# File 'sig/openai/models/responses/response_output_text.rbs', line 203

def to_hash: -> {