Class: OpenAI::Models::Responses::ResponseOutputText::Annotation::FilePath

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_output_text.rb,
sig/openai/models/responses/response_output_text.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • file_id —

    The ID of the file.

  • index —

    The index of the file in the list of files.

  • type —

    The type of the file path. Always file_path.



232
# File 'sig/openai/models/responses/response_output_text.rbs', line 232

def initialize: (

Instance Attribute Details

#file_id ⇒ String

The ID of the file.

Returns:

  • (String)


231
# File 'lib/openai/models/responses/response_output_text.rb', line 231

required :file_id, String

#index ⇒ Integer

The index of the file in the list of files.

Returns:

  • (Integer)


237
# File 'lib/openai/models/responses/response_output_text.rb', line 237

required :index, Integer

#type ⇒ :file_path

The type of the file path. Always file_path.

Returns:

  • (:file_path)


243
# File 'lib/openai/models/responses/response_output_text.rb', line 243

required :type, const: :file_path

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


238
# File 'sig/openai/models/responses/response_output_text.rbs', line 238

def to_hash: -> {