Class: OpenAI::Models::Responses::ResponseOutputText::Annotation::URLCitation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_output_text.rb,
sig/openai/models/responses/response_output_text.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



100
# File 'sig/openai/models/responses/response_output_text.rbs', line 100

def initialize: (

Instance Attribute Details

#end_indexInteger

The index of the last character of the URL citation in the message.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


111
# File 'lib/openai/models/responses/response_output_text.rb', line 111

required :end_index, Integer

#start_indexInteger

The index of the first character of the URL citation in the message.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


117
# File 'lib/openai/models/responses/response_output_text.rb', line 117

required :start_index, Integer

#titleString

The title of the web resource.

Parameters:

  • value (String)

Returns:

  • (String)


123
# File 'lib/openai/models/responses/response_output_text.rb', line 123

required :title, String

#typeSymbol, :url_citation

The type of the URL citation. Always url_citation.

Parameters:

  • value (:url_citation)

Returns:

  • (Symbol, :url_citation)


129
# File 'lib/openai/models/responses/response_output_text.rb', line 129

required :type, const: :url_citation

#urlString

The URL of the web resource.

Parameters:

  • value (String)

Returns:

  • (String)


135
# File 'lib/openai/models/responses/response_output_text.rb', line 135

required :url, String

Instance Method Details

#to_hash{

Returns:

  • ({)


108
# File 'sig/openai/models/responses/response_output_text.rbs', line 108

def to_hash: -> {