Module: OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent::Annotation
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/responses/response_output_text_annotation_added_event.rb,
sig/openai/models/responses/response_output_text_annotation_added_event.rbs
Overview
An annotation that applies to a span of output text.
Defined Under Namespace
Classes: ContainerFileCitation, FileCitation, FilePath, URLCitation
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(container_id:, end_index:, file_id:, filename:, start_index:, type: :container_file_citation) ⇒ Object
A citation for a container file used to generate a model response.
- #self?.variants ⇒ ::Array[OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent::annotation]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent::Annotation::FileCitation, OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent::Annotation::URLCitation, OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent::Annotation::ContainerFileCitation, OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent::Annotation::FilePath)
|
|
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 259
|
Instance Method Details
#initialize(container_id:, end_index:, file_id:, filename:, start_index:, type: :container_file_citation) ⇒ Object
A citation for a container file used to generate a model response.
|
|
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 116
|
#self?.variants ⇒ ::Array[OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent::annotation]
192 |
# File 'sig/openai/models/responses/response_output_text_annotation_added_event.rbs', line 192
def self?.variants: -> ::Array[OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent::annotation]
|