Class: OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent::Annotation::FilePath
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent::Annotation::FilePath
- Defined in:
- lib/openai/models/responses/response_output_text_annotation_added_event.rb,
sig/openai/models/responses/response_output_text_annotation_added_event.rbs
Instance Attribute Summary collapse
-
#file_id ⇒ String
The ID of the file.
-
#index ⇒ Integer
The index of the file in the list of files.
-
#type ⇒ Symbol, :file_path
The type of the file path.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(file_id:, index:, type: :file_path) ⇒ Object
constructor
Some parameter documentations has been truncated, see FilePath for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(file_id:, index:, type: :file_path) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent::Annotation::FilePath for more details.
A path to a file.
|
|
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 245
|
Instance Attribute Details
#file_id ⇒ String
The ID of the file.
231 |
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 231 required :file_id, String |
#index ⇒ Integer
The index of the file in the list of files.
237 |
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 237 required :index, Integer |
#type ⇒ Symbol, :file_path
The type of the file path. Always file_path.
243 |
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 243 required :type, const: :file_path |
Instance Method Details
#to_hash ⇒ {
185 |
# File 'sig/openai/models/responses/response_output_text_annotation_added_event.rbs', line 185
def to_hash: -> {
|