Class: OpenAI::Models::Responses::ResponseReasoningSummaryPartDoneEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_reasoning_summary_part_done_event.rb,
sig/openai/models/responses/response_reasoning_summary_part_done_event.rbs

Defined Under Namespace

Modules: Status Classes: Part

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(text:, type: :summary_text) ⇒ Object

Parameters:

  • item_id

    The ID of the item this summary part is associated with.

  • output_index

    The index of the output item this summary part is associated with.

  • part

    The completed summary part.

  • sequence_number

    The sequence number of this event.

  • summary_index

    The index of the summary part within the reasoning summary.

  • status

    The completion status of the summary part. Omitted when the part completed normally and set to incomplete when generation was interrupted.

  • type (defaults to: :summary_text)

    The type of the event. Always response.reasoning_summary_part.done.



# File 'lib/openai/models/responses/response_reasoning_summary_part_done_event.rb', line 50

Instance Attribute Details

#item_idString

The ID of the item this summary part is associated with.

Returns:

  • (String)


11
# File 'lib/openai/models/responses/response_reasoning_summary_part_done_event.rb', line 11

required :item_id, String

#output_indexInteger

The index of the output item this summary part is associated with.

Returns:

  • (Integer)


17
# File 'lib/openai/models/responses/response_reasoning_summary_part_done_event.rb', line 17

required :output_index, Integer

#partOpenAI::Responses::ResponseReasoningSummaryPartDoneEvent::Part

The completed summary part.

Returns:

  • (OpenAI::Responses::ResponseReasoningSummaryPartDoneEvent::Part)


23
# File 'lib/openai/models/responses/response_reasoning_summary_part_done_event.rb', line 23

required :part, -> { OpenAI::Responses::ResponseReasoningSummaryPartDoneEvent::Part }

#sequence_numberInteger

The sequence number of this event.

Returns:

  • (Integer)


29
# File 'lib/openai/models/responses/response_reasoning_summary_part_done_event.rb', line 29

required :sequence_number, Integer

#statusOpenAI::Models::Responses::ResponseReasoningSummaryPartDoneEvent::status?

The completion status of the summary part. Omitted when the part completed normally and set to incomplete when generation was interrupted.

Returns:

  • (OpenAI::Models::Responses::ResponseReasoningSummaryPartDoneEvent::status, nil)


48
# File 'lib/openai/models/responses/response_reasoning_summary_part_done_event.rb', line 48

optional :status, enum: -> { OpenAI::Responses::ResponseReasoningSummaryPartDoneEvent::Status }

#summary_indexInteger

The index of the summary part within the reasoning summary.

Returns:

  • (Integer)


35
# File 'lib/openai/models/responses/response_reasoning_summary_part_done_event.rb', line 35

required :summary_index, Integer

#type:"response.reasoning_summary_part.done"

The type of the event. Always response.reasoning_summary_part.done.

Returns:

  • (:"response.reasoning_summary_part.done")


41
# File 'lib/openai/models/responses/response_reasoning_summary_part_done_event.rb', line 41

required :type, const: :"response.reasoning_summary_part.done"

Instance Method Details

#to_hash{

Returns:

  • ({)


69
# File 'sig/openai/models/responses/response_reasoning_summary_part_done_event.rbs', line 69

def to_hash: -> {