Class: OpenAI::Models::Responses::ResponseShellCallOutputContentDeltaEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseShellCallOutputContentDeltaEvent
- Defined in:
- lib/openai/models/responses/response_shell_call_output_content_delta_event.rb,
sig/openai/models/responses/response_shell_call_output_content_delta_event.rbs
Direct Known Subclasses
OpenAI::Models::Responses::ResponsesServerEvent::ResponseShellCallOutputContentWsDelta
Defined Under Namespace
Classes: Delta
Instance Attribute Summary collapse
-
#command_index ⇒ Integer
The index of the shell command that produced output.
-
#delta ⇒ OpenAI::Models::Responses::ResponseShellCallOutputContentDeltaEvent::Delta
The stdout/stderr delta that was emitted.
-
#item_id ⇒ String
The ID of the output item that was updated.
-
#output_index ⇒ Integer
The index of the output item that was updated.
-
#sequence_number ⇒ Integer
The sequence number of the event that was emitted.
-
#type ⇒ Symbol, :"response.shell_call_output_content.delta"
The type of the event, always
response.shell_call_output_content.delta.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(command_index:, delta:, item_id:, output_index:, sequence_number:, type: :"response.shell_call_output_content.delta") ⇒ Object
constructor
A streaming event that indicated shell call output was incrementally added.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(command_index:, delta:, item_id:, output_index:, sequence_number:, type: :"response.shell_call_output_content.delta") ⇒ Object
A streaming event that indicated shell call output was incrementally added.
|
|
# File 'lib/openai/models/responses/response_shell_call_output_content_delta_event.rb', line 43
|
Instance Attribute Details
#command_index ⇒ Integer
The index of the shell command that produced output.
11 |
# File 'lib/openai/models/responses/response_shell_call_output_content_delta_event.rb', line 11 required :command_index, Integer |
#delta ⇒ OpenAI::Models::Responses::ResponseShellCallOutputContentDeltaEvent::Delta
The stdout/stderr delta that was emitted.
17 |
# File 'lib/openai/models/responses/response_shell_call_output_content_delta_event.rb', line 17 required :delta, -> { OpenAI::Responses::ResponseShellCallOutputContentDeltaEvent::Delta } |
#item_id ⇒ String
The ID of the output item that was updated.
23 |
# File 'lib/openai/models/responses/response_shell_call_output_content_delta_event.rb', line 23 required :item_id, String |
#output_index ⇒ Integer
The index of the output item that was updated.
29 |
# File 'lib/openai/models/responses/response_shell_call_output_content_delta_event.rb', line 29 required :output_index, Integer |
#sequence_number ⇒ Integer
The sequence number of the event that was emitted.
35 |
# File 'lib/openai/models/responses/response_shell_call_output_content_delta_event.rb', line 35 required :sequence_number, Integer |
#type ⇒ Symbol, :"response.shell_call_output_content.delta"
The type of the event, always response.shell_call_output_content.delta.
41 |
# File 'lib/openai/models/responses/response_shell_call_output_content_delta_event.rb', line 41 required :type, const: :"response.shell_call_output_content.delta" |
Instance Method Details
#to_hash ⇒ {
36 |
# File 'sig/openai/models/responses/response_shell_call_output_content_delta_event.rbs', line 36
def to_hash: -> {
|