Class: OpenAI::Models::Responses::ResponseShellCallOutputContentDoneEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_shell_call_output_content_done_event.rb,
sig/openai/models/responses/response_shell_call_output_content_done_event.rbs

Defined Under Namespace

Classes: Output

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



27
# File 'sig/openai/models/responses/response_shell_call_output_content_done_event.rbs', line 27

def initialize: (

Instance Attribute Details

#command_indexInteger

The index of the shell command that produced output.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


11
# File 'lib/openai/models/responses/response_shell_call_output_content_done_event.rb', line 11

required :command_index, Integer

#item_idString

The ID of the output item that was updated.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/openai/models/responses/response_shell_call_output_content_done_event.rb', line 17

required :item_id, String

#outputArray<OpenAI::Models::Responses::ResponseShellCallOutputContentDoneEvent::Output>

The output contents emitted for the shell command.

Parameters:

  • value (::Array[OpenAI::Responses::ResponseShellCallOutputContentDoneEvent::Output])

Returns:



23
24
25
26
# File 'lib/openai/models/responses/response_shell_call_output_content_done_event.rb', line 23

required(
  :output,
  -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Responses::ResponseShellCallOutputContentDoneEvent::Output] }
)

#output_indexInteger

The index of the output item that was updated.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


32
# File 'lib/openai/models/responses/response_shell_call_output_content_done_event.rb', line 32

required :output_index, Integer

#sequence_numberInteger

The sequence number of the event that was emitted.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


38
# File 'lib/openai/models/responses/response_shell_call_output_content_done_event.rb', line 38

required :sequence_number, Integer

#typeSymbol, :"response.shell_call_output_content.done"

The type of the event, always response.shell_call_output_content.done.

Parameters:

  • value (:"response.shell_call_output_content.done")

Returns:

  • (Symbol, :"response.shell_call_output_content.done")


44
# File 'lib/openai/models/responses/response_shell_call_output_content_done_event.rb', line 44

required :type, const: :"response.shell_call_output_content.done"

Instance Method Details

#to_hash{

Returns:

  • ({)


36
# File 'sig/openai/models/responses/response_shell_call_output_content_done_event.rbs', line 36

def to_hash: -> {