Class: OpenAI::Models::Responses::ResponseSteerFailedEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseSteerFailedEvent
- Defined in:
- lib/openai/models/responses/response_steer_failed_event.rb,
sig/openai/models/responses/response_steer_failed_event.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#error ⇒ OpenAI::Models::Responses::ResponseSteerFailedEvent::Error
Information about why the input could not be committed.
-
#sequence_number ⇒ Integer
The sequence number for this event.
-
#steer ⇒ OpenAI::Models::Responses::ResponseSteerFailedEvent::Steer
The steering submission that could not be committed.
-
#stream_id ⇒ String?
The WebSocket lane that emitted this event, when the target response is available and its
response.createevent supplied astream_id. -
#type ⇒ Symbol, :"response.steer.failed"
The event discriminator.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(code:, message:, type: :invalid_request_error) ⇒ Object
constructor
Information about why the input could not be committed.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code:, message:, type: :invalid_request_error) ⇒ Object
Information about why the input could not be committed.
|
|
# File 'lib/openai/models/responses/response_steer_failed_event.rb', line 38
|
Instance Attribute Details
#error ⇒ OpenAI::Models::Responses::ResponseSteerFailedEvent::Error
Information about why the input could not be committed.
11 |
# File 'lib/openai/models/responses/response_steer_failed_event.rb', line 11 required :error, -> { OpenAI::Responses::ResponseSteerFailedEvent::Error } |
#sequence_number ⇒ Integer
The sequence number for this event.
17 |
# File 'lib/openai/models/responses/response_steer_failed_event.rb', line 17 required :sequence_number, Integer |
#steer ⇒ OpenAI::Models::Responses::ResponseSteerFailedEvent::Steer
The steering submission that could not be committed.
23 |
# File 'lib/openai/models/responses/response_steer_failed_event.rb', line 23 required :steer, -> { OpenAI::Responses::ResponseSteerFailedEvent::Steer } |
#stream_id ⇒ String?
The WebSocket lane that emitted this event, when the target response is
available and its response.create event supplied a stream_id.
36 |
# File 'lib/openai/models/responses/response_steer_failed_event.rb', line 36 optional :stream_id, String |
#type ⇒ Symbol, :"response.steer.failed"
The event discriminator. Always response.steer.failed.
29 |
# File 'lib/openai/models/responses/response_steer_failed_event.rb', line 29 required :type, const: :"response.steer.failed" |
Instance Method Details
#to_hash ⇒ {
34 |
# File 'sig/openai/models/responses/response_steer_failed_event.rbs', line 34
def to_hash: -> {
|