Class: OpenAI::Models::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/responses/response_steer_input.rb,
sig/openai/models/responses/response_steer_input.rbs

Defined Under Namespace

Modules: Caller, Output, Status

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(caller_id:, type: :program) ⇒ Object

Parameters:

  • caller_id (String)

    The call ID of the program item that produced this tool call.

  • type (Symbol, :program) (defaults to: :program)

    The caller type. Always program.



# File 'lib/openai/models/responses/response_steer_input.rb', line 182

Instance Attribute Details

#call_idString?

The unique ID of the function tool call generated by the model.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


142
# File 'lib/openai/models/responses/response_steer_input.rb', line 142

optional :call_id, String, nil?: true

#caller_OpenAI::Models::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Caller::Direct, ...

The execution context that produced this tool call.

Parameters:

  • value (OpenAI::Models::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::caller_, nil)

Returns:



148
149
150
151
152
153
154
155
# File 'lib/openai/models/responses/response_steer_input.rb', line 148

optional(
  :caller_,
  union: -> {
    OpenAI::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Caller
  },
  api_name: :caller,
  nil?: true
)

#idString?

The unique ID of the function tool call output. Populated when this item is returned via API.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


136
# File 'lib/openai/models/responses/response_steer_input.rb', line 136

optional :id, String, nil?: true

#nameString?

The name of the tool that produced the output.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


161
# File 'lib/openai/models/responses/response_steer_input.rb', line 161

optional :name, String, nil?: true

#namespaceString?

The namespace of the tool that produced the output.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


167
# File 'lib/openai/models/responses/response_steer_input.rb', line 167

optional :namespace, String, nil?: true

#outputString, Array<OpenAI::Models::Responses::ResponseInputTextContent, OpenAI::Models::Responses::ResponseInputImageContent, OpenAI::Models::Responses::ResponseInputFileContent>

Text, image, or file output of the function tool call.

Parameters:

  • value (OpenAI::Models::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::output)

Returns:



118
119
120
121
122
123
# File 'lib/openai/models/responses/response_steer_input.rb', line 118

required(
  :output,
  union: -> {
    OpenAI::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Output
  }
)

#statusSymbol, ...

The status of the item. One of in_progress, completed, or incomplete. Populated when items are returned via API.

Parameters:

  • value (OpenAI::Models::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::status, nil)

Returns:



174
175
176
177
178
179
180
# File 'lib/openai/models/responses/response_steer_input.rb', line 174

optional(
  :status,
  enum: -> {
    OpenAI::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Status
  },
  nil?: true
)

#typeSymbol, :function_call_output

The type of the function tool call output. Always function_call_output.

Parameters:

  • value (:function_call_output)

Returns:

  • (Symbol, :function_call_output)


129
# File 'lib/openai/models/responses/response_steer_input.rb', line 129

required :type, const: :function_call_output

Class Method Details

.variantsArray(OpenAI::Models::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Caller::Direct, OpenAI::Models::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Caller::Program)



# File 'lib/openai/models/responses/response_steer_input.rb', line 223

Instance Method Details

#to_hash{

Returns:

  • ({)


107
# File 'sig/openai/models/responses/response_steer_input.rbs', line 107

def to_hash: -> {