Class: OpenAI::Models::Responses::ResponseSteerRequiredInput::McpApprovalResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_steer_required_input.rb,
sig/openai/models/responses/response_steer_required_input.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(approval_request_id:, type: :mcp_approval_response) ⇒ Object

Supply approve using the MCP approval response input schema. An optional reason can be supplied when denying the request. The original approval request identifies the tool and server.

Parameters:

  • approval_request_id (String)
  • type (Symbol, :mcp_approval_response) (defaults to: :mcp_approval_response)


# File 'lib/openai/models/responses/response_steer_required_input.rb', line 199

Instance Attribute Details

#approval_request_idString

Parameters:

  • value (String)

Returns:

  • (String)


192
# File 'lib/openai/models/responses/response_steer_required_input.rb', line 192

required :approval_request_id, String

#typeSymbol, :mcp_approval_response

Parameters:

  • value (:mcp_approval_response)

Returns:

  • (Symbol, :mcp_approval_response)


197
# File 'lib/openai/models/responses/response_steer_required_input.rb', line 197

required :type, const: :mcp_approval_response

Instance Method Details

#to_hash{

Returns:

  • ({)


149
# File 'sig/openai/models/responses/response_steer_required_input.rbs', line 149

def to_hash: -> {