Class: OpenAI::Models::Responses::ResponseToolSearchCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_tool_search_call.rb

Defined Under Namespace

Modules: Execution, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, arguments:, call_id:, execution:, status:, created_by: nil, type: :tool_search_call) ⇒ Object

Parameters:

  • The unique ID of the tool search call item.

  • Arguments used for the tool search call.

  • The unique ID of the tool search call generated by the model.

  • Whether tool search was executed by the server or by the client.

  • The status of the tool search call item that was recorded.

  • (defaults to: nil)

    The identifier of the actor that created the item.

  • (defaults to: :tool_search_call)

    The type of the item. Always tool_search_call.



# File 'lib/openai/models/responses/response_tool_search_call.rb', line 49


Instance Attribute Details

#argumentsObject

Arguments used for the tool search call.

Returns:



17
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 17

required :arguments, OpenAI::Internal::Type::Unknown

#call_idString?

The unique ID of the tool search call generated by the model.

Returns:



23
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 23

required :call_id, String, nil?: true

#created_byString?

The identifier of the actor that created the item.

Returns:



47
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 47

optional :created_by, String

#executionSymbol, OpenAI::Models::Responses::ResponseToolSearchCall::Execution

Whether tool search was executed by the server or by the client.

Returns:



29
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 29

required :execution, enum: -> { OpenAI::Responses::ResponseToolSearchCall::Execution }

#idString

The unique ID of the tool search call item.

Returns:



11
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 11

required :id, String

#statusSymbol, OpenAI::Models::Responses::ResponseToolSearchCall::Status

The status of the tool search call item that was recorded.

Returns:



35
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 35

required :status, enum: -> { OpenAI::Responses::ResponseToolSearchCall::Status }

#typeSymbol, :tool_search_call

The type of the item. Always tool_search_call.

Returns:



41
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 41

required :type, const: :tool_search_call

Class Method Details

.valuesArray<Symbol>

Returns:



# File 'lib/openai/models/responses/response_tool_search_call.rb', line 73