Class: OpenAI::Models::Responses::ResponseToolSearchOutputItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseToolSearchOutputItem
- Defined in:
- lib/openai/models/responses/response_tool_search_output_item.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#call_id ⇒ String?
The unique ID of the tool search call generated by the model.
-
#created_by ⇒ String?
The identifier of the actor that created the item.
-
#execution ⇒ Symbol, OpenAI::Models::Responses::ResponseToolSearchOutputItem::Execution
Whether tool search was executed by the server or by the client.
-
#id ⇒ String
The unique ID of the tool search output item.
-
#status ⇒ Symbol, OpenAI::Models::Responses::ResponseToolSearchOutputItem::Status
The status of the tool search output item that was recorded.
-
#tools ⇒ Array<OpenAI::Models::Responses::FunctionTool, OpenAI::Models::Responses::FileSearchTool, OpenAI::Models::Responses::ComputerTool, OpenAI::Models::Responses::ComputerUsePreviewTool, OpenAI::Models::Responses::Tool::Mcp, OpenAI::Models::Responses::Tool::CodeInterpreter, OpenAI::Models::Responses::Tool::ImageGeneration, OpenAI::Models::Responses::Tool::LocalShell, OpenAI::Models::Responses::FunctionShellTool, OpenAI::Models::Responses::CustomTool, OpenAI::Models::Responses::NamespaceTool, OpenAI::Models::Responses::ToolSearchTool, OpenAI::Models::Responses::ApplyPatchTool, OpenAI::Models::Responses::WebSearchTool, OpenAI::Models::Responses::WebSearchPreviewTool>
The loaded tool definitions returned by tool search.
-
#type ⇒ Symbol, :tool_search_output
The type of the item.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(id:, call_id:, execution:, status:, tools:, created_by: nil, type: :tool_search_output) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, call_id:, execution:, status:, tools:, created_by: nil, type: :tool_search_output) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_tool_search_output_item.rb', line 49
|
Instance Attribute Details
#call_id ⇒ String?
The unique ID of the tool search call generated by the model.
17 |
# File 'lib/openai/models/responses/response_tool_search_output_item.rb', line 17 required :call_id, String, nil?: true |
#created_by ⇒ String?
The identifier of the actor that created the item.
47 |
# File 'lib/openai/models/responses/response_tool_search_output_item.rb', line 47 optional :created_by, String |
#execution ⇒ Symbol, OpenAI::Models::Responses::ResponseToolSearchOutputItem::Execution
Whether tool search was executed by the server or by the client.
23 |
# File 'lib/openai/models/responses/response_tool_search_output_item.rb', line 23 required :execution, enum: -> { OpenAI::Responses::ResponseToolSearchOutputItem::Execution } |
#id ⇒ String
The unique ID of the tool search output item.
11 |
# File 'lib/openai/models/responses/response_tool_search_output_item.rb', line 11 required :id, String |
#status ⇒ Symbol, OpenAI::Models::Responses::ResponseToolSearchOutputItem::Status
The status of the tool search output item that was recorded.
29 |
# File 'lib/openai/models/responses/response_tool_search_output_item.rb', line 29 required :status, enum: -> { OpenAI::Responses::ResponseToolSearchOutputItem::Status } |
#tools ⇒ Array<OpenAI::Models::Responses::FunctionTool, OpenAI::Models::Responses::FileSearchTool, OpenAI::Models::Responses::ComputerTool, OpenAI::Models::Responses::ComputerUsePreviewTool, OpenAI::Models::Responses::Tool::Mcp, OpenAI::Models::Responses::Tool::CodeInterpreter, OpenAI::Models::Responses::Tool::ImageGeneration, OpenAI::Models::Responses::Tool::LocalShell, OpenAI::Models::Responses::FunctionShellTool, OpenAI::Models::Responses::CustomTool, OpenAI::Models::Responses::NamespaceTool, OpenAI::Models::Responses::ToolSearchTool, OpenAI::Models::Responses::ApplyPatchTool, OpenAI::Models::Responses::WebSearchTool, OpenAI::Models::Responses::WebSearchPreviewTool>
The loaded tool definitions returned by tool search.
35 |
# File 'lib/openai/models/responses/response_tool_search_output_item.rb', line 35 required :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Responses::Tool] } |
#type ⇒ Symbol, :tool_search_output
The type of the item. Always tool_search_output.
41 |
# File 'lib/openai/models/responses/response_tool_search_output_item.rb', line 41 required :type, const: :tool_search_output |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/response_tool_search_output_item.rb', line 73
|