Class: OpenAI::Models::Responses::ResponseToolSearchOutputItemParam

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_tool_search_output_item_param.rb

Defined Under Namespace

Modules: Execution, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(tools:, id: nil, call_id: nil, execution: nil, status: nil, type: :tool_search_output) ⇒ Object

Parameters:



# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 47

Instance Attribute Details

#call_idString?

The unique ID of the tool search call generated by the model.

Returns:

  • (String, nil)


29
# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 29

optional :call_id, String, nil?: true

#executionSymbol, ...

Whether tool search was executed by the server or by the client.



35
# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 35

optional :execution, enum: -> { OpenAI::Responses::ResponseToolSearchOutputItemParam::Execution }

#idString?

The unique ID of this tool search output.

Returns:

  • (String, nil)


23
# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 23

optional :id, String, nil?: true

#statusSymbol, ...

The status of the tool search output.



41
42
43
44
45
# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 41

optional :status,
enum: -> {
  OpenAI::Responses::ResponseToolSearchOutputItemParam::Status
},
nil?: true

#toolsArray<OpenAI::Models::Responses::FunctionTool, OpenAI::Models::Responses::FileSearchTool, OpenAI::Models::Responses::ComputerTool, OpenAI::Models::Responses::ComputerUsePreviewTool, OpenAI::Models::Responses::Tool::Mcp, OpenAI::Models::Responses::Tool::CodeInterpreter, OpenAI::Models::Responses::Tool::ImageGeneration, OpenAI::Models::Responses::Tool::LocalShell, OpenAI::Models::Responses::FunctionShellTool, OpenAI::Models::Responses::CustomTool, OpenAI::Models::Responses::NamespaceTool, OpenAI::Models::Responses::ToolSearchTool, OpenAI::Models::Responses::ApplyPatchTool, OpenAI::Models::Responses::WebSearchTool, OpenAI::Models::Responses::WebSearchPreviewTool>

The loaded tool definitions returned by the tool search output.



11
# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 11

required :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Responses::Tool] }

#typeSymbol, :tool_search_output

The item type. Always tool_search_output.

Returns:

  • (Symbol, :tool_search_output)


17
# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 17

required :type, const: :tool_search_output

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 69