Class: OpenAI::Models::Responses::ResponsesClientEvent::ContextManagement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/responses_client_event.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(background: nil, context_management: nil, conversation: nil, include: nil, input: nil, instructions: nil, max_output_tokens: nil, max_tool_calls: nil, metadata: nil, model: nil, parallel_tool_calls: nil, previous_response_id: nil, prompt: nil, prompt_cache_key: nil, prompt_cache_retention: nil, reasoning: nil, safety_identifier: nil, service_tier: nil, store: nil, stream: nil, stream_options: nil, temperature: nil, text: nil, tool_choice: nil, tools: nil, top_logprobs: nil, top_p: nil, truncation: nil, user: nil, type: :"response.create") ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponsesClientEvent for more details.

Parameters:



391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/openai/models/responses/responses_client_event.rb', line 391

class ContextManagement < OpenAI::Internal::Type::BaseModel
  # @!attribute type
  #   The context management entry type. Currently only 'compaction' is supported.
  #
  #   @return [String]
  required :type, String

  # @!attribute compact_threshold
  #   Token threshold at which compaction should be triggered for this entry.
  #
  #   @return [Integer, nil]
  optional :compact_threshold, Integer, nil?: true

  # @!method initialize(type:, compact_threshold: nil)
  #   @param type [String] The context management entry type. Currently only 'compaction' is supported.
  #
  #   @param compact_threshold [Integer, nil] Token threshold at which compaction should be triggered for this entry.
end

Instance Attribute Details

#compact_thresholdInteger?

Token threshold at which compaction should be triggered for this entry.

Returns:

  • (Integer, nil)


402
# File 'lib/openai/models/responses/responses_client_event.rb', line 402

optional :compact_threshold, Integer, nil?: true

#typeString

The context management entry type. Currently only ‘compaction’ is supported.

Returns:

  • (String)


396
# File 'lib/openai/models/responses/responses_client_event.rb', line 396

required :type, String