Class: OpenAI::Models::Responses::ResponsesClientEvent::ResponseCreate::Moderation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponsesClientEvent::ResponseCreate::Moderation
- Defined in:
- lib/openai/models/responses/responses_client_event.rb,
sig/openai/models/responses/responses_client_event.rbs
Overview
Defined Under Namespace
Classes: Policy
Instance Attribute Summary collapse
-
#model ⇒ String
The moderation model to use for moderated completions, e.g.
-
#policy ⇒ OpenAI::Models::Responses::ResponsesClientEvent::ResponseCreate::Moderation::Policy?
The policy to apply to moderated response input and output.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(model:, policy: nil) ⇒ Object
constructor
Configuration for running moderation on the input and output of this response.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(model:, policy: nil) ⇒ Object
Configuration for running moderation on the input and output of this response.
|
|
# File 'lib/openai/models/responses/responses_client_event.rb', line 818
|
Instance Attribute Details
#model ⇒ String
The moderation model to use for moderated completions, e.g. 'omni-moderation-latest'.
806 |
# File 'lib/openai/models/responses/responses_client_event.rb', line 806 required :model, String |
#policy ⇒ OpenAI::Models::Responses::ResponsesClientEvent::ResponseCreate::Moderation::Policy?
The policy to apply to moderated response input and output.
812 813 814 815 816 |
# File 'lib/openai/models/responses/responses_client_event.rb', line 812 optional( :policy, -> { OpenAI::Responses::ResponsesClientEvent::ResponseCreate::Moderation::Policy }, nil?: true ) |
Instance Method Details
#to_hash ⇒ {
261 |
# File 'sig/openai/models/responses/responses_client_event.rbs', line 261
def to_hash: -> {
|