Class: OpenAI::Models::Responses::ResponsesClientEvent::StreamOptions

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/responses_client_event.rb,
sig/openai/models/responses/responses_client_event.rbs

Overview

See Also:

  • OpenAI::Models::Responses::ResponsesClientEvent#stream_options

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeStreamOptions

Returns a new instance of StreamOptions.

Parameters:



417
# File 'sig/openai/models/responses/responses_client_event.rbs', line 417

def initialize: (?include_obfuscation: bool) -> void

Instance Attribute Details

#include_obfuscationBoolean?

When true, stream obfuscation will be enabled. Stream obfuscation adds random characters to an obfuscation field on streaming delta events to normalize payload sizes as a mitigation to certain side-channel attacks. These obfuscation fields are included by default, but add a small amount of overhead to the data stream. You can set include_obfuscation to false to optimize for bandwidth if you trust the network links between your application and the OpenAI API.

Parameters:

Returns:



747
# File 'lib/openai/models/responses/responses_client_event.rb', line 747

optional :include_obfuscation, OpenAI::Internal::Type::Boolean

Instance Method Details

#to_hash{ include_obfuscation: bool }

Returns:

  • ({ include_obfuscation: bool })


419
# File 'sig/openai/models/responses/responses_client_event.rbs', line 419

def to_hash: -> { include_obfuscation: bool }