Class: OpenAI::Models::Responses::ResponsesServerEvent::ResponseContentPartWsDone

Inherits:
OpenAI::Models::Responses::ResponseContentPartDoneEvent show all
Defined in:
lib/openai/models/responses/responses_server_event.rb,
sig/openai/models/responses/responses_server_event.rbs

Instance Attribute Summary collapse

Attributes inherited from OpenAI::Models::Responses::ResponseContentPartDoneEvent

#content_index, #item_id, #output_index, #part, #sequence_number, #type

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • content_index —

    The index of the content part that is done.

  • item_id —

    The ID of the output item that the content part was added to.

  • output_index —

    The index of the output item that the content part was added to.

  • part —

    The content part that is done.

  • sequence_number —

    The sequence number of this event.

  • stream_id —

    The WebSocket lane that emitted this event. This field is present when the originating response.create event supplied a stream_id.

  • type —

    The type of the event. Always response.content_part.done.



647
# File 'sig/openai/models/responses/responses_server_event.rbs', line 647

def initialize: (

Instance Attribute Details

#stream_id ⇒ String?

The WebSocket lane that emitted this event. This field is present when the originating response.create event supplied a stream_id.

Returns:

  • (String, nil)


709
# File 'lib/openai/models/responses/responses_server_event.rb', line 709

optional :stream_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


657
# File 'sig/openai/models/responses/responses_server_event.rbs', line 657

def to_hash: -> {