Class: OpenAI::Models::Responses::ResponsesServerEvent::ResponseImageGenCallPartialWsImage

Inherits:
OpenAI::Models::Responses::ResponseImageGenCallPartialImageEvent show all
Defined in:
lib/openai/models/responses/responses_server_event.rb,
sig/openai/models/responses/responses_server_event.rbs

Instance Attribute Summary collapse

Attributes inherited from OpenAI::Models::Responses::ResponseImageGenCallPartialImageEvent

#background, #item_id, #output_format, #output_index, #partial_image_b64, #partial_image_index, #quality, #sequence_number, #size, #type

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • item_id —

    The unique identifier of the image generation item being processed.

  • output_index —

    The index of the output item in the response's output array.

  • partial_image_b64 —

    Base64-encoded partial image data, suitable for rendering as an image.

  • partial_image_index —

    0-based index for the partial image (backend is 1-based, but this is 0-based for the user).

  • sequence_number —

    The sequence number of the image generation item being processed.

  • background —

    The background setting that was used.

  • output_format —

    The output format that was used.

  • quality —

    The image quality that was used.

  • size —

    The image size that was used.

  • stream_id —

    The WebSocket lane that emitted this event. This field is present when the originating response.create event supplied a stream_id.

  • type —

    The type of the event. Always 'response.image_generation_call.partial_image'.



2335
# File 'sig/openai/models/responses/responses_server_event.rbs', line 2335

def initialize: (

Instance Attribute Details

#stream_id ⇒ String?

The WebSocket lane that emitted this event. This field is present when the originating response.create event supplied a stream_id.

Returns:

  • (String, nil)


1735
# File 'lib/openai/models/responses/responses_server_event.rb', line 1735

optional :stream_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


2349
# File 'sig/openai/models/responses/responses_server_event.rbs', line 2349

def to_hash: -> {