Module: OpenAI::Models::Responses::Tool::ImageGeneration::InputFidelity

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/responses/tool.rb,
sig/openai/models/responses/tool.rbs

Overview

Control how much effort the model will exert to match the style and features, especially facial features, of input images. This parameter is only supported for gpt-image-1 and gpt-image-1.5 and later models, unsupported for gpt-image-1-mini. Supports high and low. Defaults to low.

See Also:

  • OpenAI::Models::Responses::Tool::ImageGeneration#input_fidelity

Constant Summary collapse

HIGH =

Returns:

  • (:high)
:high
LOW =

Returns:

  • (:low)
:low

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[OpenAI::Models::Responses::Tool::ImageGeneration::input_fidelity]

Returns:

  • (::Array[OpenAI::Models::Responses::Tool::ImageGeneration::input_fidelity])


526
# File 'sig/openai/models/responses/tool.rbs', line 526

def self?.values: -> ::Array[OpenAI::Models::Responses::Tool::ImageGeneration::input_fidelity]