Module: OpenAI::Models::Responses::ToolChoiceAllowed::Mode
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/responses/tool_choice_allowed.rb,
sig/openai/models/responses/tool_choice_allowed.rbs
Overview
Constrains the tools available to the model to a pre-defined set.
auto allows the model to pick from among the allowed tools and generate a
message.
required requires the model to call one or more of the allowed tools.
Constant Summary collapse
- AUTO =
:auto- REQUIRED =
:required
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/tool_choice_allowed.rb', line 67
|
Instance Method Details
#self?.values ⇒ ::Array[OpenAI::Models::Responses::ToolChoiceAllowed::mode]
38 |
# File 'sig/openai/models/responses/tool_choice_allowed.rbs', line 38
def self?.values: -> ::Array[OpenAI::Models::Responses::ToolChoiceAllowed::mode]
|