Class: OpenAI::Models::Responses::ToolChoiceCustom

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/tool_choice_custom.rb,
sig/openai/models/responses/tool_choice_custom.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, type: :custom) ⇒ ToolChoiceCustom

Returns a new instance of ToolChoiceCustom.

Parameters:

  • name —

    The name of the custom tool to call.

  • type (defaults to: :custom) —

    For custom tool calling, the type is always custom.

  • name: (String)
  • type: (:custom) (defaults to: :custom)


# File 'lib/openai/models/responses/tool_choice_custom.rb', line 19

Instance Attribute Details

#name ⇒ String

The name of the custom tool to call.

Returns:

  • (String)


11
# File 'lib/openai/models/responses/tool_choice_custom.rb', line 11

required :name, String

#type ⇒ :custom

For custom tool calling, the type is always custom.

Returns:

  • (:custom)


17
# File 'lib/openai/models/responses/tool_choice_custom.rb', line 17

required :type, const: :custom

Instance Method Details

#to_hash ⇒ { name: String, ?type: :custom }

Returns:

  • ({ name: String, ?type: :custom })


19
# File 'sig/openai/models/responses/tool_choice_custom.rbs', line 19

def to_hash: -> { name: String, ?type: :custom }