Class: OpenAI::Models::Responses::ToolChoiceMcp

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/tool_choice_mcp.rb,
sig/openai/models/responses/tool_choice_mcp.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(server_label:, name: nil, type: :mcp) ⇒ Object

Parameters:

  • server_label —

    The label of the MCP server to use.

  • name (defaults to: nil) —

    The name of the tool to call on the server.

  • type (defaults to: :mcp) —

    For MCP tools, the type is always mcp.



# File 'lib/openai/models/responses/tool_choice_mcp.rb', line 25

Instance Attribute Details

#name ⇒ String?

The name of the tool to call on the server.

Returns:

  • (String, nil)


23
# File 'lib/openai/models/responses/tool_choice_mcp.rb', line 23

optional :name, String, nil?: true

#server_label ⇒ String

The label of the MCP server to use.

Returns:

  • (String)


11
# File 'lib/openai/models/responses/tool_choice_mcp.rb', line 11

required :server_label, String

#type ⇒ :mcp

For MCP tools, the type is always mcp.

Returns:

  • (:mcp)


17
# File 'lib/openai/models/responses/tool_choice_mcp.rb', line 17

required :type, const: :mcp

Instance Method Details

#to_hash ⇒ { server_label: String, ?type: :mcp, ?name: String? }

Returns:

  • ({ server_label: String, ?type: :mcp, ?name: String? })


29
# File 'sig/openai/models/responses/tool_choice_mcp.rbs', line 29

def to_hash: -> { server_label: String, ?type: :mcp, ?name: String? }