Class: OpenAI::Models::Responses::ToolChoiceTypes
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ToolChoiceTypes
- Defined in:
- lib/openai/models/responses/tool_choice_types.rb,
sig/openai/models/responses/tool_choice_types.rbs
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#type ⇒ Symbol, OpenAI::Models::Responses::ToolChoiceTypes::Type
The type of hosted tool the model should to use.
Instance Method Summary collapse
-
#initialize(type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ToolChoiceTypes for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type:) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Responses::ToolChoiceTypes for more details.
Indicates that the model should use a built-in tool to generate a response. Learn more about built-in tools.
|
|
# File 'lib/openai/models/responses/tool_choice_types.rb', line 24
|
Instance Attribute Details
#type ⇒ Symbol, OpenAI::Models::Responses::ToolChoiceTypes::Type
The type of hosted tool the model should to use. Learn more about built-in tools.
Allowed values are:
file_searchweb_search_previewcomputercomputer_use_previewcomputer_usecode_interpreterimage_generation
22 |
# File 'lib/openai/models/responses/tool_choice_types.rb', line 22 required :type, enum: -> { OpenAI::Responses::ToolChoiceTypes::Type } |
Instance Method Details
#to_hash ⇒ {
14 |
# File 'sig/openai/models/responses/tool_choice_types.rbs', line 14
def to_hash: -> {
|