Class: OpenAI::Models::Responses::ToolSearchTool

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/tool_search_tool.rb

Defined Under Namespace

Modules: Execution

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(description: nil, execution: nil, parameters: nil, type: :tool_search) ⇒ Object

Hosted or BYOT tool search configuration for deferred tools.

Parameters:

  • description (String, nil) (defaults to: nil)

    Description shown to the model for a client-executed tool search tool.

  • execution (Symbol, OpenAI::Models::Responses::ToolSearchTool::Execution) (defaults to: nil)

    Whether tool search is executed by the server or by the client.

  • parameters (Object, nil) (defaults to: nil)

    Parameter schema for a client-executed tool search tool.

  • type (Symbol, :tool_search) (defaults to: :tool_search)

    The type of the tool. Always tool_search.



# File 'lib/openai/models/responses/tool_search_tool.rb', line 31

Instance Attribute Details

#descriptionString?

Description shown to the model for a client-executed tool search tool.

Returns:

  • (String, nil)


17
# File 'lib/openai/models/responses/tool_search_tool.rb', line 17

optional :description, String, nil?: true

#executionSymbol, ...

Whether tool search is executed by the server or by the client.



23
# File 'lib/openai/models/responses/tool_search_tool.rb', line 23

optional :execution, enum: -> { OpenAI::Responses::ToolSearchTool::Execution }

#parametersObject?

Parameter schema for a client-executed tool search tool.

Returns:

  • (Object, nil)


29
# File 'lib/openai/models/responses/tool_search_tool.rb', line 29

optional :parameters, OpenAI::Internal::Type::Unknown, nil?: true

#typeSymbol, :tool_search

The type of the tool. Always tool_search.

Returns:

  • (Symbol, :tool_search)


11
# File 'lib/openai/models/responses/tool_search_tool.rb', line 11

required :type, const: :tool_search