Class: OpenAI::Models::Uploads::UploadPart

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/uploads/upload_part.rb,
sig/openai/models/uploads/upload_part.rbs

Overview

See Also:

  • OpenAI::Resources::Uploads::Parts#create

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • id —

    The upload Part unique identifier, which can be referenced in API endpoints.

  • created_at —

    The Unix timestamp (in seconds) for when the Part was created.

  • upload_id —

    The ID of the Upload object that this Part was added to.

  • object —

    The object type, which is always upload.part.



35
# File 'sig/openai/models/uploads/upload_part.rbs', line 35

def initialize: (

Instance Attribute Details

#created_at ⇒ Integer

The Unix timestamp (in seconds) for when the Part was created.

Returns:

  • (Integer)


18
# File 'lib/openai/models/uploads/upload_part.rb', line 18

required :created_at, Integer

#id ⇒ String

The upload Part unique identifier, which can be referenced in API endpoints.

Returns:

  • (String)


12
# File 'lib/openai/models/uploads/upload_part.rb', line 12

required :id, String

#object ⇒ :"upload.part"

The object type, which is always upload.part.

Returns:

  • (:"upload.part")


24
# File 'lib/openai/models/uploads/upload_part.rb', line 24

required :object, const: :"upload.part"

#upload_id ⇒ String

The ID of the Upload object that this Part was added to.

Returns:

  • (String)


30
# File 'lib/openai/models/uploads/upload_part.rb', line 30

required :upload_id, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


42
# File 'sig/openai/models/uploads/upload_part.rbs', line 42

def to_hash: -> {