Class: OpenAI::Models::VectorStore::ExpiresAfter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/vector_store.rb,
sig/openai/models/vector_store.rbs

Overview

See Also:

  • OpenAI::Models::VectorStore#expires_after

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(days:, anchor: :last_active_at) ⇒ ExpiresAfter

Returns a new instance of ExpiresAfter.

Parameters:

  • days

    The number of days after the anchor time that the vector store will expire.

  • anchor (defaults to: :last_active_at)

    Anchor timestamp after which the expiration policy applies. Supported anchors: last_active_at.

  • days: (Integer)
  • anchor: (:last_active_at) (defaults to: :last_active_at)


# File 'lib/openai/models/vector_store.rb', line 202

Instance Attribute Details

#anchor:last_active_at

Anchor timestamp after which the expiration policy applies. Supported anchors: last_active_at.

Returns:

  • (:last_active_at)


194
# File 'lib/openai/models/vector_store.rb', line 194

required :anchor, const: :last_active_at

#daysInteger

The number of days after the anchor time that the vector store will expire.

Returns:

  • (Integer)


200
# File 'lib/openai/models/vector_store.rb', line 200

required :days, Integer

Instance Method Details

#to_hash{ ?anchor: :last_active_at, days: Integer }

Returns:

  • ({ ?anchor: :last_active_at, days: Integer })


199
# File 'sig/openai/models/vector_store.rbs', line 199

def to_hash: -> { ?anchor: :last_active_at, days: Integer }