Class: OpenAI::Models::VectorStore::FileCounts

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/vector_store.rb,
sig/openai/models/vector_store.rbs

Overview

See Also:

  • OpenAI::Models::VectorStore#file_counts

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object

Parameters:

  • cancelled —

    The number of files that were cancelled.

  • completed —

    The number of files that have been successfully processed.

  • failed —

    The number of files that have failed to process.

  • in_progress —

    The number of files that are currently being processed.

  • total —

    The total number of files.



153
# File 'sig/openai/models/vector_store.rbs', line 153

def initialize: (

Instance Attribute Details

#cancelled ⇒ Integer

The number of files that were cancelled.

Returns:

  • (Integer)


128
# File 'lib/openai/models/vector_store.rb', line 128

required :cancelled, Integer

#completed ⇒ Integer

The number of files that have been successfully processed.

Returns:

  • (Integer)


134
# File 'lib/openai/models/vector_store.rb', line 134

required :completed, Integer

#failed ⇒ Integer

The number of files that have failed to process.

Returns:

  • (Integer)


140
# File 'lib/openai/models/vector_store.rb', line 140

required :failed, Integer

#in_progress ⇒ Integer

The number of files that are currently being processed.

Returns:

  • (Integer)


146
# File 'lib/openai/models/vector_store.rb', line 146

required :in_progress, Integer

#total ⇒ Integer

The total number of files.

Returns:

  • (Integer)


152
# File 'lib/openai/models/vector_store.rb', line 152

required :total, Integer

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


161
# File 'sig/openai/models/vector_store.rbs', line 161

def to_hash: -> {