Module: OpenAI::Models::VectorStore::Status
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/vector_store.rb,
sig/openai/models/vector_store.rbs
Overview
The status of the vector store, which can be either expired, in_progress, or
completed. A status of completed indicates that the vector store is ready
for use.
Constant Summary collapse
- EXPIRED =
:expired- IN_PROGRESS =
:in_progress- COMPLETED =
:completed
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[OpenAI::Models::VectorStore::status]
119 |
# File 'sig/openai/models/vector_store.rbs', line 119
def self?.values: -> ::Array[OpenAI::Models::VectorStore::status]
|