Class: OpenAI::Models::VectorStores::FileUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/vector_stores/file_update_params.rb,
sig/openai/models/vector_stores/file_update_params.rbs

Overview

See Also:

  • OpenAI::Resources::VectorStores::Files#update

Defined Under Namespace

Modules: Attribute

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



22
# File 'sig/openai/models/vector_stores/file_update_params.rbs', line 22

def initialize: (

Instance Attribute Details

#attributesHash{Symbol=>String, Float, Boolean}?

Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard. Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters, booleans, or numbers.

Parameters:

  • value (::Hash[Symbol, OpenAI::Models::VectorStores::FileUpdateParams::attribute], nil)

Returns:

  • (Hash{Symbol=>String, Float, Boolean}, nil)


29
30
31
32
33
# File 'lib/openai/models/vector_stores/file_update_params.rb', line 29

required :attributes,
-> {
  OpenAI::Internal::Type::HashOf[union: OpenAI::VectorStores::FileUpdateParams::Attribute]
},
nil?: true

#file_idString

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/openai/models/vector_stores/file_update_params.rb', line 19

required :file_id, String

#vector_store_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/openai/models/vector_stores/file_update_params.rb', line 14

required :vector_store_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


29
# File 'sig/openai/models/vector_stores/file_update_params.rbs', line 29

def to_hash: -> {