Class: OpenAI::Models::VectorStores::VectorStoreFileBatch
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::VectorStores::VectorStoreFileBatch
- Defined in:
- lib/openai/models/vector_stores/vector_store_file_batch.rb,
sig/openai/models/vector_stores/vector_store_file_batch.rbs
Overview
Defined Under Namespace
Modules: Status Classes: FileCounts
Instance Attribute Summary collapse
-
#created_at ⇒ Integer
The Unix timestamp (in seconds) for when the vector store files batch was created.
- #file_counts ⇒ OpenAI::Models::VectorStores::VectorStoreFileBatch::FileCounts
-
#id ⇒ String
The identifier, which can be referenced in API endpoints.
-
#object ⇒ Symbol, :"vector_store.files_batch"
The object type, which is always
vector_store.file_batch. -
#status ⇒ Symbol, OpenAI::Models::VectorStores::VectorStoreFileBatch::Status
The status of the vector store files batch, which can be either
in_progress,completed,cancelledorfailed. -
#vector_store_id ⇒ String
The ID of the vector store that the File is attached to.
Instance Method Summary collapse
- #initialize(cancelled:, completed:, failed:, in_progress:, total:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cancelled:, completed:, failed:, in_progress:, total:) ⇒ Object
|
|
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 48
|
Instance Attribute Details
#created_at ⇒ Integer
The Unix timestamp (in seconds) for when the vector store files batch was created.
19 |
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 19 required :created_at, Integer |
#file_counts ⇒ OpenAI::Models::VectorStores::VectorStoreFileBatch::FileCounts
24 |
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 24 required :file_counts, -> { OpenAI::VectorStores::VectorStoreFileBatch::FileCounts } |
#id ⇒ String
The identifier, which can be referenced in API endpoints.
12 |
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 12 required :id, String |
#object ⇒ Symbol, :"vector_store.files_batch"
The object type, which is always vector_store.file_batch.
30 |
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 30 required :object, const: :"vector_store.files_batch" |
#status ⇒ Symbol, OpenAI::Models::VectorStores::VectorStoreFileBatch::Status
The status of the vector store files batch, which can be either in_progress,
completed, cancelled or failed.
37 |
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 37 required :status, enum: -> { OpenAI::VectorStores::VectorStoreFileBatch::Status } |
#vector_store_id ⇒ String
The ID of the vector store that the File is attached to.
46 |
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 46 required :vector_store_id, String |
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/openai/models/vector_stores/vector_store_file_batch.rbs', line 38
def to_hash: -> {
|