Class: OpenAI::Models::VectorStores::VectorStoreFileBatch::FileCounts

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/vector_stores/vector_store_file_batch.rb,
sig/openai/models/vector_stores/vector_store_file_batch.rbs

Overview

See Also:

  • OpenAI::Models::VectorStores::VectorStoreFileBatch#file_counts

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject

Parameters:

  • cancelled

    The number of files that where cancelled.

  • completed

    The number of files that have been processed.

  • failed

    The number of files that have failed to process.

  • in_progress

    The number of files that are currently being processed.

  • total

    The total number of files.



107
# File 'sig/openai/models/vector_stores/vector_store_file_batch.rbs', line 107

def initialize: (

Instance Attribute Details

#cancelledInteger

The number of files that where cancelled.

Returns:

  • (Integer)


79
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 79

required :cancelled, Integer

#completedInteger

The number of files that have been processed.

Returns:

  • (Integer)


85
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 85

required :completed, Integer

#failedInteger

The number of files that have failed to process.

Returns:

  • (Integer)


91
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 91

required :failed, Integer

#in_progressInteger

The number of files that are currently being processed.

Returns:

  • (Integer)


97
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 97

required :in_progress, Integer

#totalInteger

The total number of files.

Returns:

  • (Integer)


103
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 103

required :total, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


115
# File 'sig/openai/models/vector_stores/vector_store_file_batch.rbs', line 115

def to_hash: -> {