Class: OpenAI::Models::VideoCreateError

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/video_create_error.rb,
sig/openai/models/video_create_error.rbs

Defined Under Namespace

Classes: Misalignment

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(code:, message:, headers: nil, misalignment: nil) ⇒ Object

Parameters:

  • code —

    A machine-readable error code that was returned.

  • message —

    A human-readable description of the error that was returned.

  • headers (defaults to: nil) —

    The Retry-After and Retry-After-Ms headers returned with the original error, if any.



# File 'lib/openai/models/video_create_error.rb', line 30

Instance Attribute Details

#code ⇒ String

A machine-readable error code that was returned.

Returns:

  • (String)


10
# File 'lib/openai/models/video_create_error.rb', line 10

required :code, String

#headers ⇒ ::Hash[Symbol, String]?

The Retry-After and Retry-After-Ms headers returned with the original error, if any.

Returns:

  • (::Hash[Symbol, String], nil)


23
# File 'lib/openai/models/video_create_error.rb', line 23

optional :headers, OpenAI::Internal::Type::HashOf[String]

#message ⇒ String

A human-readable description of the error that was returned.

Returns:

  • (String)


16
# File 'lib/openai/models/video_create_error.rb', line 16

required :message, String

#misalignment ⇒ OpenAI::Models::VideoCreateError::Misalignment?



28
# File 'lib/openai/models/video_create_error.rb', line 28

optional :misalignment, -> { OpenAI::VideoCreateError::Misalignment }

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


46
# File 'sig/openai/models/video_create_error.rbs', line 46

def to_hash: -> {