Class: OpenAI::Models::VideoCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/video_create_params.rb

Overview

Defined Under Namespace

Modules: InputReference

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(prompt:, input_reference: nil, model: nil, seconds: nil, size: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::VideoCreateParams for more details.

Parameters:

  • Text prompt that describes the video to generate.

  • (defaults to: nil)

    Optional reference asset upload or reference object that guides generation.

  • (defaults to: nil)

    The video generation model to use (allowed values: sora-2, sora-2-pro). Defaults

  • (defaults to: nil)

    Clip duration in seconds (allowed values: 4, 8, 12). Defaults to 4 seconds.

  • (defaults to: nil)

    Output resolution formatted as width x height (allowed values: 720x1280, 1280x72

  • (defaults to: {})


# File 'lib/openai/models/video_create_params.rb', line 42


Instance Attribute Details

#input_referencePathname, ...

Optional reference asset upload or reference object that guides generation.

Returns:



20
# File 'lib/openai/models/video_create_params.rb', line 20

optional :input_reference, union: -> { OpenAI::VideoCreateParams::InputReference }

#modelString, ...

The video generation model to use (allowed values: sora-2, sora-2-pro). Defaults to sora-2.

Returns:



27
# File 'lib/openai/models/video_create_params.rb', line 27

optional :model, union: -> { OpenAI::VideoModel }

#promptString

Text prompt that describes the video to generate.

Returns:



14
# File 'lib/openai/models/video_create_params.rb', line 14

required :prompt, String

#secondsSymbol, ...

Clip duration in seconds (allowed values: 4, 8, 12). Defaults to 4 seconds.

Returns:



33
# File 'lib/openai/models/video_create_params.rb', line 33

optional :seconds, enum: -> { OpenAI::VideoSeconds }

#sizeSymbol, ...

Output resolution formatted as width x height (allowed values: 720x1280, 1280x720, 1024x1792, 1792x1024). Defaults to 720x1280.

Returns:



40
# File 'lib/openai/models/video_create_params.rb', line 40

optional :size, enum: -> { OpenAI::VideoSize }