Class: OpenAI::Models::VideoExtendParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::VideoExtendParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/video_extend_params.rb
Overview
Defined Under Namespace
Modules: Video
Instance Attribute Summary collapse
-
#prompt ⇒ String
Updated text prompt that directs the extension generation.
-
#seconds ⇒ Symbol, OpenAI::Models::VideoSeconds
Length of the newly generated extension segment in seconds (allowed values: 4, 8, 12, 16, 20).
-
#video ⇒ Pathname, ...
Reference to the completed video to extend.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(prompt:, seconds:, video:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see VideoExtendParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(prompt:, seconds:, video:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::VideoExtendParams for more details.
|
|
# File 'lib/openai/models/video_extend_params.rb', line 29
|
Instance Attribute Details
#prompt ⇒ String
Updated text prompt that directs the extension generation.
14 |
# File 'lib/openai/models/video_extend_params.rb', line 14 required :prompt, String |
#seconds ⇒ Symbol, OpenAI::Models::VideoSeconds
Length of the newly generated extension segment in seconds (allowed values: 4, 8, 12, 16, 20).
21 |
# File 'lib/openai/models/video_extend_params.rb', line 21 required :seconds, enum: -> { OpenAI::VideoSeconds } |
#video ⇒ Pathname, ...
Reference to the completed video to extend.
27 |
# File 'lib/openai/models/video_extend_params.rb', line 27 required :video, union: -> { OpenAI::VideoExtendParams::Video } |