Class: OpenAI::Models::Webhooks::SafetyIdentifierBlockedWebhookEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/webhooks/safety_identifier_blocked_webhook_event.rb,
sig/openai/models/webhooks/safety_identifier_blocked_webhook_event.rbs

Overview

See Also:

  • OpenAI::Models::Webhooks::SafetyIdentifierBlockedWebhookEvent#data

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



70
# File 'sig/openai/models/webhooks/safety_identifier_blocked_webhook_event.rbs', line 70

def initialize: (

Instance Attribute Details

#modelString?

The model used for the blocked request, if available.

Parameters:

  • (String)

Returns:

  • (String, nil)


72
# File 'lib/openai/models/webhooks/safety_identifier_blocked_webhook_event.rb', line 72

optional :model, String

#project_idString?

The project associated with the blocked request, if available.

Parameters:

  • (String)

Returns:

  • (String, nil)


78
# File 'lib/openai/models/webhooks/safety_identifier_blocked_webhook_event.rb', line 78

optional :project_id, String

#request_idString?

The OpenAI request ID for the blocked request, if available.

Parameters:

  • (String)

Returns:

  • (String, nil)


84
# File 'lib/openai/models/webhooks/safety_identifier_blocked_webhook_event.rb', line 84

optional :request_id, String

#safety_categoryString

The safety category that triggered the block, such as bio or cyber.

Parameters:

  • value (String)

Returns:

  • (String)


60
# File 'lib/openai/models/webhooks/safety_identifier_blocked_webhook_event.rb', line 60

required :safety_category, String

#safety_identifierString

The stable safety identifier associated with the blocked request.

Parameters:

  • value (String)

Returns:

  • (String)


66
# File 'lib/openai/models/webhooks/safety_identifier_blocked_webhook_event.rb', line 66

required :safety_identifier, String

Instance Method Details

#to_hash{

Returns:

  • ({)


78
# File 'sig/openai/models/webhooks/safety_identifier_blocked_webhook_event.rbs', line 78

def to_hash: -> {