Class: OpenAI::Models::Webhooks::SafetyOrgAlertCreatedWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/webhooks/safety_org_alert_created_webhook_event.rb,
sig/openai/models/webhooks/safety_org_alert_created_webhook_event.rbs

Defined Under Namespace

Classes: Data

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, data:, object: :event, type: :"safety.org_alert.created") ⇒ Object

Parameters:

  • id —

    The unique ID of the webhook event.

  • created_at —

    The Unix timestamp in seconds when the event was created.

  • object (defaults to: :event) —

    Always event.

  • type (defaults to: :"safety.org_alert.created") —

    Always safety.org_alert.created.



# File 'lib/openai/models/webhooks/safety_org_alert_created_webhook_event.rb', line 36

Instance Attribute Details

#created_at ⇒ Integer

The Unix timestamp in seconds when the event was created.

Returns:

  • (Integer)


17
# File 'lib/openai/models/webhooks/safety_org_alert_created_webhook_event.rb', line 17

required :created_at, Integer

#data ⇒ OpenAI::Models::Webhooks::SafetyOrgAlertCreatedWebhookEvent::Data

Parameters:

  • value (OpenAI::Webhooks::SafetyOrgAlertCreatedWebhookEvent::Data)

Returns:



22
# File 'lib/openai/models/webhooks/safety_org_alert_created_webhook_event.rb', line 22

required :data, -> { OpenAI::Webhooks::SafetyOrgAlertCreatedWebhookEvent::Data }

#id ⇒ String

The unique ID of the webhook event.

Returns:

  • (String)


11
# File 'lib/openai/models/webhooks/safety_org_alert_created_webhook_event.rb', line 11

required :id, String

#object ⇒ :event

Always event.

Returns:

  • (:event)


28
# File 'lib/openai/models/webhooks/safety_org_alert_created_webhook_event.rb', line 28

required :object, const: :event

#type ⇒ :"safety.org_alert.created"

Always safety.org_alert.created.

Returns:

  • (:"safety.org_alert.created")


34
# File 'lib/openai/models/webhooks/safety_org_alert_created_webhook_event.rb', line 34

required :type, const: :"safety.org_alert.created"

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


44
# File 'sig/openai/models/webhooks/safety_org_alert_created_webhook_event.rbs', line 44

def to_hash: -> {