Class: OpenAI::Models::Webhooks::WebhookEventTypeList

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/webhooks/webhook_event_type_list.rb,
sig/openai/models/webhooks/webhook_event_type_list.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(data:, object: :list) ⇒ WebhookEventTypeList

Returns a new instance of WebhookEventTypeList.

Parameters:

  • data

    The webhook event types available to the authenticated project.

  • object (defaults to: :list)

    The object type, which is always list.

  • data: (::Array[String])
  • object: (:list) (defaults to: :list)


# File 'lib/openai/models/webhooks/webhook_event_type_list.rb', line 19


Instance Attribute Details

#data::Array[String]

The webhook event types available to the authenticated project.

Returns:

  • (::Array[String])


11
# File 'lib/openai/models/webhooks/webhook_event_type_list.rb', line 11

required :data, OpenAI::Internal::Type::ArrayOf[String]

#object:list

The object type, which is always list.

Returns:

  • (:list)


17
# File 'lib/openai/models/webhooks/webhook_event_type_list.rb', line 17

required :object, const: :list

Instance Method Details

#to_hash{ data: ::Array[String], ?object: :list }

Returns:

  • ({ data: ::Array[String], ?object: :list })


19
# File 'sig/openai/models/webhooks/webhook_event_type_list.rbs', line 19

def to_hash: -> { data: ::Array[String], ?object: :list }