Class: OpenAI::Models::Webhooks::WebhookTestParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/webhooks/webhook_test_params.rb,
sig/openai/models/webhooks/webhook_test_params.rbs

Overview

See Also:

  • OpenAI::Resources::Webhooks#test_

Defined Under Namespace

Modules: EventType

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(webhook_endpoint_id:, event_type:, request_options: {}) ⇒ Object

Parameters:

  • event_type

    The event type to send as a sample delivery.



# File 'lib/openai/models/webhooks/webhook_test_params.rb', line 22

Instance Attribute Details

#event_typeOpenAI::Models::Webhooks::WebhookTestParams::event_type

The event type to send as a sample delivery.

Returns:

  • (OpenAI::Models::Webhooks::WebhookTestParams::event_type)


20
# File 'lib/openai/models/webhooks/webhook_test_params.rb', line 20

required :event_type, enum: -> { OpenAI::Webhooks::WebhookTestParams::EventType }

#webhook_endpoint_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/openai/models/webhooks/webhook_test_params.rb', line 14

required :webhook_endpoint_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


28
# File 'sig/openai/models/webhooks/webhook_test_params.rbs', line 28

def to_hash: -> {