Class: OpenAI::Models::Webhooks::WebhookUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/webhooks/webhook_update_params.rb,
sig/openai/models/webhooks/webhook_update_params.rbs

Overview

See Also:

  • OpenAI::Resources::Webhooks#update

Defined Under Namespace

Modules: EventType

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(webhook_endpoint_id:, event_types: nil, name: nil, url: nil, request_options: {}) ⇒ Object

Parameters:

  • event_types (defaults to: nil)

    The complete set of event types that should trigger deliveries.

  • name (defaults to: nil)

    A new human-readable name for the webhook endpoint.

  • url (defaults to: nil)

    A new HTTPS URL that receives webhook deliveries.



# File 'lib/openai/models/webhooks/webhook_update_params.rb', line 37

Instance Attribute Details

#event_types::Array[OpenAI::Models::Webhooks::WebhookUpdateParams::event_type]?

The complete set of event types that should trigger deliveries.

Returns:

  • (::Array[OpenAI::Models::Webhooks::WebhookUpdateParams::event_type], nil)


20
21
22
23
# File 'lib/openai/models/webhooks/webhook_update_params.rb', line 20

optional(
  :event_types,
  -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Webhooks::WebhookUpdateParams::EventType] }
)

#nameString?

A new human-readable name for the webhook endpoint.

Returns:

  • (String, nil)


29
# File 'lib/openai/models/webhooks/webhook_update_params.rb', line 29

optional :name, String

#urlString?

A new HTTPS URL that receives webhook deliveries.

Returns:

  • (String, nil)


35
# File 'lib/openai/models/webhooks/webhook_update_params.rb', line 35

optional :url, String

#webhook_endpoint_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/openai/models/webhooks/webhook_update_params.rb', line 14

required :webhook_endpoint_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


53
# File 'sig/openai/models/webhooks/webhook_update_params.rbs', line 53

def to_hash: -> {