Class: OpenAI::Resources::Chat
- Inherits:
-
Object
- Object
- OpenAI::Resources::Chat
- Defined in:
- lib/openai/resources/chat.rb,
lib/openai/resources/chat/completions.rb,
lib/openai/resources/chat/completions/messages.rb
Defined Under Namespace
Classes: Completions
Instance Attribute Summary collapse
-
#completions ⇒ OpenAI::Resources::Chat::Completions
readonly
Given a list of messages comprising a conversation, the model will return a response.
Instance Method Summary collapse
-
#initialize(client:) ⇒ Chat
constructor
private
A new instance of Chat.
Constructor Details
#initialize(client:) ⇒ Chat
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Chat.
14 15 16 17 |
# File 'lib/openai/resources/chat.rb', line 14 def initialize(client:) @client = client @completions = OpenAI::Resources::Chat::Completions.new(client: client) end |
Instance Attribute Details
#completions ⇒ OpenAI::Resources::Chat::Completions (readonly)
Given a list of messages comprising a conversation, the model will return a response.
9 10 11 |
# File 'lib/openai/resources/chat.rb', line 9 def completions @completions end |