Module: OpenAI::Helpers::StructuredOutput::JsonSchemaConverter

Included in:
ArrayOf, BaseModel, Boolean, EnumOf, UnionOf
Defined in:
lib/openai/helpers/structured_output/json_schema_converter.rb

Overview

To customize the JSON schema conversion for a type, implement the ‘JsonSchemaConverter` interface.

Constant Summary collapse

POINTER =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Object.new.tap do
  _1.define_singleton_method(:inspect) do
    "#<#{OpenAI::Helpers::StructuredOutput::JsonSchemaConverter}::POINTER>"
  end
end.freeze
COUNTER =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Object.new.tap do
  _1.define_singleton_method(:inspect) do
    "#<#{OpenAI::Helpers::StructuredOutput::JsonSchemaConverter}::COUNTER>"
  end
end.freeze
NO_REF =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Object.new.tap do
  _1.define_singleton_method(:inspect) do
    "#<#{OpenAI::Helpers::StructuredOutput::JsonSchemaConverter}::NO_REF>"
  end
end.freeze

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.cache_def!(state, type:, &blk) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • state (Hash{Symbol=>Object})

    @option state [HashObject=>String] :defs

    @option state [Array<String>] :path

  • type (Object)
  • blk (Proc)


81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/openai/helpers/structured_output/json_schema_converter.rb', line 81

def cache_def!(state, type:, &blk)
  defs, path = state.fetch_values(:defs, :path)
  if (stored = defs[type])
    stored[OpenAI::Helpers::StructuredOutput::JsonSchemaConverter::COUNTER] += 1
    stored.fetch(OpenAI::Helpers::StructuredOutput::JsonSchemaConverter::POINTER)
  else
    ref_path = String.new
    ref = {"$ref": ref_path}
    stored = {
      OpenAI::Helpers::StructuredOutput::JsonSchemaConverter::POINTER => ref,
      OpenAI::Helpers::StructuredOutput::JsonSchemaConverter::COUNTER => 1
    }
    defs.store(type, stored)
    schema = blk.call
    ref_path.replace("#/$defs/#{path.join('/')}")
    stored.update(schema)
    ref
  end
end

.to_json_schema(type) ⇒ Hash{Symbol=>Object}

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

Returns:

  • (Hash{Symbol=>Object})


106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/openai/helpers/structured_output/json_schema_converter.rb', line 106

def to_json_schema(type)
  defs = {}
  state = {defs: defs, path: []}
  schema = OpenAI::Helpers::StructuredOutput::JsonSchemaConverter.to_json_schema_inner(
    type,
    state: state
  )
  reused_defs = {}
  defs.each_value do |acc|
    ref = acc.fetch(OpenAI::Helpers::StructuredOutput::JsonSchemaConverter::POINTER)
    if (no_ref = ref.delete(OpenAI::Helpers::StructuredOutput::JsonSchemaConverter::NO_REF))
      acc[OpenAI::Helpers::StructuredOutput::JsonSchemaConverter::COUNTER] -= 1
    end
    cnt = acc.fetch(OpenAI::Helpers::StructuredOutput::JsonSchemaConverter::COUNTER)

    sch = acc.except(
      OpenAI::Helpers::StructuredOutput::JsonSchemaConverter::POINTER,
      OpenAI::Helpers::StructuredOutput::JsonSchemaConverter::COUNTER
    )
    cnt > 1 && !no_ref ? reused_defs.store(ref.fetch(:$ref), sch) : ref.replace(sch)
  end

  xformed = reused_defs.transform_keys { _1.delete_prefix("#/$defs/") }
  xformed.empty? ? schema : {"$defs": xformed}.update(schema)
end

.to_json_schema_inner(type, state:) ⇒ Hash{Symbol=>Object}

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

Returns:

  • (Hash{Symbol=>Object})

Raises:

  • (ArgumentError)


143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/openai/helpers/structured_output/json_schema_converter.rb', line 143

def to_json_schema_inner(type, state:)
  case type
  in {"$ref": String}
    return type
  in OpenAI::Helpers::StructuredOutput::JsonSchemaConverter
    return type.to_json_schema_inner(state: state)
  in Class
    case type
    in -> { _1 <= NilClass }
      return {type: "null"}
    in -> { _1 <= Integer }
      return {type: "integer"}
    in -> { _1 <= Float }
      return {type: "number"}
    in -> { _1 <= Symbol || _1 <= String }
      return {type: "string"}
    else
    end
  in _ if OpenAI::Internal::Util.primitive?(type)
    return {const: type.is_a?(Symbol) ? type.to_s : type}
  else
  end

  models = %w[
    NilClass
    String
    Symbol
    Integer
    Float
    OpenAI::Boolean
    OpenAI::ArrayOf
    OpenAI::EnumOf
    OpenAI::UnionOf
    OpenAI::BaseModel
  ]
  # rubocop:disable Layout/LineLength
  message = "#{type} does not implement the #{OpenAI::Helpers::StructuredOutput::JsonSchemaConverter} interface. Please use one of the supported types: #{models}"
  # rubocop:enable Layout/LineLength
  raise ArgumentError.new(message)
end

.to_nilable(schema) ⇒ Hash{Symbol=>Object}

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • schema (Hash{Symbol=>Object})

Returns:

  • (Hash{Symbol=>Object})


49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/openai/helpers/structured_output/json_schema_converter.rb', line 49

def to_nilable(schema)
  null = "null"
  case schema
  in {"$ref": String}
    {
      anyOf: [
        schema.update(OpenAI::Helpers::StructuredOutput::JsonSchemaConverter::NO_REF => true),
        {type: null}
      ]
    }
  in {anyOf: schemas}
    null = {type: null}
    schemas.any? { _1 == null || _1 == {type: ["null"]} } ? schema : {anyOf: [*schemas, null]}
  in {type: String => type}
    type == null ? schema : schema.update(type: [type, null])
  in {type: Array => types}
    types.include?(null) ? schema : schema.update(type: [*types, null])
  end
end

Instance Method Details

#to_json_schema_inner(state:) ⇒ Hash{Symbol=>Object}

The exact JSON schema produced is subject to improvement between minor release versions.

Parameters:

  • state (Hash{Symbol=>Object})

    @option state [HashObject=>String] :defs

    @option state [Array<String>] :path

Returns:

  • (Hash{Symbol=>Object})


38
# File 'lib/openai/helpers/structured_output/json_schema_converter.rb', line 38

def to_json_schema_inner(state:) = (raise NotImplementedError)