Class: OpenAI::Models::Admin::Organization::AuditLogListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::AuditLogListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/admin/organization/audit_log_list_params.rb
Overview
Defined Under Namespace
Modules: EventType Classes: EffectiveAt
Instance Attribute Summary collapse
-
#actor_emails ⇒ Array<String>?
Return only events performed by users with these emails.
-
#actor_ids ⇒ Array<String>?
Return only events performed by these actors.
-
#after ⇒ String?
A cursor for use in pagination.
-
#before ⇒ String?
A cursor for use in pagination.
-
#effective_at ⇒ OpenAI::Models::Admin::Organization::AuditLogListParams::EffectiveAt?
Return only events whose ‘effective_at` (Unix seconds) is in this range.
-
#event_types ⇒ Array<Symbol, OpenAI::Models::Admin::Organization::AuditLogListParams::EventType>?
Return only events with a ‘type` in one of these values.
-
#limit ⇒ Integer?
A limit on the number of objects to be returned.
-
#project_ids ⇒ Array<String>?
Return only events for these projects.
-
#resource_ids ⇒ Array<String>?
Return only events performed on these targets.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(gt: nil, gte: nil, lt: nil, lte: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see EffectiveAt for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(gt: nil, gte: nil, lt: nil, lte: nil) ⇒ Object
Some parameter documentations has been truncated, see EffectiveAt for more details.
Return only events whose ‘effective_at` (Unix seconds) is in this range.
|
|
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 130
|
Instance Attribute Details
#actor_emails ⇒ Array<String>?
Return only events performed by users with these emails.
16 |
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 16 optional :actor_emails, OpenAI::Internal::Type::ArrayOf[String] |
#actor_ids ⇒ Array<String>?
Return only events performed by these actors. Can be a user ID, a service account ID, or an api key tracking ID.
23 |
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 23 optional :actor_ids, OpenAI::Internal::Type::ArrayOf[String] |
#after ⇒ String?
A cursor for use in pagination. ‘after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include after=obj_foo in order to fetch the next page of the list.
32 |
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 32 optional :after, String |
#before ⇒ String?
A cursor for use in pagination. ‘before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_foo, your subsequent call can include before=obj_foo in order to fetch the previous page of the list.
41 |
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 41 optional :before, String |
#effective_at ⇒ OpenAI::Models::Admin::Organization::AuditLogListParams::EffectiveAt?
Return only events whose ‘effective_at` (Unix seconds) is in this range.
47 |
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 47 optional :effective_at, -> { OpenAI::Admin::Organization::AuditLogListParams::EffectiveAt } |
#event_types ⇒ Array<Symbol, OpenAI::Models::Admin::Organization::AuditLogListParams::EventType>?
Return only events with a ‘type` in one of these values. For example, `project.created`. For all options, see the documentation for the [audit log object](platform.openai.com/docs/api-reference/audit-logs/object).
55 56 |
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 55 optional :event_types, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Admin::Organization::AuditLogListParams::EventType] } |
#limit ⇒ Integer?
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20.
63 |
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 63 optional :limit, Integer |