Class: OpenAI::Models::Admin::Organization::AuditLogListParams::EffectiveAt

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/admin/organization/audit_log_list_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(actor_emails: nil, actor_ids: nil, after: nil, before: nil, effective_at: nil, event_types: nil, limit: nil, project_ids: nil, resource_ids: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::AuditLogListParams for more details.

Parameters:

  • actor_emails (Array<String>) (defaults to: nil)

    Return only events performed by users with these emails.

  • actor_ids (Array<String>) (defaults to: nil)

    Return only events performed by these actors. Can be a user ID, a service accoun

  • after (String) (defaults to: nil)

    A cursor for use in pagination. ‘after` is an object ID that defines your place

  • before (String) (defaults to: nil)

    A cursor for use in pagination. ‘before` is an object ID that defines your place

  • effective_at (OpenAI::Models::Admin::Organization::AuditLogListParams::EffectiveAt) (defaults to: nil)

    Return only events whose ‘effective_at` (Unix seconds) is in this range.

  • event_types (Array<Symbol, OpenAI::Models::Admin::Organization::AuditLogListParams::EventType>) (defaults to: nil)

    Return only events with a ‘type` in one of these values. For example, `project.c

  • limit (Integer) (defaults to: nil)

    A limit on the number of objects to be returned. Limit can range between 1 and 1

  • project_ids (Array<String>) (defaults to: nil)

    Return only events for these projects.

  • resource_ids (Array<String>) (defaults to: nil)

    Return only events performed on these targets. For example, a project ID updated

  • request_options (OpenAI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 102

class EffectiveAt < OpenAI::Internal::Type::BaseModel
  # @!attribute gt
  #   Return only events whose `effective_at` (Unix seconds) is greater than this
  #   value.
  #
  #   @return [Integer, nil]
  optional :gt, Integer

  # @!attribute gte
  #   Return only events whose `effective_at` (Unix seconds) is greater than or equal
  #   to this value.
  #
  #   @return [Integer, nil]
  optional :gte, Integer

  # @!attribute lt
  #   Return only events whose `effective_at` (Unix seconds) is less than this value.
  #
  #   @return [Integer, nil]
  optional :lt, Integer

  # @!attribute lte
  #   Return only events whose `effective_at` (Unix seconds) is less than or equal to
  #   this value.
  #
  #   @return [Integer, nil]
  optional :lte, Integer

  # @!method initialize(gt: nil, gte: nil, lt: nil, lte: nil)
  #   Some parameter documentations has been truncated, see
  #   {OpenAI::Models::Admin::Organization::AuditLogListParams::EffectiveAt} for more
  #   details.
  #
  #   Return only events whose `effective_at` (Unix seconds) is in this range.
  #
  #   @param gt [Integer] Return only events whose `effective_at` (Unix seconds) is greater than this valu
  #
  #   @param gte [Integer] Return only events whose `effective_at` (Unix seconds) is greater than or equal
  #
  #   @param lt [Integer] Return only events whose `effective_at` (Unix seconds) is less than this value.
  #
  #   @param lte [Integer] Return only events whose `effective_at` (Unix seconds) is less than or equal to
end

Instance Attribute Details

#gtInteger?

Return only events whose ‘effective_at` (Unix seconds) is greater than this value.

Returns:

  • (Integer, nil)


108
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 108

optional :gt, Integer

#gteInteger?

Return only events whose ‘effective_at` (Unix seconds) is greater than or equal to this value.

Returns:

  • (Integer, nil)


115
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 115

optional :gte, Integer

#ltInteger?

Return only events whose ‘effective_at` (Unix seconds) is less than this value.

Returns:

  • (Integer, nil)


121
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 121

optional :lt, Integer

#lteInteger?

Return only events whose ‘effective_at` (Unix seconds) is less than or equal to this value.

Returns:

  • (Integer, nil)


128
# File 'lib/openai/models/admin/organization/audit_log_list_params.rb', line 128

optional :lte, Integer