Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor
- Defined in:
- lib/openai/models/admin/organization/audit_log_list_response.rb
Overview
Defined Under Namespace
Modules: Type Classes: APIKey, Session
Instance Attribute Summary collapse
-
#api_key ⇒ OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::APIKey?
The API Key used to perform the audit logged action.
-
#session ⇒ OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::Session?
The session in which the audit logged action was performed.
-
#type ⇒ Symbol, ...
The type of actor.
Instance Method Summary collapse
-
#initialize(id: nil, email: nil) ⇒ Object
constructor
The user who performed the audit logged action.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, email: nil) ⇒ Object
The user who performed the audit logged action.
|
|
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 606
|
Instance Attribute Details
#api_key ⇒ OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::APIKey?
The API Key used to perform the audit logged action.
592 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 592 optional :api_key, -> { OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::APIKey } |
#session ⇒ OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::Session?
The session in which the audit logged action was performed.
598 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 598 optional :session, -> { OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::Session } |
#type ⇒ Symbol, ...
The type of actor. Is either ‘session` or `api_key`.
604 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 604 optional :type, enum: -> { OpenAI::Models::Admin::Organization::AuditLogListResponse::Actor::Type } |