Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::OrganizationUpdated::ChangesRequested

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/admin/organization/audit_log_list_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from OpenAI::Internal::Type::BaseModel

Instance Attribute Details

#api_call_loggingString?

How your organization logs data from supported API calls. One of ‘disabled`, `enabled_per_call`, `enabled_for_all_projects`, or `enabled_for_selected_projects`

Returns:

  • (String, nil)


1468
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1468

optional :api_call_logging, String

#api_call_logging_project_idsString?

The list of project ids if api_call_logging is set to ‘enabled_for_selected_projects`

Returns:

  • (String, nil)


1475
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1475

optional :api_call_logging_project_ids, String

#descriptionString?

The organization description.

Returns:

  • (String, nil)


1481
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1481

optional :description, String

#nameString?

The organization name.

Returns:

  • (String, nil)


1487
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1487

optional :name, String

#threads_ui_visibilityString?

Visibility of the threads page which shows messages created with the Assistants API and Playground. One of ‘ANY_ROLE`, `OWNERS`, or `NONE`.

Returns:

  • (String, nil)


1494
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1494

optional :threads_ui_visibility, String

#titleString?

The organization title.

Returns:

  • (String, nil)


1500
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1500

optional :title, String

#usage_dashboard_visibilityString?

Visibility of the usage dashboard which shows activity and costs for your organization. One of ‘ANY_ROLE` or `OWNERS`.

Returns:

  • (String, nil)


1507
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1507

optional :usage_dashboard_visibility, String