Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleAssignmentCreated
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleAssignmentCreated
- Defined in:
- lib/openai/models/admin/organization/audit_log_list_response.rb
Overview
Instance Attribute Summary collapse
-
#id ⇒ String?
The identifier of the role assignment.
-
#principal_id ⇒ String?
The principal (user or group) that received the role.
-
#principal_type ⇒ String?
The type of principal (user or group) that received the role.
-
#resource_id ⇒ String?
The resource the role assignment is scoped to.
-
#resource_type ⇒ String?
The type of resource the role assignment is scoped to.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#id ⇒ String?
The identifier of the role assignment.
1762 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1762 optional :id, String |
#principal_id ⇒ String?
The principal (user or group) that received the role.
1768 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1768 optional :principal_id, String |
#principal_type ⇒ String?
The type of principal (user or group) that received the role.
1774 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1774 optional :principal_type, String |
#resource_id ⇒ String?
The resource the role assignment is scoped to.
1780 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1780 optional :resource_id, String |
#resource_type ⇒ String?
The type of resource the role assignment is scoped to.
1786 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1786 optional :resource_type, String |