Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleBoundToResource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleBoundToResource
- Defined in:
- lib/openai/models/admin/organization/audit_log_list_response.rb
Overview
Defined Under Namespace
Modules: Source
Instance Attribute Summary collapse
-
#connector_id ⇒ String?
The connector ID for a ChatGPT workspace connector resource.
-
#connector_name ⇒ String?
The connector display name for a ChatGPT workspace connector resource, or the connector ID when the display name could not be resolved.
-
#enabled ⇒ Boolean?
Whether the connector is enabled for the role.
-
#id ⇒ String?
The ID of the resource the role was bound to.
-
#permissions ⇒ Array<String>?
The permissions granted to the role for the resource.
-
#resource_id ⇒ String?
The ID of the resource the role was bound to.
-
#resource_type ⇒ String?
The type of resource the role was bound to.
-
#role_id ⇒ String?
The ID of the role that was bound to the resource.
-
#source ⇒ Symbol, ...
The connector role mutation path that produced the event.
-
#workspace_id ⇒ String?
The workspace ID for a ChatGPT workspace connector resource.
Instance Method Summary collapse
-
#initialize(id: nil, connector_id: nil, connector_name: nil, enabled: nil, permissions: nil, resource_id: nil, resource_type: nil, role_id: nil, source: nil, workspace_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RoleBoundToResource for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, connector_id: nil, connector_name: nil, enabled: nil, permissions: nil, resource_id: nil, resource_type: nil, role_id: nil, source: nil, workspace_id: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleBoundToResource for more details.
The details for events with this ‘type`.
|
|
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2001
|
Instance Attribute Details
#connector_id ⇒ String?
The connector ID for a ChatGPT workspace connector resource.
1949 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1949 optional :connector_id, String |
#connector_name ⇒ String?
The connector display name for a ChatGPT workspace connector resource, or the connector ID when the display name could not be resolved.
1956 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1956 optional :connector_name, String |
#enabled ⇒ Boolean?
Whether the connector is enabled for the role.
1962 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1962 optional :enabled, OpenAI::Internal::Type::Boolean |
#id ⇒ String?
The ID of the resource the role was bound to. ChatGPT workspace connector resources use ‘<workspace_id>__<connector_id>`.
1943 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1943 optional :id, String |
#permissions ⇒ Array<String>?
The permissions granted to the role for the resource.
1968 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1968 optional :permissions, OpenAI::Internal::Type::ArrayOf[String] |
#resource_id ⇒ String?
The ID of the resource the role was bound to.
1974 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1974 optional :resource_id, String |
#resource_type ⇒ String?
The type of resource the role was bound to.
1980 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1980 optional :resource_type, String |
#role_id ⇒ String?
The ID of the role that was bound to the resource.
1986 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1986 optional :role_id, String |
#source ⇒ Symbol, ...
The connector role mutation path that produced the event.
1992 1993 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1992 optional :source, enum: -> { OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleBoundToResource::Source } |
#workspace_id ⇒ String?
The workspace ID for a ChatGPT workspace connector resource.
1999 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 1999 optional :workspace_id, String |