Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleUnboundFromResource

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/admin/organization/audit_log_list_response.rb,
sig/openai/models/admin/organization/audit_log_list_response.rbs

Overview

See Also:

  • OpenAI::Models::Admin::Organization::AuditLogListResponse#role_unbound_from_resource

Defined Under Namespace

Modules: Source

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, connector_id: nil, connector_name: nil, enabled: nil, permissions: nil, resource_id: nil, resource_type: nil, role_id: nil, source: nil, workspace_id: nil) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleUnboundFromResource for more details.

The details for events with this type.

Parameters:

  • id (String) (defaults to: nil)

    The ID of the resource the role was unbound from. ChatGPT workspace connector re

  • connector_id (String) (defaults to: nil)

    The connector ID for a ChatGPT workspace connector resource.

  • connector_name (String) (defaults to: nil)

    The connector display name for a ChatGPT workspace connector resource, or the co

  • enabled (Boolean) (defaults to: nil)

    Whether the connector is enabled for the role.

  • permissions (Array<String>) (defaults to: nil)

    The permissions remaining for the role after the change.

  • resource_id (String) (defaults to: nil)

    The ID of the resource the role was unbound from.

  • resource_type (String) (defaults to: nil)

    The type of resource the role was unbound from.

  • role_id (String) (defaults to: nil)

    The ID of the role that was unbound from the resource.

  • source (Symbol, OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleUnboundFromResource::Source) (defaults to: nil)

    The connector role mutation path that produced the event.

  • workspace_id (String) (defaults to: nil)

    The workspace ID for a ChatGPT workspace connector resource.



# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2254

Instance Attribute Details

#connector_idString?

The connector ID for a ChatGPT workspace connector resource.

Parameters:

  • (String)

Returns:

  • (String, nil)


2202
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2202

optional :connector_id, String

#connector_nameString?

The connector display name for a ChatGPT workspace connector resource, or the connector ID when the display name could not be resolved.

Parameters:

  • (String)

Returns:

  • (String, nil)


2209
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2209

optional :connector_name, String

#enabledBoolean?

Whether the connector is enabled for the role.

Parameters:

Returns:



2215
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2215

optional :enabled, OpenAI::Internal::Type::Boolean

#idString?

The ID of the resource the role was unbound from. ChatGPT workspace connector resources use <workspace_id>__<connector_id>.

Parameters:

  • (String)

Returns:

  • (String, nil)


2196
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2196

optional :id, String

#permissionsArray<String>?

The permissions remaining for the role after the change.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


2221
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2221

optional :permissions, OpenAI::Internal::Type::ArrayOf[String]

#resource_idString?

The ID of the resource the role was unbound from.

Parameters:

  • (String)

Returns:

  • (String, nil)


2227
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2227

optional :resource_id, String

#resource_typeString?

The type of resource the role was unbound from.

Parameters:

  • (String)

Returns:

  • (String, nil)


2233
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2233

optional :resource_type, String

#role_idString?

The ID of the role that was unbound from the resource.

Parameters:

  • (String)

Returns:

  • (String, nil)


2239
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2239

optional :role_id, String

#sourceSymbol, ...

The connector role mutation path that produced the event.



2245
2246
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2245

optional :source,
enum: -> { OpenAI::Models::Admin::Organization::AuditLogListResponse::RoleUnboundFromResource::Source }

#workspace_idString?

The workspace ID for a ChatGPT workspace connector resource.

Parameters:

  • (String)

Returns:

  • (String, nil)


2252
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2252

optional :workspace_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


2304
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 2304

def to_hash: -> {