Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::WorkloadIdentityProviderMappingCreated
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::AuditLogListResponse::WorkloadIdentityProviderMappingCreated
- Defined in:
- lib/openai/models/admin/organization/audit_log_list_response.rb,
sig/openai/models/admin/organization/audit_log_list_response.rbs
Overview
Instance Attribute Summary collapse
-
#data ⇒ Object?
The payload used to create the workload identity provider mapping.
-
#id ⇒ String?
The workload identity provider mapping ID.
-
#identity_provider_id ⇒ String?
The workload identity provider ID.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
2650 |
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 2650
def initialize: (
|
Instance Attribute Details
#data ⇒ Object?
The payload used to create the workload identity provider mapping.
2598 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2598 optional :data, OpenAI::Internal::Type::Unknown |
#id ⇒ String?
The workload identity provider mapping ID.
2592 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2592 optional :id, String |
#identity_provider_id ⇒ String?
The workload identity provider ID.
2604 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2604 optional :identity_provider_id, String |
Instance Method Details
#to_hash ⇒ {
2656 |
# File 'sig/openai/models/admin/organization/audit_log_list_response.rbs', line 2656
def to_hash: -> {
|