Class: OpenAI::Models::Admin::Organization::AuditLogListResponse::WorkloadIdentityProviderMappingUpdated
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::AuditLogListResponse::WorkloadIdentityProviderMappingUpdated
- Defined in:
- lib/openai/models/admin/organization/audit_log_list_response.rb
Overview
Instance Attribute Summary collapse
-
#changes_requested ⇒ Object?
The payload used to update the workload identity provider mapping.
-
#id ⇒ String?
The workload identity provider mapping ID.
-
#identity_provider_id ⇒ String?
The workload identity provider ID.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#changes_requested ⇒ Object?
The payload used to update the workload identity provider mapping.
2342 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2342 optional :changes_requested, OpenAI::Internal::Type::Unknown |
#id ⇒ String?
The workload identity provider mapping ID.
2336 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2336 optional :id, String |
#identity_provider_id ⇒ String?
The workload identity provider ID.
2348 |
# File 'lib/openai/models/admin/organization/audit_log_list_response.rb', line 2348 optional :identity_provider_id, String |