Class: OpenAI::Models::Admin::Organization::Certificate

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/admin/organization/certificate.rb

Overview

Defined Under Namespace

Modules: Object Classes: CertificateDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content: nil, expires_at: nil, valid_at: nil) ⇒ Object

Parameters:

  • content (String) (defaults to: nil)

    The content of the certificate in PEM format.

  • expires_at (Integer) (defaults to: nil)

    The Unix timestamp (in seconds) of when the certificate expires.

  • valid_at (Integer) (defaults to: nil)

    The Unix timestamp (in seconds) of when the certificate becomes valid.



# File 'lib/openai/models/admin/organization/certificate.rb', line 52

Instance Attribute Details

#activeBoolean?

Whether the certificate is currently active at the specified scope. Not returned when getting details for a specific certificate.

Returns:



50
# File 'lib/openai/models/admin/organization/certificate.rb', line 50

optional :active, OpenAI::Internal::Type::Boolean

#certificate_detailsOpenAI::Models::Admin::Organization::Certificate::CertificateDetails



18
# File 'lib/openai/models/admin/organization/certificate.rb', line 18

required :certificate_details, -> { OpenAI::Admin::Organization::Certificate::CertificateDetails }

#created_atInteger

The Unix timestamp (in seconds) of when the certificate was uploaded.

Returns:

  • (Integer)


24
# File 'lib/openai/models/admin/organization/certificate.rb', line 24

required :created_at, Integer

#idString

The identifier, which can be referenced in API endpoints

Returns:

  • (String)


13
# File 'lib/openai/models/admin/organization/certificate.rb', line 13

required :id, String

#nameString?

The name of the certificate.

Returns:

  • (String, nil)


30
# File 'lib/openai/models/admin/organization/certificate.rb', line 30

required :name, String, nil?: true

#objectSymbol, OpenAI::Models::Admin::Organization::Certificate::Object

The object type.

  • If creating, updating, or getting a specific certificate, the object type is ‘certificate`.

  • If listing, activating, or deactivating certificates for the organization, the object type is ‘organization.certificate`.

  • If listing, activating, or deactivating certificates for a project, the object type is ‘organization.project.certificate`.



43
# File 'lib/openai/models/admin/organization/certificate.rb', line 43

required :object, enum: -> { OpenAI::Admin::Organization::Certificate::Object }