Module: OpenAI::Models::Admin::Organization::Certificate::Object
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/admin/organization/certificate.rb
Overview
The object type.
-
If creating, updating, or getting a specific certificate, the object type is ‘certificate`.
-
If listing, activating, or deactivating certificates for the organization, the object type is ‘organization.certificate`.
-
If listing, activating, or deactivating certificates for a project, the object type is ‘organization.project.certificate`.
Constant Summary collapse
- CERTIFICATE =
:certificate- ORGANIZATION_CERTIFICATE =
:"organization.certificate"- ORGANIZATION_PROJECT_CERTIFICATE =
:"organization.project.certificate"
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/admin/organization/certificate.rb', line 115
|