Class: OpenAI::Models::Admin::Organization::Groups::UserCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/admin/organization/groups/user_create_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(group_id:, user_id:, object: :"group.user") ⇒ Object

Confirmation payload returned after adding a user to a group.

Parameters:

  • group_id (String)

    Identifier of the group the user was added to.

  • user_id (String)

    Identifier of the user that was added.

  • object (Symbol, :"group.user") (defaults to: :"group.user")

    Always ‘group.user`.



# File 'lib/openai/models/admin/organization/groups/user_create_response.rb', line 28

Instance Attribute Details

#group_idString

Identifier of the group the user was added to.

Returns:

  • (String)


14
# File 'lib/openai/models/admin/organization/groups/user_create_response.rb', line 14

required :group_id, String

#objectSymbol, :"group.user"

Always ‘group.user`.

Returns:

  • (Symbol, :"group.user")


20
# File 'lib/openai/models/admin/organization/groups/user_create_response.rb', line 20

required :object, const: :"group.user"

#user_idString

Identifier of the user that was added.

Returns:

  • (String)


26
# File 'lib/openai/models/admin/organization/groups/user_create_response.rb', line 26

required :user_id, String