Class: OpenAI::Models::Admin::Organization::Groups::UserListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::Groups::UserListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/admin/organization/groups/user_list_params.rb
Overview
Defined Under Namespace
Modules: Order
Instance Attribute Summary collapse
-
#after ⇒ String?
A cursor for use in pagination.
- #group_id ⇒ String
-
#limit ⇒ Integer?
A limit on the number of users to be returned.
-
#order ⇒ Symbol, ...
Specifies the sort order of users in the list.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(group_id:, after: nil, limit: nil, order: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see UserListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(group_id:, after: nil, limit: nil, order: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::Groups::UserListParams for more details.
|
|
# File 'lib/openai/models/admin/organization/groups/user_list_params.rb', line 38
|
Instance Attribute Details
#after ⇒ String?
A cursor for use in pagination. Provide the ID of the last user from the previous list response to retrieve the next page.
23 |
# File 'lib/openai/models/admin/organization/groups/user_list_params.rb', line 23 optional :after, String |
#group_id ⇒ String
16 |
# File 'lib/openai/models/admin/organization/groups/user_list_params.rb', line 16 required :group_id, String |
#limit ⇒ Integer?
A limit on the number of users to be returned. Limit can range between 0 and 1000, and the default is 100.
30 |
# File 'lib/openai/models/admin/organization/groups/user_list_params.rb', line 30 optional :limit, Integer |