Class: OpenAI::Models::Admin::Organization::Invite
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::Invite
- Defined in:
- lib/openai/models/admin/organization/invite.rb
Overview
Defined Under Namespace
Modules: Role, Status Classes: Project
Instance Attribute Summary collapse
-
#accepted_at ⇒ Integer?
The Unix timestamp (in seconds) of when the invite was accepted.
-
#created_at ⇒ Integer
The Unix timestamp (in seconds) of when the invite was sent.
-
#email ⇒ String
The email address of the individual to whom the invite was sent.
-
#expires_at ⇒ Integer?
The Unix timestamp (in seconds) of when the invite expires.
-
#id ⇒ String
The identifier, which can be referenced in API endpoints.
-
#object ⇒ Symbol, :"organization.invite"
The object type, which is always ‘organization.invite`.
-
#projects ⇒ Array<OpenAI::Models::Admin::Organization::Invite::Project>
The projects that were granted membership upon acceptance of the invite.
-
#role ⇒ Symbol, OpenAI::Models::Admin::Organization::Invite::Role
‘owner` or `reader`.
-
#status ⇒ Symbol, OpenAI::Models::Admin::Organization::Invite::Status
‘accepted`,`expired`, or `pending`.
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#accepted_at ⇒ Integer?
The Unix timestamp (in seconds) of when the invite was accepted.
55 |
# File 'lib/openai/models/admin/organization/invite.rb', line 55 optional :accepted_at, Integer, nil?: true |
#created_at ⇒ Integer
The Unix timestamp (in seconds) of when the invite was sent.
19 |
# File 'lib/openai/models/admin/organization/invite.rb', line 19 required :created_at, Integer |
#email ⇒ String
The email address of the individual to whom the invite was sent
25 |
# File 'lib/openai/models/admin/organization/invite.rb', line 25 required :email, String |
#expires_at ⇒ Integer?
The Unix timestamp (in seconds) of when the invite expires.
61 |
# File 'lib/openai/models/admin/organization/invite.rb', line 61 optional :expires_at, Integer, nil?: true |
#id ⇒ String
The identifier, which can be referenced in API endpoints
13 |
# File 'lib/openai/models/admin/organization/invite.rb', line 13 required :id, String |
#object ⇒ Symbol, :"organization.invite"
The object type, which is always ‘organization.invite`
31 |
# File 'lib/openai/models/admin/organization/invite.rb', line 31 required :object, const: :"organization.invite" |
#projects ⇒ Array<OpenAI::Models::Admin::Organization::Invite::Project>
The projects that were granted membership upon acceptance of the invite.
37 |
# File 'lib/openai/models/admin/organization/invite.rb', line 37 required :projects, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Admin::Organization::Invite::Project] } |
#role ⇒ Symbol, OpenAI::Models::Admin::Organization::Invite::Role
‘owner` or `reader`
43 |
# File 'lib/openai/models/admin/organization/invite.rb', line 43 required :role, enum: -> { OpenAI::Admin::Organization::Invite::Role } |
#status ⇒ Symbol, OpenAI::Models::Admin::Organization::Invite::Status
‘accepted`,`expired`, or `pending`
49 |
# File 'lib/openai/models/admin/organization/invite.rb', line 49 required :status, enum: -> { OpenAI::Admin::Organization::Invite::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/admin/organization/invite.rb', line 111
|