Class: OpenAI::Models::Admin::Organization::InviteCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/admin/organization/invite_create_params.rb

Overview

Defined Under Namespace

Modules: Role Classes: Project

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(email:, role:, projects: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::InviteCreateParams for more details.

Parameters:



# File 'lib/openai/models/admin/organization/invite_create_params.rb', line 33

Instance Attribute Details

#emailString

Send an email to this address

Returns:

  • (String)


16
# File 'lib/openai/models/admin/organization/invite_create_params.rb', line 16

required :email, String

#projectsArray<OpenAI::Models::Admin::Organization::InviteCreateParams::Project>?

An array of projects to which membership is granted at the same time the org invite is accepted. If omitted, the user will be invited to the default project for compatibility with legacy behavior.



30
31
# File 'lib/openai/models/admin/organization/invite_create_params.rb', line 30

optional :projects,
-> { OpenAI::Internal::Type::ArrayOf[OpenAI::Admin::Organization::InviteCreateParams::Project] }

#roleSymbol, OpenAI::Models::Admin::Organization::InviteCreateParams::Role

‘owner` or `reader`



22
# File 'lib/openai/models/admin/organization/invite_create_params.rb', line 22

required :role, enum: -> { OpenAI::Admin::Organization::InviteCreateParams::Role }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/admin/organization/invite_create_params.rb', line 52