Class: OpenAI::Models::Admin::Organization::InviteCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::InviteCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/admin/organization/invite_create_params.rb
Overview
Defined Under Namespace
Modules: Role Classes: Project
Instance Attribute Summary collapse
-
#email ⇒ String
Send an email to this address.
-
#projects ⇒ Array<OpenAI::Models::Admin::Organization::InviteCreateParams::Project>?
An array of projects to which membership is granted at the same time the org invite is accepted.
-
#role ⇒ Symbol, OpenAI::Models::Admin::Organization::InviteCreateParams::Role
‘owner` or `reader`.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(email:, role:, projects: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see InviteCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(email:, role:, projects: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::InviteCreateParams for more details.
|
|
# File 'lib/openai/models/admin/organization/invite_create_params.rb', line 33
|
Instance Attribute Details
#email ⇒ String
Send an email to this address
16 |
# File 'lib/openai/models/admin/organization/invite_create_params.rb', line 16 required :email, String |
#projects ⇒ Array<OpenAI::Models::Admin::Organization::InviteCreateParams::Project>?
An array of projects to which membership is granted at the same time the org invite is accepted. If omitted, the user will be invited to the default project for compatibility with legacy behavior.
30 31 |
# File 'lib/openai/models/admin/organization/invite_create_params.rb', line 30 optional :projects, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Admin::Organization::InviteCreateParams::Project] } |
#role ⇒ Symbol, OpenAI::Models::Admin::Organization::InviteCreateParams::Role
‘owner` or `reader`
22 |
# File 'lib/openai/models/admin/organization/invite_create_params.rb', line 22 required :role, enum: -> { OpenAI::Admin::Organization::InviteCreateParams::Role } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/admin/organization/invite_create_params.rb', line 52
|