Class: OpenAI::Models::Admin::Organization::OrganizationSpendLimit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::OrganizationSpendLimit
- Defined in:
- lib/openai/models/admin/organization/organization_spend_limit.rb,
sig/openai/models/admin/organization/organization_spend_limit.rbs
Overview
Defined Under Namespace
Modules: Currency, Interval Classes: Enforcement
Instance Attribute Summary collapse
-
#currency ⇒ String, ...
The currency for the threshold amount.
-
#enforcement ⇒ OpenAI::Models::Admin::Organization::OrganizationSpendLimit::Enforcement
The current enforcement state of the hard spend limit.
-
#interval ⇒ String, ...
The time interval for evaluating spend against the threshold.
-
#object ⇒ Symbol, :"organization.spend_limit"
The object type, which is always
organization.spend_limit. -
#threshold_amount ⇒ Integer
The hard spend limit amount, in cents.
Instance Method Summary collapse
-
#initialize(currency:, enforcement:, interval:, threshold_amount:, object: :"organization.spend_limit") ⇒ Object
constructor
Some parameter documentations has been truncated, see OrganizationSpendLimit for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(currency:, enforcement:, interval:, threshold_amount:, object: :"organization.spend_limit") ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::OrganizationSpendLimit for more details.
Represents a hard spend limit configured at the organization level.
|
|
# File 'lib/openai/models/admin/organization/organization_spend_limit.rb', line 40
|
Instance Attribute Details
#currency ⇒ String, ...
The currency for the threshold amount. Currently, only USD is supported.
13 |
# File 'lib/openai/models/admin/organization/organization_spend_limit.rb', line 13 required :currency, union: -> { OpenAI::Admin::Organization::OrganizationSpendLimit::Currency } |
#enforcement ⇒ OpenAI::Models::Admin::Organization::OrganizationSpendLimit::Enforcement
The current enforcement state of the hard spend limit.
19 |
# File 'lib/openai/models/admin/organization/organization_spend_limit.rb', line 19 required :enforcement, -> { OpenAI::Admin::Organization::OrganizationSpendLimit::Enforcement } |
#interval ⇒ String, ...
The time interval for evaluating spend against the threshold. Currently, only
month is supported.
26 |
# File 'lib/openai/models/admin/organization/organization_spend_limit.rb', line 26 required :interval, union: -> { OpenAI::Admin::Organization::OrganizationSpendLimit::Interval } |
#object ⇒ Symbol, :"organization.spend_limit"
The object type, which is always organization.spend_limit.
32 |
# File 'lib/openai/models/admin/organization/organization_spend_limit.rb', line 32 required :object, const: :"organization.spend_limit" |
#threshold_amount ⇒ Integer
The hard spend limit amount, in cents.
38 |
# File 'lib/openai/models/admin/organization/organization_spend_limit.rb', line 38 required :threshold_amount, Integer |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/openai/models/admin/organization/organization_spend_limit.rbs', line 35
def to_hash: -> {
|