Class: OpenAI::Models::Admin::Organization::OrganizationUser
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::OrganizationUser
- Defined in:
- lib/openai/models/admin/organization/organization_user.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#added_at ⇒ Integer
The Unix timestamp (in seconds) of when the user was added.
-
#api_key_last_used_at ⇒ Integer?
The Unix timestamp (in seconds) of the user’s last API key usage.
-
#created ⇒ Integer?
The Unix timestamp (in seconds) of when the user was created.
-
#developer_persona ⇒ String?
The developer persona metadata for the user.
-
#email ⇒ String?
The email address of the user.
-
#id ⇒ String
The identifier, which can be referenced in API endpoints.
-
#is_default ⇒ Boolean?
Whether this is the organization’s default user.
-
#is_scale_tier_authorized_purchaser ⇒ Boolean?
Whether the user is an authorized purchaser for Scale Tier.
-
#is_scim_managed ⇒ Boolean?
Whether the user is managed through SCIM.
-
#is_service_account ⇒ Boolean?
Whether the user is a service account.
-
#name ⇒ String?
The name of the user.
-
#object ⇒ Symbol, :"organization.user"
The object type, which is always ‘organization.user`.
-
#projects ⇒ OpenAI::Models::Admin::Organization::OrganizationUser::Projects?
Projects associated with the user, if included.
-
#role ⇒ String?
‘owner` or `reader`.
-
#technical_level ⇒ String?
The technical level metadata for the user.
-
#user ⇒ OpenAI::Models::Admin::Organization::OrganizationUser::User?
Nested user details.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, name: nil, role: nil) ⇒ Object
|
|
# File 'lib/openai/models/admin/organization/organization_user.rb', line 105
|
Instance Attribute Details
#added_at ⇒ Integer
The Unix timestamp (in seconds) of when the user was added.
19 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 19 required :added_at, Integer |
#api_key_last_used_at ⇒ Integer?
The Unix timestamp (in seconds) of the user’s last API key usage.
31 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 31 optional :api_key_last_used_at, Integer, nil?: true |
#created ⇒ Integer?
The Unix timestamp (in seconds) of when the user was created.
37 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 37 optional :created, Integer |
#developer_persona ⇒ String?
The developer persona metadata for the user.
43 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 43 optional :developer_persona, String, nil?: true |
#email ⇒ String?
The email address of the user
49 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 49 optional :email, String, nil?: true |
#id ⇒ String
The identifier, which can be referenced in API endpoints
13 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 13 required :id, String |
#is_default ⇒ Boolean?
Whether this is the organization’s default user.
55 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 55 optional :is_default, OpenAI::Internal::Type::Boolean |
#is_scale_tier_authorized_purchaser ⇒ Boolean?
Whether the user is an authorized purchaser for Scale Tier.
61 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 61 optional :is_scale_tier_authorized_purchaser, OpenAI::Internal::Type::Boolean, nil?: true |
#is_scim_managed ⇒ Boolean?
Whether the user is managed through SCIM.
67 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 67 optional :is_scim_managed, OpenAI::Internal::Type::Boolean |
#is_service_account ⇒ Boolean?
Whether the user is a service account.
73 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 73 optional :is_service_account, OpenAI::Internal::Type::Boolean |
#name ⇒ String?
The name of the user
79 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 79 optional :name, String, nil?: true |
#object ⇒ Symbol, :"organization.user"
The object type, which is always ‘organization.user`
25 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 25 required :object, const: :"organization.user" |
#projects ⇒ OpenAI::Models::Admin::Organization::OrganizationUser::Projects?
Projects associated with the user, if included.
85 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 85 optional :projects, -> { OpenAI::Admin::Organization::OrganizationUser::Projects }, nil?: true |
#role ⇒ String?
‘owner` or `reader`
91 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 91 optional :role, String, nil?: true |
#technical_level ⇒ String?
The technical level metadata for the user.
97 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 97 optional :technical_level, String, nil?: true |
#user ⇒ OpenAI::Models::Admin::Organization::OrganizationUser::User?
Nested user details.
103 |
# File 'lib/openai/models/admin/organization/organization_user.rb', line 103 optional :user, -> { OpenAI::Admin::Organization::OrganizationUser::User } |