Class: OpenAI::Models::Admin::Organization::ProjectCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::ProjectCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/admin/organization/project_create_params.rb,
sig/openai/models/admin/organization/project_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#external_key_id ⇒ String?
External key ID to associate with the project.
-
#geography ⇒ String?
Create the project with the specified data residency region.
-
#name ⇒ String
The friendly name of the project, this name appears in reports.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(name:, external_key_id: nil, geography: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ProjectCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, external_key_id: nil, geography: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::ProjectCreateParams for more details.
|
|
# File 'lib/openai/models/admin/organization/project_create_params.rb', line 33
|
Instance Attribute Details
#external_key_id ⇒ String?
External key ID to associate with the project.
22 |
# File 'lib/openai/models/admin/organization/project_create_params.rb', line 22 optional :external_key_id, String, nil?: true |
#geography ⇒ String?
Create the project with the specified data residency region. Your organization must have access to Data residency functionality in order to use. See data residency controls to review the functionality and limitations of setting this field.
31 |
# File 'lib/openai/models/admin/organization/project_create_params.rb', line 31 optional :geography, String, nil?: true |
#name ⇒ String
The friendly name of the project, this name appears in reports.
16 |
# File 'lib/openai/models/admin/organization/project_create_params.rb', line 16 required :name, String |
Instance Method Details
#to_hash ⇒ {
26 |
# File 'sig/openai/models/admin/organization/project_create_params.rbs', line 26
def to_hash: -> {
|