Class: OpenAI::Models::Admin::Organization::ProjectCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/admin/organization/project_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, external_key_id: nil, geography: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::ProjectCreateParams for more details.

Parameters:

  • name (String)

    The friendly name of the project, this name appears in reports.

  • external_key_id (String, nil) (defaults to: nil)

    External key ID to associate with the project.

  • geography (String, nil) (defaults to: nil)

    Create the project with the specified data residency region. Your organization m

  • request_options (OpenAI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/openai/models/admin/organization/project_create_params.rb', line 33

Instance Attribute Details

#external_key_idString?

External key ID to associate with the project.

Returns:

  • (String, nil)


22
# File 'lib/openai/models/admin/organization/project_create_params.rb', line 22

optional :external_key_id, String, nil?: true

#geographyString?

Create the project with the specified data residency region. Your organization must have access to Data residency functionality in order to use. See [data residency controls](platform.openai.com/docs/guides/your-data#data-residency-controls) to review the functionality and limitations of setting this field.

Returns:

  • (String, nil)


31
# File 'lib/openai/models/admin/organization/project_create_params.rb', line 31

optional :geography, String, nil?: true

#nameString

The friendly name of the project, this name appears in reports.

Returns:

  • (String)


16
# File 'lib/openai/models/admin/organization/project_create_params.rb', line 16

required :name, String