Class: OpenAI::Models::Admin::Organization::Projects::CertificateListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/admin/organization/projects/certificate_list_response.rb

Overview

Defined Under Namespace

Classes: CertificateDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, active:, certificate_details:, created_at:, name:, object: :"organization.project.certificate") ⇒ Object

Represents an individual certificate configured at the project level.

Parameters:

  • id (String)

    The identifier, which can be referenced in API endpoints

  • active (Boolean)

    Whether the certificate is currently active at the project level.

  • certificate_details (OpenAI::Models::Admin::Organization::Projects::CertificateListResponse::CertificateDetails)
  • created_at (Integer)

    The Unix timestamp (in seconds) of when the certificate was uploaded.

  • name (String, nil)

    The name of the certificate.

  • object (Symbol, :"organization.project.certificate") (defaults to: :"organization.project.certificate")

    The object type, which is always ‘organization.project.certificate`.



# File 'lib/openai/models/admin/organization/projects/certificate_list_response.rb', line 46

Instance Attribute Details

#activeBoolean

Whether the certificate is currently active at the project level.

Returns:



20
# File 'lib/openai/models/admin/organization/projects/certificate_list_response.rb', line 20

required :active, OpenAI::Internal::Type::Boolean

#certificate_detailsOpenAI::Models::Admin::Organization::Projects::CertificateListResponse::CertificateDetails



25
26
# File 'lib/openai/models/admin/organization/projects/certificate_list_response.rb', line 25

required :certificate_details,
-> { OpenAI::Models::Admin::Organization::Projects::CertificateListResponse::CertificateDetails }

#created_atInteger

The Unix timestamp (in seconds) of when the certificate was uploaded.

Returns:

  • (Integer)


32
# File 'lib/openai/models/admin/organization/projects/certificate_list_response.rb', line 32

required :created_at, Integer

#idString

The identifier, which can be referenced in API endpoints

Returns:

  • (String)


14
# File 'lib/openai/models/admin/organization/projects/certificate_list_response.rb', line 14

required :id, String

#nameString?

The name of the certificate.

Returns:

  • (String, nil)


38
# File 'lib/openai/models/admin/organization/projects/certificate_list_response.rb', line 38

required :name, String, nil?: true

#objectSymbol, :"organization.project.certificate"

The object type, which is always ‘organization.project.certificate`.

Returns:

  • (Symbol, :"organization.project.certificate")


44
# File 'lib/openai/models/admin/organization/projects/certificate_list_response.rb', line 44

required :object, const: :"organization.project.certificate"