Class: OpenAI::Models::Admin::Organization::Projects::Groups::RoleCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/admin/organization/projects/groups/role_create_response.rb

Overview

Defined Under Namespace

Classes: Group

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(group:, role:, object: :"group.role") ⇒ Object

Role assignment linking a group to a role.

Parameters:



# File 'lib/openai/models/admin/organization/projects/groups/role_create_response.rb', line 29

Instance Attribute Details

#groupOpenAI::Models::Admin::Organization::Projects::Groups::RoleCreateResponse::Group

Summary information about a group returned in role assignment responses.



15
# File 'lib/openai/models/admin/organization/projects/groups/role_create_response.rb', line 15

required :group, -> { OpenAI::Models::Admin::Organization::Projects::Groups::RoleCreateResponse::Group }

#objectSymbol, :"group.role"

Always ‘group.role`.

Returns:



21
# File 'lib/openai/models/admin/organization/projects/groups/role_create_response.rb', line 21

required :object, const: :"group.role"

#roleOpenAI::Models::Admin::Organization::Role

Details about a role that can be assigned through the public Roles API.



27
# File 'lib/openai/models/admin/organization/projects/groups/role_create_response.rb', line 27

required :role, -> { OpenAI::Admin::Organization::Role }