Class: OpenAI::Models::Admin::Organization::Projects::ProjectSpendAlert
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::Projects::ProjectSpendAlert
- Defined in:
- lib/openai/models/admin/organization/projects/project_spend_alert.rb
Overview
Defined Under Namespace
Modules: Currency, Interval Classes: NotificationChannel
Instance Attribute Summary collapse
-
#currency ⇒ Symbol, OpenAI::Models::Admin::Organization::Projects::ProjectSpendAlert::Currency
The currency for the threshold amount.
-
#id ⇒ String
The identifier, which can be referenced in API endpoints.
-
#interval ⇒ Symbol, OpenAI::Models::Admin::Organization::Projects::ProjectSpendAlert::Interval
The time interval for evaluating spend against the threshold.
-
#notification_channel ⇒ OpenAI::Models::Admin::Organization::Projects::ProjectSpendAlert::NotificationChannel
Email notification settings for a spend alert.
-
#object ⇒ Symbol, :"project.spend_alert"
The object type, which is always ‘project.spend_alert`.
-
#threshold_amount ⇒ Integer
The alert threshold amount, in cents.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, currency:, interval:, notification_channel:, threshold_amount:, object: :"project.spend_alert") ⇒ Object
constructor
Represents a spend alert configured at the project level.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, currency:, interval:, notification_channel:, threshold_amount:, object: :"project.spend_alert") ⇒ Object
Represents a spend alert configured at the project level.
|
|
# File 'lib/openai/models/admin/organization/projects/project_spend_alert.rb', line 47
|
Instance Attribute Details
#currency ⇒ Symbol, OpenAI::Models::Admin::Organization::Projects::ProjectSpendAlert::Currency
The currency for the threshold amount.
20 |
# File 'lib/openai/models/admin/organization/projects/project_spend_alert.rb', line 20 required :currency, enum: -> { OpenAI::Admin::Organization::Projects::ProjectSpendAlert::Currency } |
#id ⇒ String
The identifier, which can be referenced in API endpoints.
14 |
# File 'lib/openai/models/admin/organization/projects/project_spend_alert.rb', line 14 required :id, String |
#interval ⇒ Symbol, OpenAI::Models::Admin::Organization::Projects::ProjectSpendAlert::Interval
The time interval for evaluating spend against the threshold.
26 |
# File 'lib/openai/models/admin/organization/projects/project_spend_alert.rb', line 26 required :interval, enum: -> { OpenAI::Admin::Organization::Projects::ProjectSpendAlert::Interval } |
#notification_channel ⇒ OpenAI::Models::Admin::Organization::Projects::ProjectSpendAlert::NotificationChannel
Email notification settings for a spend alert.
32 33 |
# File 'lib/openai/models/admin/organization/projects/project_spend_alert.rb', line 32 required :notification_channel, -> { OpenAI::Admin::Organization::Projects::ProjectSpendAlert::NotificationChannel } |
#object ⇒ Symbol, :"project.spend_alert"
The object type, which is always ‘project.spend_alert`.
39 |
# File 'lib/openai/models/admin/organization/projects/project_spend_alert.rb', line 39 required :object, const: :"project.spend_alert" |
#threshold_amount ⇒ Integer
The alert threshold amount, in cents.
45 |
# File 'lib/openai/models/admin/organization/projects/project_spend_alert.rb', line 45 required :threshold_amount, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/admin/organization/projects/project_spend_alert.rb', line 70
|