Class: OpenAI::Models::Admin::Organization::SpendLimitUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::SpendLimitUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/admin/organization/spend_limit_update_params.rb,
sig/openai/models/admin/organization/spend_limit_update_params.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#currency ⇒ Symbol, OpenAI::Models::Admin::Organization::SpendLimitUpdateParams::Currency
The currency for the threshold amount.
-
#interval ⇒ Symbol, OpenAI::Models::Admin::Organization::SpendLimitUpdateParams::Interval
The time interval for evaluating spend against the threshold.
-
#threshold_amount ⇒ Integer
The hard spend limit amount, in cents.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(currency:, interval:, threshold_amount:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SpendLimitUpdateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(currency:, interval:, threshold_amount:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::SpendLimitUpdateParams for more details.
|
|
# File 'lib/openai/models/admin/organization/spend_limit_update_params.rb', line 31
|
Instance Attribute Details
#currency ⇒ Symbol, OpenAI::Models::Admin::Organization::SpendLimitUpdateParams::Currency
The currency for the threshold amount. Currently, only USD is supported.
16 |
# File 'lib/openai/models/admin/organization/spend_limit_update_params.rb', line 16 required :currency, enum: -> { OpenAI::Admin::Organization::SpendLimitUpdateParams::Currency } |
#interval ⇒ Symbol, OpenAI::Models::Admin::Organization::SpendLimitUpdateParams::Interval
The time interval for evaluating spend against the threshold. Currently, only
month is supported.
23 |
# File 'lib/openai/models/admin/organization/spend_limit_update_params.rb', line 23 required :interval, enum: -> { OpenAI::Admin::Organization::SpendLimitUpdateParams::Interval } |
#threshold_amount ⇒ Integer
The hard spend limit amount, in cents.
29 |
# File 'lib/openai/models/admin/organization/spend_limit_update_params.rb', line 29 required :threshold_amount, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/admin/organization/spend_limit_update_params.rb', line 49
|
Instance Method Details
#to_hash ⇒ {
30 |
# File 'sig/openai/models/admin/organization/spend_limit_update_params.rbs', line 30
def to_hash: -> {
|