Class: OpenAI::Models::Admin::Organization::UsageAudioSpeechesResponse::Data::Result::OrganizationUsageImagesResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::UsageAudioSpeechesResponse::Data::Result::OrganizationUsageImagesResult
- Defined in:
- lib/openai/models/admin/organization/usage_audio_speeches_response.rb,
sig/openai/models/admin/organization/usage_audio_speeches_response.rbs
Instance Attribute Summary collapse
-
#api_key_id ⇒ String?
When
group_by=api_key_id, this field provides the API key ID of the grouped usage result. -
#images ⇒ Integer
The number of images processed.
-
#model ⇒ String?
When
group_by=model, this field provides the model name of the grouped usage result. -
#num_model_requests ⇒ Integer
The count of requests made to the model.
- #object ⇒ Symbol, :"organization.usage.images.result"
-
#project_id ⇒ String?
When
group_by=project_id, this field provides the project ID of the grouped usage result. -
#size ⇒ String?
When
group_by=size, this field provides the image size of the grouped usage result. -
#source ⇒ String?
When
group_by=source, this field provides the source of the grouped usage result, possible values areimage.generation,image.edit,image.variation. -
#user_id ⇒ String?
When
group_by=user_id, this field provides the user ID of the grouped usage result.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
292 |
# File 'sig/openai/models/admin/organization/usage_audio_speeches_response.rbs', line 292
def initialize: (
|
Instance Attribute Details
#api_key_id ⇒ String?
When group_by=api_key_id, this field provides the API key ID of the grouped
usage result.
395 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 395 optional :api_key_id, String, nil?: true |
#images ⇒ Integer
The number of images processed.
377 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 377 required :images, Integer |
#model ⇒ String?
When group_by=model, this field provides the model name of the grouped usage
result.
402 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 402 optional :model, String, nil?: true |
#num_model_requests ⇒ Integer
The count of requests made to the model.
383 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 383 required :num_model_requests, Integer |
#object ⇒ Symbol, :"organization.usage.images.result"
388 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 388 required :object, const: :"organization.usage.images.result" |
#project_id ⇒ String?
When group_by=project_id, this field provides the project ID of the grouped
usage result.
409 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 409 optional :project_id, String, nil?: true |
#size ⇒ String?
When group_by=size, this field provides the image size of the grouped usage
result.
416 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 416 optional :size, String, nil?: true |
#source ⇒ String?
When group_by=source, this field provides the source of the grouped usage
result, possible values are image.generation, image.edit, image.variation.
423 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 423 optional :source, String, nil?: true |
#user_id ⇒ String?
When group_by=user_id, this field provides the user ID of the grouped usage
result.
430 |
# File 'lib/openai/models/admin/organization/usage_audio_speeches_response.rb', line 430 optional :user_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
304 |
# File 'sig/openai/models/admin/organization/usage_audio_speeches_response.rbs', line 304
def to_hash: -> {
|