Class: OpenAI::Models::Admin::Organization::UsageCostsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::UsageCostsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/admin/organization/usage_costs_params.rb
Overview
Defined Under Namespace
Modules: BucketWidth, GroupBy
Instance Attribute Summary collapse
-
#api_key_ids ⇒ Array<String>?
Return only costs for these API keys.
-
#bucket_width ⇒ Symbol, ...
Width of each time bucket in response.
-
#end_time ⇒ Integer?
End time (Unix seconds) of the query time range, exclusive.
-
#group_by ⇒ Array<Symbol, OpenAI::Models::Admin::Organization::UsageCostsParams::GroupBy>?
Group the costs by the specified fields.
-
#limit ⇒ Integer?
A limit on the number of buckets to be returned.
-
#page ⇒ String?
A cursor for use in pagination.
-
#project_ids ⇒ Array<String>?
Return only costs for these projects.
-
#start_time ⇒ Integer
Start time (Unix seconds) of the query time range, inclusive.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(start_time:, api_key_ids: nil, bucket_width: nil, end_time: nil, group_by: nil, limit: nil, page: nil, project_ids: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see UsageCostsParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(start_time:, api_key_ids: nil, bucket_width: nil, end_time: nil, group_by: nil, limit: nil, page: nil, project_ids: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::UsageCostsParams for more details.
|
|
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 65
|
Instance Attribute Details
#api_key_ids ⇒ Array<String>?
Return only costs for these API keys.
22 |
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 22 optional :api_key_ids, OpenAI::Internal::Type::ArrayOf[String] |
#bucket_width ⇒ Symbol, ...
Width of each time bucket in response. Currently only ‘1d` is supported, default to `1d`.
29 |
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 29 optional :bucket_width, enum: -> { OpenAI::Admin::Organization::UsageCostsParams::BucketWidth } |
#end_time ⇒ Integer?
End time (Unix seconds) of the query time range, exclusive.
35 |
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 35 optional :end_time, Integer |
#group_by ⇒ Array<Symbol, OpenAI::Models::Admin::Organization::UsageCostsParams::GroupBy>?
Group the costs by the specified fields. Support fields include ‘project_id`, `line_item`, `api_key_id` and any combination of them.
42 43 |
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 42 optional :group_by, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Admin::Organization::UsageCostsParams::GroupBy] } |
#limit ⇒ Integer?
A limit on the number of buckets to be returned. Limit can range between 1 and 180, and the default is 7.
50 |
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 50 optional :limit, Integer |
#page ⇒ String?
A cursor for use in pagination. Corresponding to the ‘next_page` field from the previous response.
57 |
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 57 optional :page, String |
#project_ids ⇒ Array<String>?
Return only costs for these projects.
63 |
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 63 optional :project_ids, OpenAI::Internal::Type::ArrayOf[String] |
#start_time ⇒ Integer
Start time (Unix seconds) of the query time range, inclusive.
16 |
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 16 required :start_time, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/admin/organization/usage_costs_params.rb', line 94
|