Class: OpenAI::Models::Admin::Organization::UsageCostsResponse::Data::Result::OrganizationUsageCompletionsResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::UsageCostsResponse::Data::Result::OrganizationUsageCompletionsResult
- Defined in:
- lib/openai/models/admin/organization/usage_costs_response.rb,
sig/openai/models/admin/organization/usage_costs_response.rbs
Instance Attribute Summary collapse
-
#api_key_id ⇒ String?
When
group_by=api_key_id, this field provides the API key ID of the grouped usage result. -
#batch ⇒ Boolean?
When
group_by=batch, this field tells whether the grouped usage result is batch or not. -
#input_audio_tokens ⇒ Integer?
The aggregated number of uncached audio input tokens used.
-
#input_cache_write_tokens ⇒ Integer?
The aggregated number of input tokens written to the cache.
-
#input_cached_audio_tokens ⇒ Integer?
The aggregated number of cached audio input tokens used.
-
#input_cached_image_tokens ⇒ Integer?
The aggregated number of cached image input tokens used.
-
#input_cached_text_tokens ⇒ Integer?
The aggregated number of cached text input tokens used.
-
#input_cached_tokens ⇒ Integer?
The aggregated number of cached input tokens used across text, audio, and image inputs.
-
#input_image_tokens ⇒ Integer?
The aggregated number of uncached image input tokens used.
-
#input_text_tokens ⇒ Integer?
The aggregated number of uncached text input tokens used, excluding cache-write tokens.
-
#input_tokens ⇒ Integer
The aggregated number of input tokens used, including cached and cache-write tokens.
-
#input_uncached_tokens ⇒ Integer?
The aggregated number of uncached input tokens used across text, audio, and image inputs, excluding cache-write tokens.
-
#model ⇒ String?
When
group_by=model, this field provides the model name of the grouped usage result. -
#num_model_requests ⇒ Integer
The count of requests made to the model.
- #object ⇒ Symbol, :"organization.usage.completions.result"
-
#output_audio_tokens ⇒ Integer?
The aggregated number of audio output tokens used.
-
#output_image_tokens ⇒ Integer?
The aggregated number of image output tokens used.
-
#output_text_tokens ⇒ Integer?
The aggregated number of text output tokens used.
-
#output_tokens ⇒ Integer
The aggregated number of output tokens used across text, audio, and image outputs.
-
#project_id ⇒ String?
When
group_by=project_id, this field provides the project ID of the grouped usage result. -
#service_tier ⇒ String?
When
group_by=service_tier, this field provides the service tier of the grouped usage result. -
#user_id ⇒ String?
When
group_by=user_id, this field provides the user ID of the grouped usage result.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
178 |
# File 'sig/openai/models/admin/organization/usage_costs_response.rbs', line 178
def initialize: (
|
Instance Attribute Details
#api_key_id ⇒ String?
When group_by=api_key_id, this field provides the API key ID of the grouped
usage result.
197 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 197 optional :api_key_id, String, nil?: true |
#batch ⇒ Boolean?
When group_by=batch, this field tells whether the grouped usage result is
batch or not.
204 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 204 optional :batch, OpenAI::Internal::Type::Boolean, nil?: true |
#input_audio_tokens ⇒ Integer?
The aggregated number of uncached audio input tokens used.
210 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 210 optional :input_audio_tokens, Integer |
#input_cache_write_tokens ⇒ Integer?
The aggregated number of input tokens written to the cache.
216 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 216 optional :input_cache_write_tokens, Integer |
#input_cached_audio_tokens ⇒ Integer?
The aggregated number of cached audio input tokens used.
222 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 222 optional :input_cached_audio_tokens, Integer |
#input_cached_image_tokens ⇒ Integer?
The aggregated number of cached image input tokens used.
228 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 228 optional :input_cached_image_tokens, Integer |
#input_cached_text_tokens ⇒ Integer?
The aggregated number of cached text input tokens used.
234 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 234 optional :input_cached_text_tokens, Integer |
#input_cached_tokens ⇒ Integer?
The aggregated number of cached input tokens used across text, audio, and image inputs. For customers subscribed to Scale Tier, this includes Scale Tier tokens.
241 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 241 optional :input_cached_tokens, Integer |
#input_image_tokens ⇒ Integer?
The aggregated number of uncached image input tokens used.
247 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 247 optional :input_image_tokens, Integer |
#input_text_tokens ⇒ Integer?
The aggregated number of uncached text input tokens used, excluding cache-write tokens.
254 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 254 optional :input_text_tokens, Integer |
#input_tokens ⇒ Integer
The aggregated number of input tokens used, including cached and cache-write tokens. This includes text, audio, and image tokens. For customers subscribed to Scale Tier, this includes Scale Tier tokens.
171 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 171 required :input_tokens, Integer |
#input_uncached_tokens ⇒ Integer?
The aggregated number of uncached input tokens used across text, audio, and image inputs, excluding cache-write tokens.
261 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 261 optional :input_uncached_tokens, Integer |
#model ⇒ String?
When group_by=model, this field provides the model name of the grouped usage
result.
268 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 268 optional :model, String, nil?: true |
#num_model_requests ⇒ Integer
The count of requests made to the model.
177 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 177 required :num_model_requests, Integer |
#object ⇒ Symbol, :"organization.usage.completions.result"
182 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 182 required :object, const: :"organization.usage.completions.result" |
#output_audio_tokens ⇒ Integer?
The aggregated number of audio output tokens used.
274 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 274 optional :output_audio_tokens, Integer |
#output_image_tokens ⇒ Integer?
The aggregated number of image output tokens used.
280 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 280 optional :output_image_tokens, Integer |
#output_text_tokens ⇒ Integer?
The aggregated number of text output tokens used.
286 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 286 optional :output_text_tokens, Integer |
#output_tokens ⇒ Integer
The aggregated number of output tokens used across text, audio, and image outputs. For customers subscribed to Scale Tier, this includes Scale Tier tokens.
190 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 190 required :output_tokens, Integer |
#project_id ⇒ String?
When group_by=project_id, this field provides the project ID of the grouped
usage result.
293 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 293 optional :project_id, String, nil?: true |
#service_tier ⇒ String?
When group_by=service_tier, this field provides the service tier of the
grouped usage result.
300 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 300 optional :service_tier, String, nil?: true |
#user_id ⇒ String?
When group_by=user_id, this field provides the user ID of the grouped usage
result.
307 |
# File 'lib/openai/models/admin/organization/usage_costs_response.rb', line 307 optional :user_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
203 |
# File 'sig/openai/models/admin/organization/usage_costs_response.rbs', line 203
def to_hash: -> {
|