Class: OpenAI::Models::Admin::Organization::UsageEmbeddingsResponse::Data::Result::OrganizationUsageCompletionsResult

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/admin/organization/usage_embeddings_response.rb,
sig/openai/models/admin/organization/usage_embeddings_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



178
# File 'sig/openai/models/admin/organization/usage_embeddings_response.rbs', line 178

def initialize: (

Instance Attribute Details

#api_key_idString?

When group_by=api_key_id, this field provides the API key ID of the grouped usage result.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


147
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 147

optional :api_key_id, String, nil?: true

#batchBoolean?

When group_by=batch, this field tells whether the grouped usage result is batch or not.

Parameters:

Returns:



154
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 154

optional :batch, OpenAI::Internal::Type::Boolean, nil?: true

#input_audio_tokensInteger?

The aggregated number of uncached audio input tokens used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


160
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 160

optional :input_audio_tokens, Integer

#input_cache_write_tokensInteger?

The aggregated number of input tokens written to the cache.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


166
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 166

optional :input_cache_write_tokens, Integer

#input_cached_audio_tokensInteger?

The aggregated number of cached audio input tokens used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


172
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 172

optional :input_cached_audio_tokens, Integer

#input_cached_image_tokensInteger?

The aggregated number of cached image input tokens used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


178
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 178

optional :input_cached_image_tokens, Integer

#input_cached_text_tokensInteger?

The aggregated number of cached text input tokens used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


184
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 184

optional :input_cached_text_tokens, Integer

#input_cached_tokensInteger?

The aggregated number of cached input tokens used across text, audio, and image inputs. For customers subscribed to Scale Tier, this includes Scale Tier tokens.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


191
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 191

optional :input_cached_tokens, Integer

#input_image_tokensInteger?

The aggregated number of uncached image input tokens used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


197
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 197

optional :input_image_tokens, Integer

#input_text_tokensInteger?

The aggregated number of uncached text input tokens used, excluding cache-write tokens.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


204
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 204

optional :input_text_tokens, Integer

#input_tokensInteger

The aggregated number of input tokens used, including cached and cache-write tokens. This includes text, audio, and image tokens. For customers subscribed to Scale Tier, this includes Scale Tier tokens.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


121
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 121

required :input_tokens, Integer

#input_uncached_tokensInteger?

The aggregated number of uncached input tokens used across text, audio, and image inputs, excluding cache-write tokens.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


211
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 211

optional :input_uncached_tokens, Integer

#modelString?

When group_by=model, this field provides the model name of the grouped usage result.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


218
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 218

optional :model, String, nil?: true

#num_model_requestsInteger

The count of requests made to the model.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


127
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 127

required :num_model_requests, Integer

#objectSymbol, :"organization.usage.completions.result"

Parameters:

  • value (:"organization.usage.completions.result")

Returns:

  • (Symbol, :"organization.usage.completions.result")


132
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 132

required :object, const: :"organization.usage.completions.result"

#output_audio_tokensInteger?

The aggregated number of audio output tokens used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


224
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 224

optional :output_audio_tokens, Integer

#output_image_tokensInteger?

The aggregated number of image output tokens used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


230
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 230

optional :output_image_tokens, Integer

#output_text_tokensInteger?

The aggregated number of text output tokens used.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


236
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 236

optional :output_text_tokens, Integer

#output_tokensInteger

The aggregated number of output tokens used across text, audio, and image outputs. For customers subscribed to Scale Tier, this includes Scale Tier tokens.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


140
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 140

required :output_tokens, Integer

#project_idString?

When group_by=project_id, this field provides the project ID of the grouped usage result.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


243
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 243

optional :project_id, String, nil?: true

#service_tierString?

When group_by=service_tier, this field provides the service tier of the grouped usage result.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


250
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 250

optional :service_tier, String, nil?: true

#user_idString?

When group_by=user_id, this field provides the user ID of the grouped usage result.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


257
# File 'lib/openai/models/admin/organization/usage_embeddings_response.rb', line 257

optional :user_id, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


203
# File 'sig/openai/models/admin/organization/usage_embeddings_response.rbs', line 203

def to_hash: -> {