Class: OpenAI::Models::Admin::Organization::UsageModerationsResponse::Data::Result::OrganizationCostsResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Admin::Organization::UsageModerationsResponse::Data::Result::OrganizationCostsResult
- Defined in:
- lib/openai/models/admin/organization/usage_moderations_response.rb
Defined Under Namespace
Classes: Amount
Instance Attribute Summary collapse
-
#amount ⇒ OpenAI::Models::Admin::Organization::UsageModerationsResponse::Data::Result::OrganizationCostsResult::Amount?
The monetary value in its associated currency.
-
#api_key_id ⇒ String?
When ‘group_by=api_key_id`, this field provides the API Key ID of the grouped costs result.
-
#line_item ⇒ String?
When ‘group_by=line_item`, this field provides the line item of the grouped costs result.
- #object ⇒ Symbol, :"organization.costs.result"
-
#project_id ⇒ String?
When ‘group_by=project_id`, this field provides the project ID of the grouped costs result.
Instance Method Summary collapse
-
#initialize(amount: nil, api_key_id: nil, line_item: nil, project_id: nil, object: :"organization.costs.result") ⇒ Object
constructor
Some parameter documentations has been truncated, see OrganizationCostsResult for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount: nil, api_key_id: nil, line_item: nil, project_id: nil, object: :"organization.costs.result") ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Admin::Organization::UsageModerationsResponse::Data::Result::OrganizationCostsResult for more details.
The aggregated costs details of the specific time bucket.
|
|
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 687
|
Instance Attribute Details
#amount ⇒ OpenAI::Models::Admin::Organization::UsageModerationsResponse::Data::Result::OrganizationCostsResult::Amount?
The monetary value in its associated currency.
663 664 |
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 663 optional :amount, -> { OpenAI::Models::Admin::Organization::UsageModerationsResponse::Data::Result::OrganizationCostsResult::Amount } |
#api_key_id ⇒ String?
When ‘group_by=api_key_id`, this field provides the API Key ID of the grouped costs result.
671 |
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 671 optional :api_key_id, String, nil?: true |
#line_item ⇒ String?
When ‘group_by=line_item`, this field provides the line item of the grouped costs result.
678 |
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 678 optional :line_item, String, nil?: true |
#object ⇒ Symbol, :"organization.costs.result"
657 |
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 657 required :object, const: :"organization.costs.result" |
#project_id ⇒ String?
When ‘group_by=project_id`, this field provides the project ID of the grouped costs result.
685 |
# File 'lib/openai/models/admin/organization/usage_moderations_response.rb', line 685 optional :project_id, String, nil?: true |