Class: OpenAI::Models::Audio::SpeechCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Audio::SpeechCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/audio/speech_create_params.rb,
sig/openai/models/audio/speech_create_params.rbs
Overview
Defined Under Namespace
Modules: Model, ResponseFormat, StreamFormat, Voice
Instance Attribute Summary collapse
-
#input ⇒ String
The text to generate audio for.
-
#instructions ⇒ String?
Control the voice of your generated audio with additional instructions.
-
#model ⇒ OpenAI::Models::Audio::SpeechCreateParams::model
One of the available TTS models:
tts-1,tts-1-hd,gpt-4o-mini-tts, orgpt-4o-mini-tts-2025-12-15. -
#response_format ⇒ OpenAI::Models::Audio::SpeechCreateParams::response_format?
The format to audio in.
-
#speed ⇒ Float?
The speed of the generated audio.
-
#stream_format ⇒ OpenAI::Models::Audio::SpeechCreateParams::stream_format?
The format to stream the audio in.
-
#voice ⇒ OpenAI::Models::Audio::SpeechCreateParams::voice
The voice to use when generating the audio.
Attributes included from Internal::Type::RequestParameters
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(input:, model:, voice:, instructions: nil, response_format: nil, speed: nil, stream_format: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(input:, model:, voice:, instructions: nil, response_format: nil, speed: nil, stream_format: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/openai/models/audio/speech_create_params.rb', line 64
|
Instance Attribute Details
#input ⇒ String
The text to generate audio for. The maximum length is 4096 characters.
15 |
# File 'lib/openai/models/audio/speech_create_params.rb', line 15 required :input, String |
#instructions ⇒ String?
Control the voice of your generated audio with additional instructions. Does not
work with tts-1 or tts-1-hd.
41 |
# File 'lib/openai/models/audio/speech_create_params.rb', line 41 optional :instructions, String |
#model ⇒ OpenAI::Models::Audio::SpeechCreateParams::model
One of the available
TTS models:
tts-1, tts-1-hd, gpt-4o-mini-tts, or gpt-4o-mini-tts-2025-12-15.
23 |
# File 'lib/openai/models/audio/speech_create_params.rb', line 23 required :model, union: -> { OpenAI::Audio::SpeechCreateParams::Model } |
#response_format ⇒ OpenAI::Models::Audio::SpeechCreateParams::response_format?
The format to audio in. Supported formats are mp3, opus, aac, flac,
wav, and pcm.
48 |
# File 'lib/openai/models/audio/speech_create_params.rb', line 48 optional :response_format, enum: -> { OpenAI::Audio::SpeechCreateParams::ResponseFormat } |
#speed ⇒ Float?
The speed of the generated audio. Select a value from 0.25 to 4.0. 1.0 is
the default.
55 |
# File 'lib/openai/models/audio/speech_create_params.rb', line 55 optional :speed, Float |
#stream_format ⇒ OpenAI::Models::Audio::SpeechCreateParams::stream_format?
The format to stream the audio in. Supported formats are sse and audio.
sse is not supported for tts-1 or tts-1-hd.
62 |
# File 'lib/openai/models/audio/speech_create_params.rb', line 62 optional :stream_format, enum: -> { OpenAI::Audio::SpeechCreateParams::StreamFormat } |
#voice ⇒ OpenAI::Models::Audio::SpeechCreateParams::voice
The voice to use when generating the audio. Supported built-in voices are
alloy, ash, ballad, coral, echo, fable, onyx, nova, sage,
shimmer, verse, marin, and cedar. You may also provide a custom voice
object with an id, for example { "id": "voice_1234" }. Previews of the
voices are available in the
Text to speech guide.
34 |
# File 'lib/openai/models/audio/speech_create_params.rb', line 34 required :voice, union: -> { OpenAI::Audio::SpeechCreateParams::Voice } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/audio/speech_create_params.rb', line 203
|
.variants ⇒ Array(String, Symbol, OpenAI::Models::Audio::SpeechModel)
|
|
# File 'lib/openai/models/audio/speech_create_params.rb', line 110
|
Instance Method Details
#to_hash ⇒ {
108 |
# File 'sig/openai/models/audio/speech_create_params.rbs', line 108 def to_hash: -> { |