Class: OpenAI::Models::Audio::SpeechCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/audio/speech_create_params.rb

Overview

Defined Under Namespace

Modules: Model, ResponseFormat, StreamFormat, Voice

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(input:, model:, voice:, instructions: nil, response_format: nil, speed: nil, stream_format: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Audio::SpeechCreateParams for more details.

Parameters:

  • The text to generate audio for. The maximum length is 4096 characters.

  • One of the available [TTS models](platform.openai.com/docs/models#tts):

  • The voice to use when generating the audio. Supported built-in voices are ‘alloy

  • (defaults to: nil)

    Control the voice of your generated audio with additional instructions. Does not

  • (defaults to: nil)

    The format to audio in. Supported formats are mp3, opus, aac, flac, ‘wav

  • (defaults to: nil)

    The speed of the generated audio. Select a value from 0.25 to 4.0. 1.0 is

  • (defaults to: nil)

    The format to stream the audio in. Supported formats are sse and audio. ‘sse

  • (defaults to: {})


# File 'lib/openai/models/audio/speech_create_params.rb', line 62


Instance Attribute Details

#inputString

The text to generate audio for. The maximum length is 4096 characters.

Returns:



15
# File 'lib/openai/models/audio/speech_create_params.rb', line 15

required :input, String

#instructionsString?

Control the voice of your generated audio with additional instructions. Does not work with tts-1 or tts-1-hd.

Returns:



39
# File 'lib/openai/models/audio/speech_create_params.rb', line 39

optional :instructions, String

#modelString, ...

One of the available [TTS models](platform.openai.com/docs/models#tts): tts-1, tts-1-hd, gpt-4o-mini-tts, or gpt-4o-mini-tts-2025-12-15.

Returns:



22
# File 'lib/openai/models/audio/speech_create_params.rb', line 22

required :model, union: -> { OpenAI::Audio::SpeechCreateParams::Model }

#response_formatSymbol, ...

The format to audio in. Supported formats are mp3, opus, aac, flac, wav, and pcm.

Returns:



46
# File 'lib/openai/models/audio/speech_create_params.rb', line 46

optional :response_format, enum: -> { OpenAI::Audio::SpeechCreateParams::ResponseFormat }

#speedFloat?

The speed of the generated audio. Select a value from 0.25 to 4.0. 1.0 is the default.

Returns:



53
# File 'lib/openai/models/audio/speech_create_params.rb', line 53

optional :speed, Float

#stream_formatSymbol, ...

The format to stream the audio in. Supported formats are sse and audio. sse is not supported for tts-1 or tts-1-hd.

Returns:



60
# File 'lib/openai/models/audio/speech_create_params.rb', line 60

optional :stream_format, enum: -> { OpenAI::Audio::SpeechCreateParams::StreamFormat }

#voiceString, ...

The voice to use when generating the audio. Supported built-in voices are alloy, ash, ballad, coral, echo, fable, onyx, nova, sage, shimmer, verse, marin, and cedar. Previews of the voices are available in the [Text to speech guide](platform.openai.com/docs/guides/text-to-speech#voice-options).

Returns:



32
# File 'lib/openai/models/audio/speech_create_params.rb', line 32

required :voice, union: -> { OpenAI::Audio::SpeechCreateParams::Voice }

Class Method Details

.valuesArray<Symbol>

Returns:



# File 'lib/openai/models/audio/speech_create_params.rb', line 161


.variantsArray(String, Symbol, OpenAI::Models::Audio::SpeechModel)

Returns:



# File 'lib/openai/models/audio/speech_create_params.rb', line 92