Module: OpenAI::Models::Audio::SpeechCreateParams::Voice
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/audio/speech_create_params.rb
Overview
The voice to use when generating the audio. Supported built-in voices are ‘alloy`, `ash`, `ballad`, `coral`, `echo`, `fable`, `onyx`, `nova`, `sage`, `shimmer`, `verse`, `marin`, and `cedar`. You may also provide a custom voice object with an `id`, for example `{ “id”: “voice_1234” }`. Previews of the voices are available in the [Text to speech guide](platform.openai.com/docs/guides/text-to-speech#voice-options).
Defined Under Namespace
Classes: ID
collapse
- ALLOY =
:alloy- ASH =
:ash- BALLAD =
:ballad- CORAL =
:coral- ECHO =
:echo- SAGE =
:sage- SHIMMER =
:shimmer- VERSE =
:verse- MARIN =
:marin- CEDAR =
:cedar
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
Custom voice reference.
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(String, Symbol, OpenAI::Models::Audio::SpeechCreateParams::Voice::ID)
147 148 149 150 151 152 153 154 155 |
# File 'lib/openai/models/audio/speech_create_params.rb', line 147 define_sorbet_constant!(:Variants) do T.type_alias do T.any( String, OpenAI::Audio::SpeechCreateParams::Voice::TaggedSymbol, OpenAI::Audio::SpeechCreateParams::Voice::ID ) end end |
Instance Method Details
#initialize(id:) ⇒ Object
Custom voice reference.
|
|
# File 'lib/openai/models/audio/speech_create_params.rb', line 138
|