Class: OpenAI::Models::Audio::TranscriptionTextDoneEvent::Logprob

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/audio/transcription_text_done_event.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(text:, logprobs: nil, usage: nil, type: :"transcript.text.done") ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Audio::TranscriptionTextDoneEvent for more details.

Emitted when the transcription is complete. Contains the complete transcription text. Only emitted when you [create a transcription](platform.openai.com/docs/api-reference/audio/create-transcription) with the Stream parameter set to true.

Parameters:

  • The text that was transcribed.

  • (defaults to: nil)

    The log probabilities of the individual tokens in the transcription. Only includ

  • (defaults to: nil)

    Usage statistics for models billed by token usage.

  • (defaults to: :"transcript.text.done")

    The type of the event. Always transcript.text.done.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/openai/models/audio/transcription_text_done_event.rb', line 52

class Logprob < OpenAI::Internal::Type::BaseModel
  # @!attribute token
  #   The token that was used to generate the log probability.
  #
  #   @return [String, nil]
  optional :token, String

  # @!attribute bytes
  #   The bytes that were used to generate the log probability.
  #
  #   @return [Array<Integer>, nil]
  optional :bytes, OpenAI::Internal::Type::ArrayOf[Integer]

  # @!attribute logprob
  #   The log probability of the token.
  #
  #   @return [Float, nil]
  optional :logprob, Float

  # @!method initialize(token: nil, bytes: nil, logprob: nil)
  #   Some parameter documentations has been truncated, see
  #   {OpenAI::Models::Audio::TranscriptionTextDoneEvent::Logprob} for more details.
  #
  #   @param token [String] The token that was used to generate the log probability.
  #
  #   @param bytes [Array<Integer>] The bytes that were used to generate the log probability.
  #
  #   @param logprob [Float] The log probability of the token.
end

Instance Attribute Details

#bytesArray<Integer>?

The bytes that were used to generate the log probability.

Returns:



63
# File 'lib/openai/models/audio/transcription_text_done_event.rb', line 63

optional :bytes, OpenAI::Internal::Type::ArrayOf[Integer]

#logprobFloat?

The log probability of the token.

Returns:



69
# File 'lib/openai/models/audio/transcription_text_done_event.rb', line 69

optional :logprob, Float

#tokenString?

The token that was used to generate the log probability.

Returns:



57
# File 'lib/openai/models/audio/transcription_text_done_event.rb', line 57

optional :token, String