Class: OpenAI::Models::Beta::AgentOutputItem::ComputerUseApprovalRequest::Request
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::AgentOutputItem::ComputerUseApprovalRequest::Request
- Defined in:
- lib/openai/models/beta/agent_output_item.rb,
sig/openai/models/beta/agent_output_item.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#credential_origin ⇒ String?
The registered form or frame origin where values will be entered.
-
#fields ⇒ ::Array[OpenAI::Beta::AgentOutputItem::ComputerUseApprovalRequest::Request::Field]
Controls to render.
-
#options ⇒ ::Array[OpenAI::Beta::AgentOutputItem::ComputerUseApprovalRequest::Request::Option]
Sign-in methods.
-
#reason ⇒ String?
Why the agent needs the user to sign in.
-
#type ⇒ :browser_authentication
The type of the object.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, label:, required:, type:) ⇒ Object
|
|
# File 'lib/openai/models/beta/agent_output_item.rb', line 273
|
Instance Attribute Details
#credential_origin ⇒ String?
The registered form or frame origin where values will be entered.
191 |
# File 'lib/openai/models/beta/agent_output_item.rb', line 191 required :credential_origin, String, nil?: true |
#fields ⇒ ::Array[OpenAI::Beta::AgentOutputItem::ComputerUseApprovalRequest::Request::Field]
Controls to render. All submitted values are sensitive.
197 198 199 200 201 202 203 204 |
# File 'lib/openai/models/beta/agent_output_item.rb', line 197 required( :fields, -> { OpenAI::Internal::Type::ArrayOf[ OpenAI::Beta::AgentOutputItem::ComputerUseApprovalRequest::Request::Field ] } ) |
#options ⇒ ::Array[OpenAI::Beta::AgentOutputItem::ComputerUseApprovalRequest::Request::Option]
Sign-in methods. Empty for a plain form.
210 211 212 213 214 215 216 217 |
# File 'lib/openai/models/beta/agent_output_item.rb', line 210 required( :options, -> { OpenAI::Internal::Type::ArrayOf[ OpenAI::Beta::AgentOutputItem::ComputerUseApprovalRequest::Request::Option ] } ) |
#reason ⇒ String?
Why the agent needs the user to sign in.
223 |
# File 'lib/openai/models/beta/agent_output_item.rb', line 223 required :reason, String, nil?: true |
#type ⇒ :browser_authentication
The type of the object. Always browser_authentication.
229 |
# File 'lib/openai/models/beta/agent_output_item.rb', line 229 required :type, const: :browser_authentication |
Instance Method Details
#to_hash ⇒ {
194 |
# File 'sig/openai/models/beta/agent_output_item.rbs', line 194 def to_hash: -> { |