Class: OpenAI::Models::Beta::AgentOutputItem::ComputerUseApprovalRequest::Request::Field
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::AgentOutputItem::ComputerUseApprovalRequest::Request::Field
- Defined in:
- lib/openai/models/beta/agent_output_item.rb,
sig/openai/models/beta/agent_output_item.rbs
Instance Attribute Summary collapse
-
#id ⇒ String
The field ID to submit as field_id in a fields entry.
-
#label ⇒ String
The label to display beside the control.
-
#required ⇒ Boolean
Whether this control requires a nonempty value.
-
#type ⇒ String
The rendering type, such as email, password, or text.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(credential_origin:, fields:, options:, reason:, type: :browser_authentication) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(credential_origin:, fields:, options:, reason:, type: :browser_authentication) ⇒ Object
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/openai/models/beta/agent_output_item.rb', line 248 class Field < OpenAI::Internal::Type::BaseModel # @!attribute id # The field ID to submit as field_id in a fields entry. # # @return [String] required :id, String # @!attribute label # The label to display beside the control. # # @return [String] required :label, String # @!attribute required # Whether this control requires a nonempty value. # # @return [Boolean] required :required, OpenAI::Internal::Type::Boolean # @!attribute type # The rendering type, such as email, password, or text. # # @return [String] required :type, String # @!method initialize(id:, label:, required:, type:) # A control in a registered browser-login form. # # @param id [String] # The field ID to submit as field_id in a fields entry. # # @param label [String] # The label to display beside the control. # # @param required [Boolean] # Whether this control requires a nonempty value. # # @param type [String] # The rendering type, such as email, password, or text. end |
Instance Attribute Details
#id ⇒ String
The field ID to submit as field_id in a fields entry.
253 |
# File 'lib/openai/models/beta/agent_output_item.rb', line 253 required :id, String |
#label ⇒ String
The label to display beside the control.
259 |
# File 'lib/openai/models/beta/agent_output_item.rb', line 259 required :label, String |
#required ⇒ Boolean
Whether this control requires a nonempty value.
265 |
# File 'lib/openai/models/beta/agent_output_item.rb', line 265 required :required, OpenAI::Internal::Type::Boolean |
#type ⇒ String
The rendering type, such as email, password, or text.
271 |
# File 'lib/openai/models/beta/agent_output_item.rb', line 271 required :type, String |
Instance Method Details
#to_hash ⇒ {
233 |
# File 'sig/openai/models/beta/agent_output_item.rbs', line 233 def to_hash: -> { |