Class: OpenAI::Models::Beta::AgentSession::RequiredAction::ComputerUseApprovalRequest::Request::BrowserAuthentication
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::AgentSession::RequiredAction::ComputerUseApprovalRequest::Request::BrowserAuthentication
- Defined in:
- lib/openai/models/beta/agent_session.rb,
sig/openai/models/beta/agent_session.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#credential_origin ⇒ String?
The registered form or frame origin where values will be entered.
-
#fields ⇒ ::Array[OpenAI::Beta::AgentSession::RequiredAction::ComputerUseApprovalRequest::Request::BrowserAuthentication::Field]
Controls to render.
-
#options ⇒ ::Array[OpenAI::Beta::AgentSession::RequiredAction::ComputerUseApprovalRequest::Request::BrowserAuthentication::Option]
Sign-in methods.
-
#reason ⇒ String?
Why the agent needs the user to sign in.
-
#type ⇒ :browser_authentication
The type of the object.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, label:, required:, type:) ⇒ Object
|
|
# File 'lib/openai/models/beta/agent_session.rb', line 401
|
Instance Attribute Details
#credential_origin ⇒ String?
The registered form or frame origin where values will be entered.
319 |
# File 'lib/openai/models/beta/agent_session.rb', line 319 required :credential_origin, String, nil?: true |
#fields ⇒ ::Array[OpenAI::Beta::AgentSession::RequiredAction::ComputerUseApprovalRequest::Request::BrowserAuthentication::Field]
Controls to render. All submitted values are sensitive.
325 326 327 328 329 330 331 332 |
# File 'lib/openai/models/beta/agent_session.rb', line 325 required( :fields, -> do OpenAI::Internal::Type::ArrayOf[ OpenAI::Beta::AgentSession::RequiredAction::ComputerUseApprovalRequest::Request::BrowserAuthentication::Field ] end ) |
#options ⇒ ::Array[OpenAI::Beta::AgentSession::RequiredAction::ComputerUseApprovalRequest::Request::BrowserAuthentication::Option]
Sign-in methods. Empty for a plain form.
338 339 340 341 342 343 344 345 |
# File 'lib/openai/models/beta/agent_session.rb', line 338 required( :options, -> do OpenAI::Internal::Type::ArrayOf[ OpenAI::Beta::AgentSession::RequiredAction::ComputerUseApprovalRequest::Request::BrowserAuthentication::Option ] end ) |
#reason ⇒ String?
Why the agent needs the user to sign in.
351 |
# File 'lib/openai/models/beta/agent_session.rb', line 351 required :reason, String, nil?: true |
#type ⇒ :browser_authentication
The type of the object. Always browser_authentication.
357 |
# File 'lib/openai/models/beta/agent_session.rb', line 357 required :type, const: :browser_authentication |
Instance Method Details
#to_hash ⇒ {
316 |
# File 'sig/openai/models/beta/agent_session.rbs', line 316 def to_hash: -> { |