Class: OpenAI::Models::Beta::AgentSession::RequiredAction::FunctionCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::AgentSession::RequiredAction::FunctionCall
- Defined in:
- lib/openai/models/beta/agent_session.rb,
sig/openai/models/beta/agent_session.rbs
Instance Attribute Summary collapse
-
#arguments ⇒ Object
The arguments supplied by the model.
-
#call_id ⇒ String
The ID to include when submitting the function result.
-
#name ⇒ String
The function name.
-
#turn_id ⇒ String
The ID of the turn that requested the function call.
-
#type ⇒ Symbol, :function_call
The type of the object.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
173 |
# File 'sig/openai/models/beta/agent_session.rbs', line 173
def initialize: (
|
Instance Attribute Details
#arguments ⇒ Object
The arguments supplied by the model.
243 |
# File 'lib/openai/models/beta/agent_session.rb', line 243 required :arguments, OpenAI::Internal::Type::Unknown |
#call_id ⇒ String
The ID to include when submitting the function result.
249 |
# File 'lib/openai/models/beta/agent_session.rb', line 249 required :call_id, String |
#name ⇒ String
The function name.
255 |
# File 'lib/openai/models/beta/agent_session.rb', line 255 required :name, String |
#turn_id ⇒ String
The ID of the turn that requested the function call.
261 |
# File 'lib/openai/models/beta/agent_session.rb', line 261 required :turn_id, String |
#type ⇒ Symbol, :function_call
The type of the object. Always function_call.
267 |
# File 'lib/openai/models/beta/agent_session.rb', line 267 required :type, const: :function_call |
Instance Method Details
#to_hash ⇒ {
181 |
# File 'sig/openai/models/beta/agent_session.rbs', line 181
def to_hash: -> {
|