Class: OpenAI::Models::Beta::AgentSessionDeleted
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::AgentSessionDeleted
- Defined in:
- lib/openai/models/beta/agent_session_deleted.rb,
sig/openai/models/beta/agent_session_deleted.rbs
Instance Attribute Summary collapse
-
#deleted ⇒ Boolean
Whether the session has been removed from the public API.
-
#id ⇒ String
The ID of the deleted session.
-
#object ⇒ Symbol, :"agent.session.deleted"
The object type.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(id:, deleted:, object: :"agent.session.deleted") ⇒ Object
constructor
A Managed Agents session removed from the public API.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, deleted:, object: :"agent.session.deleted") ⇒ Object
A Managed Agents session removed from the public API. Physical cleanup may continue asynchronously.
|
|
# File 'lib/openai/models/beta/agent_session_deleted.rb', line 26
|
Instance Attribute Details
#deleted ⇒ Boolean
Whether the session has been removed from the public API. Always true.
Physical cleanup may still be in progress.
18 |
# File 'lib/openai/models/beta/agent_session_deleted.rb', line 18 required :deleted, OpenAI::Internal::Type::Boolean |
#id ⇒ String
The ID of the deleted session.
11 |
# File 'lib/openai/models/beta/agent_session_deleted.rb', line 11 required :id, String |
#object ⇒ Symbol, :"agent.session.deleted"
The object type. Always agent.session.deleted.
24 |
# File 'lib/openai/models/beta/agent_session_deleted.rb', line 24 required :object, const: :"agent.session.deleted" |
Instance Method Details
#to_hash ⇒ {
20 |
# File 'sig/openai/models/beta/agent_session_deleted.rbs', line 20
def to_hash: -> {
|