Class: OpenAI::Models::Beta::AgentSessionInputParam::AgentSessionInputToolResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::AgentSessionInputParam::AgentSessionInputToolResult
- Defined in:
- lib/openai/models/beta/agent_session_input_param.rb,
sig/openai/models/beta/agent_session_input_param.rbs
Instance Attribute Summary collapse
-
#call_id ⇒ String
The ID of the function call.
-
#error ⇒ String?
The error message when the call failed.
-
#output ⇒ String, ...
A function result represented as text or supported model-input content.
-
#success ⇒ Boolean
Whether the function call succeeded.
-
#turn_id ⇒ String
The ID of the turn that requested the function call.
-
#type ⇒ Symbol, :"agent.session.input.tool_result"
The type of the object.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(call_id:, success:, turn_id:, error: nil, output: nil, type: :"agent.session.input.tool_result") ⇒ Object
constructor
Submits the result of a function call.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_id:, success:, turn_id:, error: nil, output: nil, type: :"agent.session.input.tool_result") ⇒ Object
Submits the result of a function call.
|
|
# File 'lib/openai/models/beta/agent_session_input_param.rb', line 104
|
Instance Attribute Details
#call_id ⇒ String
The ID of the function call.
72 |
# File 'lib/openai/models/beta/agent_session_input_param.rb', line 72 required :call_id, String |
#error ⇒ String?
The error message when the call failed.
96 |
# File 'lib/openai/models/beta/agent_session_input_param.rb', line 96 optional :error, String, nil?: true |
#output ⇒ String, ...
A function result represented as text or supported model-input content.
102 |
# File 'lib/openai/models/beta/agent_session_input_param.rb', line 102 optional :output, union: -> { OpenAI::Beta::AgentFunctionCallOutputParam }, nil?: true |
#success ⇒ Boolean
Whether the function call succeeded.
78 |
# File 'lib/openai/models/beta/agent_session_input_param.rb', line 78 required :success, OpenAI::Internal::Type::Boolean |
#turn_id ⇒ String
The ID of the turn that requested the function call.
84 |
# File 'lib/openai/models/beta/agent_session_input_param.rb', line 84 required :turn_id, String |
#type ⇒ Symbol, :"agent.session.input.tool_result"
The type of the object. Always agent.session.input.tool_result.
90 |
# File 'lib/openai/models/beta/agent_session_input_param.rb', line 90 required :type, const: :"agent.session.input.tool_result" |
Instance Method Details
#to_hash ⇒ {
77 |
# File 'sig/openai/models/beta/agent_session_input_param.rbs', line 77
def to_hash: -> {
|