Class: OpenAI::Models::Beta::AgentSessionItem::ComputerUseApprovalRequestResult::Response::Submit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::AgentSessionItem::ComputerUseApprovalRequestResult::Response::Submit
- Defined in:
- lib/openai/models/beta/agent_session_item.rb,
sig/openai/models/beta/agent_session_item.rbs
Instance Attribute Summary collapse
- #action ⇒ Symbol, :submit
-
#selected_option ⇒ String?
The chosen sign-in method, or null when no options were offered.
- #type ⇒ Symbol, :browser_authentication
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
478 |
# File 'sig/openai/models/beta/agent_session_item.rbs', line 478
def initialize: (
|
Instance Attribute Details
#action ⇒ Symbol, :submit
528 |
# File 'lib/openai/models/beta/agent_session_item.rb', line 528 required :action, const: :submit |
#selected_option ⇒ String?
The chosen sign-in method, or null when no options were offered.
534 |
# File 'lib/openai/models/beta/agent_session_item.rb', line 534 required :selected_option, String, nil?: true |
#type ⇒ Symbol, :browser_authentication
539 |
# File 'lib/openai/models/beta/agent_session_item.rb', line 539 required :type, const: :browser_authentication |
Instance Method Details
#to_hash ⇒ {
484 |
# File 'sig/openai/models/beta/agent_session_item.rbs', line 484
def to_hash: -> {
|