Class: OpenAI::Models::Beta::AgentTool::WebSearch
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::AgentTool::WebSearch
- Defined in:
- lib/openai/models/beta/agent_tool.rb,
sig/openai/models/beta/agent_tool.rbs
Defined Under Namespace
Modules: ContextSize, Mode Classes: Location
Instance Attribute Summary collapse
-
#allowed_domains ⇒ Array<String>?
Allowed search domains, or
nullwhen the search is unrestricted. -
#context_size ⇒ Symbol, OpenAI::Models::Beta::AgentTool::WebSearch::ContextSize
The amount of search context made available to the model.
-
#location ⇒ OpenAI::Models::Beta::AgentTool::WebSearch::Location?
Approximate user location used to localize web search results.
-
#mode ⇒ Symbol, OpenAI::Models::Beta::AgentTool::WebSearch::Mode
The source used for web search results.
-
#type ⇒ Symbol, :web_search
The type of the object.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(city:, country:, region:, timezone:) ⇒ Object
constructor
Approximate user location used to localize web search results.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, region:, timezone:) ⇒ Object
Approximate user location used to localize web search results.
|
|
# File 'lib/openai/models/beta/agent_tool.rb', line 220
|
Instance Attribute Details
#allowed_domains ⇒ Array<String>?
Allowed search domains, or null when the search is unrestricted.
194 |
# File 'lib/openai/models/beta/agent_tool.rb', line 194 required :allowed_domains, OpenAI::Internal::Type::ArrayOf[String], nil?: true |
#context_size ⇒ Symbol, OpenAI::Models::Beta::AgentTool::WebSearch::ContextSize
The amount of search context made available to the model. Defaults to medium.
200 |
# File 'lib/openai/models/beta/agent_tool.rb', line 200 required :context_size, enum: -> { OpenAI::Beta::AgentTool::WebSearch::ContextSize } |
#location ⇒ OpenAI::Models::Beta::AgentTool::WebSearch::Location?
Approximate user location used to localize web search results.
206 |
# File 'lib/openai/models/beta/agent_tool.rb', line 206 required :location, -> { OpenAI::Beta::AgentTool::WebSearch::Location }, nil?: true |
#mode ⇒ Symbol, OpenAI::Models::Beta::AgentTool::WebSearch::Mode
The source used for web search results.
212 |
# File 'lib/openai/models/beta/agent_tool.rb', line 212 required :mode, enum: -> { OpenAI::Beta::AgentTool::WebSearch::Mode } |
#type ⇒ Symbol, :web_search
The type of the object. Always web_search.
218 |
# File 'lib/openai/models/beta/agent_tool.rb', line 218 required :type, const: :web_search |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/agent_tool.rb', line 248
|
Instance Method Details
#to_hash ⇒ {
157 |
# File 'sig/openai/models/beta/agent_tool.rbs', line 157
def to_hash: -> {
|