Class: OpenAI::Models::Beta::Agents::EnvironmentInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agents/environment_info.rb,
sig/openai/models/beta/agents/environment_info.rbs

Overview

See Also:

  • OpenAI::Resources::Beta::Agents::Environments#retrieve

Defined Under Namespace

Modules: Status, Type

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, files:, plugins:, skills:, status:, type:, object: :"agent.environment") ⇒ Object

Safe metadata for a first-class execution environment.

Parameters:



# File 'lib/openai/models/beta/agents/environment_info.rb', line 51

Instance Attribute Details

#filesArray<OpenAI::Models::Beta::HostedEnvironmentFileID, OpenAI::Models::Beta::HostedEnvironmentFile::Inline>

Files installed in the environment, without their contents.

Parameters:

  • value (::Array[OpenAI::Models::Beta::hosted_environment_file])

Returns:



19
# File 'lib/openai/models/beta/agents/environment_info.rb', line 19

required :files, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::HostedEnvironmentFile] }

#idString

The ID of the environment.

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/openai/models/beta/agents/environment_info.rb', line 13

required :id, String

#objectSymbol, :"agent.environment"

The object type. Always agent.environment.

Parameters:

  • value (:"agent.environment")

Returns:

  • (Symbol, :"agent.environment")


25
# File 'lib/openai/models/beta/agents/environment_info.rb', line 25

required :object, const: :"agent.environment"

#pluginsArray<OpenAI::Models::Beta::HostedPlugin>

Plugins installed in the environment, without their archive contents.

Parameters:

  • value (::Array[OpenAI::Beta::HostedPlugin])

Returns:



31
# File 'lib/openai/models/beta/agents/environment_info.rb', line 31

required :plugins, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::HostedPlugin] }

#skillsArray<OpenAI::Models::Beta::HostedSkillReference, OpenAI::Models::Beta::HostedSkill::Inline>

Skills installed in the environment, without their archive contents.

Parameters:

  • value (::Array[OpenAI::Models::Beta::hosted_skill])

Returns:



37
# File 'lib/openai/models/beta/agents/environment_info.rb', line 37

required :skills, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::HostedSkill] }

#statusSymbol, OpenAI::Models::Beta::Agents::EnvironmentInfo::Status

The current environment connection status.

Parameters:

  • value (OpenAI::Models::Beta::Agents::EnvironmentInfo::status)

Returns:



43
# File 'lib/openai/models/beta/agents/environment_info.rb', line 43

required :status, enum: -> { OpenAI::Beta::Agents::EnvironmentInfo::Status }

#typeSymbol, OpenAI::Models::Beta::Agents::EnvironmentInfo::Type

Whether the environment is hosted by OpenAI or by the application.

Parameters:

  • value (OpenAI::Models::Beta::Agents::EnvironmentInfo::type_)

Returns:



49
# File 'lib/openai/models/beta/agents/environment_info.rb', line 49

required :type, enum: -> { OpenAI::Beta::Agents::EnvironmentInfo::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/agents/environment_info.rb', line 87

Instance Method Details

#to_hash{

Returns:

  • ({)


41
# File 'sig/openai/models/beta/agents/environment_info.rbs', line 41

def to_hash: -> {