Class: OpenAI::Models::Beta::Agents::EnvironmentInfo
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Agents::EnvironmentInfo
- Defined in:
- lib/openai/models/beta/agents/environment_info.rb,
sig/openai/models/beta/agents/environment_info.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#files ⇒ Array<OpenAI::Models::Beta::HostedEnvironmentFileID, OpenAI::Models::Beta::HostedEnvironmentFile::Inline>
Files installed in the environment, without their contents.
-
#id ⇒ String
The ID of the environment.
-
#object ⇒ Symbol, :"agent.environment"
The object type.
-
#plugins ⇒ Array<OpenAI::Models::Beta::HostedPlugin>
Plugins installed in the environment, without their archive contents.
-
#skills ⇒ Array<OpenAI::Models::Beta::HostedSkillReference, OpenAI::Models::Beta::HostedSkill::Inline>
Skills installed in the environment, without their archive contents.
-
#status ⇒ Symbol, OpenAI::Models::Beta::Agents::EnvironmentInfo::Status
The current environment connection status.
-
#type ⇒ Symbol, OpenAI::Models::Beta::Agents::EnvironmentInfo::Type
Whether the environment is hosted by OpenAI or by the application.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, files:, plugins:, skills:, status:, type:, object: :"agent.environment") ⇒ Object
constructor
Safe metadata for a first-class execution environment.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, files:, plugins:, skills:, status:, type:, object: :"agent.environment") ⇒ Object
Safe metadata for a first-class execution environment.
|
|
# File 'lib/openai/models/beta/agents/environment_info.rb', line 51
|
Instance Attribute Details
#files ⇒ Array<OpenAI::Models::Beta::HostedEnvironmentFileID, OpenAI::Models::Beta::HostedEnvironmentFile::Inline>
Files installed in the environment, without their contents.
19 |
# File 'lib/openai/models/beta/agents/environment_info.rb', line 19 required :files, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::HostedEnvironmentFile] } |
#id ⇒ String
The ID of the environment.
13 |
# File 'lib/openai/models/beta/agents/environment_info.rb', line 13 required :id, String |
#object ⇒ Symbol, :"agent.environment"
The object type. Always agent.environment.
25 |
# File 'lib/openai/models/beta/agents/environment_info.rb', line 25 required :object, const: :"agent.environment" |
#plugins ⇒ Array<OpenAI::Models::Beta::HostedPlugin>
Plugins installed in the environment, without their archive contents.
31 |
# File 'lib/openai/models/beta/agents/environment_info.rb', line 31 required :plugins, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::HostedPlugin] } |
#skills ⇒ Array<OpenAI::Models::Beta::HostedSkillReference, OpenAI::Models::Beta::HostedSkill::Inline>
Skills installed in the environment, without their archive contents.
37 |
# File 'lib/openai/models/beta/agents/environment_info.rb', line 37 required :skills, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::HostedSkill] } |
#status ⇒ Symbol, OpenAI::Models::Beta::Agents::EnvironmentInfo::Status
The current environment connection status.
43 |
# File 'lib/openai/models/beta/agents/environment_info.rb', line 43 required :status, enum: -> { OpenAI::Beta::Agents::EnvironmentInfo::Status } |
#type ⇒ Symbol, OpenAI::Models::Beta::Agents::EnvironmentInfo::Type
Whether the environment is hosted by OpenAI or by the application.
49 |
# File 'lib/openai/models/beta/agents/environment_info.rb', line 49 required :type, enum: -> { OpenAI::Beta::Agents::EnvironmentInfo::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/agents/environment_info.rb', line 87
|
Instance Method Details
#to_hash ⇒ {
41 |
# File 'sig/openai/models/beta/agents/environment_info.rbs', line 41
def to_hash: -> {
|