Class: OpenAI::Models::Beta::Agents::Environments::FileListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Agents::Environments::FileListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/beta/agents/environments/file_list_params.rb,
sig/openai/models/beta/agents/environments/file_list_params.rbs
Overview
Defined Under Namespace
Modules: Order
Instance Attribute Summary collapse
- #environment_id ⇒ String
-
#limit ⇒ Integer?
The maximum number of files to return, between 1 and 100.
-
#order ⇒ Symbol, ...
Sort by case-sensitive path components.
-
#page ⇒ String?
The opaque token from the previous page.
-
#path ⇒ String?
Restrict the listing to this absolute workspace directory.
Attributes included from Internal::Type::RequestParameters
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(environment_id:, limit: nil, order: nil, page: nil, path: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(environment_id:, limit: nil, order: nil, page: nil, path: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/openai/models/beta/agents/environments/file_list_params.rb', line 42
|
Instance Attribute Details
#environment_id ⇒ String
16 |
# File 'lib/openai/models/beta/agents/environments/file_list_params.rb', line 16 required :environment_id, String |
#limit ⇒ Integer?
The maximum number of files to return, between 1 and 100.
22 |
# File 'lib/openai/models/beta/agents/environments/file_list_params.rb', line 22 optional :limit, Integer, nil?: true |
#order ⇒ Symbol, ...
Sort by case-sensitive path components. Defaults to descending.
28 |
# File 'lib/openai/models/beta/agents/environments/file_list_params.rb', line 28 optional :order, enum: -> { OpenAI::Beta::Agents::Environments::FileListParams::Order } |
#page ⇒ String?
The opaque token from the previous page. Keep the same path, order, and limit.
34 |
# File 'lib/openai/models/beta/agents/environments/file_list_params.rb', line 34 optional :page, String |
#path ⇒ String?
Restrict the listing to this absolute workspace directory.
40 |
# File 'lib/openai/models/beta/agents/environments/file_list_params.rb', line 40 optional :path, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
45 |
# File 'sig/openai/models/beta/agents/environments/file_list_params.rbs', line 45
def to_hash: -> {
|