Class: OpenAI::Models::Beta::Agents::Environments::TemplateUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Agents::Environments::TemplateUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/beta/agents/environments/template_update_params.rb,
sig/openai/models/beta/agents/environments/template_update_params.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#capability_directories ⇒ Array<String>?
Directories that expose capabilities to the agent.
-
#env ⇒ Hash{Symbol=>String}?
Replacement confidential environment values.
- #environment_template_id ⇒ String
-
#files ⇒ Array<OpenAI::Models::Beta::HostedEnvironmentFileParam::FileID, OpenAI::Models::Beta::HostedEnvironmentFileParam::Inline>?
Replacement file configuration materialized for each new session.
-
#name ⇒ String?
A replacement human-readable display name, or
nullto clear the name. -
#network ⇒ OpenAI::Models::Beta::Agents::Environments::TemplateUpdateParams::Network?
Network access for an OpenAI-hosted environment.
-
#packages ⇒ OpenAI::Models::Beta::Agents::Environments::TemplateUpdateParams::Packages?
Packages to install in an OpenAI-hosted environment.
-
#plugins ⇒ Array<OpenAI::Models::Beta::HostedPluginParam>?
Replacement plugin configuration installed for each new session.
-
#setup_commands ⇒ Array<OpenAI::Models::Beta::SetupCommandParam>?
Replacement confidential setup commands, never included in returned resources.
-
#skills ⇒ Array<OpenAI::Models::Beta::HostedSkillParam::SkillReference, OpenAI::Models::Beta::HostedSkillParam::Inline>?
Replacement skill configuration installed for each new session.
Attributes included from Internal::Type::RequestParameters
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
45 |
# File 'sig/openai/models/beta/agents/environments/template_update_params.rbs', line 45
def initialize: (
|
Instance Attribute Details
#capability_directories ⇒ Array<String>?
Directories that expose capabilities to the agent.
22 |
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 22 optional :capability_directories, OpenAI::Internal::Type::ArrayOf[String], nil?: true |
#env ⇒ Hash{Symbol=>String}?
Replacement confidential environment values.
28 |
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 28 optional :env, OpenAI::Internal::Type::HashOf[String], nil?: true |
#environment_template_id ⇒ String
16 |
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 16 required :environment_template_id, String |
#files ⇒ Array<OpenAI::Models::Beta::HostedEnvironmentFileParam::FileID, OpenAI::Models::Beta::HostedEnvironmentFileParam::Inline>?
Replacement file configuration materialized for each new session.
34 35 36 37 38 |
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 34 optional( :files, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::HostedEnvironmentFileParam] }, nil?: true ) |
#name ⇒ String?
A replacement human-readable display name, or null to clear the name.
44 |
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 44 optional :name, String, nil?: true |
#network ⇒ OpenAI::Models::Beta::Agents::Environments::TemplateUpdateParams::Network?
Network access for an OpenAI-hosted environment.
50 51 52 53 54 55 56 |
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 50 optional( :network, -> { OpenAI::Beta::Agents::Environments::TemplateUpdateParams::Network }, nil?: true ) |
#packages ⇒ OpenAI::Models::Beta::Agents::Environments::TemplateUpdateParams::Packages?
Packages to install in an OpenAI-hosted environment.
62 63 64 65 66 67 68 |
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 62 optional( :packages, -> { OpenAI::Beta::Agents::Environments::TemplateUpdateParams::Packages }, nil?: true ) |
#plugins ⇒ Array<OpenAI::Models::Beta::HostedPluginParam>?
Replacement plugin configuration installed for each new session.
74 75 76 77 78 79 80 |
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 74 optional( :plugins, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::HostedPluginParam] }, nil?: true ) |
#setup_commands ⇒ Array<OpenAI::Models::Beta::SetupCommandParam>?
Replacement confidential setup commands, never included in returned resources.
86 87 88 89 90 |
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 86 optional( :setup_commands, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::SetupCommandParam] }, nil?: true ) |
#skills ⇒ Array<OpenAI::Models::Beta::HostedSkillParam::SkillReference, OpenAI::Models::Beta::HostedSkillParam::Inline>?
Replacement skill configuration installed for each new session.
96 97 98 99 100 |
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 96 optional( :skills, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::HostedSkillParam] }, nil?: true ) |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/agents/environments/template_update_params.rb', line 171
|
Instance Method Details
#to_hash ⇒ {
59 |
# File 'sig/openai/models/beta/agents/environments/template_update_params.rbs', line 59
def to_hash: -> {
|