Class: OpenAI::Models::Beta::Agents::Sessions::SessionArtifact
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Agents::Sessions::SessionArtifact
- Defined in:
- lib/openai/models/beta/agents/sessions/session_artifact.rb,
sig/openai/models/beta/agents/sessions/session_artifact.rbs
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ Integer
The Unix timestamp, in seconds, when the artifact was published.
-
#environment_id ⇒ String
The ID of the environment that produced the artifact.
-
#id ⇒ String
The immutable artifact ID.
-
#object ⇒ Symbol, :"agent.session.artifact"
The object type.
-
#path ⇒ String
The original absolute file path in the execution environment.
-
#session_id ⇒ String
The ID of the session that owns the artifact.
-
#size_bytes ⇒ Integer
The immutable artifact size in bytes.
-
#turn_id ⇒ String
The ID of the completed turn that published the artifact.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
37 |
# File 'sig/openai/models/beta/agents/sessions/session_artifact.rbs', line 37
def initialize: (
|
Instance Attribute Details
#created_at ⇒ Integer
The Unix timestamp, in seconds, when the artifact was published.
20 |
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 20 required :created_at, Integer |
#environment_id ⇒ String
The ID of the environment that produced the artifact.
26 |
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 26 required :environment_id, String |
#id ⇒ String
The immutable artifact ID.
14 |
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 14 required :id, String |
#object ⇒ Symbol, :"agent.session.artifact"
The object type. Always agent.session.artifact.
32 |
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 32 required :object, const: :"agent.session.artifact" |
#path ⇒ String
The original absolute file path in the execution environment.
38 |
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 38 required :path, String |
#session_id ⇒ String
The ID of the session that owns the artifact.
44 |
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 44 required :session_id, String |
#size_bytes ⇒ Integer
The immutable artifact size in bytes.
50 |
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 50 required :size_bytes, Integer |
#turn_id ⇒ String
The ID of the completed turn that published the artifact.
56 |
# File 'lib/openai/models/beta/agents/sessions/session_artifact.rb', line 56 required :turn_id, String |
Instance Method Details
#to_hash ⇒ {
48 |
# File 'sig/openai/models/beta/agents/sessions/session_artifact.rbs', line 48
def to_hash: -> {
|