Class: OpenAI::Models::Beta::Agents::Vaults::Credential
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Agents::Vaults::Credential
- Defined in:
- lib/openai/models/beta/agents/vaults/credential.rb,
sig/openai/models/beta/agents/vaults/credential.rbs
Overview
Instance Attribute Summary collapse
-
#auth ⇒ OpenAI::Models::Beta::Agents::Vaults::CredentialAuth::McpOauth, OpenAI::Models::Beta::Agents::Vaults::CredentialAuth::StaticBearer
The authentication method and non-secret configuration for the MCP server.
-
#created_at ⇒ Integer
The Unix timestamp, in seconds, when the credential was created.
-
#id ⇒ String
The ID of the credential.
-
#name ⇒ String
The human-readable name of the credential.
-
#object ⇒ Symbol, :"vault.credential"
The object type.
-
#updated_at ⇒ Integer
The Unix timestamp, in seconds, when the credential was last updated.
-
#vault_id ⇒ String
The ID of the vault containing this credential.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(id:, auth:, created_at:, name:, updated_at:, vault_id:, object: :"vault.credential") ⇒ Object
constructor
Metadata for a stored MCP server credential.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, auth:, created_at:, name:, updated_at:, vault_id:, object: :"vault.credential") ⇒ Object
Metadata for a stored MCP server credential. Secret values are never returned.
|
|
# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 52
|
Instance Attribute Details
#auth ⇒ OpenAI::Models::Beta::Agents::Vaults::CredentialAuth::McpOauth, OpenAI::Models::Beta::Agents::Vaults::CredentialAuth::StaticBearer
The authentication method and non-secret configuration for the MCP server.
20 |
# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 20 required :auth, union: -> { OpenAI::Beta::Agents::Vaults::CredentialAuth } |
#created_at ⇒ Integer
The Unix timestamp, in seconds, when the credential was created.
26 |
# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 26 required :created_at, Integer |
#id ⇒ String
The ID of the credential.
14 |
# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 14 required :id, String |
#name ⇒ String
The human-readable name of the credential.
32 |
# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 32 required :name, String |
#object ⇒ Symbol, :"vault.credential"
The object type. Always vault.credential.
38 |
# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 38 required :object, const: :"vault.credential" |
#updated_at ⇒ Integer
The Unix timestamp, in seconds, when the credential was last updated.
44 |
# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 44 required :updated_at, Integer |
#vault_id ⇒ String
The ID of the vault containing this credential.
50 |
# File 'lib/openai/models/beta/agents/vaults/credential.rb', line 50 required :vault_id, String |
Instance Method Details
#to_hash ⇒ {
42 |
# File 'sig/openai/models/beta/agents/vaults/credential.rbs', line 42
def to_hash: -> {
|