Class: OpenAI::Models::Beta::Agents::Vaults::CredentialAuthRotateParam::EnvironmentVariable
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Agents::Vaults::CredentialAuthRotateParam::EnvironmentVariable
- Defined in:
- lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb,
sig/openai/models/beta/agents/vaults/credential_auth_rotate_param.rbs
Instance Attribute Summary collapse
-
#secret_value ⇒ String
The write-only replacement secret.
-
#type ⇒ :environment_variable
The type of the object.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(secret_value:, type: :environment_variable) ⇒ Object
|
|
# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 159
|
Instance Attribute Details
#secret_value ⇒ String
The write-only replacement secret. Never returned in credential resources or supplied directly to sandbox code. Must be nonempty and must not contain carriage returns, newlines, or NUL bytes.
151 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 151 required :secret_value, String |
#type ⇒ :environment_variable
The type of the object. Always environment_variable.
157 |
# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 157 required :type, const: :environment_variable |
Instance Method Details
#to_hash ⇒ {
145 |
# File 'sig/openai/models/beta/agents/vaults/credential_auth_rotate_param.rbs', line 145
def to_hash: -> {
|