Class: OpenAI::Models::Beta::Agents::Vaults::CredentialAuthRotateParam::McpOauth

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb,
sig/openai/models/beta/agents/vaults/credential_auth_rotate_param.rbs

Defined Under Namespace

Classes: Refresh

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(access_token: nil, expires_at: nil, refresh: nil, type: :mcp_oauth) ⇒ Object

Rotate an OAuth credential for an HTTPS MCP destination.

Parameters:

  • access_token (String, nil) (defaults to: nil)

    A write-only replacement OAuth access token.

  • expires_at (String, nil) (defaults to: nil)

    The replacement expiry as an RFC 3339 timestamp, or null to clear it. Omitting this field preserves the expiry unless a new access token is supplied, in which case the expiry is cleared.

  • refresh (OpenAI::Models::Beta::Agents::Vaults::CredentialAuthRotateParam::McpOauth::Refresh, nil) (defaults to: nil)

    Updates to an MCP credential's existing OAuth refresh configuration.

  • type (Symbol, :mcp_oauth) (defaults to: :mcp_oauth)

    The type of the object. Always mcp_oauth.



# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 52

Instance Attribute Details

#access_tokenString?

A write-only replacement OAuth access token.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


32
# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 32

optional :access_token, String, nil?: true

#expires_atString?

The replacement expiry as an RFC 3339 timestamp, or null to clear it. Omitting this field preserves the expiry unless a new access token is supplied, in which case the expiry is cleared.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


40
# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 40

optional :expires_at, String, nil?: true

#refreshOpenAI::Models::Beta::Agents::Vaults::CredentialAuthRotateParam::McpOauth::Refresh?

Updates to an MCP credential's existing OAuth refresh configuration.

Parameters:

  • value (OpenAI::Beta::Agents::Vaults::CredentialAuthRotateParam::McpOauth::Refresh, nil)

Returns:



46
47
48
49
50
# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 46

optional(
  :refresh,
  -> { OpenAI::Beta::Agents::Vaults::CredentialAuthRotateParam::McpOauth::Refresh },
  nil?: true
)

#typeSymbol, :mcp_oauth

The type of the object. Always mcp_oauth.

Parameters:

  • value (:mcp_oauth)

Returns:

  • (Symbol, :mcp_oauth)


26
# File 'lib/openai/models/beta/agents/vaults/credential_auth_rotate_param.rb', line 26

required :type, const: :mcp_oauth

Instance Method Details

#to_hash{

Returns:

  • ({)


37
# File 'sig/openai/models/beta/agents/vaults/credential_auth_rotate_param.rbs', line 37

def to_hash: -> {