Class: OpenAI::Models::Beta::AssistantUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/beta/assistant_update_params.rb,
sig/openai/models/beta/assistant_update_params.rbs

Overview

See Also:

  • OpenAI::Resources::Beta::Assistants#update

Defined Under Namespace

Modules: Model Classes: ToolResources

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(assistant_id:, description: nil, instructions: nil, metadata: nil, model: nil, name: nil, reasoning_effort: nil, response_format: nil, temperature: nil, tool_resources: nil, tools: nil, top_p: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Beta::AssistantUpdateParams for more details.

Parameters:



# File 'lib/openai/models/beta/assistant_update_params.rb', line 127

Instance Attribute Details

#assistant_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/openai/models/beta/assistant_update_params.rb', line 14

required :assistant_id, String

#descriptionString?

The description of the assistant. The maximum length is 512 characters.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


20
# File 'lib/openai/models/beta/assistant_update_params.rb', line 20

optional :description, String, nil?: true

#instructionsString?

The system instructions that the assistant uses. The maximum length is 256,000 characters.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


27
# File 'lib/openai/models/beta/assistant_update_params.rb', line 27

optional :instructions, String, nil?: true

#metadataHash{Symbol=>String}?

Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

Parameters:

  • value (OpenAI::Models::metadata, nil)

Returns:

  • (Hash{Symbol=>String}, nil)


38
# File 'lib/openai/models/beta/assistant_update_params.rb', line 38

optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true

#modelString, ...

ID of the model to use. You can use the List models API to see all of your available models, or see our Model overview for descriptions of them.

Returns:



48
# File 'lib/openai/models/beta/assistant_update_params.rb', line 48

optional :model, union: -> { OpenAI::Beta::AssistantUpdateParams::Model }

#nameString?

The name of the assistant. The maximum length is 256 characters.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


54
# File 'lib/openai/models/beta/assistant_update_params.rb', line 54

optional :name, String, nil?: true

#reasoning_effortSymbol, ...

Constrains effort on reasoning for reasoning models. Currently supported values are none, minimal, low, medium, high, xhigh, and max. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response. Not all reasoning models support every value. See the reasoning guide for model-specific support.

Parameters:

  • value (OpenAI::Models::reasoning_effort, nil)

Returns:



65
# File 'lib/openai/models/beta/assistant_update_params.rb', line 65

optional :reasoning_effort, enum: -> { OpenAI::ReasoningEffort }, nil?: true

#response_formatSymbol, ...

Specifies the format that the model must output. Compatible with GPT-4o, GPT-4 Turbo, and all GPT-3.5 Turbo models since gpt-3.5-turbo-1106.

Setting to { "type": "json_schema", "json_schema": {...} } enables Structured Outputs which ensures the model will match your supplied JSON schema. Learn more in the Structured Outputs guide.

Setting to { "type": "json_object" } enables JSON mode, which ensures the message the model generates is valid JSON.

Important: when using JSON mode, you must also instruct the model to produce JSON yourself via a system or user message. Without this, the model may generate an unending stream of whitespace until the generation reaches the token limit, resulting in a long-running and seemingly "stuck" request. Also note that the message content may be partially cut off if finish_reason="length", which indicates the generation exceeded max_tokens or the conversation exceeded the max context length.

Parameters:

  • value (OpenAI::Models::Beta::assistant_response_format_option, nil)

Returns:



90
# File 'lib/openai/models/beta/assistant_update_params.rb', line 90

optional :response_format, union: -> { OpenAI::Beta::AssistantResponseFormatOption }, nil?: true

#temperatureFloat?

What sampling temperature to use, between 0 and 2. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


98
# File 'lib/openai/models/beta/assistant_update_params.rb', line 98

optional :temperature, Float, nil?: true

#tool_resourcesOpenAI::Models::Beta::AssistantUpdateParams::ToolResources?

A set of resources that are used by the assistant's tools. The resources are specific to the type of tool. For example, the code_interpreter tool requires a list of file IDs, while the file_search tool requires a list of vector store IDs.

Parameters:

  • value (OpenAI::Beta::AssistantUpdateParams::ToolResources, nil)

Returns:



107
# File 'lib/openai/models/beta/assistant_update_params.rb', line 107

optional :tool_resources, -> { OpenAI::Beta::AssistantUpdateParams::ToolResources }, nil?: true

#toolsArray<OpenAI::Models::Beta::CodeInterpreterTool, OpenAI::Models::Beta::FileSearchTool, OpenAI::Models::Beta::FunctionTool>?

A list of tool enabled on the assistant. There can be a maximum of 128 tools per assistant. Tools can be of types code_interpreter, file_search, or function.



115
# File 'lib/openai/models/beta/assistant_update_params.rb', line 115

optional :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::AssistantTool] }

#top_pFloat?

An alternative to sampling with temperature, called nucleus sampling, where the model considers the results of the tokens with top_p probability mass. So 0.1 means only the tokens comprising the top 10% probability mass are considered.

We generally recommend altering this or temperature but not both.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


125
# File 'lib/openai/models/beta/assistant_update_params.rb', line 125

optional :top_p, Float, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


73
# File 'sig/openai/models/beta/assistant_update_params.rbs', line 73

def to_hash: -> {