Class: OpenAI::Models::Beta::BetaFileSearchTool::RankingOptions::HybridSearch
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaFileSearchTool::RankingOptions::HybridSearch
- Defined in:
- lib/openai/models/beta/beta_file_search_tool.rb,
sig/openai/models/beta/beta_file_search_tool.rbs
Overview
Instance Attribute Summary collapse
-
#embedding_weight ⇒ Float
The weight of the embedding in the reciprocal ranking fusion.
-
#text_weight ⇒ Float
The weight of the text in the reciprocal ranking fusion.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
276 |
# File 'sig/openai/models/beta/beta_file_search_tool.rbs', line 276
def initialize: (
|
Instance Attribute Details
#embedding_weight ⇒ Float
The weight of the embedding in the reciprocal ranking fusion.
389 |
# File 'lib/openai/models/beta/beta_file_search_tool.rb', line 389 required :embedding_weight, Float |
#text_weight ⇒ Float
The weight of the text in the reciprocal ranking fusion.
395 |
# File 'lib/openai/models/beta/beta_file_search_tool.rb', line 395 required :text_weight, Float |
Instance Method Details
#to_hash ⇒ { embedding_weight: Float, text_weight: Float }
281 |
# File 'sig/openai/models/beta/beta_file_search_tool.rbs', line 281
def to_hash: -> { embedding_weight: Float, text_weight: Float }
|