Class: OpenAI::Models::Beta::BetaNamespaceTool::Tool::Function
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaNamespaceTool::Tool::Function
- Defined in:
- lib/openai/models/beta/beta_namespace_tool.rb,
sig/openai/models/beta/beta_namespace_tool.rbs
Defined Under Namespace
Modules: AllowedCaller
Instance Attribute Summary collapse
-
#allowed_callers ⇒ Array<Symbol, OpenAI::Models::Beta::BetaNamespaceTool::Tool::Function::AllowedCaller>?
The tool invocation context(s).
-
#defer_loading ⇒ Boolean?
Whether this function should be deferred and discovered via tool search.
- #description ⇒ String?
- #name ⇒ String
-
#output_schema ⇒ Hash{Symbol=>Object}?
A JSON Schema describing the JSON value encoded in string outputs for this function tool.
- #parameters ⇒ Object?
-
#strict ⇒ Boolean?
Whether to enforce strict parameter validation.
- #type ⇒ Symbol, :function
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
75 |
# File 'sig/openai/models/beta/beta_namespace_tool.rbs', line 75
def initialize: (
|
Instance Attribute Details
#allowed_callers ⇒ Array<Symbol, OpenAI::Models::Beta::BetaNamespaceTool::Tool::Function::AllowedCaller>?
The tool invocation context(s).
68 69 70 71 72 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 68 optional :allowed_callers, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Beta::BetaNamespaceTool::Tool::Function::AllowedCaller] }, nil?: true |
#defer_loading ⇒ Boolean?
Whether this function should be deferred and discovered via tool search.
78 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 78 optional :defer_loading, OpenAI::Internal::Type::Boolean |
#description ⇒ String?
83 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 83 optional :description, String, nil?: true |
#name ⇒ String
57 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 57 required :name, String |
#output_schema ⇒ Hash{Symbol=>Object}?
A JSON Schema describing the JSON value encoded in string outputs for this function tool. This does not describe content-array outputs.
90 91 92 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 90 optional :output_schema, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Unknown], nil?: true |
#parameters ⇒ Object?
97 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 97 optional :parameters, OpenAI::Internal::Type::Unknown, nil?: true |
#strict ⇒ Boolean?
Whether to enforce strict parameter validation. If omitted, Responses attempts to use strict validation when the schema is compatible, and falls back to non-strict validation otherwise.
105 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 105 optional :strict, OpenAI::Internal::Type::Boolean, nil?: true |
#type ⇒ Symbol, :function
62 |
# File 'lib/openai/models/beta/beta_namespace_tool.rb', line 62 required :type, const: :function |
Instance Method Details
#to_hash ⇒ {
86 |
# File 'sig/openai/models/beta/beta_namespace_tool.rbs', line 86
def to_hash: -> {
|