Class: OpenAI::Models::Beta::BetaResponse::Moderation::Input::ModerationResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponse::Moderation::Input::ModerationResult
- Defined in:
- lib/openai/models/beta/beta_response.rb,
sig/openai/models/beta/beta_response.rbs
Defined Under Namespace
Modules: CategoryAppliedInputType
Instance Attribute Summary collapse
-
#categories ⇒ Hash{Symbol=>Boolean}
A dictionary of moderation categories to booleans, True if the input is flagged under this category.
-
#category_applied_input_types ⇒ Hash{Symbol=>Array<Symbol, OpenAI::Models::Beta::BetaResponse::Moderation::Input::ModerationResult::CategoryAppliedInputType>}
Which modalities of input are reflected by the score for each category.
-
#category_scores ⇒ Hash{Symbol=>Float}
A dictionary of moderation categories to scores.
-
#flagged ⇒ Boolean
A boolean indicating whether the content was flagged by any category.
-
#model ⇒ String
The moderation model that produced this result.
-
#type ⇒ Symbol, :moderation_result
The object type, which was always
moderation_resultfor successful moderation results.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
545 |
# File 'sig/openai/models/beta/beta_response.rbs', line 545
def initialize: (
|
Instance Attribute Details
#categories ⇒ Hash{Symbol=>Boolean}
A dictionary of moderation categories to booleans, True if the input is flagged under this category.
904 |
# File 'lib/openai/models/beta/beta_response.rb', line 904 required :categories, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Boolean] |
#category_applied_input_types ⇒ Hash{Symbol=>Array<Symbol, OpenAI::Models::Beta::BetaResponse::Moderation::Input::ModerationResult::CategoryAppliedInputType>}
Which modalities of input are reflected by the score for each category.
910 911 912 913 914 915 |
# File 'lib/openai/models/beta/beta_response.rb', line 910 required :category_applied_input_types, -> do OpenAI::Internal::Type::HashOf[ OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Beta::BetaResponse::Moderation::Input::ModerationResult::CategoryAppliedInputType] ] end |
#category_scores ⇒ Hash{Symbol=>Float}
A dictionary of moderation categories to scores.
921 |
# File 'lib/openai/models/beta/beta_response.rb', line 921 required :category_scores, OpenAI::Internal::Type::HashOf[Float] |
#flagged ⇒ Boolean
A boolean indicating whether the content was flagged by any category.
927 |
# File 'lib/openai/models/beta/beta_response.rb', line 927 required :flagged, OpenAI::Internal::Type::Boolean |
#model ⇒ String
The moderation model that produced this result.
933 |
# File 'lib/openai/models/beta/beta_response.rb', line 933 required :model, String |
#type ⇒ Symbol, :moderation_result
The object type, which was always moderation_result for successful moderation
results.
940 |
# File 'lib/openai/models/beta/beta_response.rb', line 940 required :type, const: :moderation_result |
Instance Method Details
#to_hash ⇒ {
554 |
# File 'sig/openai/models/beta/beta_response.rbs', line 554
def to_hash: -> {
|