Class: OpenAI::Models::Beta::BetaResponse::PromptCacheDiagnostics::CacheMiss
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponse::PromptCacheDiagnostics::CacheMiss
- Defined in:
- lib/openai/models/beta/beta_response.rb,
sig/openai/models/beta/beta_response.rbs
Defined Under Namespace
Modules: Reason
Instance Attribute Summary collapse
-
#cache_missed_tokens ⇒ Integer
The estimated number of input tokens affected after the first detected divergence.
-
#comparison_reusable_tokens ⇒ Integer?
The raw token count of the reusable prefix in the compared response.
-
#reason ⇒ Symbol, OpenAI::Models::Beta::BetaResponse::PromptCacheDiagnostics::CacheMiss::Reason
The reason prompt cache reuse did not occur.
- #type ⇒ Symbol, :cache_miss
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(cache_missed_tokens:, reason:, comparison_reusable_tokens: nil, type: :cache_miss) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cache_missed_tokens:, reason:, comparison_reusable_tokens: nil, type: :cache_miss) ⇒ Object
|
|
# File 'lib/openai/models/beta/beta_response.rb', line 1392
|
Instance Attribute Details
#cache_missed_tokens ⇒ Integer
The estimated number of input tokens affected after the first detected divergence.
1373 |
# File 'lib/openai/models/beta/beta_response.rb', line 1373 required :cache_missed_tokens, Integer |
#comparison_reusable_tokens ⇒ Integer?
The raw token count of the reusable prefix in the compared response.
1390 |
# File 'lib/openai/models/beta/beta_response.rb', line 1390 optional :comparison_reusable_tokens, Integer |
#reason ⇒ Symbol, OpenAI::Models::Beta::BetaResponse::PromptCacheDiagnostics::CacheMiss::Reason
The reason prompt cache reuse did not occur.
1379 |
# File 'lib/openai/models/beta/beta_response.rb', line 1379 required :reason, enum: -> { OpenAI::Beta::BetaResponse::PromptCacheDiagnostics::CacheMiss::Reason } |
#type ⇒ Symbol, :cache_miss
1384 |
# File 'lib/openai/models/beta/beta_response.rb', line 1384 required :type, const: :cache_miss |
Instance Method Details
#to_hash ⇒ {
733 |
# File 'sig/openai/models/beta/beta_response.rbs', line 733
def to_hash: -> {
|