Class: OpenAI::Models::Beta::BetaResponseApplyPatchToolCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_apply_patch_tool_call.rb,
sig/openai/models/beta/beta_response_apply_patch_tool_call.rbs

Defined Under Namespace

Modules: Caller, Operation, Status Classes: Agent

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_name:) ⇒ Object

The agent that produced this item.

Parameters:

  • agent_name (String)

    The canonical name of the agent that produced this item.



# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 60

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Agent?

The agent that produced this item.



43
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 43

optional :agent, -> { OpenAI::Beta::BetaResponseApplyPatchToolCall::Agent }

#call_idString

The unique ID of the apply patch tool call generated by the model.

Parameters:

  • value (String)

Returns:

  • (String)


18
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 18

required :call_id, String

#caller_OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Caller::Direct, ...

The execution context that produced this tool call.

Parameters:

  • value (OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::caller_, nil)

Returns:



49
50
51
52
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 49

optional :caller_,
union: -> { OpenAI::Beta::BetaResponseApplyPatchToolCall::Caller },
api_name: :caller,
nil?: true

#created_byString?

The ID of the entity that created this tool call.

Parameters:

  • (String)

Returns:

  • (String, nil)


58
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 58

optional :created_by, String

#idString

The unique ID of the apply patch tool call. Populated when this item is returned via API.

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 12

required :id, String

#operationOpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Operation::CreateFile, ...

One of the create_file, delete_file, or update_file operations applied via apply_patch.



25
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 25

required :operation, union: -> { OpenAI::Beta::BetaResponseApplyPatchToolCall::Operation }

#statusSymbol, OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Status

The status of the apply patch tool call. One of in_progress or completed.

Parameters:

  • value (OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::status)

Returns:



31
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 31

required :status, enum: -> { OpenAI::Beta::BetaResponseApplyPatchToolCall::Status }

#typeSymbol, :apply_patch_call

The type of the item. Always apply_patch_call.

Parameters:

  • value (:apply_patch_call)

Returns:

  • (Symbol, :apply_patch_call)


37
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 37

required :type, const: :apply_patch_call

Instance Method Details

#to_hash{

Returns:

  • ({)


52
# File 'sig/openai/models/beta/beta_response_apply_patch_tool_call.rbs', line 52

def to_hash: -> {