Class: OpenAI::Models::Beta::BetaResponseApplyPatchToolCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseApplyPatchToolCall
- Defined in:
- lib/openai/models/beta/beta_response_apply_patch_tool_call.rb,
sig/openai/models/beta/beta_response_apply_patch_tool_call.rbs
Defined Under Namespace
Modules: Caller, Operation, Status Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Caller::Direct, ...
The execution context that produced this tool call.
-
#created_by ⇒ String?
The ID of the entity that created this tool call.
-
#id ⇒ String
The unique ID of the apply patch tool call.
-
#operation ⇒ OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Operation::CreateFile, ...
One of the create_file, delete_file, or update_file operations applied via apply_patch.
-
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Status
The status of the apply patch tool call.
-
#type ⇒ Symbol, :apply_patch_call
The type of the item.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Operation::CreateFile, OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Operation::DeleteFile, OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Operation::UpdateFile)
Instance Method Summary collapse
-
#initialize(agent_name:) ⇒ Object
constructor
The agent that produced this item.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_name:) ⇒ Object
The agent that produced this item.
|
|
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 60
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Agent?
The agent that produced this item.
43 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 43 optional :agent, -> { OpenAI::Beta::BetaResponseApplyPatchToolCall::Agent } |
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
18 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 18 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Caller::Direct, ...
The execution context that produced this tool call.
49 50 51 52 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 49 optional :caller_, union: -> { OpenAI::Beta::BetaResponseApplyPatchToolCall::Caller }, api_name: :caller, nil?: true |
#created_by ⇒ String?
The ID of the entity that created this tool call.
58 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 58 optional :created_by, String |
#id ⇒ String
The unique ID of the apply patch tool call. Populated when this item is returned via API.
12 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 12 required :id, String |
#operation ⇒ OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Operation::CreateFile, ...
One of the create_file, delete_file, or update_file operations applied via apply_patch.
25 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 25 required :operation, union: -> { OpenAI::Beta::BetaResponseApplyPatchToolCall::Operation } |
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Status
The status of the apply patch tool call. One of in_progress or completed.
31 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 31 required :status, enum: -> { OpenAI::Beta::BetaResponseApplyPatchToolCall::Status } |
#type ⇒ Symbol, :apply_patch_call
The type of the item. Always apply_patch_call.
37 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 37 required :type, const: :apply_patch_call |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 192
|
.variants ⇒ Array(OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Operation::CreateFile, OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Operation::DeleteFile, OpenAI::Models::Beta::BetaResponseApplyPatchToolCall::Operation::UpdateFile)
|
|
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call.rb', line 179
|
Instance Method Details
#to_hash ⇒ {
52 |
# File 'sig/openai/models/beta/beta_response_apply_patch_tool_call.rbs', line 52
def to_hash: -> {
|