Class: OpenAI::Models::Beta::BetaResponseApplyPatchToolCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseApplyPatchToolCallOutput
- Defined in:
- lib/openai/models/beta/beta_response_apply_patch_tool_call_output.rb,
sig/openai/models/beta/beta_response_apply_patch_tool_call_output.rbs
Defined Under Namespace
Modules: Caller, Status Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseApplyPatchToolCallOutput::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseApplyPatchToolCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
-
#created_by ⇒ String?
The ID of the entity that created this tool call output.
-
#id ⇒ String
The unique ID of the apply patch tool call output.
-
#output ⇒ String?
Optional textual output returned by the apply patch tool.
-
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseApplyPatchToolCallOutput::Status
The status of the apply patch tool call output.
-
#type ⇒ Symbol, :apply_patch_call_output
The type of the item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(agent_name:) ⇒ Object
constructor
The agent that produced this item.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_name:) ⇒ Object
The agent that produced this item.
|
|
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call_output.rb', line 59
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseApplyPatchToolCallOutput::Agent?
The agent that produced this item.
36 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call_output.rb', line 36 optional :agent, -> { OpenAI::Beta::BetaResponseApplyPatchToolCallOutput::Agent } |
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
18 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call_output.rb', line 18 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseApplyPatchToolCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
42 43 44 45 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call_output.rb', line 42 optional :caller_, union: -> { OpenAI::Beta::BetaResponseApplyPatchToolCallOutput::Caller }, api_name: :caller, nil?: true |
#created_by ⇒ String?
The ID of the entity that created this tool call output.
51 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call_output.rb', line 51 optional :created_by, String |
#id ⇒ String
The unique ID of the apply patch tool call output. Populated when this item is returned via API.
12 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call_output.rb', line 12 required :id, String |
#output ⇒ String?
Optional textual output returned by the apply patch tool.
57 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call_output.rb', line 57 optional :output, String, nil?: true |
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseApplyPatchToolCallOutput::Status
The status of the apply patch tool call output. One of completed or failed.
24 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call_output.rb', line 24 required :status, enum: -> { OpenAI::Beta::BetaResponseApplyPatchToolCallOutput::Status } |
#type ⇒ Symbol, :apply_patch_call_output
The type of the item. Always apply_patch_call_output.
30 |
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call_output.rb', line 30 required :type, const: :apply_patch_call_output |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_response_apply_patch_tool_call_output.rb', line 90
|
Instance Method Details
#to_hash ⇒ {
52 |
# File 'sig/openai/models/beta/beta_response_apply_patch_tool_call_output.rbs', line 52
def to_hash: -> {
|