Class: OpenAI::Models::Beta::BetaResponseComputerToolCallOutputItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseComputerToolCallOutputItem
- Defined in:
- lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb,
sig/openai/models/beta/beta_response_computer_tool_call_output_item.rbs
Defined Under Namespace
Modules: Status Classes: AcknowledgedSafetyCheck, Agent
Instance Attribute Summary collapse
-
#acknowledged_safety_checks ⇒ Array<OpenAI::Models::Beta::BetaResponseComputerToolCallOutputItem::AcknowledgedSafetyCheck>?
The safety checks reported by the API that have been acknowledged by the developer.
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseComputerToolCallOutputItem::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The ID of the computer tool call that produced the output.
-
#created_by ⇒ String?
The identifier of the actor that created the item.
-
#id ⇒ String
The unique ID of the computer call tool output.
-
#output ⇒ OpenAI::Models::Beta::BetaResponseComputerToolCallOutputScreenshot
A computer screenshot image used with the computer use tool.
-
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseComputerToolCallOutputItem::Status
The status of the message input.
-
#type ⇒ Symbol, :computer_call_output
The type of the computer tool call output.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, code: nil, message: nil) ⇒ Object
constructor
A pending safety check for the computer call.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, code: nil, message: nil) ⇒ Object
A pending safety check for the computer call.
|
|
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 58
|
Instance Attribute Details
#acknowledged_safety_checks ⇒ Array<OpenAI::Models::Beta::BetaResponseComputerToolCallOutputItem::AcknowledgedSafetyCheck>?
The safety checks reported by the API that have been acknowledged by the developer.
43 44 |
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 43 optional :acknowledged_safety_checks, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::BetaResponseComputerToolCallOutputItem::AcknowledgedSafetyCheck] } |
#agent ⇒ OpenAI::Models::Beta::BetaResponseComputerToolCallOutputItem::Agent?
The agent that produced this item.
50 |
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 50 optional :agent, -> { OpenAI::Beta::BetaResponseComputerToolCallOutputItem::Agent }, nil?: true |
#call_id ⇒ String
The ID of the computer tool call that produced the output.
17 |
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 17 required :call_id, String |
#created_by ⇒ String?
The identifier of the actor that created the item.
56 |
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 56 optional :created_by, String |
#id ⇒ String
The unique ID of the computer call tool output.
11 |
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 11 required :id, String |
#output ⇒ OpenAI::Models::Beta::BetaResponseComputerToolCallOutputScreenshot
A computer screenshot image used with the computer use tool.
23 |
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 23 required :output, -> { OpenAI::Beta::BetaResponseComputerToolCallOutputScreenshot } |
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseComputerToolCallOutputItem::Status
The status of the message input. One of in_progress, completed, or
incomplete. Populated when input items are returned via API.
30 |
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 30 required :status, enum: -> { OpenAI::Beta::BetaResponseComputerToolCallOutputItem::Status } |
#type ⇒ Symbol, :computer_call_output
The type of the computer tool call output. Always computer_call_output.
36 |
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 36 required :type, const: :computer_call_output |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_response_computer_tool_call_output_item.rb', line 90
|
Instance Method Details
#to_hash ⇒ {
52 |
# File 'sig/openai/models/beta/beta_response_computer_tool_call_output_item.rbs', line 52
def to_hash: -> {
|