Class: OpenAI::Models::Beta::BetaResponseCustomToolCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseCustomToolCall
- Defined in:
- lib/openai/models/beta/beta_response_custom_tool_call.rb,
sig/openai/models/beta/beta_response_custom_tool_call.rbs
Direct Known Subclasses
Defined Under Namespace
Modules: Caller Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseCustomToolCall::Agent?
The agent that produced this item.
-
#call_id ⇒ String
An identifier used to map this custom tool call to a tool call output.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseCustomToolCall::Caller::Direct, ...
The execution context that produced this tool call.
-
#id ⇒ String?
The unique ID of the custom tool call in the OpenAI platform.
-
#input ⇒ String
The input for the custom tool call generated by the model.
-
#name ⇒ String
The name of the custom tool being called.
-
#namespace ⇒ String?
The namespace of the custom tool being called.
-
#type ⇒ Symbol, :custom_tool_call
The type of the custom tool call.
Instance Method Summary collapse
-
#initialize(agent_name:) ⇒ Object
constructor
The agent that produced this item.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_name:) ⇒ Object
The agent that produced this item.
|
|
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 58
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseCustomToolCall::Agent?
The agent that produced this item.
41 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 41 optional :agent, -> { OpenAI::Beta::BetaResponseCustomToolCall::Agent }, nil?: true |
#call_id ⇒ String
An identifier used to map this custom tool call to a tool call output.
11 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 11 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseCustomToolCall::Caller::Direct, ...
The execution context that produced this tool call.
47 48 49 50 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 47 optional :caller_, union: -> { OpenAI::Beta::BetaResponseCustomToolCall::Caller }, api_name: :caller, nil?: true |
#id ⇒ String?
The unique ID of the custom tool call in the OpenAI platform.
35 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 35 optional :id, String |
#input ⇒ String
The input for the custom tool call generated by the model.
17 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 17 required :input, String |
#name ⇒ String
The name of the custom tool being called.
23 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 23 required :name, String |
#namespace ⇒ String?
The namespace of the custom tool being called.
56 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 56 optional :namespace, String |
#type ⇒ Symbol, :custom_tool_call
The type of the custom tool call. Always custom_tool_call.
29 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call.rb', line 29 required :type, const: :custom_tool_call |
Instance Method Details
#to_hash ⇒ {
50 |
# File 'sig/openai/models/beta/beta_response_custom_tool_call.rbs', line 50
def to_hash: -> {
|