Class: OpenAI::Models::Beta::BetaResponseCustomToolCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseCustomToolCallOutput
- Defined in:
- lib/openai/models/beta/beta_response_custom_tool_call_output.rb,
sig/openai/models/beta/beta_response_custom_tool_call_output.rbs
Direct Known Subclasses
Defined Under Namespace
Modules: Caller, Output Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseCustomToolCallOutput::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The call ID, used to map this custom tool call output to a custom tool call.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseCustomToolCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
-
#id ⇒ String?
The unique ID of the custom tool call output in the OpenAI platform.
-
#output ⇒ String, Array<OpenAI::Models::Beta::BetaResponseInputText, OpenAI::Models::Beta::BetaResponseInputImage, OpenAI::Models::Beta::BetaResponseInputFile>
The output from the custom tool call generated by your code.
-
#type ⇒ Symbol, :custom_tool_call_output
The type of the custom tool call output.
Instance Method Summary collapse
-
#initialize(agent_name:) ⇒ Object
constructor
The agent that produced this item.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_name:) ⇒ Object
The agent that produced this item.
|
|
# File 'lib/openai/models/beta/beta_response_custom_tool_call_output.rb', line 47
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseCustomToolCallOutput::Agent?
The agent that produced this item.
36 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call_output.rb', line 36 optional :agent, -> { OpenAI::Beta::BetaResponseCustomToolCallOutput::Agent }, nil?: true |
#call_id ⇒ String
The call ID, used to map this custom tool call output to a custom tool call.
11 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call_output.rb', line 11 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseCustomToolCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
42 43 44 45 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call_output.rb', line 42 optional :caller_, union: -> { OpenAI::Beta::BetaResponseCustomToolCallOutput::Caller }, api_name: :caller, nil?: true |
#id ⇒ String?
The unique ID of the custom tool call output in the OpenAI platform.
30 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call_output.rb', line 30 optional :id, String |
#output ⇒ String, Array<OpenAI::Models::Beta::BetaResponseInputText, OpenAI::Models::Beta::BetaResponseInputImage, OpenAI::Models::Beta::BetaResponseInputFile>
The output from the custom tool call generated by your code. Can be a string or an list of output content.
18 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call_output.rb', line 18 required :output, union: -> { OpenAI::Beta::BetaResponseCustomToolCallOutput::Output } |
#type ⇒ Symbol, :custom_tool_call_output
The type of the custom tool call output. Always custom_tool_call_output.
24 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call_output.rb', line 24 required :type, const: :custom_tool_call_output |
Instance Method Details
#to_hash ⇒ {
40 |
# File 'sig/openai/models/beta/beta_response_custom_tool_call_output.rbs', line 40
def to_hash: -> {
|