Class: OpenAI::Models::Beta::BetaResponseCustomToolCallOutputItem
- Inherits:
-
BetaResponseCustomToolCallOutput
- Object
- Internal::Type::BaseModel
- BetaResponseCustomToolCallOutput
- OpenAI::Models::Beta::BetaResponseCustomToolCallOutputItem
- Defined in:
- lib/openai/models/beta/beta_response_custom_tool_call_output_item.rb,
sig/openai/models/beta/beta_response_custom_tool_call_output_item.rbs
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#created_by ⇒ String?
The identifier of the actor that created the item.
-
#id ⇒ String
The unique ID of the custom tool call output item.
-
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseCustomToolCallOutputItem::Status
The status of the item.
Attributes inherited from BetaResponseCustomToolCallOutput
#agent, #call_id, #caller_, #output, #type
Instance Method Summary collapse
-
#initialize(id:, status:, created_by: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaResponseCustomToolCallOutputItem for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, status:, created_by: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Beta::BetaResponseCustomToolCallOutputItem for more details.
The output of a custom tool call from your code, being sent back to the model.
|
|
# File 'lib/openai/models/beta/beta_response_custom_tool_call_output_item.rb', line 26
|
Instance Attribute Details
#created_by ⇒ String?
The identifier of the actor that created the item.
24 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call_output_item.rb', line 24 optional :created_by, String |
#id ⇒ String
The unique ID of the custom tool call output item.
11 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call_output_item.rb', line 11 required :id, String |
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseCustomToolCallOutputItem::Status
The status of the item. One of in_progress, completed, or incomplete.
Populated when items are returned via API.
18 |
# File 'lib/openai/models/beta/beta_response_custom_tool_call_output_item.rb', line 18 required :status, enum: -> { OpenAI::Beta::BetaResponseCustomToolCallOutputItem::Status } |
Instance Method Details
#to_hash ⇒ {
34 |
# File 'sig/openai/models/beta/beta_response_custom_tool_call_output_item.rbs', line 34
def to_hash: -> {
|