Class: OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput
- Defined in:
- lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb,
sig/openai/models/beta/beta_response_function_shell_tool_call_output.rbs
Defined Under Namespace
Modules: Caller, Status Classes: Agent, Output
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
-
#created_by ⇒ String?
The identifier of the actor that created the item.
-
#id ⇒ String
The unique ID of the shell call output.
-
#max_output_length ⇒ Integer?
The maximum length of the shell command output.
-
#output ⇒ Array<OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Output>
An array of shell call output contents.
-
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Status
The status of the shell call output.
-
#type ⇒ Symbol, :shell_call_output
The type of the shell call output.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Output::Outcome::Timeout, OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Output::Outcome::Exit)
Instance Method Summary collapse
-
#initialize(agent_name:) ⇒ Object
constructor
The agent that produced this item.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_name:) ⇒ Object
The agent that produced this item.
|
|
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 175
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Agent?
The agent that produced this item.
51 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 51 optional :agent, -> { OpenAI::Beta::BetaResponseFunctionShellToolCallOutput::Agent } |
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
18 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 18 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
57 58 59 60 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 57 optional :caller_, union: -> { OpenAI::Beta::BetaResponseFunctionShellToolCallOutput::Caller }, api_name: :caller, nil?: true |
#created_by ⇒ String?
The identifier of the actor that created the item.
66 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 66 optional :created_by, String |
#id ⇒ String
The unique ID of the shell call output. Populated when this item is returned via API.
12 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 12 required :id, String |
#max_output_length ⇒ Integer?
The maximum length of the shell command output. This is generated by the model and should be passed back with the raw output.
25 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 25 required :max_output_length, Integer, nil?: true |
#output ⇒ Array<OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Output>
An array of shell call output contents
31 32 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 31 required :output, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::BetaResponseFunctionShellToolCallOutput::Output] } |
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Status
The status of the shell call output. One of in_progress, completed, or
incomplete.
39 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 39 required :status, enum: -> { OpenAI::Beta::BetaResponseFunctionShellToolCallOutput::Status } |
#type ⇒ Symbol, :shell_call_output
The type of the shell call output. Always shell_call_output.
45 |
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 45 required :type, const: :shell_call_output |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 199
|
.variants ⇒ Array(OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Output::Outcome::Timeout, OpenAI::Models::Beta::BetaResponseFunctionShellToolCallOutput::Output::Outcome::Exit)
|
|
# File 'lib/openai/models/beta/beta_response_function_shell_tool_call_output.rb', line 183
|
Instance Method Details
#to_hash ⇒ {
56 |
# File 'sig/openai/models/beta/beta_response_function_shell_tool_call_output.rbs', line 56
def to_hash: -> {
|