Class: OpenAI::Models::Beta::BetaResponseFunctionToolCallOutputItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseFunctionToolCallOutputItem
- Defined in:
- lib/openai/models/beta/beta_response_function_tool_call_output_item.rb,
sig/openai/models/beta/beta_response_function_tool_call_output_item.rbs
Defined Under Namespace
Modules: Caller, Output, Status Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseFunctionToolCallOutputItem::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The unique ID of the function tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseFunctionToolCallOutputItem::Caller::Direct, ...
The execution context that produced this tool call.
-
#created_by ⇒ String?
The identifier of the actor that created the item.
-
#id ⇒ String
The unique ID of the function call tool output.
-
#output ⇒ String, Array<OpenAI::Models::Beta::BetaResponseInputText, OpenAI::Models::Beta::BetaResponseInputImage, OpenAI::Models::Beta::BetaResponseInputFile>
The output from the function call generated by your code.
-
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseFunctionToolCallOutputItem::Status
The status of the item.
-
#type ⇒ Symbol, :function_call_output
The type of the function tool call output.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(agent_name:) ⇒ Object
constructor
The agent that produced this item.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_name:) ⇒ Object
The agent that produced this item.
|
|
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 60
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseFunctionToolCallOutputItem::Agent?
The agent that produced this item.
43 |
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 43 optional :agent, -> { OpenAI::Beta::BetaResponseFunctionToolCallOutputItem::Agent }, nil?: true |
#call_id ⇒ String
The unique ID of the function tool call generated by the model.
17 |
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 17 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseFunctionToolCallOutputItem::Caller::Direct, ...
The execution context that produced this tool call.
49 50 51 52 |
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 49 optional :caller_, union: -> { OpenAI::Beta::BetaResponseFunctionToolCallOutputItem::Caller }, api_name: :caller, nil?: true |
#created_by ⇒ String?
The identifier of the actor that created the item.
58 |
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 58 optional :created_by, String |
#id ⇒ String
The unique ID of the function call tool output.
11 |
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 11 required :id, String |
#output ⇒ String, Array<OpenAI::Models::Beta::BetaResponseInputText, OpenAI::Models::Beta::BetaResponseInputImage, OpenAI::Models::Beta::BetaResponseInputFile>
The output from the function call generated by your code. Can be a string or an list of output content.
24 |
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 24 required :output, union: -> { OpenAI::Beta::BetaResponseFunctionToolCallOutputItem::Output } |
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseFunctionToolCallOutputItem::Status
The status of the item. One of in_progress, completed, or incomplete.
Populated when items are returned via API.
31 |
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 31 required :status, enum: -> { OpenAI::Beta::BetaResponseFunctionToolCallOutputItem::Status } |
#type ⇒ Symbol, :function_call_output
The type of the function tool call output. Always function_call_output.
37 |
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 37 required :type, const: :function_call_output |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_response_function_tool_call_output_item.rb', line 133
|
Instance Method Details
#to_hash ⇒ {
48 |
# File 'sig/openai/models/beta/beta_response_function_tool_call_output_item.rbs', line 48
def to_hash: -> {
|