Module: OpenAI::Models::Beta::BetaResponseInputItem
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/beta/beta_response_input_item.rb
Overview
A message input to the model with a role indicating instruction following
hierarchy. Instructions given with the developer or system role take
precedence over instructions given with the user role. Messages with the
assistant role are presumed to have been generated by the model in previous
interactions.
Defined Under Namespace
Classes: AdditionalTools, AgentMessage, ApplyPatchCall, ApplyPatchCallOutput, CompactionTrigger, ComputerCallOutput, FunctionCallOutput, ImageGenerationCall, ItemReference, LocalShellCall, LocalShellCallOutput, McpApprovalRequest, McpApprovalResponse, McpCall, McpListTools, Message, MultiAgentCall, MultiAgentCallOutput, Program, ProgramOutput, ShellCall, ShellCallOutput, ToolSearchCall
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Caller::Direct, OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Caller::Program)
Instance Method Summary collapse
-
#initialize(agent_name:) ⇒ Object
The agent that produced this item.
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 229
|
.variants ⇒ Array(OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Caller::Direct, OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Caller::Program)
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2055
|
Instance Method Details
#initialize(agent_name:) ⇒ Object
The agent that produced this item.
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 635
|