Class: OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_input_item.rb

Defined Under Namespace

Modules: Caller, Operation, Status Classes: Agent

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_name:) ⇒ Object

The agent that produced this item.

Parameters:

  • agent_name (String)

    The canonical name of the agent that produced this item.



# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1848

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Agent?

The agent that produced this item.



1837
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1837

optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCall::Agent }, nil?: true

#call_idString

The unique ID of the apply patch tool call generated by the model.

Returns:

  • (String)


1805
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1805

required :call_id, String

#caller_OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Caller::Direct, ...

The execution context that produced this tool call.



1843
1844
1845
1846
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1843

optional :caller_,
union: -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCall::Caller },
api_name: :caller,
nil?: true

#idString?

The unique ID of the apply patch tool call. Populated when this item is returned via API.

Returns:

  • (String, nil)


1831
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1831

optional :id, String, nil?: true

#operationOpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Operation::CreateFile, ...

The specific create, delete, or update instruction for the apply_patch tool call.



1812
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1812

required :operation, union: -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCall::Operation }

#statusSymbol, OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Status

The status of the apply patch tool call. One of in_progress or completed.



1818
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1818

required :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCall::Status }

#typeSymbol, :apply_patch_call

The type of the item. Always apply_patch_call.

Returns:

  • (Symbol, :apply_patch_call)


1824
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1824

required :type, const: :apply_patch_call