Class: OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall
- Defined in:
- lib/openai/models/beta/beta_response_input_item.rb
Defined Under Namespace
Modules: Caller, Operation, Status Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Caller::Direct, ...
The execution context that produced this tool call.
-
#id ⇒ String?
The unique ID of the apply patch tool call.
-
#operation ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Operation::CreateFile, ...
The specific create, delete, or update instruction for the apply_patch tool call.
-
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Status
The status of the apply patch tool call.
-
#type ⇒ Symbol, :apply_patch_call
The type of the item.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Operation::CreateFile, OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Operation::DeleteFile, OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Operation::UpdateFile)
Instance Method Summary collapse
-
#initialize(agent_name:) ⇒ Object
constructor
The agent that produced this item.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_name:) ⇒ Object
The agent that produced this item.
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1864
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Agent?
The agent that produced this item.
1853 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1853 optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCall::Agent }, nil?: true |
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
1821 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1821 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Caller::Direct, ...
The execution context that produced this tool call.
1859 1860 1861 1862 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1859 optional :caller_, union: -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCall::Caller }, api_name: :caller, nil?: true |
#id ⇒ String?
The unique ID of the apply patch tool call. Populated when this item is returned via API.
1847 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1847 optional :id, String, nil?: true |
#operation ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Operation::CreateFile, ...
The specific create, delete, or update instruction for the apply_patch tool call.
1828 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1828 required :operation, union: -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCall::Operation } |
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Status
The status of the apply patch tool call. One of in_progress or completed.
1834 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1834 required :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCall::Status } |
#type ⇒ Symbol, :apply_patch_call
The type of the item. Always apply_patch_call.
1840 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1840 required :type, const: :apply_patch_call |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1995
|
.variants ⇒ Array(OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Operation::CreateFile, OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Operation::DeleteFile, OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::Operation::UpdateFile)
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1982
|