Class: OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput
- Defined in:
- lib/openai/models/beta/beta_response_input_item.rb
Defined Under Namespace
Modules: Caller, Status Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
-
#id ⇒ String?
The unique ID of the apply patch tool call output.
-
#output ⇒ String?
Optional human-readable log text from the apply patch tool (e.g., patch results or errors).
-
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Status
The status of the apply patch tool call output.
-
#type ⇒ Symbol, :apply_patch_call_output
The type of the item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(agent_name:) ⇒ Object
constructor
The agent that produced this item.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_name:) ⇒ Object
The agent that produced this item.
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2108
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Agent?
The agent that produced this item.
2090 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2090 optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Agent }, nil?: true |
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
2065 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2065 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
2096 2097 2098 2099 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2096 optional :caller_, union: -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Caller }, api_name: :caller, nil?: true |
#id ⇒ String?
The unique ID of the apply patch tool call output. Populated when this item is returned via API.
2084 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2084 optional :id, String, nil?: true |
#output ⇒ String?
Optional human-readable log text from the apply patch tool (e.g., patch results or errors).
2106 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2106 optional :output, String, nil?: true |
#status ⇒ Symbol, OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Status
The status of the apply patch tool call output. One of completed or failed.
2071 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2071 required :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::ApplyPatchCallOutput::Status } |
#type ⇒ Symbol, :apply_patch_call_output
The type of the item. Always apply_patch_call_output.
2077 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2077 required :type, const: :apply_patch_call_output |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 2138
|