Class: OpenAI::Models::Beta::BetaResponseInputItem::ComputerCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseInputItem::ComputerCallOutput
- Defined in:
- lib/openai/models/beta/beta_response_input_item.rb
Defined Under Namespace
Modules: Status Classes: AcknowledgedSafetyCheck, Agent
Instance Attribute Summary collapse
-
#acknowledged_safety_checks ⇒ Array<OpenAI::Models::Beta::BetaResponseInputItem::ComputerCallOutput::AcknowledgedSafetyCheck>?
The safety checks reported by the API that have been acknowledged by the developer.
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ComputerCallOutput::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The ID of the computer tool call that produced the output.
-
#id ⇒ String?
The ID of the computer tool call output.
-
#output ⇒ OpenAI::Models::Beta::BetaResponseComputerToolCallOutputScreenshot
A computer screenshot image used with the computer use tool.
-
#status ⇒ Symbol, ...
The status of the message input.
-
#type ⇒ Symbol, :computer_call_output
The type of the computer tool call output.
Instance Method Summary collapse
-
#initialize(agent_name:) ⇒ Object
constructor
The agent that produced this item.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_name:) ⇒ Object
The agent that produced this item.
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 327
|
Instance Attribute Details
#acknowledged_safety_checks ⇒ Array<OpenAI::Models::Beta::BetaResponseInputItem::ComputerCallOutput::AcknowledgedSafetyCheck>?
The safety checks reported by the API that have been acknowledged by the developer.
264 265 266 267 268 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 264 optional :acknowledged_safety_checks, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::BetaResponseInputItem::ComputerCallOutput::AcknowledgedSafetyCheck] }, nil?: true |
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ComputerCallOutput::Agent?
The agent that produced this item.
274 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 274 optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ComputerCallOutput::Agent }, nil?: true |
#call_id ⇒ String
The ID of the computer tool call that produced the output.
239 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 239 required :call_id, String |
#id ⇒ String?
The ID of the computer tool call output.
257 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 257 optional :id, String, nil?: true |
#output ⇒ OpenAI::Models::Beta::BetaResponseComputerToolCallOutputScreenshot
A computer screenshot image used with the computer use tool.
245 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 245 required :output, -> { OpenAI::Beta::BetaResponseComputerToolCallOutputScreenshot } |
#status ⇒ Symbol, ...
The status of the message input. One of in_progress, completed, or
incomplete. Populated when input items are returned via API.
281 282 283 284 285 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 281 optional :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::ComputerCallOutput::Status }, nil?: true |
#type ⇒ Symbol, :computer_call_output
The type of the computer tool call output. Always computer_call_output.
251 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 251 required :type, const: :computer_call_output |