Class: OpenAI::Models::Beta::BetaResponseInputItem::FunctionCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_input_item.rb

Defined Under Namespace

Modules: Caller, Output, Status Classes: Agent

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(caller_id:, type: :program) ⇒ Object

Parameters:

  • caller_id (String)

    The call ID of the program item that produced this tool call.

  • type (Symbol, :program) (defaults to: :program)

    The caller type. Always program.



# File 'lib/openai/models/beta/beta_response_input_item.rb', line 419

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseInputItem::FunctionCallOutput::Agent?

The agent that produced this item.



397
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 397

optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::FunctionCallOutput::Agent }, nil?: true

#call_idString

The unique ID of the function tool call generated by the model.

Returns:

  • (String)


372
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 372

required :call_id, String

#caller_OpenAI::Models::Beta::BetaResponseInputItem::FunctionCallOutput::Caller::Direct, ...

The execution context that produced this tool call.



403
404
405
406
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 403

optional :caller_,
union: -> { OpenAI::Beta::BetaResponseInputItem::FunctionCallOutput::Caller },
api_name: :caller,
nil?: true

#idString?

The unique ID of the function tool call output. Populated when this item is returned via API.

Returns:

  • (String, nil)


391
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 391

optional :id, String, nil?: true

#outputString, Array<OpenAI::Models::Beta::BetaResponseInputTextContent, OpenAI::Models::Beta::BetaResponseInputImageContent, OpenAI::Models::Beta::BetaResponseInputFileContent>

Text, image, or file output of the function tool call.



378
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 378

required :output, union: -> { OpenAI::Beta::BetaResponseInputItem::FunctionCallOutput::Output }

#statusSymbol, ...

The status of the item. One of in_progress, completed, or incomplete. Populated when items are returned via API.



413
414
415
416
417
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 413

optional :status,
enum: -> {
  OpenAI::Beta::BetaResponseInputItem::FunctionCallOutput::Status
},
nil?: true

#typeSymbol, :function_call_output

The type of the function tool call output. Always function_call_output.

Returns:

  • (Symbol, :function_call_output)


384
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 384

required :type, const: :function_call_output