Class: OpenAI::Models::Beta::BetaResponseInputItem::FunctionCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseInputItem::FunctionCallOutput
- Defined in:
- lib/openai/models/beta/beta_response_input_item.rb
Defined Under Namespace
Modules: Caller, Output, Status Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::FunctionCallOutput::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The unique ID of the function tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseInputItem::FunctionCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
-
#id ⇒ String?
The unique ID of the function tool call output.
-
#output ⇒ String, Array<OpenAI::Models::Beta::BetaResponseInputTextContent, OpenAI::Models::Beta::BetaResponseInputImageContent, OpenAI::Models::Beta::BetaResponseInputFileContent>
Text, image, or file output of the function tool call.
-
#status ⇒ Symbol, ...
The status of the item.
-
#type ⇒ Symbol, :function_call_output
The type of the function tool call output.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(caller_id:, type: :program) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caller_id:, type: :program) ⇒ Object
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 419
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::FunctionCallOutput::Agent?
The agent that produced this item.
397 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 397 optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::FunctionCallOutput::Agent }, nil?: true |
#call_id ⇒ String
The unique ID of the function tool call generated by the model.
372 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 372 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseInputItem::FunctionCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
403 404 405 406 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 403 optional :caller_, union: -> { OpenAI::Beta::BetaResponseInputItem::FunctionCallOutput::Caller }, api_name: :caller, nil?: true |
#id ⇒ String?
The unique ID of the function tool call output. Populated when this item is returned via API.
391 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 391 optional :id, String, nil?: true |
#output ⇒ String, Array<OpenAI::Models::Beta::BetaResponseInputTextContent, OpenAI::Models::Beta::BetaResponseInputImageContent, OpenAI::Models::Beta::BetaResponseInputFileContent>
Text, image, or file output of the function tool call.
378 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 378 required :output, union: -> { OpenAI::Beta::BetaResponseInputItem::FunctionCallOutput::Output } |
#status ⇒ Symbol, ...
The status of the item. One of in_progress, completed, or incomplete.
Populated when items are returned via API.
413 414 415 416 417 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 413 optional :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::FunctionCallOutput::Status }, nil?: true |
#type ⇒ Symbol, :function_call_output
The type of the function tool call output. Always function_call_output.
384 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 384 required :type, const: :function_call_output |
Class Method Details
.variants ⇒ Array(OpenAI::Models::Beta::BetaResponseInputItem::FunctionCallOutput::Caller::Direct, OpenAI::Models::Beta::BetaResponseInputItem::FunctionCallOutput::Caller::Program)
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 452
|