Class: OpenAI::Models::Beta::BetaResponseInputItem::ShellCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseInputItem::ShellCall
- Defined in:
- lib/openai/models/beta/beta_response_input_item.rb
Defined Under Namespace
Modules: Caller, Environment, Status Classes: Action, Agent
Instance Attribute Summary collapse
-
#action ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCall::Action
The shell commands and limits that describe how to run the tool call.
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCall::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCall::Caller::Direct, ...
The execution context that produced this tool call.
-
#environment ⇒ OpenAI::Models::Beta::BetaLocalEnvironment, ...
The environment to execute the shell commands in.
-
#id ⇒ String?
The unique ID of the shell tool call.
-
#status ⇒ Symbol, ...
The status of the shell call.
-
#type ⇒ Symbol, :shell_call
The type of the item.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(caller_id:, type: :program) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caller_id:, type: :program) ⇒ Object
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1548
|
Instance Attribute Details
#action ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCall::Action
The shell commands and limits that describe how to run the tool call.
1493 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1493 required :action, -> { OpenAI::Beta::BetaResponseInputItem::ShellCall::Action } |
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCall::Agent?
The agent that produced this item.
1518 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1518 optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ShellCall::Agent }, nil?: true |
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
1499 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1499 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCall::Caller::Direct, ...
The execution context that produced this tool call.
1524 1525 1526 1527 1528 1529 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1524 optional( :caller_, union: -> { OpenAI::Beta::BetaResponseInputItem::ShellCall::Caller }, api_name: :caller, nil?: true ) |
#environment ⇒ OpenAI::Models::Beta::BetaLocalEnvironment, ...
The environment to execute the shell commands in.
1535 1536 1537 1538 1539 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1535 optional( :environment, union: -> { OpenAI::Beta::BetaResponseInputItem::ShellCall::Environment }, nil?: true ) |
#id ⇒ String?
The unique ID of the shell tool call. Populated when this item is returned via API.
1512 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1512 optional :id, String, nil?: true |
#status ⇒ Symbol, ...
The status of the shell call. One of in_progress, completed, or
incomplete.
1546 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1546 optional :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::ShellCall::Status }, nil?: true |
#type ⇒ Symbol, :shell_call
The type of the item. Always shell_call.
1505 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1505 required :type, const: :shell_call |
Class Method Details
.variants ⇒ Array(OpenAI::Models::Beta::BetaLocalEnvironment, OpenAI::Models::Beta::BetaContainerReference)
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1661
|