Class: OpenAI::Models::Beta::BetaResponseInputItem::ShellCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_input_item.rb

Defined Under Namespace

Modules: Caller, Environment, Status Classes: Action, Agent

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(caller_id:, type: :program) ⇒ Object

Parameters:

  • caller_id (String)

    The call ID of the program item that produced this tool call.

  • type (Symbol, :program) (defaults to: :program)

    The caller type. Always program.



# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1494

Instance Attribute Details

#actionOpenAI::Models::Beta::BetaResponseInputItem::ShellCall::Action

The shell commands and limits that describe how to run the tool call.



1443
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1443

required :action, -> { OpenAI::Beta::BetaResponseInputItem::ShellCall::Action }

#agentOpenAI::Models::Beta::BetaResponseInputItem::ShellCall::Agent?

The agent that produced this item.



1468
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1468

optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ShellCall::Agent }, nil?: true

#call_idString

The unique ID of the shell tool call generated by the model.

Returns:

  • (String)


1449
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1449

required :call_id, String

#caller_OpenAI::Models::Beta::BetaResponseInputItem::ShellCall::Caller::Direct, ...

The execution context that produced this tool call.



1474
1475
1476
1477
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1474

optional :caller_,
union: -> { OpenAI::Beta::BetaResponseInputItem::ShellCall::Caller },
api_name: :caller,
nil?: true

#environmentOpenAI::Models::Beta::BetaLocalEnvironment, ...

The environment to execute the shell commands in.



1483
1484
1485
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1483

optional :environment,
union: -> { OpenAI::Beta::BetaResponseInputItem::ShellCall::Environment },
nil?: true

#idString?

The unique ID of the shell tool call. Populated when this item is returned via API.

Returns:

  • (String, nil)


1462
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1462

optional :id, String, nil?: true

#statusSymbol, ...

The status of the shell call. One of in_progress, completed, or incomplete.



1492
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1492

optional :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::ShellCall::Status }, nil?: true

#typeSymbol, :shell_call

The type of the item. Always shell_call.

Returns:

  • (Symbol, :shell_call)


1455
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1455

required :type, const: :shell_call

Class Method Details

.variantsArray(OpenAI::Models::Beta::BetaLocalEnvironment, OpenAI::Models::Beta::BetaContainerReference)



# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1607