Class: OpenAI::Models::Beta::BetaResponseInputItem::ShellCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseInputItem::ShellCall
- Defined in:
- lib/openai/models/beta/beta_response_input_item.rb
Defined Under Namespace
Modules: Caller, Environment, Status Classes: Action, Agent
Instance Attribute Summary collapse
-
#action ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCall::Action
The shell commands and limits that describe how to run the tool call.
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCall::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCall::Caller::Direct, ...
The execution context that produced this tool call.
-
#environment ⇒ OpenAI::Models::Beta::BetaLocalEnvironment, ...
The environment to execute the shell commands in.
-
#id ⇒ String?
The unique ID of the shell tool call.
-
#status ⇒ Symbol, ...
The status of the shell call.
-
#type ⇒ Symbol, :shell_call
The type of the item.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(caller_id:, type: :program) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caller_id:, type: :program) ⇒ Object
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1494
|
Instance Attribute Details
#action ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCall::Action
The shell commands and limits that describe how to run the tool call.
1443 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1443 required :action, -> { OpenAI::Beta::BetaResponseInputItem::ShellCall::Action } |
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCall::Agent?
The agent that produced this item.
1468 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1468 optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ShellCall::Agent }, nil?: true |
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
1449 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1449 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCall::Caller::Direct, ...
The execution context that produced this tool call.
1474 1475 1476 1477 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1474 optional :caller_, union: -> { OpenAI::Beta::BetaResponseInputItem::ShellCall::Caller }, api_name: :caller, nil?: true |
#environment ⇒ OpenAI::Models::Beta::BetaLocalEnvironment, ...
The environment to execute the shell commands in.
1483 1484 1485 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1483 optional :environment, union: -> { OpenAI::Beta::BetaResponseInputItem::ShellCall::Environment }, nil?: true |
#id ⇒ String?
The unique ID of the shell tool call. Populated when this item is returned via API.
1462 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1462 optional :id, String, nil?: true |
#status ⇒ Symbol, ...
The status of the shell call. One of in_progress, completed, or
incomplete.
1492 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1492 optional :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::ShellCall::Status }, nil?: true |
#type ⇒ Symbol, :shell_call
The type of the item. Always shell_call.
1455 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1455 required :type, const: :shell_call |
Class Method Details
.variants ⇒ Array(OpenAI::Models::Beta::BetaLocalEnvironment, OpenAI::Models::Beta::BetaContainerReference)
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1607
|