Class: OpenAI::Models::Beta::BetaResponseInputItem::ShellCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_input_item.rb

Defined Under Namespace

Modules: Caller, Status Classes: Agent

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(caller_id:, type: :program) ⇒ Object

Parameters:

  • caller_id (String)

    The call ID of the program item that produced this tool call.

  • type (Symbol, :program) (defaults to: :program)

    The caller type. Always program.



# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1719

Instance Attribute Details

#agentOpenAI::Models::Beta::BetaResponseInputItem::ShellCallOutput::Agent?

The agent that produced this item.



1691
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1691

optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ShellCallOutput::Agent }, nil?: true

#call_idString

The unique ID of the shell tool call generated by the model.

Returns:

  • (String)


1664
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1664

required :call_id, String

#caller_OpenAI::Models::Beta::BetaResponseInputItem::ShellCallOutput::Caller::Direct, ...

The execution context that produced this tool call.



1697
1698
1699
1700
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1697

optional :caller_,
union: -> { OpenAI::Beta::BetaResponseInputItem::ShellCallOutput::Caller },
api_name: :caller,
nil?: true

#idString?

The unique ID of the shell tool call output. Populated when this item is returned via API.

Returns:

  • (String, nil)


1685
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1685

optional :id, String, nil?: true

#max_output_lengthInteger?

The maximum number of UTF-8 characters captured for this shell call's combined output.

Returns:

  • (Integer, nil)


1707
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1707

optional :max_output_length, Integer, nil?: true

#outputArray<OpenAI::Models::Beta::BetaResponseFunctionShellCallOutputContent>

Captured chunks of stdout and stderr output, along with their associated outcomes.



1671
1672
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1671

required :output,
-> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::BetaResponseFunctionShellCallOutputContent] }

#statusSymbol, ...

The status of the shell call output.



1713
1714
1715
1716
1717
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1713

optional :status,
enum: -> {
  OpenAI::Beta::BetaResponseInputItem::ShellCallOutput::Status
},
nil?: true

#typeSymbol, :shell_call_output

The type of the item. Always shell_call_output.

Returns:

  • (Symbol, :shell_call_output)


1678
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1678

required :type, const: :shell_call_output