Class: OpenAI::Models::Beta::BetaResponseInputItem::ShellCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseInputItem::ShellCallOutput
- Defined in:
- lib/openai/models/beta/beta_response_input_item.rb
Defined Under Namespace
Modules: Caller, Status Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCallOutput::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
-
#id ⇒ String?
The unique ID of the shell tool call output.
-
#max_output_length ⇒ Integer?
The maximum number of UTF-8 characters captured for this shell call's combined output.
-
#output ⇒ Array<OpenAI::Models::Beta::BetaResponseFunctionShellCallOutputContent>
Captured chunks of stdout and stderr output, along with their associated outcomes.
-
#status ⇒ Symbol, ...
The status of the shell call output.
-
#type ⇒ Symbol, :shell_call_output
The type of the item.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(caller_id:, type: :program) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caller_id:, type: :program) ⇒ Object
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1719
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCallOutput::Agent?
The agent that produced this item.
1691 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1691 optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ShellCallOutput::Agent }, nil?: true |
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
1664 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1664 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ShellCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
1697 1698 1699 1700 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1697 optional :caller_, union: -> { OpenAI::Beta::BetaResponseInputItem::ShellCallOutput::Caller }, api_name: :caller, nil?: true |
#id ⇒ String?
The unique ID of the shell tool call output. Populated when this item is returned via API.
1685 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1685 optional :id, String, nil?: true |
#max_output_length ⇒ Integer?
The maximum number of UTF-8 characters captured for this shell call's combined output.
1707 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1707 optional :max_output_length, Integer, nil?: true |
#output ⇒ Array<OpenAI::Models::Beta::BetaResponseFunctionShellCallOutputContent>
Captured chunks of stdout and stderr output, along with their associated outcomes.
1671 1672 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1671 required :output, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::BetaResponseFunctionShellCallOutputContent] } |
#status ⇒ Symbol, ...
The status of the shell call output.
1713 1714 1715 1716 1717 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1713 optional :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::ShellCallOutput::Status }, nil?: true |
#type ⇒ Symbol, :shell_call_output
The type of the item. Always shell_call_output.
1678 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1678 required :type, const: :shell_call_output |
Class Method Details
.variants ⇒ Array(OpenAI::Models::Beta::BetaResponseInputItem::ShellCallOutput::Caller::Direct, OpenAI::Models::Beta::BetaResponseInputItem::ShellCallOutput::Caller::Program)
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1797
|