Class: OpenAI::Models::Beta::BetaResponseInputItem::ToolSearchCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseInputItem::ToolSearchCall
- Defined in:
- lib/openai/models/beta/beta_response_input_item.rb
Defined Under Namespace
Modules: Execution, Status Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ToolSearchCall::Agent?
The agent that produced this item.
-
#arguments ⇒ Object
The arguments supplied to the tool search call.
-
#call_id ⇒ String?
The unique ID of the tool search call generated by the model.
-
#execution ⇒ Symbol, ...
Whether tool search was executed by the server or by the client.
-
#id ⇒ String?
The unique ID of this tool search call.
-
#status ⇒ Symbol, ...
The status of the tool search call.
-
#type ⇒ Symbol, :tool_search_call
The item type.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(agent_name:) ⇒ Object
constructor
The agent that produced this item.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_name:) ⇒ Object
The agent that produced this item.
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1045
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ToolSearchCall::Agent?
The agent that produced this item.
1021 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1021 optional :agent, -> { OpenAI::Beta::BetaResponseInputItem::ToolSearchCall::Agent }, nil?: true |
#arguments ⇒ Object
The arguments supplied to the tool search call.
1003 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1003 required :arguments, OpenAI::Internal::Type::Unknown |
#call_id ⇒ String?
The unique ID of the tool search call generated by the model.
1027 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1027 optional :call_id, String, nil?: true |
#execution ⇒ Symbol, ...
Whether tool search was executed by the server or by the client.
1033 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1033 optional :execution, enum: -> { OpenAI::Beta::BetaResponseInputItem::ToolSearchCall::Execution } |
#id ⇒ String?
The unique ID of this tool search call.
1015 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1015 optional :id, String, nil?: true |
#status ⇒ Symbol, ...
The status of the tool search call.
1039 1040 1041 1042 1043 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1039 optional :status, enum: -> { OpenAI::Beta::BetaResponseInputItem::ToolSearchCall::Status }, nil?: true |
#type ⇒ Symbol, :tool_search_call
The item type. Always tool_search_call.
1009 |
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1009 required :type, const: :tool_search_call |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_response_input_item.rb', line 1083
|