Class: OpenAI::Models::Beta::BetaResponseOutputAudio
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseOutputAudio
- Defined in:
- lib/openai/models/beta/beta_response_output_audio.rb,
sig/openai/models/beta/beta_response_output_audio.rbs
Instance Attribute Summary collapse
-
#data ⇒ String
Base64-encoded audio data from the model.
-
#transcript ⇒ String
The transcript of the audio data from the model.
-
#type ⇒ Symbol, :output_audio
The type of the output audio.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
16 |
# File 'sig/openai/models/beta/beta_response_output_audio.rbs', line 16
def initialize: (
|
Instance Attribute Details
#data ⇒ String
Base64-encoded audio data from the model.
11 |
# File 'lib/openai/models/beta/beta_response_output_audio.rb', line 11 required :data, String |
#transcript ⇒ String
The transcript of the audio data from the model.
17 |
# File 'lib/openai/models/beta/beta_response_output_audio.rb', line 17 required :transcript, String |
#type ⇒ Symbol, :output_audio
The type of the output audio. Always output_audio.
23 |
# File 'lib/openai/models/beta/beta_response_output_audio.rb', line 23 required :type, const: :output_audio |
Instance Method Details
#to_hash ⇒ {
22 |
# File 'sig/openai/models/beta/beta_response_output_audio.rbs', line 22
def to_hash: -> {
|