Class: OpenAI::Models::Beta::BetaResponseOutputText::Annotation::ContainerFileCitation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/beta_response_output_text.rb,
sig/openai/models/beta/beta_response_output_text.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



142
# File 'sig/openai/models/beta/beta_response_output_text.rbs', line 142

def initialize: (

Instance Attribute Details

#container_idString

The ID of the container file.

Parameters:

  • value (String)

Returns:

  • (String)


148
# File 'lib/openai/models/beta/beta_response_output_text.rb', line 148

required :container_id, String

#end_indexInteger

The index of the last character of the container file citation in the message.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


154
# File 'lib/openai/models/beta/beta_response_output_text.rb', line 154

required :end_index, Integer

#file_idString

The ID of the file.

Parameters:

  • value (String)

Returns:

  • (String)


160
# File 'lib/openai/models/beta/beta_response_output_text.rb', line 160

required :file_id, String

#filenameString

The filename of the container file cited.

Parameters:

  • value (String)

Returns:

  • (String)


166
# File 'lib/openai/models/beta/beta_response_output_text.rb', line 166

required :filename, String

#start_indexInteger

The index of the first character of the container file citation in the message.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


172
# File 'lib/openai/models/beta/beta_response_output_text.rb', line 172

required :start_index, Integer

#typeSymbol, :container_file_citation

The type of the container file citation. Always container_file_citation.

Parameters:

  • value (:container_file_citation)

Returns:

  • (Symbol, :container_file_citation)


178
# File 'lib/openai/models/beta/beta_response_output_text.rb', line 178

required :type, const: :container_file_citation

Instance Method Details

#to_hash{

Returns:

  • ({)


151
# File 'sig/openai/models/beta/beta_response_output_text.rbs', line 151

def to_hash: -> {