Module: OpenAI::Models::Beta::BetaResponseSteerErrorCode
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/beta/beta_response_steer_error_code.rb
Overview
A machine-readable steering error code. Clients should handle unknown values because additional codes may be introduced. Known values include:
response_not_found: The target response is not available on this connection.invalid_input: The event or input failed validation.steering_not_supported: The model or response execution mode does not support steering.too_many_pending_steers: Too much steering input is pending for the response.response_already_completed: The response completed and is no longer accepting steering input.response_not_active: The response is no longer accepting steering input.successor_creation_failed: The successor response could not be created.
collapse
- RESPONSE_NOT_FOUND =
:response_not_found- INVALID_INPUT =
:invalid_input- STEERING_NOT_SUPPORTED =
:steering_not_supported- TOO_MANY_PENDING_STEERS =
:too_many_pending_steers- RESPONSE_ALREADY_COMPLETED =
:response_already_completed- RESPONSE_NOT_ACTIVE =
:response_not_active- SUCCESSOR_CREATION_FAILED =
:successor_creation_failed
Class Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Symbol, String)
41 42 43 |
# File 'lib/openai/models/beta/beta_response_steer_error_code.rb', line 41 define_sorbet_constant!(:Variants) do T.type_alias { T.any(OpenAI::Beta::BetaResponseSteerErrorCode::TaggedSymbol, String) } end |