Module: OpenAI::Models::Beta::BetaResponseSteerInput
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/beta/beta_response_steer_input.rb
Overview
Input to queue for a continuation of the response. Uses the same string or
input-item shape as response.create.input, with a non-empty array when
supplying input items.
Steering accepts only messages with the user role. Each message may contain
only type, role, and content, with content as a string or an array of
input_text, input_image, and input_file parts. The optional type must be
message. Other roles, tool outputs, and item types are not supported for
steering.
Defined Under Namespace
Modules: ResponseSteerInputItemList
Constant Summary collapse
- ResponseSteerInputItemListArray =
OpenAI::Internal::Type::ArrayOf[ union: -> { OpenAI::Beta::BetaResponseSteerInput::ResponseSteerInputItemList } ]
Class Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_response_steer_input.rb', line 355
|
.variants ⇒ Array(String, Array<Hash{Symbol=>Object}>)
|
|
# File 'lib/openai/models/beta/beta_response_steer_input.rb', line 360
|