Class: OpenAI::Models::Beta::BetaResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput
- Defined in:
- lib/openai/models/beta/beta_response_steer_input.rb
Defined Under Namespace
Modules: Caller, Output, Status Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Models::Beta::BetaResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Agent?
The agent that produced this item.
-
#call_id ⇒ String?
The unique ID of the function tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
-
#id ⇒ String?
The unique ID of the function tool call output.
-
#name ⇒ String?
The name of the tool that produced the output.
-
#namespace ⇒ String?
The namespace of the tool that produced the output.
-
#output ⇒ String, Array<OpenAI::Models::Beta::BetaResponseInputTextContent, OpenAI::Models::Beta::BetaResponseInputImageContent, OpenAI::Models::Beta::BetaResponseInputFileContent>
Text, image, or file output of the function tool call.
-
#status ⇒ Symbol, ...
The status of the item.
-
#type ⇒ Symbol, :function_call_output
The type of the function tool call output.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(caller_id:, type: :program) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caller_id:, type: :program) ⇒ Object
|
|
# File 'lib/openai/models/beta/beta_response_steer_input.rb', line 222
|
Instance Attribute Details
#agent ⇒ OpenAI::Models::Beta::BetaResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Agent?
The agent that produced this item.
170 171 172 173 174 175 176 |
# File 'lib/openai/models/beta/beta_response_steer_input.rb', line 170 optional( :agent, -> { OpenAI::Beta::BetaResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Agent }, nil?: true ) |
#call_id ⇒ String?
The unique ID of the function tool call generated by the model.
182 |
# File 'lib/openai/models/beta/beta_response_steer_input.rb', line 182 optional :call_id, String, nil?: true |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
188 189 190 191 192 193 194 195 |
# File 'lib/openai/models/beta/beta_response_steer_input.rb', line 188 optional( :caller_, union: -> { OpenAI::Beta::BetaResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Caller }, api_name: :caller, nil?: true ) |
#id ⇒ String?
The unique ID of the function tool call output. Populated when this item is returned via API.
164 |
# File 'lib/openai/models/beta/beta_response_steer_input.rb', line 164 optional :id, String, nil?: true |
#name ⇒ String?
The name of the tool that produced the output.
201 |
# File 'lib/openai/models/beta/beta_response_steer_input.rb', line 201 optional :name, String, nil?: true |
#namespace ⇒ String?
The namespace of the tool that produced the output.
207 |
# File 'lib/openai/models/beta/beta_response_steer_input.rb', line 207 optional :namespace, String, nil?: true |
#output ⇒ String, Array<OpenAI::Models::Beta::BetaResponseInputTextContent, OpenAI::Models::Beta::BetaResponseInputImageContent, OpenAI::Models::Beta::BetaResponseInputFileContent>
Text, image, or file output of the function tool call.
146 147 148 149 150 151 |
# File 'lib/openai/models/beta/beta_response_steer_input.rb', line 146 required( :output, union: -> { OpenAI::Beta::BetaResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Output } ) |
#status ⇒ Symbol, ...
The status of the item. One of in_progress, completed, or incomplete.
Populated when items are returned via API.
214 215 216 217 218 219 220 |
# File 'lib/openai/models/beta/beta_response_steer_input.rb', line 214 optional( :status, enum: -> { OpenAI::Beta::BetaResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Status }, nil?: true ) |
#type ⇒ Symbol, :function_call_output
The type of the function tool call output. Always function_call_output.
157 |
# File 'lib/openai/models/beta/beta_response_steer_input.rb', line 157 required :type, const: :function_call_output |
Class Method Details
.variants ⇒ Array(OpenAI::Models::Beta::BetaResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Caller::Direct, OpenAI::Models::Beta::BetaResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Caller::Program)
|
|
# File 'lib/openai/models/beta/beta_response_steer_input.rb', line 266
|