Module: OpenAI::Models::Beta::BetaResponseSteerRequiredInput
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/beta/beta_response_steer_required_input.rb
Overview
An input stub identifying an outstanding client-owned tool result or approval
decision. Copy the stub and fill the result fields using the corresponding
response.create input schema. Use saved results without rerunning the tool.
The server does not supply results, approval decisions, or safety
acknowledgements in these stubs.
Defined Under Namespace
Classes: ApplyPatchCallOutput, ComputerCallOutput, CustomToolCallOutput, FunctionCallOutput, McpApprovalResponse, ShellCallOutput, ToolSearchOutput
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(call_id:, type: :apply_patch_call_output) ⇒ Object
Supply
statusand optionaloutputusing the apply patch tool call output input schema.
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_response_steer_required_input.rb', line 183
|
Instance Method Details
#initialize(call_id:, type: :apply_patch_call_output) ⇒ Object
Supply status and optional output using the apply patch tool call output
input schema.
|
|
# File 'lib/openai/models/beta/beta_response_steer_required_input.rb', line 66
|