Class: OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy
- Defined in:
- lib/openai/models/beta/beta_responses_client_event.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#input ⇒ OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy::Input?
The moderation policy for the response input.
-
#output ⇒ OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy::Output?
The moderation policy for the response output.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(input: nil, output: nil) ⇒ Object
constructor
The policy to apply to moderated response input and output.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(input: nil, output: nil) ⇒ Object
The policy to apply to moderated response input and output.
|
|
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 906
|
Instance Attribute Details
#input ⇒ OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy::Input?
The moderation policy for the response input.
890 891 892 893 894 |
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 890 optional :input, -> { OpenAI::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy::Input }, nil?: true |
#output ⇒ OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy::Output?
The moderation policy for the response output.
900 901 902 903 904 |
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 900 optional :output, -> { OpenAI::Beta::BetaResponsesClientEvent::ResponseCreate::Moderation::Policy::Output }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 933
|