Module: OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::PromptCacheOptions::Mode
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/beta/beta_responses_client_event.rb
Overview
Controls whether OpenAI automatically creates an implicit cache breakpoint.
Defaults to implicit. With implicit, OpenAI creates one implicit breakpoint
and writes up to the latest three explicit breakpoints in the request. With
explicit, OpenAI does not create an implicit breakpoint and writes up to the
latest four explicit breakpoints. If there are no explicit breakpoints, the
request does not use prompt caching.
Constant Summary collapse
- IMPLICIT =
:implicit- EXPLICIT =
:explicit
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info