Class: OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Reasoning
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Reasoning
- Defined in:
- lib/openai/models/beta/beta_responses_client_event.rb
Overview
Defined Under Namespace
Modules: Context, Effort, GenerateSummary, Mode, Summary
Instance Attribute Summary collapse
-
#context ⇒ Symbol, ...
Controls which reasoning items are rendered back to the model on later turns.
-
#effort ⇒ Symbol, ...
Constrains effort on reasoning for reasoning models.
- #generate_summary ⇒ Symbol, ... deprecated Deprecated.
-
#mode ⇒ String, ...
Controls the reasoning execution mode for the request.
-
#summary ⇒ Symbol, ...
A summary of the reasoning performed by the model.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(context: nil, effort: nil, generate_summary: nil, mode: nil, summary: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Reasoning for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(context: nil, effort: nil, generate_summary: nil, mode: nil, summary: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Beta::BetaResponsesClientEvent::ResponseCreate::Reasoning for more details.
gpt-5 and o-series models only
Configuration options for reasoning models.
|
|
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1171
|
Instance Attribute Details
#context ⇒ Symbol, ...
Controls which reasoning items are rendered back to the model on later turns. If
omitted or set to auto, the model determines the context mode. The gpt-5.6
model family defaults to all_turns; earlier models default to current_turn.
When returned on a response, this is the effective reasoning context mode used for the response.
1117 1118 1119 |
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1117 optional :context, enum: -> { OpenAI::Beta::BetaResponsesClientEvent::ResponseCreate::Reasoning::Context }, nil?: true |
#effort ⇒ Symbol, ...
Constrains effort on reasoning for reasoning models. Currently supported values
are none, minimal, low, medium, high, xhigh, and max. Reducing
reasoning effort can result in faster responses and fewer tokens used on
reasoning in a response. Not all reasoning models support every value. See the
reasoning guide for
model-specific support.
1130 1131 1132 |
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1130 optional :effort, enum: -> { OpenAI::Beta::BetaResponsesClientEvent::ResponseCreate::Reasoning::Effort }, nil?: true |
#generate_summary ⇒ Symbol, ...
Deprecated: use summary instead.
A summary of the reasoning performed by the model. This can be useful for
debugging and understanding the model's reasoning process. One of auto,
concise, or detailed.
1144 1145 1146 1147 1148 |
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1144 optional :generate_summary, enum: -> { OpenAI::Beta::BetaResponsesClientEvent::ResponseCreate::Reasoning::GenerateSummary }, nil?: true |
#mode ⇒ String, ...
Controls the reasoning execution mode for the request.
When returned on a response, this is the effective execution mode.
1156 |
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1156 optional :mode, union: -> { OpenAI::Beta::BetaResponsesClientEvent::ResponseCreate::Reasoning::Mode } |
#summary ⇒ Symbol, ...
A summary of the reasoning performed by the model. This can be useful for
debugging and understanding the model's reasoning process. One of auto,
concise, or detailed.
concise is supported for computer-use-preview models and all reasoning
models after gpt-5.
1167 1168 1169 |
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1167 optional :summary, enum: -> { OpenAI::Beta::BetaResponsesClientEvent::ResponseCreate::Reasoning::Summary }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_responses_client_event.rb', line 1206
|