Class: OpenAI::Models::Beta::BetaResponsesServerEvent::BetaResponseWsError::Error
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponsesServerEvent::BetaResponseWsError::Error
- Defined in:
- lib/openai/models/beta/beta_responses_server_event.rb
Overview
Instance Attribute Summary collapse
-
#code ⇒ String?
The error code that was emitted, if any.
-
#headers ⇒ Hash{Symbol=>String}?
The response headers that were emitted with the error, if any.
-
#message ⇒ String
The human-readable error message that was emitted.
-
#param ⇒ String?
The parameter name that was associated with the error, if any.
-
#type ⇒ String
The error type that was emitted.
Attributes inherited from Internal::Type::BaseModel
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#code ⇒ String?
The error code that was emitted, if any.
1230 |
# File 'lib/openai/models/beta/beta_responses_server_event.rb', line 1230 required :code, String, nil?: true |
#headers ⇒ Hash{Symbol=>String}?
The response headers that were emitted with the error, if any.
1254 |
# File 'lib/openai/models/beta/beta_responses_server_event.rb', line 1254 optional :headers, OpenAI::Internal::Type::HashOf[String] |
#message ⇒ String
The human-readable error message that was emitted.
1236 |
# File 'lib/openai/models/beta/beta_responses_server_event.rb', line 1236 required :message, String |
#param ⇒ String?
The parameter name that was associated with the error, if any.
1242 |
# File 'lib/openai/models/beta/beta_responses_server_event.rb', line 1242 required :param, String, nil?: true |
#type ⇒ String
The error type that was emitted.
1248 |
# File 'lib/openai/models/beta/beta_responses_server_event.rb', line 1248 required :type, String |