Class: OpenAI::Models::Beta::BetaResponsesServerEvent::BetaResponseWsError::Error
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaResponsesServerEvent::BetaResponseWsError::Error
- Defined in:
- lib/openai/models/beta/beta_responses_server_event.rb
Overview
Defined Under Namespace
Classes: Misalignment
Instance Attribute Summary collapse
-
#code ⇒ String?
The error code that was emitted, if any.
-
#headers ⇒ Hash{Symbol=>String}?
The response headers that were emitted with the error, if any.
-
#message ⇒ String
The human-readable error message that was emitted.
- #misalignment ⇒ OpenAI::Models::Beta::BetaResponsesServerEvent::BetaResponseWsError::Error::Misalignment?
-
#param ⇒ String?
The parameter name that was associated with the error, if any.
-
#type ⇒ String
The error type that was emitted.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(code:, message:, param:, type:, headers: nil, misalignment: nil) ⇒ Object
constructor
Details about the error.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code:, message:, param:, type:, headers: nil, misalignment: nil) ⇒ Object
Details about the error.
|
|
# File 'lib/openai/models/beta/beta_responses_server_event.rb', line 2431
|
Instance Attribute Details
#code ⇒ String?
The error code that was emitted, if any.
2397 |
# File 'lib/openai/models/beta/beta_responses_server_event.rb', line 2397 required :code, String, nil?: true |
#headers ⇒ Hash{Symbol=>String}?
The response headers that were emitted with the error, if any.
2421 |
# File 'lib/openai/models/beta/beta_responses_server_event.rb', line 2421 optional :headers, OpenAI::Internal::Type::HashOf[String] |
#message ⇒ String
The human-readable error message that was emitted.
2403 |
# File 'lib/openai/models/beta/beta_responses_server_event.rb', line 2403 required :message, String |
#misalignment ⇒ OpenAI::Models::Beta::BetaResponsesServerEvent::BetaResponseWsError::Error::Misalignment?
2426 2427 2428 2429 |
# File 'lib/openai/models/beta/beta_responses_server_event.rb', line 2426 optional( :misalignment, -> { OpenAI::Beta::BetaResponsesServerEvent::BetaResponseWsError::Error::Misalignment } ) |
#param ⇒ String?
The parameter name that was associated with the error, if any.
2409 |
# File 'lib/openai/models/beta/beta_responses_server_event.rb', line 2409 required :param, String, nil?: true |
#type ⇒ String
The error type that was emitted.
2415 |
# File 'lib/openai/models/beta/beta_responses_server_event.rb', line 2415 required :type, String |