Module: OpenAI::Models::Beta::BetaTool::Mcp::AllowedCaller
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/beta/beta_tool.rb
Constant Summary collapse
- DIRECT =
:direct- PROGRAMMATIC =
:programmatic
Instance Method Summary collapse
-
#initialize(server_label:, allowed_callers: nil, allowed_tools: nil, authorization: nil, connector_id: nil, defer_loading: nil, headers: nil, require_approval: nil, server_description: nil, server_url: nil, tunnel_id: nil, type: :mcp) ⇒ Object
Give the model access to additional tools via remote Model Context Protocol (MCP) servers.
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(server_label:, allowed_callers: nil, allowed_tools: nil, authorization: nil, connector_id: nil, defer_loading: nil, headers: nil, require_approval: nil, server_description: nil, server_url: nil, tunnel_id: nil, type: :mcp) ⇒ Object
Give the model access to additional tools via remote Model Context Protocol (MCP) servers. Learn more about MCP.
226 227 228 229 230 231 232 233 234 |
# File 'lib/openai/models/beta/beta_tool.rb', line 226 module AllowedCaller extend OpenAI::Internal::Type::Enum DIRECT = :direct PROGRAMMATIC = :programmatic # @!method self.values # @return [Array<Symbol>] end |