Class: OpenAI::Models::Beta::BetaWebSearchPreviewTool
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaWebSearchPreviewTool
- Defined in:
- lib/openai/models/beta/beta_web_search_preview_tool.rb,
sig/openai/models/beta/beta_web_search_preview_tool.rbs
Defined Under Namespace
Modules: SearchContentType, SearchContextSize, Type Classes: UserLocation
Instance Attribute Summary collapse
- #search_content_types ⇒ Array<Symbol, OpenAI::Models::Beta::BetaWebSearchPreviewTool::SearchContentType>?
-
#search_context_size ⇒ Symbol, ...
High level guidance for the amount of context window space to use for the search.
-
#type ⇒ Symbol, OpenAI::Models::Beta::BetaWebSearchPreviewTool::Type
The type of the web search tool.
-
#user_location ⇒ OpenAI::Models::Beta::BetaWebSearchPreviewTool::UserLocation?
The user's location.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(type:, search_content_types: nil, search_context_size: nil, user_location: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaWebSearchPreviewTool for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type:, search_content_types: nil, search_context_size: nil, user_location: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Beta::BetaWebSearchPreviewTool for more details.
This tool searches the web for relevant results to use in a response. Learn more about the web search tool.
|
|
# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 33
|
Instance Attribute Details
#search_content_types ⇒ Array<Symbol, OpenAI::Models::Beta::BetaWebSearchPreviewTool::SearchContentType>?
17 18 |
# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 17 optional :search_content_types, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Beta::BetaWebSearchPreviewTool::SearchContentType] } |
#search_context_size ⇒ Symbol, ...
High level guidance for the amount of context window space to use for the
search. One of low, medium, or high. medium is the default.
25 |
# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 25 optional :search_context_size, enum: -> { OpenAI::Beta::BetaWebSearchPreviewTool::SearchContextSize } |
#type ⇒ Symbol, OpenAI::Models::Beta::BetaWebSearchPreviewTool::Type
The type of the web search tool. One of web_search_preview or
web_search_preview_2025_03_11.
12 |
# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 12 required :type, enum: -> { OpenAI::Beta::BetaWebSearchPreviewTool::Type } |
#user_location ⇒ OpenAI::Models::Beta::BetaWebSearchPreviewTool::UserLocation?
The user's location.
31 |
# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 31 optional :user_location, -> { OpenAI::Beta::BetaWebSearchPreviewTool::UserLocation }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 59
|
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/openai/models/beta/beta_web_search_preview_tool.rbs', line 38
def to_hash: -> {
|