Class: OpenAI::Models::Beta::BetaWebSearchPreviewTool::UserLocation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::BetaWebSearchPreviewTool::UserLocation
- Defined in:
- lib/openai/models/beta/beta_web_search_preview_tool.rb,
sig/openai/models/beta/beta_web_search_preview_tool.rbs
Overview
Instance Attribute Summary collapse
-
#city ⇒ String?
Free text input for the city of the user, e.g.
-
#country ⇒ String?
The two-letter ISO country code of the user, e.g.
-
#region ⇒ String?
Free text input for the region of the user, e.g.
-
#timezone ⇒ String?
The IANA timezone of the user, e.g.
-
#type ⇒ Symbol, :approximate
The type of location approximation.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
99 |
# File 'sig/openai/models/beta/beta_web_search_preview_tool.rbs', line 99
def initialize: (
|
Instance Attribute Details
#city ⇒ String?
Free text input for the city of the user, e.g. San Francisco.
100 |
# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 100 optional :city, String, nil?: true |
#country ⇒ String?
The two-letter ISO country code of
the user, e.g. US.
107 |
# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 107 optional :country, String, nil?: true |
#region ⇒ String?
Free text input for the region of the user, e.g. California.
113 |
# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 113 optional :region, String, nil?: true |
#timezone ⇒ String?
The IANA timezone of the
user, e.g. America/Los_Angeles.
120 |
# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 120 optional :timezone, String, nil?: true |
#type ⇒ Symbol, :approximate
The type of location approximation. Always approximate.
94 |
# File 'lib/openai/models/beta/beta_web_search_preview_tool.rb', line 94 required :type, const: :approximate |
Instance Method Details
#to_hash ⇒ {
107 |
# File 'sig/openai/models/beta/beta_web_search_preview_tool.rbs', line 107
def to_hash: -> {
|