Class: OpenAI::Models::Beta::ChatKit::ChatSessionChatKitConfigurationParam::FileUpload
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::ChatKit::ChatSessionChatKitConfigurationParam::FileUpload
- Defined in:
- lib/openai/models/beta/chatkit/chat_session_chatkit_configuration_param.rb,
sig/openai/models/beta/chatkit/chat_session_chatkit_configuration_param.rbs
Overview
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean?
Enable uploads for this session.
-
#max_file_size ⇒ Integer?
Maximum size in megabytes for each uploaded file.
-
#max_files ⇒ Integer?
Maximum number of files that can be uploaded to the session.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
71 |
# File 'sig/openai/models/beta/chatkit/chat_session_chatkit_configuration_param.rbs', line 71
def initialize: (
|
Instance Attribute Details
#enabled ⇒ Boolean?
Enable uploads for this session. Defaults to false.
64 |
# File 'lib/openai/models/beta/chatkit/chat_session_chatkit_configuration_param.rb', line 64 optional :enabled, OpenAI::Internal::Type::Boolean |
#max_file_size ⇒ Integer?
Maximum size in megabytes for each uploaded file. Defaults to 512 MB, which is the maximum allowable size.
71 |
# File 'lib/openai/models/beta/chatkit/chat_session_chatkit_configuration_param.rb', line 71 optional :max_file_size, Integer |
#max_files ⇒ Integer?
Maximum number of files that can be uploaded to the session. Defaults to 10.
77 |
# File 'lib/openai/models/beta/chatkit/chat_session_chatkit_configuration_param.rb', line 77 optional :max_files, Integer |
Instance Method Details
#to_hash ⇒ {
77 |
# File 'sig/openai/models/beta/chatkit/chat_session_chatkit_configuration_param.rbs', line 77
def to_hash: -> {
|