Class: OpenAI::Models::Beta::Environment::OpenAIHosted
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Environment::OpenAIHosted
- Defined in:
- lib/openai/models/beta/environment.rb,
sig/openai/models/beta/environment.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#capability_directories ⇒ Array<String>
Directories that contain capabilities exposed to the agent.
-
#files ⇒ Array<OpenAI::Models::Beta::HostedEnvironmentFileID, OpenAI::Models::Beta::HostedEnvironmentFile::Inline>
Files available in the environment, excluding their contents.
-
#id ⇒ String
The public ID of the environment.
-
#network ⇒ OpenAI::Models::Beta::Environment::OpenAIHosted::Network
The effective network access policy for the environment.
-
#packages ⇒ OpenAI::Models::Beta::Environment::OpenAIHosted::Packages
Packages installed in the environment.
-
#plugins ⇒ Array<OpenAI::Models::Beta::HostedPlugin>
Plugins installed in the environment, excluding their archive contents.
-
#skills ⇒ Array<OpenAI::Models::Beta::HostedSkillReference, OpenAI::Models::Beta::HostedSkill::Inline>
Skills installed in the environment, excluding their archive contents.
-
#type ⇒ Symbol, :openai_hosted
The type of the object.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, capability_directories:, files:, network:, packages:, plugins:, skills:, type: :openai_hosted) ⇒ Object
constructor
An environment hosted by OpenAI.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, capability_directories:, files:, network:, packages:, plugins:, skills:, type: :openai_hosted) ⇒ Object
An environment hosted by OpenAI.
|
|
# File 'lib/openai/models/beta/environment.rb', line 85
|
Instance Attribute Details
#capability_directories ⇒ Array<String>
Directories that contain capabilities exposed to the agent.
47 |
# File 'lib/openai/models/beta/environment.rb', line 47 required :capability_directories, OpenAI::Internal::Type::ArrayOf[String] |
#files ⇒ Array<OpenAI::Models::Beta::HostedEnvironmentFileID, OpenAI::Models::Beta::HostedEnvironmentFile::Inline>
Files available in the environment, excluding their contents.
53 |
# File 'lib/openai/models/beta/environment.rb', line 53 required :files, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::HostedEnvironmentFile] } |
#id ⇒ String
The public ID of the environment.
41 |
# File 'lib/openai/models/beta/environment.rb', line 41 required :id, String |
#network ⇒ OpenAI::Models::Beta::Environment::OpenAIHosted::Network
The effective network access policy for the environment.
59 |
# File 'lib/openai/models/beta/environment.rb', line 59 required :network, -> { OpenAI::Beta::Environment::OpenAIHosted::Network } |
#packages ⇒ OpenAI::Models::Beta::Environment::OpenAIHosted::Packages
Packages installed in the environment.
65 |
# File 'lib/openai/models/beta/environment.rb', line 65 required :packages, -> { OpenAI::Beta::Environment::OpenAIHosted::Packages } |
#plugins ⇒ Array<OpenAI::Models::Beta::HostedPlugin>
Plugins installed in the environment, excluding their archive contents.
71 |
# File 'lib/openai/models/beta/environment.rb', line 71 required :plugins, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::HostedPlugin] } |
#skills ⇒ Array<OpenAI::Models::Beta::HostedSkillReference, OpenAI::Models::Beta::HostedSkill::Inline>
Skills installed in the environment, excluding their archive contents.
77 |
# File 'lib/openai/models/beta/environment.rb', line 77 required :skills, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::HostedSkill] } |
#type ⇒ Symbol, :openai_hosted
The type of the object. Always openai_hosted.
83 |
# File 'lib/openai/models/beta/environment.rb', line 83 required :type, const: :openai_hosted |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/environment.rb', line 150
|
Instance Method Details
#to_hash ⇒ {
62 |
# File 'sig/openai/models/beta/environment.rbs', line 62
def to_hash: -> {
|