Class: OpenAI::Models::Beta::ImagePart
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::ImagePart
- Defined in:
- lib/openai/models/beta/image_part.rb
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the uploaded image.
-
#mime_type ⇒ String
MIME type of the uploaded image.
-
#name ⇒ String?
Original filename for the uploaded image.
-
#preview_url ⇒ String
Preview URL that can be rendered inline for the image.
-
#type ⇒ Symbol, :image
Type discriminator that is always ‘image`.
-
#upload_url ⇒ String?
Signed URL for downloading the uploaded image.
Instance Method Summary collapse
-
#initialize(id: , mime_type: , name: , preview_url: , upload_url: , type: :image) ⇒ Object
constructor
Some parameter documentations has been truncated, see ImagePart for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , mime_type: , name: , preview_url: , upload_url: , type: :image) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Beta::ImagePart for more details.
Metadata for an image uploaded through ChatKit.
|
|
# File 'lib/openai/models/beta/image_part.rb', line 44
|
Instance Attribute Details
#id ⇒ String
Unique identifier for the uploaded image.
11 |
# File 'lib/openai/models/beta/image_part.rb', line 11 required :id, String |
#mime_type ⇒ String
MIME type of the uploaded image.
17 |
# File 'lib/openai/models/beta/image_part.rb', line 17 required :mime_type, String |
#name ⇒ String?
Original filename for the uploaded image. Defaults to null when unnamed.
23 |
# File 'lib/openai/models/beta/image_part.rb', line 23 required :name, String, nil?: true |
#preview_url ⇒ String
Preview URL that can be rendered inline for the image.
29 |
# File 'lib/openai/models/beta/image_part.rb', line 29 required :preview_url, String |
#type ⇒ Symbol, :image
Type discriminator that is always ‘image`.
35 |
# File 'lib/openai/models/beta/image_part.rb', line 35 required :type, const: :image |
#upload_url ⇒ String?
Signed URL for downloading the uploaded image. Defaults to null when no download link is available.
42 |
# File 'lib/openai/models/beta/image_part.rb', line 42 required :upload_url, String, nil?: true |