Class: OpenAI::Models::Beta::PersistedMcpTransportParam::Stdio
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::PersistedMcpTransportParam::Stdio
- Defined in:
- lib/openai/models/beta/persisted_mcp_transport_param.rb,
sig/openai/models/beta/persisted_mcp_transport_param.rbs
Instance Attribute Summary collapse
-
#args ⇒ Array<String>?
Arguments passed to the MCP server command.
-
#command ⇒ String
The command used to start the MCP server.
-
#cwd ⇒ String
The working directory used to start the MCP server.
-
#env_vars ⇒ Array<String>?
Environment variable names to inherit from the selected execution environment.
-
#type ⇒ Symbol, :stdio
The type of the object.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(command:, cwd:, args: nil, env_vars: nil, type: :stdio) ⇒ Object
constructor
Starts an MCP server as a local process.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(command:, cwd:, args: nil, env_vars: nil, type: :stdio) ⇒ Object
Starts an MCP server as a local process.
|
|
# File 'lib/openai/models/beta/persisted_mcp_transport_param.rb', line 81
|
Instance Attribute Details
#args ⇒ Array<String>?
Arguments passed to the MCP server command.
73 |
# File 'lib/openai/models/beta/persisted_mcp_transport_param.rb', line 73 optional :args, OpenAI::Internal::Type::ArrayOf[String], nil?: true |
#command ⇒ String
The command used to start the MCP server.
55 |
# File 'lib/openai/models/beta/persisted_mcp_transport_param.rb', line 55 required :command, String |
#cwd ⇒ String
The working directory used to start the MCP server.
61 |
# File 'lib/openai/models/beta/persisted_mcp_transport_param.rb', line 61 required :cwd, String |
#env_vars ⇒ Array<String>?
Environment variable names to inherit from the selected execution environment.
79 |
# File 'lib/openai/models/beta/persisted_mcp_transport_param.rb', line 79 optional :env_vars, OpenAI::Internal::Type::ArrayOf[String], nil?: true |
#type ⇒ Symbol, :stdio
The type of the object. Always stdio.
67 |
# File 'lib/openai/models/beta/persisted_mcp_transport_param.rb', line 67 required :type, const: :stdio |
Instance Method Details
#to_hash ⇒ {
66 |
# File 'sig/openai/models/beta/persisted_mcp_transport_param.rbs', line 66
def to_hash: -> {
|