Class: OpenAI::Models::Beta::Responses::InputTokenCountParams::Reasoning

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/responses/input_token_count_params.rb,
sig/openai/models/beta/responses/input_token_count_params.rbs

Defined Under Namespace

Modules: Context, Effort, GenerateSummary, Mode, Summary

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(context: nil, effort: nil, generate_summary: nil, mode: nil, summary: nil) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Beta::Responses::InputTokenCountParams::Reasoning for more details.

gpt-5 and o-series models only Configuration options for reasoning models.

Parameters:



# File 'lib/openai/models/beta/responses/input_token_count_params.rb', line 292

Instance Attribute Details

#contextSymbol, ...

Controls which reasoning items are rendered back to the model on later turns. If omitted or set to auto, the model determines the context mode. The gpt-5.6 model family defaults to all_turns; earlier models default to current_turn.

When returned on a response, this is the effective reasoning context mode used for the response.

Parameters:

  • value (OpenAI::Models::Beta::Responses::InputTokenCountParams::Reasoning::context, nil)

Returns:



232
233
234
235
236
# File 'lib/openai/models/beta/responses/input_token_count_params.rb', line 232

optional(
  :context,
  enum: -> { OpenAI::Beta::Responses::InputTokenCountParams::Reasoning::Context },
  nil?: true
)

#effortSymbol, ...

Constrains effort on reasoning for reasoning models. Currently supported values are none, minimal, low, medium, high, xhigh, and max. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response. Not all reasoning models support every value. See the reasoning guide for model-specific support.

Parameters:

  • value (OpenAI::Models::Beta::Responses::InputTokenCountParams::Reasoning::effort, nil)

Returns:



247
248
249
250
251
# File 'lib/openai/models/beta/responses/input_token_count_params.rb', line 247

optional(
  :effort,
  enum: -> { OpenAI::Beta::Responses::InputTokenCountParams::Reasoning::Effort },
  nil?: true
)

#generate_summarySymbol, ...

Deprecated.

Deprecated: use summary instead.

A summary of the reasoning performed by the model. This can be useful for debugging and understanding the model's reasoning process. One of auto, concise, or detailed.

Parameters:

  • value (OpenAI::Models::Beta::Responses::InputTokenCountParams::Reasoning::generate_summary, nil)

Returns:



263
264
265
266
267
# File 'lib/openai/models/beta/responses/input_token_count_params.rb', line 263

optional(
  :generate_summary,
  enum: -> { OpenAI::Beta::Responses::InputTokenCountParams::Reasoning::GenerateSummary },
  nil?: true
)

#modeString, ...

Controls the reasoning execution mode for the request.

When returned on a response, this is the effective execution mode.



275
# File 'lib/openai/models/beta/responses/input_token_count_params.rb', line 275

optional :mode, union: -> { OpenAI::Beta::Responses::InputTokenCountParams::Reasoning::Mode }

#summarySymbol, ...

A summary of the reasoning performed by the model. This can be useful for debugging and understanding the model's reasoning process. One of auto, concise, or detailed.

concise is supported for computer-use-preview models and all reasoning models after gpt-5.

Parameters:

  • value (OpenAI::Models::Beta::Responses::InputTokenCountParams::Reasoning::summary, nil)

Returns:



286
287
288
289
290
# File 'lib/openai/models/beta/responses/input_token_count_params.rb', line 286

optional(
  :summary,
  enum: -> { OpenAI::Beta::Responses::InputTokenCountParams::Reasoning::Summary },
  nil?: true
)

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/beta/responses/input_token_count_params.rb', line 325

Instance Method Details

#to_hash{

Returns:

  • ({)


162
# File 'sig/openai/models/beta/responses/input_token_count_params.rbs', line 162

def to_hash: -> {