Class: OpenAI::Models::Beta::Responses::InputTokenCountParams::Reasoning
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Responses::InputTokenCountParams::Reasoning
- Defined in:
- lib/openai/models/beta/responses/input_token_count_params.rb,
sig/openai/models/beta/responses/input_token_count_params.rbs
Defined Under Namespace
Modules: Context, Effort, GenerateSummary, Mode, Summary
Instance Attribute Summary collapse
-
#context ⇒ Symbol, ...
Controls which reasoning items are rendered back to the model on later turns.
-
#effort ⇒ Symbol, ...
Constrains effort on reasoning for reasoning models.
- #generate_summary ⇒ Symbol, ... deprecated Deprecated.
-
#mode ⇒ String, ...
Controls the reasoning execution mode for the request.
-
#summary ⇒ Symbol, ...
A summary of the reasoning performed by the model.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(context: nil, effort: nil, generate_summary: nil, mode: nil, summary: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Reasoning for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(context: nil, effort: nil, generate_summary: nil, mode: nil, summary: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Beta::Responses::InputTokenCountParams::Reasoning for more details.
gpt-5 and o-series models only Configuration options for reasoning models.
|
|
# File 'lib/openai/models/beta/responses/input_token_count_params.rb', line 292
|
Instance Attribute Details
#context ⇒ Symbol, ...
Controls which reasoning items are rendered back to the model on later turns. If
omitted or set to auto, the model determines the context mode. The gpt-5.6
model family defaults to all_turns; earlier models default to current_turn.
When returned on a response, this is the effective reasoning context mode used for the response.
232 233 234 235 236 |
# File 'lib/openai/models/beta/responses/input_token_count_params.rb', line 232 optional( :context, enum: -> { OpenAI::Beta::Responses::InputTokenCountParams::Reasoning::Context }, nil?: true ) |
#effort ⇒ Symbol, ...
Constrains effort on reasoning for reasoning models. Currently supported values
are none, minimal, low, medium, high, xhigh, and max. Reducing
reasoning effort can result in faster responses and fewer tokens used on
reasoning in a response. Not all reasoning models support every value. See the
reasoning guide for
model-specific support.
247 248 249 250 251 |
# File 'lib/openai/models/beta/responses/input_token_count_params.rb', line 247 optional( :effort, enum: -> { OpenAI::Beta::Responses::InputTokenCountParams::Reasoning::Effort }, nil?: true ) |
#generate_summary ⇒ Symbol, ...
Deprecated: use summary instead.
A summary of the reasoning performed by the model. This can be useful for
debugging and understanding the model's reasoning process. One of auto,
concise, or detailed.
263 264 265 266 267 |
# File 'lib/openai/models/beta/responses/input_token_count_params.rb', line 263 optional( :generate_summary, enum: -> { OpenAI::Beta::Responses::InputTokenCountParams::Reasoning::GenerateSummary }, nil?: true ) |
#mode ⇒ String, ...
Controls the reasoning execution mode for the request.
When returned on a response, this is the effective execution mode.
275 |
# File 'lib/openai/models/beta/responses/input_token_count_params.rb', line 275 optional :mode, union: -> { OpenAI::Beta::Responses::InputTokenCountParams::Reasoning::Mode } |
#summary ⇒ Symbol, ...
A summary of the reasoning performed by the model. This can be useful for
debugging and understanding the model's reasoning process. One of auto,
concise, or detailed.
concise is supported for computer-use-preview models and all reasoning
models after gpt-5.
286 287 288 289 290 |
# File 'lib/openai/models/beta/responses/input_token_count_params.rb', line 286 optional( :summary, enum: -> { OpenAI::Beta::Responses::InputTokenCountParams::Reasoning::Summary }, nil?: true ) |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/beta/responses/input_token_count_params.rb', line 325
|
Instance Method Details
#to_hash ⇒ {
162 |
# File 'sig/openai/models/beta/responses/input_token_count_params.rbs', line 162
def to_hash: -> {
|