Class: OpenAI::Models::Beta::SessionError
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::SessionError
- Defined in:
- lib/openai/models/beta/session_error.rb,
sig/openai/models/beta/session_error.rbs
Instance Attribute Summary collapse
-
#code ⇒ String?
The machine-readable error code, if any.
-
#message ⇒ String
A customer-safe explanation of the error.
-
#param ⇒ String?
The request parameter associated with the error, if any.
-
#type ⇒ String
The error type.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(code:, message:, param:, type:) ⇒ Object
constructor
An error payload with the same public fields as Responses API streaming errors.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code:, message:, param:, type:) ⇒ Object
An error payload with the same public fields as Responses API streaming errors.
|
|
# File 'lib/openai/models/beta/session_error.rb', line 31
|
Instance Attribute Details
#code ⇒ String?
The machine-readable error code, if any.
11 |
# File 'lib/openai/models/beta/session_error.rb', line 11 required :code, String, nil?: true |
#message ⇒ String
A customer-safe explanation of the error.
17 |
# File 'lib/openai/models/beta/session_error.rb', line 17 required :message, String |
#param ⇒ String?
The request parameter associated with the error, if any.
23 |
# File 'lib/openai/models/beta/session_error.rb', line 23 required :param, String, nil?: true |
#type ⇒ String
The error type.
29 |
# File 'lib/openai/models/beta/session_error.rb', line 29 required :type, String |
Instance Method Details
#to_hash ⇒ {
23 |
# File 'sig/openai/models/beta/session_error.rbs', line 23
def to_hash: -> {
|