Class: OpenAI::Models::Beta::ThreadUpdateParams::ToolResources

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/thread_update_params.rb,
sig/openai/models/beta/thread_update_params.rbs

Defined Under Namespace

Classes: CodeInterpreter, FileSearch

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(file_ids: nil) ⇒ Object

Some parameter documentations has been truncated, see CodeInterpreter for more details.

Parameters:

  • file_ids (Array<String>) (defaults to: nil)

    A list of file IDs made



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/openai/models/beta/thread_update_params.rb', line 48

class ToolResources < OpenAI::Internal::Type::BaseModel
  # @!attribute code_interpreter
  #
  #   @return [OpenAI::Models::Beta::ThreadUpdateParams::ToolResources::CodeInterpreter, nil]
  optional :code_interpreter, -> { OpenAI::Beta::ThreadUpdateParams::ToolResources::CodeInterpreter }

  # @!attribute file_search
  #
  #   @return [OpenAI::Models::Beta::ThreadUpdateParams::ToolResources::FileSearch, nil]
  optional :file_search, -> { OpenAI::Beta::ThreadUpdateParams::ToolResources::FileSearch }

  # @!method initialize(code_interpreter: nil, file_search: nil)
  #   A set of resources that are made available to the assistant's tools in this
  #   thread. The resources are specific to the type of tool. For example, the
  #   `code_interpreter` tool requires a list of file IDs, while the `file_search`
  #   tool requires a list of vector store IDs.
  #
  #   @param code_interpreter [OpenAI::Models::Beta::ThreadUpdateParams::ToolResources::CodeInterpreter]
  #   @param file_search [OpenAI::Models::Beta::ThreadUpdateParams::ToolResources::FileSearch]

  # @see OpenAI::Models::Beta::ThreadUpdateParams::ToolResources#code_interpreter
  class CodeInterpreter < OpenAI::Internal::Type::BaseModel
    # @!attribute file_ids
    #   A list of [file](https://platform.openai.com/docs/api-reference/files) IDs made
    #   available to the `code_interpreter` tool. There can be a maximum of 20 files
    #   associated with the tool.
    #
    #   @return [Array<String>, nil]
    optional :file_ids, OpenAI::Internal::Type::ArrayOf[String]

    # @!method initialize(file_ids: nil)
    #   Some parameter documentations has been truncated, see
    #   {OpenAI::Models::Beta::ThreadUpdateParams::ToolResources::CodeInterpreter} for
    #   more details.
    #
    #   @param file_ids [Array<String>] A list of [file](https://platform.openai.com/docs/api-reference/files) IDs made
  end

  # @see OpenAI::Models::Beta::ThreadUpdateParams::ToolResources#file_search
  class FileSearch < OpenAI::Internal::Type::BaseModel
    # @!attribute vector_store_ids
    #   The
    #   [vector store](https://platform.openai.com/docs/api-reference/vector-stores/object)
    #   attached to this thread. There can be a maximum of 1 vector store attached to
    #   the thread.
    #
    #   @return [Array<String>, nil]
    optional :vector_store_ids, OpenAI::Internal::Type::ArrayOf[String]

    # @!method initialize(vector_store_ids: nil)
    #   Some parameter documentations has been truncated, see
    #   {OpenAI::Models::Beta::ThreadUpdateParams::ToolResources::FileSearch} for more
    #   details.
    #
    #   @param vector_store_ids [Array<String>] The [vector store](https://platform.openai.com/docs/api-reference/vector-stores/
  end
end

Instance Attribute Details

#code_interpreterOpenAI::Models::Beta::ThreadUpdateParams::ToolResources::CodeInterpreter?



52
# File 'lib/openai/models/beta/thread_update_params.rb', line 52

optional :code_interpreter, -> { OpenAI::Beta::ThreadUpdateParams::ToolResources::CodeInterpreter }

#file_searchOpenAI::Models::Beta::ThreadUpdateParams::ToolResources::FileSearch?



57
# File 'lib/openai/models/beta/thread_update_params.rb', line 57

optional :file_search, -> { OpenAI::Beta::ThreadUpdateParams::ToolResources::FileSearch }

Instance Method Details

#to_hash{

Returns:

  • ({)


60
# File 'sig/openai/models/beta/thread_update_params.rbs', line 60

def to_hash: -> {