Class: OpenAI::Models::Beta::ThreadUpdateParams::ToolResources
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::ThreadUpdateParams::ToolResources
- Defined in:
- lib/openai/models/beta/thread_update_params.rb,
sig/openai/models/beta/thread_update_params.rbs
Defined Under Namespace
Classes: CodeInterpreter, FileSearch
Instance Attribute Summary collapse
- #code_interpreter ⇒ OpenAI::Models::Beta::ThreadUpdateParams::ToolResources::CodeInterpreter?
- #file_search ⇒ OpenAI::Models::Beta::ThreadUpdateParams::ToolResources::FileSearch?
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(file_ids: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(file_ids: nil) ⇒ Object
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/openai/models/beta/thread_update_params.rb', line 55 class ToolResources < OpenAI::Internal::Type::BaseModel # @!attribute code_interpreter # # @return [OpenAI::Models::Beta::ThreadUpdateParams::ToolResources::CodeInterpreter, nil] optional :code_interpreter, -> { OpenAI::Beta::ThreadUpdateParams::ToolResources::CodeInterpreter } # @!attribute file_search # # @return [OpenAI::Models::Beta::ThreadUpdateParams::ToolResources::FileSearch, nil] optional :file_search, -> { OpenAI::Beta::ThreadUpdateParams::ToolResources::FileSearch } # @!method initialize(code_interpreter: nil, file_search: nil) # A set of resources that are made available to the assistant's tools in this # thread. The resources are specific to the type of tool. For example, the # `code_interpreter` tool requires a list of file IDs, while the `file_search` # tool requires a list of vector store IDs. # # @param code_interpreter [OpenAI::Models::Beta::ThreadUpdateParams::ToolResources::CodeInterpreter] # @param file_search [OpenAI::Models::Beta::ThreadUpdateParams::ToolResources::FileSearch] # @see OpenAI::Models::Beta::ThreadUpdateParams::ToolResources#code_interpreter class CodeInterpreter < OpenAI::Internal::Type::BaseModel # @!attribute file_ids # A list of [file](https://developers.openai.com/api/reference/resources/files) # IDs made available to the `code_interpreter` tool. There can be a maximum of 20 # files associated with the tool. # # @return [Array<String>, nil] optional :file_ids, OpenAI::Internal::Type::ArrayOf[String] # @!method initialize(file_ids: nil) # @param file_ids [Array<String>] # A list of [file](https://developers.openai.com/api/reference/resources/files) # IDs made available to the `code_interpreter` tool. There can be a maximum of 20 # files associated with the tool. end # @see OpenAI::Models::Beta::ThreadUpdateParams::ToolResources#file_search class FileSearch < OpenAI::Internal::Type::BaseModel # @!attribute vector_store_ids # The # [vector store](https://developers.openai.com/api/reference/resources/vector_stores) # attached to this thread. There can be a maximum of 1 vector store attached to # the thread. # # @return [Array<String>, nil] optional :vector_store_ids, OpenAI::Internal::Type::ArrayOf[String] # @!method initialize(vector_store_ids: nil) # @param vector_store_ids [Array<String>] # The # [vector store](https://developers.openai.com/api/reference/resources/vector_stores) # attached to this thread. There can be a maximum of 1 vector store attached to # the thread. end end |
Instance Attribute Details
#code_interpreter ⇒ OpenAI::Models::Beta::ThreadUpdateParams::ToolResources::CodeInterpreter?
59 |
# File 'lib/openai/models/beta/thread_update_params.rb', line 59 optional :code_interpreter, -> { OpenAI::Beta::ThreadUpdateParams::ToolResources::CodeInterpreter } |
#file_search ⇒ OpenAI::Models::Beta::ThreadUpdateParams::ToolResources::FileSearch?
64 |
# File 'lib/openai/models/beta/thread_update_params.rb', line 64 optional :file_search, -> { OpenAI::Beta::ThreadUpdateParams::ToolResources::FileSearch } |
Instance Method Details
#to_hash ⇒ {
82 |
# File 'sig/openai/models/beta/thread_update_params.rbs', line 82
def to_hash: -> {
|