Class: OpenAI::Models::Beta::Threads::MessageDelta
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Threads::MessageDelta
- Defined in:
- lib/openai/models/beta/threads/message_delta.rb,
sig/openai/models/beta/threads/message_delta.rbs
Defined Under Namespace
Modules: Role
Instance Attribute Summary collapse
-
#content ⇒ ::Array[OpenAI::Models::Beta::Threads::message_content_delta]?
The content of the message in array of text and/or images.
-
#role ⇒ OpenAI::Models::Beta::Threads::MessageDelta::role?
The entity that produced the message.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content: nil, role: nil) ⇒ Object
|
|
# File 'lib/openai/models/beta/threads/message_delta.rb', line 23
|
Instance Attribute Details
#content ⇒ ::Array[OpenAI::Models::Beta::Threads::message_content_delta]?
The content of the message in array of text and/or images.
12 13 14 15 |
# File 'lib/openai/models/beta/threads/message_delta.rb', line 12 optional( :content, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Beta::Threads::MessageContentDelta] } ) |
#role ⇒ OpenAI::Models::Beta::Threads::MessageDelta::role?
The entity that produced the message. One of user or assistant.
21 |
# File 'lib/openai/models/beta/threads/message_delta.rb', line 21 optional :role, enum: -> { OpenAI::Beta::Threads::MessageDelta::Role } |
Instance Method Details
#to_hash ⇒ {
37 |
# File 'sig/openai/models/beta/threads/message_delta.rbs', line 37
def to_hash: -> {
|