Class: OpenAI::Models::Beta::Threads::Run::RequiredAction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Threads::Run::RequiredAction
- Defined in:
- lib/openai/models/beta/threads/run.rb,
sig/openai/models/beta/threads/run.rbs
Overview
Defined Under Namespace
Classes: SubmitToolOutputs
Instance Attribute Summary collapse
-
#submit_tool_outputs ⇒ OpenAI::Beta::Threads::Run::RequiredAction::SubmitToolOutputs
Details on the tool outputs needed for this run to continue.
-
#type ⇒ :submit_tool_outputs
For now, this is always
submit_tool_outputs.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(submit_tool_outputs:, type: :submit_tool_outputs) ⇒ Object
|
|
# File 'lib/openai/models/beta/threads/run.rb', line 442
|
Instance Attribute Details
#submit_tool_outputs ⇒ OpenAI::Beta::Threads::Run::RequiredAction::SubmitToolOutputs
Details on the tool outputs needed for this run to continue.
434 |
# File 'lib/openai/models/beta/threads/run.rb', line 434 required :submit_tool_outputs, -> { OpenAI::Beta::Threads::Run::RequiredAction::SubmitToolOutputs } |
#type ⇒ :submit_tool_outputs
For now, this is always submit_tool_outputs.
440 |
# File 'lib/openai/models/beta/threads/run.rb', line 440 required :type, const: :submit_tool_outputs |
Instance Method Details
#to_hash ⇒ {
433 |
# File 'sig/openai/models/beta/threads/run.rbs', line 433 def to_hash: -> { |