Class: OpenAI::Models::Beta::Threads::Runs::FileSearchToolCall::FileSearch::Result
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Beta::Threads::Runs::FileSearchToolCall::FileSearch::Result
- Defined in:
- lib/openai/models/beta/threads/runs/file_search_tool_call.rb,
sig/openai/models/beta/threads/runs/file_search_tool_call.rbs
Defined Under Namespace
Classes: Content
Instance Attribute Summary collapse
-
#content ⇒ Array<OpenAI::Models::Beta::Threads::Runs::FileSearchToolCall::FileSearch::Result::Content>?
The content of the result that was found.
-
#file_id ⇒ String
The ID of the file that result was found in.
-
#file_name ⇒ String
The name of the file that result was found in.
-
#score ⇒ Float
The score of the result.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
115 |
# File 'sig/openai/models/beta/threads/runs/file_search_tool_call.rbs', line 115
def initialize: (
|
Instance Attribute Details
#content ⇒ Array<OpenAI::Models::Beta::Threads::Runs::FileSearchToolCall::FileSearch::Result::Content>?
The content of the result that was found. The content is only included if requested via the include query parameter.
129 130 |
# File 'lib/openai/models/beta/threads/runs/file_search_tool_call.rb', line 129 optional :content, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Beta::Threads::Runs::FileSearchToolCall::FileSearch::Result::Content] } |
#file_id ⇒ String
The ID of the file that result was found in.
109 |
# File 'lib/openai/models/beta/threads/runs/file_search_tool_call.rb', line 109 required :file_id, String |
#file_name ⇒ String
The name of the file that result was found in.
115 |
# File 'lib/openai/models/beta/threads/runs/file_search_tool_call.rb', line 115 required :file_name, String |
#score ⇒ Float
The score of the result. All values must be a floating point number between 0 and 1.
122 |
# File 'lib/openai/models/beta/threads/runs/file_search_tool_call.rb', line 122 required :score, Float |
Instance Method Details
#to_hash ⇒ {
122 |
# File 'sig/openai/models/beta/threads/runs/file_search_tool_call.rbs', line 122
def to_hash: -> {
|