Class: OpenAI::Models::Beta::Threads::Runs::FunctionToolCallDelta

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/beta/threads/runs/function_tool_call_delta.rb

Defined Under Namespace

Classes: Function

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(index:, id: nil, function: nil, type: :function) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Beta::Threads::Runs::FunctionToolCallDelta for more details.

Parameters:

  • The index of the tool call in the tool calls array.

  • (defaults to: nil)

    The ID of the tool call object.

  • (defaults to: nil)

    The definition of the function that was called.

  • (defaults to: :function)

    The type of tool call. This is always going to be function for this type of to



# File 'lib/openai/models/beta/threads/runs/function_tool_call_delta.rb', line 34

Instance Attribute Details

#functionOpenAI::Models::Beta::Threads::Runs::FunctionToolCallDelta::Function?

The definition of the function that was called.

Returns:



32
# File 'lib/openai/models/beta/threads/runs/function_tool_call_delta.rb', line 32

optional :function, -> { OpenAI::Beta::Threads::Runs::FunctionToolCallDelta::Function }

#idString?

The ID of the tool call object.

Returns:



26
# File 'lib/openai/models/beta/threads/runs/function_tool_call_delta.rb', line 26

optional :id, String

#indexInteger

The index of the tool call in the tool calls array.

Returns:



13
# File 'lib/openai/models/beta/threads/runs/function_tool_call_delta.rb', line 13

required :index, Integer

#typeSymbol, :function

The type of tool call. This is always going to be function for this type of tool call.

Returns:



20
# File 'lib/openai/models/beta/threads/runs/function_tool_call_delta.rb', line 20

required :type, const: :function