Class: OpenAI::Models::BetaComputerAction::Beta::BetaComputerAction::Click
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::BetaComputerAction::Beta::BetaComputerAction::Click
- Defined in:
- sig/openai/models/beta/beta_computer_action.rbs
Defined Under Namespace
Modules: Button
Instance Attribute Summary collapse
-
#button ⇒ OpenAI::Models::Beta::BetaComputerAction::Click::button
Indicates which mouse button was pressed during the click.
-
#keys ⇒ ::Array[String]?
The keys being held while clicking.
-
#type ⇒ :click
Specifies the event type.
-
#x ⇒ Integer
The x-coordinate where the click occurred.
-
#y_ ⇒ Integer
The y-coordinate where the click occurred.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
57 |
# File 'sig/openai/models/beta/beta_computer_action.rbs', line 57
def initialize: (
|
Instance Attribute Details
#button ⇒ OpenAI::Models::Beta::BetaComputerAction::Click::button
Indicates which mouse button was pressed during the click. One of left,
right, wheel, back, or forward.
32 33 34 |
# File 'sig/openai/models/beta/beta_computer_action.rbs', line 32 def @button end |
#keys ⇒ ::Array[String]?
The keys being held while clicking.
44 45 46 |
# File 'sig/openai/models/beta/beta_computer_action.rbs', line 44 def keys @keys end |
#type ⇒ :click
Specifies the event type. For a click action, this property is always click.
35 36 37 |
# File 'sig/openai/models/beta/beta_computer_action.rbs', line 35 def type @type end |
#x ⇒ Integer
The x-coordinate where the click occurred.
38 39 40 |
# File 'sig/openai/models/beta/beta_computer_action.rbs', line 38 def x @x end |
#y_ ⇒ Integer
The y-coordinate where the click occurred.
41 42 43 |
# File 'sig/openai/models/beta/beta_computer_action.rbs', line 41 def y_ @y_ end |
Instance Method Details
#to_hash ⇒ {
65 |
# File 'sig/openai/models/beta/beta_computer_action.rbs', line 65
def to_hash: -> {
|