Class: OpenAI::Models::BetaResponseInputItem::Beta::BetaResponseInputItem::ApplyPatchCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::BetaResponseInputItem::Beta::BetaResponseInputItem::ApplyPatchCall
- Defined in:
- sig/openai/models/beta/beta_response_input_item.rbs
Defined Under Namespace
Modules: Caller, Operation, Status Classes: Agent
Instance Attribute Summary collapse
-
#agent ⇒ OpenAI::Beta::BetaResponseInputItem::ApplyPatchCall::Agent?
The agent that produced this item.
-
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::caller_?
The execution context that produced this tool call.
-
#id ⇒ String?
The unique ID of the apply patch tool call.
-
#operation ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::operation
The specific create, delete, or update instruction for the apply_patch tool call.
-
#status ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::status
The status of the apply patch tool call.
-
#type ⇒ :apply_patch_call
The type of the item.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1935 |
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1935
def initialize: (
|
Instance Attribute Details
#agent ⇒ OpenAI::Beta::BetaResponseInputItem::ApplyPatchCall::Agent?
The agent that produced this item.
1914 1915 1916 |
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1914 def agent @agent end |
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
1897 1898 1899 |
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1897 def call_id @call_id end |
#caller_ ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::caller_?
The execution context that produced this tool call.
1917 1918 1919 |
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1917 def caller_ @caller_ end |
#id ⇒ String?
The unique ID of the apply patch tool call. Populated when this item is returned via API.
1911 1912 1913 |
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1911 def id @id end |
#operation ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::operation
The specific create, delete, or update instruction for the apply_patch tool call.
1901 1902 1903 |
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1901 def operation @operation end |
#status ⇒ OpenAI::Models::Beta::BetaResponseInputItem::ApplyPatchCall::status
The status of the apply patch tool call. One of in_progress or completed.
1904 1905 1906 |
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1904 def status @status end |
#type ⇒ :apply_patch_call
The type of the item. Always apply_patch_call.
1907 1908 1909 |
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1907 def type @type end |
Instance Method Details
#to_hash ⇒ {
1945 |
# File 'sig/openai/models/beta/beta_response_input_item.rbs', line 1945
def to_hash: -> {
|