Class: OpenAI::Models::Chat::ChatCompletion::Choice::Logprobs
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Chat::ChatCompletion::Choice::Logprobs
- Defined in:
- lib/openai/models/chat/chat_completion.rb,
sig/openai/models/chat/chat_completion.rbs
Overview
Instance Attribute Summary collapse
-
#content ⇒ Array<OpenAI::Models::Chat::ChatCompletionTokenLogprob>?
A list of message content tokens with log probability information.
-
#refusal ⇒ Array<OpenAI::Models::Chat::ChatCompletionTokenLogprob>?
A list of message refusal tokens with log probability information.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
123 |
# File 'sig/openai/models/chat/chat_completion.rbs', line 123
def initialize: (
|
Instance Attribute Details
#content ⇒ Array<OpenAI::Models::Chat::ChatCompletionTokenLogprob>?
A list of message content tokens with log probability information.
182 183 184 |
# File 'lib/openai/models/chat/chat_completion.rb', line 182 required :content, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Chat::ChatCompletionTokenLogprob] }, nil?: true |
#refusal ⇒ Array<OpenAI::Models::Chat::ChatCompletionTokenLogprob>?
A list of message refusal tokens with log probability information.
190 191 192 |
# File 'lib/openai/models/chat/chat_completion.rb', line 190 required :refusal, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Chat::ChatCompletionTokenLogprob] }, nil?: true |
Instance Method Details
#to_hash ⇒ {
128 |
# File 'sig/openai/models/chat/chat_completion.rbs', line 128
def to_hash: -> {
|