Class: OpenAI::Models::Chat::ChatCompletion::Moderation::Input::ModerationResults::Result
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Chat::ChatCompletion::Moderation::Input::ModerationResults::Result
- Defined in:
- lib/openai/models/chat/chat_completion.rb,
sig/openai/models/chat/chat_completion.rbs
Defined Under Namespace
Modules: CategoryAppliedInputType
Instance Attribute Summary collapse
-
#categories ⇒ ::Hash[Symbol, bool]
A dictionary of moderation categories to booleans, True if the input is flagged under this category.
-
#category_applied_input_types ⇒ ::Hash[Symbol, ::Array[OpenAI::Models::Chat::ChatCompletion::Moderation::Input::ModerationResults::Result::category_applied_input_type]]
Which modalities of input are reflected by the score for each category.
-
#category_scores ⇒ ::Hash[Symbol, Float]
A dictionary of moderation categories to scores.
-
#flagged ⇒ Boolean
A boolean indicating whether the content was flagged by any category.
-
#model ⇒ String
The moderation model that produced this result.
-
#type ⇒ :moderation_result
The object type, which was always
moderation_resultfor successful moderation results.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(model:, results:, type: :moderation_results) ⇒ Object
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/openai/models/chat/chat_completion.rb', line 347 class Result < OpenAI::Internal::Type::BaseModel # @!attribute categories # A dictionary of moderation categories to booleans, True if the input is flagged # under this category. # # @return [Hash{Symbol=>Boolean}] required :categories, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Boolean] # @!attribute category_applied_input_types # Which modalities of input are reflected by the score for each category. # # @return [Hash{Symbol=>Array<Symbol, OpenAI::Models::Chat::ChatCompletion::Moderation::Input::ModerationResults::Result::CategoryAppliedInputType>}] required( :category_applied_input_types, -> do OpenAI::Internal::Type::HashOf[ OpenAI::Internal::Type::ArrayOf[ enum: OpenAI::Chat::ChatCompletion::Moderation::Input::ModerationResults::Result::CategoryAppliedInputType ] ] end ) # @!attribute category_scores # A dictionary of moderation categories to scores. # # @return [Hash{Symbol=>Float}] required :category_scores, OpenAI::Internal::Type::HashOf[Float] # @!attribute flagged # A boolean indicating whether the content was flagged by any category. # # @return [Boolean] required :flagged, OpenAI::Internal::Type::Boolean # @!attribute model # The moderation model that produced this result. # # @return [String] required :model, String # @!attribute type # The object type, which was always `moderation_result` for successful moderation # results. # # @return [Symbol, :moderation_result] required :type, const: :moderation_result # @!method initialize(categories:, category_applied_input_types:, category_scores:, flagged:, model:, type: :moderation_result) # A moderation result produced for the response input or output. # # @param categories [Hash{Symbol=>Boolean}] # A dictionary of moderation categories to booleans, True if the input is flagged # under this category. # # @param category_applied_input_types [Hash{Symbol=>Array<Symbol, OpenAI::Models::Chat::ChatCompletion::Moderation::Input::ModerationResults::Result::CategoryAppliedInputType>}] # Which modalities of input are reflected by the score for each category. # # @param category_scores [Hash{Symbol=>Float}] # A dictionary of moderation categories to scores. # # @param flagged [Boolean] # A boolean indicating whether the content was flagged by any category. # # @param model [String] # The moderation model that produced this result. # # @param type [Symbol, :moderation_result] # The object type, which was always `moderation_result` for successful moderation # results. module CategoryAppliedInputType extend OpenAI::Internal::Type::Enum TEXT = :text IMAGE = :image # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#categories ⇒ ::Hash[Symbol, bool]
A dictionary of moderation categories to booleans, True if the input is flagged under this category.
353 |
# File 'lib/openai/models/chat/chat_completion.rb', line 353 required :categories, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Boolean] |
#category_applied_input_types ⇒ ::Hash[Symbol, ::Array[OpenAI::Models::Chat::ChatCompletion::Moderation::Input::ModerationResults::Result::category_applied_input_type]]
Which modalities of input are reflected by the score for each category.
359 360 361 362 363 364 365 366 367 368 |
# File 'lib/openai/models/chat/chat_completion.rb', line 359 required( :category_applied_input_types, -> do OpenAI::Internal::Type::HashOf[ OpenAI::Internal::Type::ArrayOf[ enum: OpenAI::Chat::ChatCompletion::Moderation::Input::ModerationResults::Result::CategoryAppliedInputType ] ] end ) |
#category_scores ⇒ ::Hash[Symbol, Float]
A dictionary of moderation categories to scores.
374 |
# File 'lib/openai/models/chat/chat_completion.rb', line 374 required :category_scores, OpenAI::Internal::Type::HashOf[Float] |
#flagged ⇒ Boolean
A boolean indicating whether the content was flagged by any category.
380 |
# File 'lib/openai/models/chat/chat_completion.rb', line 380 required :flagged, OpenAI::Internal::Type::Boolean |
#model ⇒ String
The moderation model that produced this result.
386 |
# File 'lib/openai/models/chat/chat_completion.rb', line 386 required :model, String |
#type ⇒ :moderation_result
The object type, which was always moderation_result for successful moderation
results.
393 |
# File 'lib/openai/models/chat/chat_completion.rb', line 393 required :type, const: :moderation_result |
Instance Method Details
#to_hash ⇒ {
390 |
# File 'sig/openai/models/chat/chat_completion.rbs', line 390
def to_hash: -> {
|