Class: OpenAI::Models::Chat::ChatCompletionChunk::Choice::Delta::ToolCall::Function
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Chat::ChatCompletionChunk::Choice::Delta::ToolCall::Function
- Defined in:
- lib/openai/models/chat/chat_completion_chunk.rb,
sig/openai/models/chat/chat_completion_chunk.rbs
Overview
Instance Attribute Summary collapse
-
#arguments ⇒ String?
The arguments to call the function with, as generated by the model in JSON format.
-
#name ⇒ String?
The name of the function to call.
Instance Method Summary collapse
-
#initialize ⇒ Function
constructor
A new instance of Function.
- #to_hash ⇒ { arguments: String, name: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Function
Returns a new instance of Function.
225 |
# File 'sig/openai/models/chat/chat_completion_chunk.rbs', line 225
def initialize: (?arguments: String, ?name: String) -> void
|
Instance Attribute Details
#arguments ⇒ String?
The arguments to call the function with, as generated by the model in JSON format. Note that the model does not always generate valid JSON, and may hallucinate parameters not defined by your function schema. Validate the arguments in your code before calling your function.
302 |
# File 'lib/openai/models/chat/chat_completion_chunk.rb', line 302 optional :arguments, String |
#name ⇒ String?
The name of the function to call.
308 |
# File 'lib/openai/models/chat/chat_completion_chunk.rb', line 308 optional :name, String |
Instance Method Details
#to_hash ⇒ { arguments: String, name: String }
227 |
# File 'sig/openai/models/chat/chat_completion_chunk.rbs', line 227
def to_hash: -> { arguments: String, name: String }
|