Class: OpenAI::Models::Chat::ChatCompletionChunk::Moderation::Output::ModerationResults::Result

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/chat/chat_completion_chunk.rb,
sig/openai/models/chat/chat_completion_chunk.rbs

Defined Under Namespace

Modules: CategoryAppliedInputType

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(model:, results:, type: :moderation_results) ⇒ Object

Successful moderation results for the request input or generated output.

Parameters:



642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
# File 'lib/openai/models/chat/chat_completion_chunk.rb', line 642

class Result < OpenAI::Internal::Type::BaseModel
  # @!attribute categories
  #   A dictionary of moderation categories to booleans, True if the input is flagged
  #   under this category.
  #
  #   @return [Hash{Symbol=>Boolean}]
  required :categories, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Boolean]

  # @!attribute category_applied_input_types
  #   Which modalities of input are reflected by the score for each category.
  #
  #   @return [Hash{Symbol=>Array<Symbol, OpenAI::Models::Chat::ChatCompletionChunk::Moderation::Output::ModerationResults::Result::CategoryAppliedInputType>}]
  required(
    :category_applied_input_types,
    -> do
      OpenAI::Internal::Type::HashOf[
        OpenAI::Internal::Type::ArrayOf[
          enum: OpenAI::Chat::ChatCompletionChunk::Moderation::Output::ModerationResults::Result::CategoryAppliedInputType
        ]
      ]
    end
  )

  # @!attribute category_scores
  #   A dictionary of moderation categories to scores.
  #
  #   @return [Hash{Symbol=>Float}]
  required :category_scores, OpenAI::Internal::Type::HashOf[Float]

  # @!attribute flagged
  #   A boolean indicating whether the content was flagged by any category.
  #
  #   @return [Boolean]
  required :flagged, OpenAI::Internal::Type::Boolean

  # @!attribute model
  #   The moderation model that produced this result.
  #
  #   @return [String]
  required :model, String

  # @!attribute type
  #   The object type, which was always `moderation_result` for successful moderation
  #   results.
  #
  #   @return [Symbol, :moderation_result]
  required :type, const: :moderation_result

  # @!method initialize(categories:, category_applied_input_types:, category_scores:, flagged:, model:, type: :moderation_result)
  #   Some parameter documentations has been truncated, see
  #   {OpenAI::Models::Chat::ChatCompletionChunk::Moderation::Output::ModerationResults::Result}
  #   for more details.
  #
  #   A moderation result produced for the response input or output.
  #
  #   @param categories [Hash{Symbol=>Boolean}] A dictionary of moderation categories to booleans, True if the input is flagged
  #
  #   @param category_applied_input_types [Hash{Symbol=>Array<Symbol, OpenAI::Models::Chat::ChatCompletionChunk::Moderation::Output::ModerationResults::Result::CategoryAppliedInputType>}] Which modalities of input are reflected by the score for each category.
  #
  #   @param category_scores [Hash{Symbol=>Float}] A dictionary of moderation categories to scores.
  #
  #   @param flagged [Boolean] A boolean indicating whether the content was flagged by any category.
  #
  #   @param model [String] The moderation model that produced this result.
  #
  #   @param type [Symbol, :moderation_result] The object type, which was always `moderation_result` for successful moderation

  module CategoryAppliedInputType
    extend OpenAI::Internal::Type::Enum

    TEXT = :text
    IMAGE = :image

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#categoriesHash{Symbol=>Boolean}

A dictionary of moderation categories to booleans, True if the input is flagged under this category.

Parameters:

  • value (::Hash[Symbol, bool])

Returns:



648
# File 'lib/openai/models/chat/chat_completion_chunk.rb', line 648

required :categories, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Boolean]

#category_applied_input_typesHash{Symbol=>Array<Symbol, OpenAI::Models::Chat::ChatCompletionChunk::Moderation::Output::ModerationResults::Result::CategoryAppliedInputType>}

Which modalities of input are reflected by the score for each category.

Parameters:

  • value (::Hash[Symbol, ::Array[OpenAI::Models::Chat::ChatCompletionChunk::Moderation::Output::ModerationResults::Result::category_applied_input_type]])

Returns:



654
655
656
657
658
659
660
661
662
663
# File 'lib/openai/models/chat/chat_completion_chunk.rb', line 654

required(
  :category_applied_input_types,
  -> do
    OpenAI::Internal::Type::HashOf[
      OpenAI::Internal::Type::ArrayOf[
        enum: OpenAI::Chat::ChatCompletionChunk::Moderation::Output::ModerationResults::Result::CategoryAppliedInputType
      ]
    ]
  end
)

#category_scoresHash{Symbol=>Float}

A dictionary of moderation categories to scores.

Parameters:

  • value (::Hash[Symbol, Float])

Returns:

  • (Hash{Symbol=>Float})


669
# File 'lib/openai/models/chat/chat_completion_chunk.rb', line 669

required :category_scores, OpenAI::Internal::Type::HashOf[Float]

#flaggedBoolean

A boolean indicating whether the content was flagged by any category.

Parameters:

Returns:



675
# File 'lib/openai/models/chat/chat_completion_chunk.rb', line 675

required :flagged, OpenAI::Internal::Type::Boolean

#modelString

The moderation model that produced this result.

Parameters:

  • value (String)

Returns:

  • (String)


681
# File 'lib/openai/models/chat/chat_completion_chunk.rb', line 681

required :model, String

#typeSymbol, :moderation_result

The object type, which was always moderation_result for successful moderation results.

Parameters:

  • value (:moderation_result)

Returns:

  • (Symbol, :moderation_result)


688
# File 'lib/openai/models/chat/chat_completion_chunk.rb', line 688

required :type, const: :moderation_result

Instance Method Details

#to_hash{

Returns:

  • ({)


481
# File 'sig/openai/models/chat/chat_completion_chunk.rbs', line 481

def to_hash: -> {