Class: OpenAI::Models::Chat::ChatCompletionMessage::Annotation::URLCitation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Chat::ChatCompletionMessage::Annotation::URLCitation
- Defined in:
- lib/openai/models/chat/chat_completion_message.rb,
sig/openai/models/chat/chat_completion_message.rbs
Overview
Instance Attribute Summary collapse
-
#end_index ⇒ Integer
The index of the last character of the URL citation in the message.
-
#start_index ⇒ Integer
The index of the first character of the URL citation in the message.
-
#title ⇒ String
The title of the web resource.
-
#url ⇒ String
The URL of the web resource.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
102 |
# File 'sig/openai/models/chat/chat_completion_message.rbs', line 102
def initialize: (
|
Instance Attribute Details
#end_index ⇒ Integer
The index of the last character of the URL citation in the message.
111 |
# File 'lib/openai/models/chat/chat_completion_message.rb', line 111 required :end_index, Integer |
#start_index ⇒ Integer
The index of the first character of the URL citation in the message.
117 |
# File 'lib/openai/models/chat/chat_completion_message.rb', line 117 required :start_index, Integer |
#title ⇒ String
The title of the web resource.
123 |
# File 'lib/openai/models/chat/chat_completion_message.rb', line 123 required :title, String |
#url ⇒ String
The URL of the web resource.
129 |
# File 'lib/openai/models/chat/chat_completion_message.rb', line 129 required :url, String |
Instance Method Details
#to_hash ⇒ {
109 |
# File 'sig/openai/models/chat/chat_completion_message.rbs', line 109
def to_hash: -> {
|