Class: OpenAI::Models::Chat::ChatCompletionMessage::FunctionCall Deprecated
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Chat::ChatCompletionMessage::FunctionCall
- Defined in:
- lib/openai/models/chat/chat_completion_message.rb,
sig/openai/models/chat/chat_completion_message.rbs
Overview
Instance Attribute Summary collapse
-
#arguments ⇒ String
The arguments to call the function with, as generated by the model in JSON format.
-
#name ⇒ String
The name of the function to call.
Instance Method Summary collapse
-
#initialize ⇒ FunctionCall
constructor
A new instance of FunctionCall.
- #to_hash ⇒ { arguments: String, name: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ FunctionCall
Returns a new instance of FunctionCall.
125 |
# File 'sig/openai/models/chat/chat_completion_message.rbs', line 125
def initialize: (arguments: String, name: String) -> void
|
Instance Attribute Details
#arguments ⇒ String
The arguments to call the function with, as generated by the model in JSON format. Note that the model does not always generate valid JSON, and may hallucinate parameters not defined by your function schema. Validate the arguments in your code before calling your function.
155 |
# File 'lib/openai/models/chat/chat_completion_message.rb', line 155 required :arguments, String |
#name ⇒ String
The name of the function to call.
161 |
# File 'lib/openai/models/chat/chat_completion_message.rb', line 161 required :name, String |
Instance Method Details
#to_hash ⇒ { arguments: String, name: String }
127 |
# File 'sig/openai/models/chat/chat_completion_message.rbs', line 127
def to_hash: -> { arguments: String, name: String }
|