Class: OpenAI::Models::Chat::ChatCompletionStreamOptions
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Chat::ChatCompletionStreamOptions
- Defined in:
- lib/openai/models/chat/chat_completion_stream_options.rb,
sig/openai/models/chat/chat_completion_stream_options.rbs
Instance Attribute Summary collapse
-
#include_obfuscation ⇒ Boolean?
When true, stream obfuscation will be enabled.
-
#include_usage ⇒ Boolean?
If set, an additional chunk will be streamed before the
data: [DONE]message.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
18 |
# File 'sig/openai/models/chat/chat_completion_stream_options.rbs', line 18
def initialize: (
|
Instance Attribute Details
#include_obfuscation ⇒ Boolean?
When true, stream obfuscation will be enabled. Stream obfuscation adds random
characters to an obfuscation field on streaming delta events to normalize
payload sizes as a mitigation to certain side-channel attacks. These obfuscation
fields are included by default, but add a small amount of overhead to the data
stream. You can set include_obfuscation to false to optimize for bandwidth if
you trust the network links between your application and the OpenAI API.
16 |
# File 'lib/openai/models/chat/chat_completion_stream_options.rb', line 16 optional :include_obfuscation, OpenAI::Internal::Type::Boolean |
#include_usage ⇒ Boolean?
If set, an additional chunk will be streamed before the data: [DONE] message.
The usage field on this chunk shows the token usage statistics for the entire
request, and the choices field will always be an empty array.
All other chunks will also include a usage field, but with a null value.
NOTE: If the stream is interrupted, you may not receive the final usage
chunk which contains the total token usage for the request.
28 |
# File 'lib/openai/models/chat/chat_completion_stream_options.rb', line 28 optional :include_usage, OpenAI::Internal::Type::Boolean |
Instance Method Details
#to_hash ⇒ { include_obfuscation: bool, include_usage: bool }
23 |
# File 'sig/openai/models/chat/chat_completion_stream_options.rbs', line 23
def to_hash: -> { include_obfuscation: bool, include_usage: bool }
|