Class: OpenAI::Models::Chat::CompletionCreateParams::Function Deprecated
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Chat::CompletionCreateParams::Function
- Defined in:
- lib/openai/models/chat/completion_create_params.rb,
sig/openai/models/chat/completion_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#description ⇒ String?
A description of what the function does, used by the model to choose when and how to call the function.
-
#name ⇒ String
The name of the function to be called.
-
#parameters ⇒ Hash{Symbol=>Object}?
The parameters the functions accepts, described as a JSON Schema object.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
286 |
# File 'sig/openai/models/chat/completion_create_params.rbs', line 286
def initialize: (
|
Instance Attribute Details
#description ⇒ String?
A description of what the function does, used by the model to choose when and how to call the function.
571 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 571 optional :description, String |
#name ⇒ String
The name of the function to be called. Must be a-z, A-Z, 0-9, or contain underscores and dashes, with a maximum length of 64.
564 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 564 required :name, String |
#parameters ⇒ Hash{Symbol=>Object}?
The parameters the functions accepts, described as a JSON Schema object. See the guide for examples, and the JSON Schema reference for documentation about the format.
Omitting parameters defines a function with an empty parameter list.
583 |
# File 'lib/openai/models/chat/completion_create_params.rb', line 583 optional :parameters, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Unknown] |
Instance Method Details
#to_hash ⇒ {
292 |
# File 'sig/openai/models/chat/completion_create_params.rbs', line 292
def to_hash: -> {
|