Class: OpenAI::Models::CompletionUsage::CompletionTokensDetails

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/completion_usage.rb,
sig/openai/models/completion_usage.rbs

Overview

See Also:

  • OpenAI::Models::CompletionUsage#completion_tokens_details

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



72
# File 'sig/openai/models/completion_usage.rbs', line 72

def initialize: (

Instance Attribute Details

#accepted_prediction_tokensInteger?

When using Predicted Outputs, the number of tokens in the prediction that appeared in the completion.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


56
# File 'lib/openai/models/completion_usage.rb', line 56

optional :accepted_prediction_tokens, Integer

#audio_tokensInteger?

Audio input tokens generated by the model.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


62
# File 'lib/openai/models/completion_usage.rb', line 62

optional :audio_tokens, Integer

#reasoning_tokensInteger?

Tokens generated by the model for reasoning.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


68
# File 'lib/openai/models/completion_usage.rb', line 68

optional :reasoning_tokens, Integer

#rejected_prediction_tokensInteger?

When using Predicted Outputs, the number of tokens in the prediction that did not appear in the completion. However, like reasoning tokens, these tokens are still counted in the total completion tokens for purposes of billing, output, and context window limits.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


77
# File 'lib/openai/models/completion_usage.rb', line 77

optional :rejected_prediction_tokens, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


79
# File 'sig/openai/models/completion_usage.rbs', line 79

def to_hash: -> {