Class: OpenAI::Models::ContentProvenanceCheck

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/content_provenance_check.rb,
sig/openai/models/content_provenance_check.rbs

Overview

See Also:

  • OpenAI::Resources::ContentProvenanceChecks#create

Defined Under Namespace

Modules: Object, Result

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_at:, object:, results:) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::ContentProvenanceCheck for more details.

Parameters:



# File 'lib/openai/models/content_provenance_check.rb', line 26

Instance Attribute Details

#created_atInteger

The Unix timestamp, in seconds, when the provenance check was created.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


11
# File 'lib/openai/models/content_provenance_check.rb', line 11

required :created_at, Integer

#objectSymbol, OpenAI::Models::ContentProvenanceCheck::Object

The object type. Always content_provenance_check for this endpoint.

Parameters:

  • value (OpenAI::Models::ContentProvenanceCheck::object)

Returns:



17
# File 'lib/openai/models/content_provenance_check.rb', line 17

required :object, enum: -> { OpenAI::ContentProvenanceCheck::Object }

#resultsArray<OpenAI::Models::ContentProvenanceCheck::Result::C2PA, OpenAI::Models::ContentProvenanceCheck::Result::SynthID>

The provenance results that apply to the uploaded file. Image results include C2PA and SynthID; audio results include SynthID.

Parameters:

  • value (::Array[OpenAI::Models::ContentProvenanceCheck::result])

Returns:



24
# File 'lib/openai/models/content_provenance_check.rb', line 24

required :results, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::ContentProvenanceCheck::Result] }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/content_provenance_check.rb', line 44

Instance Method Details

#to_hash{

Returns:

  • ({)


23
# File 'sig/openai/models/content_provenance_check.rbs', line 23

def to_hash: -> {