Class: OpenAI::Models::ContentProvenanceCheck
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::ContentProvenanceCheck
- Defined in:
- lib/openai/models/content_provenance_check.rb,
sig/openai/models/content_provenance_check.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#created_at ⇒ Integer
The Unix timestamp, in seconds, when the provenance check was created.
-
#object ⇒ Symbol, OpenAI::Models::ContentProvenanceCheck::Object
The object type.
-
#results ⇒ Array<OpenAI::Models::ContentProvenanceCheck::Result::C2PA, OpenAI::Models::ContentProvenanceCheck::Result::SynthID>
The provenance results that apply to the uploaded file.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(created_at:, object:, results:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContentProvenanceCheck for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(created_at:, object:, results:) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::ContentProvenanceCheck for more details.
|
|
# File 'lib/openai/models/content_provenance_check.rb', line 26
|
Instance Attribute Details
#created_at ⇒ Integer
The Unix timestamp, in seconds, when the provenance check was created.
11 |
# File 'lib/openai/models/content_provenance_check.rb', line 11 required :created_at, Integer |
#object ⇒ Symbol, OpenAI::Models::ContentProvenanceCheck::Object
The object type. Always content_provenance_check for this endpoint.
17 |
# File 'lib/openai/models/content_provenance_check.rb', line 17 required :object, enum: -> { OpenAI::ContentProvenanceCheck::Object } |
#results ⇒ Array<OpenAI::Models::ContentProvenanceCheck::Result::C2PA, OpenAI::Models::ContentProvenanceCheck::Result::SynthID>
The provenance results that apply to the uploaded file. Image results include C2PA and SynthID; audio results include SynthID.
24 |
# File 'lib/openai/models/content_provenance_check.rb', line 24 required :results, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::ContentProvenanceCheck::Result] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/content_provenance_check.rb', line 44
|
Instance Method Details
#to_hash ⇒ {
23 |
# File 'sig/openai/models/content_provenance_check.rbs', line 23
def to_hash: -> {
|