Class: OpenAI::Models::ContentProvenanceCheck::Result::C2PA
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::ContentProvenanceCheck::Result::C2PA
- Defined in:
- lib/openai/models/content_provenance_check.rb,
sig/openai/models/content_provenance_check.rbs
Defined Under Namespace
Modules: Outcome, ValidationState
Instance Attribute Summary collapse
-
#generated_at ⇒ String?
The UTC RFC 3339 timestamp recorded by the provenance signal for when the asset was generated, when available.
-
#issuer ⇒ String?
The C2PA manifest issuer, when available.
-
#model ⇒ String?
The OpenAI model recorded by the provenance signal, when available.
-
#outcome ⇒ Symbol, OpenAI::Models::ContentProvenanceCheck::Result::C2PA::Outcome
Whether a supported OpenAI C2PA provenance signal was detected.
-
#type ⇒ Symbol, :c2pa
The provenance signal type.
-
#validation_state ⇒ Symbol, OpenAI::Models::ContentProvenanceCheck::Result::C2PA::ValidationState
The validation status of the C2PA manifest in the uploaded image.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(generated_at:, issuer:, model:, outcome:, validation_state:, type: :c2pa) ⇒ Object
constructor
Some parameter documentations has been truncated, see C2PA for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(generated_at:, issuer:, model:, outcome:, validation_state:, type: :c2pa) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::ContentProvenanceCheck::Result::C2PA for more details.
|
|
# File 'lib/openai/models/content_provenance_check.rb', line 101
|
Instance Attribute Details
#generated_at ⇒ String?
The UTC RFC 3339 timestamp recorded by the provenance signal for when the asset was generated, when available.
63 |
# File 'lib/openai/models/content_provenance_check.rb', line 63 required :generated_at, String, nil?: true |
#issuer ⇒ String?
The C2PA manifest issuer, when available.
69 |
# File 'lib/openai/models/content_provenance_check.rb', line 69 required :issuer, String, nil?: true |
#model ⇒ String?
The OpenAI model recorded by the provenance signal, when available.
75 |
# File 'lib/openai/models/content_provenance_check.rb', line 75 required :model, String, nil?: true |
#outcome ⇒ Symbol, OpenAI::Models::ContentProvenanceCheck::Result::C2PA::Outcome
Whether a supported OpenAI C2PA provenance signal was detected. If
not_detected, it means the tool did not find supported signals in the uploaded
file. The content could still have been generated by OpenAI if the metadata was
stripped or has evidence of tampering, the watermark was degraded, it comes from
a legacy generation model, or it was created before provenance signals were
available. Content could also still be AI-generated by another company's model,
which the tool currently does not detect.
87 |
# File 'lib/openai/models/content_provenance_check.rb', line 87 required :outcome, enum: -> { OpenAI::ContentProvenanceCheck::Result::C2PA::Outcome } |
#type ⇒ Symbol, :c2pa
The provenance signal type. Always c2pa.
93 |
# File 'lib/openai/models/content_provenance_check.rb', line 93 required :type, const: :c2pa |
#validation_state ⇒ Symbol, OpenAI::Models::ContentProvenanceCheck::Result::C2PA::ValidationState
The validation status of the C2PA manifest in the uploaded image.
99 |
# File 'lib/openai/models/content_provenance_check.rb', line 99 required :validation_state, enum: -> { OpenAI::ContentProvenanceCheck::Result::C2PA::ValidationState } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/content_provenance_check.rb', line 132
|
Instance Method Details
#to_hash ⇒ {
78 |
# File 'sig/openai/models/content_provenance_check.rbs', line 78
def to_hash: -> {
|