Class: OpenAI::Models::ContentProvenanceCheck::Result::C2PA
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::ContentProvenanceCheck::Result::C2PA
- Defined in:
- lib/openai/models/content_provenance_check.rb,
sig/openai/models/content_provenance_check.rbs
Defined Under Namespace
Modules: Outcome, ValidationState
Instance Attribute Summary collapse
-
#generated_at ⇒ String?
The UTC RFC 3339 timestamp recorded by the provenance signal for when the asset was generated, when available.
-
#issuer ⇒ String?
The C2PA manifest issuer, when available.
-
#model ⇒ String?
The OpenAI model recorded by the provenance signal, when available.
-
#outcome ⇒ OpenAI::Models::ContentProvenanceCheck::Result::C2PA::outcome
Whether a supported OpenAI C2PA provenance signal was detected.
-
#type ⇒ :c2pa
The provenance signal type.
-
#validation_state ⇒ OpenAI::Models::ContentProvenanceCheck::Result::C2PA::validation_state
The validation status of the C2PA manifest in the uploaded image.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(generated_at:, issuer:, model:, outcome:, validation_state:, type: :c2pa) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(generated_at:, issuer:, model:, outcome:, validation_state:, type: :c2pa) ⇒ Object
|
|
# File 'lib/openai/models/content_provenance_check.rb', line 102
|
Instance Attribute Details
#generated_at ⇒ String?
The UTC RFC 3339 timestamp recorded by the provenance signal for when the asset was generated, when available.
64 |
# File 'lib/openai/models/content_provenance_check.rb', line 64 required :generated_at, String, nil?: true |
#issuer ⇒ String?
The C2PA manifest issuer, when available.
70 |
# File 'lib/openai/models/content_provenance_check.rb', line 70 required :issuer, String, nil?: true |
#model ⇒ String?
The OpenAI model recorded by the provenance signal, when available.
76 |
# File 'lib/openai/models/content_provenance_check.rb', line 76 required :model, String, nil?: true |
#outcome ⇒ OpenAI::Models::ContentProvenanceCheck::Result::C2PA::outcome
Whether a supported OpenAI C2PA provenance signal was detected. If
not_detected, it means the tool did not find supported signals in the uploaded
file. The content could still have been generated by OpenAI if the metadata was
stripped or has evidence of tampering, the watermark was degraded, it comes from
a legacy generation model, or it was created before provenance signals were
available. Content could also still be AI-generated by another company's model,
which the tool currently does not detect.
88 |
# File 'lib/openai/models/content_provenance_check.rb', line 88 required :outcome, enum: -> { OpenAI::ContentProvenanceCheck::Result::C2PA::Outcome } |
#type ⇒ :c2pa
The provenance signal type. Always c2pa.
94 |
# File 'lib/openai/models/content_provenance_check.rb', line 94 required :type, const: :c2pa |
#validation_state ⇒ OpenAI::Models::ContentProvenanceCheck::Result::C2PA::validation_state
The validation status of the C2PA manifest in the uploaded image.
100 |
# File 'lib/openai/models/content_provenance_check.rb', line 100 required :validation_state, enum: -> { OpenAI::ContentProvenanceCheck::Result::C2PA::ValidationState } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/content_provenance_check.rb', line 143
|
Instance Method Details
#to_hash ⇒ {
121 |
# File 'sig/openai/models/content_provenance_check.rbs', line 121
def to_hash: -> {
|