Module: OpenAI::Models::ContentProvenanceCheck::Result::C2PA::Outcome
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/content_provenance_check.rb,
sig/openai/models/content_provenance_check.rbs
Overview
Whether a supported OpenAI C2PA provenance signal was detected. If
not_detected, it means the tool did not find supported signals in the uploaded
file. The content could still have been generated by OpenAI if the metadata was
stripped or has evidence of tampering, the watermark was degraded, it comes from
a legacy generation model, or it was created before provenance signals were
available. Content could also still be AI-generated by another company's model,
which the tool currently does not detect.
Constant Summary collapse
- DETECTED =
:detected- NOT_DETECTED =
:not_detected
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[OpenAI::Models::ContentProvenanceCheck::Result::C2PA::outcome]
95 |
# File 'sig/openai/models/content_provenance_check.rbs', line 95
def self?.values: -> ::Array[OpenAI::Models::ContentProvenanceCheck::Result::C2PA::outcome]
|