Class: OpenAI::Models::ContentProvenanceCheck::Result::SynthID
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::ContentProvenanceCheck::Result::SynthID
- Defined in:
- lib/openai/models/content_provenance_check.rb,
sig/openai/models/content_provenance_check.rbs
Defined Under Namespace
Modules: Outcome
Instance Attribute Summary collapse
-
#generated_at ⇒ String?
The UTC RFC 3339 timestamp recorded by the provenance signal for when the asset was generated, when available.
-
#model ⇒ String?
The OpenAI model recorded by the provenance signal, when available.
-
#outcome ⇒ Symbol, OpenAI::Models::ContentProvenanceCheck::Result::SynthID::Outcome
Whether a supported OpenAI SynthID watermark was detected.
-
#type ⇒ Symbol, :synthid
The provenance signal type.
Instance Method Summary collapse
-
#initialize(generated_at:, model:, outcome:, type: :synthid) ⇒ Object
constructor
Some parameter documentations has been truncated, see SynthID for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(generated_at:, model:, outcome:, type: :synthid) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::ContentProvenanceCheck::Result::SynthID for more details.
|
|
# File 'lib/openai/models/content_provenance_check.rb', line 184
|
Instance Attribute Details
#generated_at ⇒ String?
The UTC RFC 3339 timestamp recorded by the provenance signal for when the asset was generated, when available.
158 |
# File 'lib/openai/models/content_provenance_check.rb', line 158 required :generated_at, String, nil?: true |
#model ⇒ String?
The OpenAI model recorded by the provenance signal, when available.
164 |
# File 'lib/openai/models/content_provenance_check.rb', line 164 required :model, String, nil?: true |
#outcome ⇒ Symbol, OpenAI::Models::ContentProvenanceCheck::Result::SynthID::Outcome
Whether a supported OpenAI SynthID watermark was detected. If not_detected, it
means the tool did not find supported signals in the uploaded file. The content
could still have been generated by OpenAI if the metadata was stripped or has
evidence of tampering, the watermark was degraded, it comes from a legacy
generation model, or it was created before provenance signals were available.
Content could also still be AI-generated by another company's model, which the
tool currently does not detect.
176 |
# File 'lib/openai/models/content_provenance_check.rb', line 176 required :outcome, enum: -> { OpenAI::ContentProvenanceCheck::Result::SynthID::Outcome } |
#type ⇒ Symbol, :synthid
The provenance signal type. Always synthid.
182 |
# File 'lib/openai/models/content_provenance_check.rb', line 182 required :type, const: :synthid |
Instance Method Details
#to_hash ⇒ {
136 |
# File 'sig/openai/models/content_provenance_check.rbs', line 136
def to_hash: -> {
|