Class: OpenAI::Models::Conversations::ComputerScreenshotContent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/conversations/computer_screenshot_content.rb

Defined Under Namespace

Modules: Detail

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(detail:, file_id:, image_url:, type: :computer_screenshot) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Conversations::ComputerScreenshotContent for more details.

A screenshot of a computer.

Parameters:

  • The detail level of the screenshot image to be sent to the model. One of high,

  • The identifier of an uploaded file that contains the screenshot.

  • The URL of the screenshot image.

  • (defaults to: :computer_screenshot)

    Specifies the event type. For a computer screenshot, this property is always set



# File 'lib/openai/models/conversations/computer_screenshot_content.rb', line 33


Instance Attribute Details

#detailSymbol, OpenAI::Models::Conversations::ComputerScreenshotContent::Detail

The detail level of the screenshot image to be sent to the model. One of high, low, auto, or original. Defaults to auto.

Returns:



12
# File 'lib/openai/models/conversations/computer_screenshot_content.rb', line 12

required :detail, enum: -> { OpenAI::Conversations::ComputerScreenshotContent::Detail }

#file_idString?

The identifier of an uploaded file that contains the screenshot.

Returns:



18
# File 'lib/openai/models/conversations/computer_screenshot_content.rb', line 18

required :file_id, String, nil?: true

#image_urlString?

The URL of the screenshot image.

Returns:



24
# File 'lib/openai/models/conversations/computer_screenshot_content.rb', line 24

required :image_url, String, nil?: true

#typeSymbol, :computer_screenshot

Specifies the event type. For a computer screenshot, this property is always set to computer_screenshot.

Returns:



31
# File 'lib/openai/models/conversations/computer_screenshot_content.rb', line 31

required :type, const: :computer_screenshot