Class: OpenAI::Models::Conversations::ContainerFileCitationBody
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Conversations::ContainerFileCitationBody
- Defined in:
- lib/openai/models/conversations/container_file_citation_body.rb
Instance Attribute Summary collapse
-
#container_id ⇒ String
The ID of the container file.
-
#end_index ⇒ Integer
The index of the last character of the container file citation in the message.
-
#file_id ⇒ String
The ID of the file.
-
#filename ⇒ String
The filename of the container file cited.
-
#start_index ⇒ Integer
The index of the first character of the container file citation in the message.
-
#type ⇒ Symbol, :container_file_citation
The type of the container file citation.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(container_id: , end_index: , file_id: , filename: , start_index: , type: :container_file_citation) ⇒ Object
|
|
# File 'lib/openai/models/conversations/container_file_citation_body.rb', line 43
|
Instance Attribute Details
#container_id ⇒ String
The ID of the container file.
11 |
# File 'lib/openai/models/conversations/container_file_citation_body.rb', line 11 required :container_id, String |
#end_index ⇒ Integer
The index of the last character of the container file citation in the message.
17 |
# File 'lib/openai/models/conversations/container_file_citation_body.rb', line 17 required :end_index, Integer |
#file_id ⇒ String
The ID of the file.
23 |
# File 'lib/openai/models/conversations/container_file_citation_body.rb', line 23 required :file_id, String |
#filename ⇒ String
The filename of the container file cited.
29 |
# File 'lib/openai/models/conversations/container_file_citation_body.rb', line 29 required :filename, String |
#start_index ⇒ Integer
The index of the first character of the container file citation in the message.
35 |
# File 'lib/openai/models/conversations/container_file_citation_body.rb', line 35 required :start_index, Integer |
#type ⇒ Symbol, :container_file_citation
The type of the container file citation. Always ‘container_file_citation`.
41 |
# File 'lib/openai/models/conversations/container_file_citation_body.rb', line 41 required :type, const: :container_file_citation |