Class: OpenAI::Models::Conversations::ItemListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Conversations::ItemListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/conversations/item_list_params.rb
Overview
Defined Under Namespace
Modules: Order
Instance Attribute Summary collapse
-
#after ⇒ String?
An item ID to list items after, used in pagination.
- #conversation_id ⇒ String
-
#include ⇒ Array<Symbol, OpenAI::Models::Responses::ResponseIncludable>?
Specify additional output data to include in the model response.
-
#limit ⇒ Integer?
A limit on the number of objects to be returned.
-
#order ⇒ Symbol, ...
The order to return the input items in.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(conversation_id:, after: nil, include: nil, limit: nil, order: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ItemListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(conversation_id:, after: nil, include: nil, limit: nil, order: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Conversations::ItemListParams for more details.
|
|
# File 'lib/openai/models/conversations/item_list_params.rb', line 61
|
Instance Attribute Details
#after ⇒ String?
An item ID to list items after, used in pagination.
20 |
# File 'lib/openai/models/conversations/item_list_params.rb', line 20 optional :after, String |
#conversation_id ⇒ String
14 |
# File 'lib/openai/models/conversations/item_list_params.rb', line 14 required :conversation_id, String |
#include ⇒ Array<Symbol, OpenAI::Models::Responses::ResponseIncludable>?
Specify additional output data to include in the model response. Currently supported values are:
-
web_search_call.action.sources: Include the sources of the web search tool call. -
code_interpreter_call.outputs: Includes the outputs of python code execution in code interpreter tool call items. -
computer_call_output.output.image_url: Include image urls from the computer call output. -
file_search_call.results: Include the search results of the file search tool call. -
message.input_image.image_url: Include image urls from the input message. -
message.output_text.logprobs: Include logprobs with assistant messages. -
reasoning.encrypted_content: Includes an encrypted version of reasoning tokens in reasoning item outputs. This enables reasoning items to be used in multi-turn conversations when using the Responses API statelessly (like when thestoreparameter is set tofalse, or when an organization is enrolled in the zero data retention program).
43 |
# File 'lib/openai/models/conversations/item_list_params.rb', line 43 optional :include, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Responses::ResponseIncludable] } |
#limit ⇒ Integer?
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 20.
50 |
# File 'lib/openai/models/conversations/item_list_params.rb', line 50 optional :limit, Integer |
#order ⇒ Symbol, ...
The order to return the input items in. Default is desc.
-
asc: Return the input items in ascending order. -
desc: Return the input items in descending order.
59 |
# File 'lib/openai/models/conversations/item_list_params.rb', line 59 optional :order, enum: -> { OpenAI::Conversations::ItemListParams::Order } |