Class: OpenAI::Models::EvalCreateParams::DataSourceConfig::Custom

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/eval_create_params.rb,
sig/openai/models/eval_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



66
# File 'sig/openai/models/eval_create_params.rbs', line 66

def initialize: (

Instance Attribute Details

#include_sample_schemaBoolean?

Whether the eval should expect you to populate the sample namespace (ie, by generating responses off of your data source)

Parameters:

Returns:



96
# File 'lib/openai/models/eval_create_params.rb', line 96

optional :include_sample_schema, OpenAI::Internal::Type::Boolean

#item_schemaHash{Symbol=>Object}

The json schema for each row in the data source.

Parameters:

  • value (::Hash[Symbol, top])

Returns:

  • (Hash{Symbol=>Object})


83
# File 'lib/openai/models/eval_create_params.rb', line 83

required :item_schema, OpenAI::Internal::Type::HashOf[OpenAI::Internal::Type::Unknown]

#typeSymbol, :custom

The type of data source. Always custom.

Parameters:

  • value (:custom)

Returns:

  • (Symbol, :custom)


89
# File 'lib/openai/models/eval_create_params.rb', line 89

required :type, const: :custom

Instance Method Details

#to_hash{

Returns:

  • ({)


72
# File 'sig/openai/models/eval_create_params.rbs', line 72

def to_hash: -> {