Class: OpenAI::Models::Evals::CreateEvalCompletionsRunDataSource::SamplingParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Evals::CreateEvalCompletionsRunDataSource::SamplingParams
- Defined in:
- lib/openai/models/evals/create_eval_completions_run_data_source.rb,
sig/openai/models/evals/create_eval_completions_run_data_source.rbs
Overview
Defined Under Namespace
Modules: ResponseFormat
Constant Summary collapse
- OpenAI =
Instance Attribute Summary collapse
-
#max_completion_tokens ⇒ Integer?
The maximum number of tokens in the generated output.
-
#reasoning_effort ⇒ OpenAI::Models::reasoning_effort?
Constrains effort on reasoning for reasoning models.
-
#response_format ⇒ OpenAI::Models::Evals::CreateEvalCompletionsRunDataSource::SamplingParams::response_format?
An object specifying the format that the model must output.
-
#seed ⇒ Integer?
A seed value to initialize the randomness, during sampling.
-
#temperature ⇒ Float?
A higher temperature increases randomness in the outputs.
-
#tools ⇒ ::Array[OpenAI::Chat::ChatCompletionFunctionTool]?
A list of tools the model may call.
-
#top_p ⇒ Float?
An alternative to temperature for nucleus sampling; 1.0 includes all tokens.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(max_completion_tokens: nil, reasoning_effort: nil, response_format: nil, seed: nil, temperature: nil, tools: nil, top_p: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(max_completion_tokens: nil, reasoning_effort: nil, response_format: nil, seed: nil, temperature: nil, tools: nil, top_p: nil) ⇒ Object
|
|
# File 'lib/openai/models/evals/create_eval_completions_run_data_source.rb', line 568
|
Instance Attribute Details
#max_completion_tokens ⇒ Integer?
The maximum number of tokens in the generated output.
511 |
# File 'lib/openai/models/evals/create_eval_completions_run_data_source.rb', line 511 optional :max_completion_tokens, Integer |
#reasoning_effort ⇒ OpenAI::Models::reasoning_effort?
Constrains effort on reasoning for reasoning models. Currently supported values
are none, minimal, low, medium, high, xhigh, and max. Reducing
reasoning effort can result in faster responses and fewer tokens used on
reasoning in a response. Not all reasoning models support every value. See the
reasoning guide for
model-specific support.
522 |
# File 'lib/openai/models/evals/create_eval_completions_run_data_source.rb', line 522 optional :reasoning_effort, enum: -> { OpenAI::ReasoningEffort }, nil?: true |
#response_format ⇒ OpenAI::Models::Evals::CreateEvalCompletionsRunDataSource::SamplingParams::response_format?
An object specifying the format that the model must output.
Setting to { "type": "json_schema", "json_schema": {...} } enables Structured
Outputs which ensures the model will match your supplied JSON schema. Learn more
in the
Structured Outputs guide.
Setting to { "type": "json_object" } enables the older JSON mode, which
ensures the message the model generates is valid JSON. Using json_schema is
preferred for models that support it.
537 538 539 540 |
# File 'lib/openai/models/evals/create_eval_completions_run_data_source.rb', line 537 optional( :response_format, union: -> { OpenAI::Evals::CreateEvalCompletionsRunDataSource::SamplingParams::ResponseFormat } ) |
#seed ⇒ Integer?
A seed value to initialize the randomness, during sampling.
546 |
# File 'lib/openai/models/evals/create_eval_completions_run_data_source.rb', line 546 optional :seed, Integer |
#temperature ⇒ Float?
A higher temperature increases randomness in the outputs.
552 |
# File 'lib/openai/models/evals/create_eval_completions_run_data_source.rb', line 552 optional :temperature, Float |
#tools ⇒ ::Array[OpenAI::Chat::ChatCompletionFunctionTool]?
A list of tools the model may call. Currently, only functions are supported as a tool. Use this to provide a list of functions the model may generate JSON inputs for. A max of 128 functions are supported.
560 |
# File 'lib/openai/models/evals/create_eval_completions_run_data_source.rb', line 560 optional :tools, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Chat::ChatCompletionFunctionTool] } |
#top_p ⇒ Float?
An alternative to temperature for nucleus sampling; 1.0 includes all tokens.
566 |
# File 'lib/openai/models/evals/create_eval_completions_run_data_source.rb', line 566 optional :top_p, Float |
Instance Method Details
#to_hash ⇒ {
563 |
# File 'sig/openai/models/evals/create_eval_completions_run_data_source.rbs', line 563
def to_hash: -> {
|