Class: OpenAI::Models::Evals::CreateEvalCompletionsRunDataSource::Source::StoredCompletions
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Evals::CreateEvalCompletionsRunDataSource::Source::StoredCompletions
- Defined in:
- lib/openai/models/evals/create_eval_completions_run_data_source.rb,
sig/openai/models/evals/create_eval_completions_run_data_source.rbs
Instance Attribute Summary collapse
-
#created_after ⇒ Integer?
An optional Unix timestamp to filter items created after this time.
-
#created_before ⇒ Integer?
An optional Unix timestamp to filter items created before this time.
-
#limit ⇒ Integer?
An optional maximum number of items to return.
-
#metadata ⇒ OpenAI::Models::metadata?
Set of 16 key-value pairs that can be attached to an object.
-
#model ⇒ String?
An optional model to filter by (e.g., 'gpt-6-astra').
-
#type ⇒ :stored_completions
The type of source.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
199 |
# File 'sig/openai/models/evals/create_eval_completions_run_data_source.rbs', line 199
def initialize: (
|
Instance Attribute Details
#created_after ⇒ Integer?
An optional Unix timestamp to filter items created after this time.
152 |
# File 'lib/openai/models/evals/create_eval_completions_run_data_source.rb', line 152 optional :created_after, Integer, nil?: true |
#created_before ⇒ Integer?
An optional Unix timestamp to filter items created before this time.
158 |
# File 'lib/openai/models/evals/create_eval_completions_run_data_source.rb', line 158 optional :created_before, Integer, nil?: true |
#limit ⇒ Integer?
An optional maximum number of items to return.
164 |
# File 'lib/openai/models/evals/create_eval_completions_run_data_source.rb', line 164 optional :limit, Integer, nil?: true |
#metadata ⇒ OpenAI::Models::metadata?
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
175 |
# File 'lib/openai/models/evals/create_eval_completions_run_data_source.rb', line 175 optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true |
#model ⇒ String?
An optional model to filter by (e.g., 'gpt-6-astra').
181 |
# File 'lib/openai/models/evals/create_eval_completions_run_data_source.rb', line 181 optional :model, String, nil?: true |
#type ⇒ :stored_completions
The type of source. Always stored_completions.
146 |
# File 'lib/openai/models/evals/create_eval_completions_run_data_source.rb', line 146 required :type, const: :stored_completions |
Instance Method Details
#to_hash ⇒ {
208 |
# File 'sig/openai/models/evals/create_eval_completions_run_data_source.rbs', line 208
def to_hash: -> {
|