Class: OpenAI::Models::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::SamplingParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::SamplingParams
- Defined in:
- lib/openai/models/evals/run_create_params.rb,
sig/openai/models/evals/run_create_params.rbs
Overview
Defined Under Namespace
Classes: Text
Instance Attribute Summary collapse
-
#max_completion_tokens ⇒ Integer?
The maximum number of tokens in the generated output.
-
#reasoning_effort ⇒ OpenAI::Models::reasoning_effort?
Constrains effort on reasoning for reasoning models.
-
#seed ⇒ Integer?
A seed value to initialize the randomness, during sampling.
-
#temperature ⇒ Float?
A higher temperature increases randomness in the outputs.
-
#text ⇒ OpenAI::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::SamplingParams::Text?
Configuration options for a text response from the model.
-
#tools ⇒ ::Array[OpenAI::Models::Responses::tool]?
An array of tools the model may call while generating a response.
-
#top_p ⇒ Float?
An alternative to temperature for nucleus sampling; 1.0 includes all tokens.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(max_completion_tokens: nil, reasoning_effort: nil, seed: nil, temperature: nil, text: nil, tools: nil, top_p: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(max_completion_tokens: nil, reasoning_effort: nil, seed: nil, temperature: nil, text: nil, tools: nil, top_p: nil) ⇒ Object
|
|
# File 'lib/openai/models/evals/run_create_params.rb', line 746
|
Instance Attribute Details
#max_completion_tokens ⇒ Integer?
The maximum number of tokens in the generated output.
680 |
# File 'lib/openai/models/evals/run_create_params.rb', line 680 optional :max_completion_tokens, Integer |
#reasoning_effort ⇒ OpenAI::Models::reasoning_effort?
Constrains effort on reasoning for reasoning models. Currently supported values
are none, minimal, low, medium, high, xhigh, and max. Reducing
reasoning effort can result in faster responses and fewer tokens used on
reasoning in a response. Not all reasoning models support every value. See the
reasoning guide for
model-specific support.
691 |
# File 'lib/openai/models/evals/run_create_params.rb', line 691 optional :reasoning_effort, enum: -> { OpenAI::ReasoningEffort }, nil?: true |
#seed ⇒ Integer?
A seed value to initialize the randomness, during sampling.
697 |
# File 'lib/openai/models/evals/run_create_params.rb', line 697 optional :seed, Integer |
#temperature ⇒ Float?
A higher temperature increases randomness in the outputs.
703 |
# File 'lib/openai/models/evals/run_create_params.rb', line 703 optional :temperature, Float |
#text ⇒ OpenAI::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::SamplingParams::Text?
Configuration options for a text response from the model. Can be plain text or structured JSON data. Learn more:
713 714 715 716 717 718 |
# File 'lib/openai/models/evals/run_create_params.rb', line 713 optional( :text, -> { OpenAI::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::SamplingParams::Text } ) |
#tools ⇒ ::Array[OpenAI::Models::Responses::tool]?
An array of tools the model may call while generating a response. You can
specify which tool to use by setting the tool_choice parameter.
The two categories of tools you can provide the model are:
- Built-in tools: Tools that are provided by OpenAI that extend the model's capabilities, like web search or file search. Learn more about built-in tools.
- Function calls (custom tools): Functions that are defined by you, enabling the model to call your own code. Learn more about function calling.
738 |
# File 'lib/openai/models/evals/run_create_params.rb', line 738 optional :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Responses::Tool] } |
#top_p ⇒ Float?
An alternative to temperature for nucleus sampling; 1.0 includes all tokens.
744 |
# File 'lib/openai/models/evals/run_create_params.rb', line 744 optional :top_p, Float |
Instance Method Details
#to_hash ⇒ {
729 |
# File 'sig/openai/models/evals/run_create_params.rbs', line 729
def to_hash: -> {
|