Class: OpenAI::Models::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::Source::Responses

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/evals/run_create_params.rb,
sig/openai/models/evals/run_create_params.rbs

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



198
# File 'sig/openai/models/evals/run_create_params.rbs', line 198

def initialize: (

Instance Attribute Details

#created_afterInteger?

Only include items created after this timestamp (inclusive). This is a query parameter used to select responses.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


227
# File 'lib/openai/models/evals/run_create_params.rb', line 227

optional :created_after, Integer, nil?: true

#created_beforeInteger?

Only include items created before this timestamp (inclusive). This is a query parameter used to select responses.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


234
# File 'lib/openai/models/evals/run_create_params.rb', line 234

optional :created_before, Integer, nil?: true

#instructions_searchString?

Optional string to search the 'instructions' field. This is a query parameter used to select responses.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


241
# File 'lib/openai/models/evals/run_create_params.rb', line 241

optional :instructions_search, String, nil?: true

#metadataObject?

Metadata filter for the responses. This is a query parameter used to select responses.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


248
# File 'lib/openai/models/evals/run_create_params.rb', line 248

optional :metadata, OpenAI::Internal::Type::Unknown, nil?: true

#modelString?

The name of the model to find responses for. This is a query parameter used to select responses.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


255
# File 'lib/openai/models/evals/run_create_params.rb', line 255

optional :model, String, nil?: true

#reasoning_effortSymbol, ...

Constrains effort on reasoning for reasoning models. Currently supported values are none, minimal, low, medium, high, xhigh, and max. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response. Not all reasoning models support every value. See the reasoning guide for model-specific support.

Parameters:

  • value (OpenAI::Models::reasoning_effort, nil)

Returns:



266
# File 'lib/openai/models/evals/run_create_params.rb', line 266

optional :reasoning_effort, enum: -> { OpenAI::ReasoningEffort }, nil?: true

#temperatureFloat?

Sampling temperature. This is a query parameter used to select responses.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


272
# File 'lib/openai/models/evals/run_create_params.rb', line 272

optional :temperature, Float, nil?: true

#toolsArray<String>?

List of tool names. This is a query parameter used to select responses.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


278
# File 'lib/openai/models/evals/run_create_params.rb', line 278

optional :tools, OpenAI::Internal::Type::ArrayOf[String], nil?: true

#top_pFloat?

Nucleus sampling parameter. This is a query parameter used to select responses.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


284
# File 'lib/openai/models/evals/run_create_params.rb', line 284

optional :top_p, Float, nil?: true

#typeSymbol, :responses

The type of run data source. Always responses.

Parameters:

  • value (:responses)

Returns:

  • (Symbol, :responses)


220
# File 'lib/openai/models/evals/run_create_params.rb', line 220

required :type, const: :responses

#usersArray<String>?

List of user identifiers. This is a query parameter used to select responses.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


290
# File 'lib/openai/models/evals/run_create_params.rb', line 290

optional :users, OpenAI::Internal::Type::ArrayOf[String], nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


212
# File 'sig/openai/models/evals/run_create_params.rbs', line 212

def to_hash: -> {