Class: OpenAI::Models::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::Source::Responses
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::Source::Responses
- Defined in:
- lib/openai/models/evals/run_create_params.rb,
sig/openai/models/evals/run_create_params.rbs
Instance Attribute Summary collapse
-
#created_after ⇒ Integer?
Only include items created after this timestamp (inclusive).
-
#created_before ⇒ Integer?
Only include items created before this timestamp (inclusive).
-
#instructions_search ⇒ String?
Optional string to search the 'instructions' field.
-
#metadata ⇒ top?
Metadata filter for the responses.
-
#model ⇒ String?
The name of the model to find responses for.
-
#reasoning_effort ⇒ OpenAI::Models::reasoning_effort?
Constrains effort on reasoning for reasoning models.
-
#temperature ⇒ Float?
Sampling temperature.
-
#tools ⇒ ::Array[String]?
List of tool names.
-
#top_p ⇒ Float?
Nucleus sampling parameter.
-
#type ⇒ :responses
The type of run data source.
-
#users ⇒ ::Array[String]?
List of user identifiers.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
306 |
# File 'sig/openai/models/evals/run_create_params.rbs', line 306
def initialize: (
|
Instance Attribute Details
#created_after ⇒ Integer?
Only include items created after this timestamp (inclusive). This is a query parameter used to select responses.
238 |
# File 'lib/openai/models/evals/run_create_params.rb', line 238 optional :created_after, Integer, nil?: true |
#created_before ⇒ Integer?
Only include items created before this timestamp (inclusive). This is a query parameter used to select responses.
245 |
# File 'lib/openai/models/evals/run_create_params.rb', line 245 optional :created_before, Integer, nil?: true |
#instructions_search ⇒ String?
Optional string to search the 'instructions' field. This is a query parameter used to select responses.
252 |
# File 'lib/openai/models/evals/run_create_params.rb', line 252 optional :instructions_search, String, nil?: true |
#metadata ⇒ top?
Metadata filter for the responses. This is a query parameter used to select responses.
259 |
# File 'lib/openai/models/evals/run_create_params.rb', line 259 optional :metadata, OpenAI::Internal::Type::Unknown, nil?: true |
#model ⇒ String?
The name of the model to find responses for. This is a query parameter used to select responses.
266 |
# File 'lib/openai/models/evals/run_create_params.rb', line 266 optional :model, String, nil?: true |
#reasoning_effort ⇒ OpenAI::Models::reasoning_effort?
Constrains effort on reasoning for reasoning models. Currently supported values
are none, minimal, low, medium, high, xhigh, and max. Reducing
reasoning effort can result in faster responses and fewer tokens used on
reasoning in a response. Not all reasoning models support every value. See the
reasoning guide for
model-specific support.
277 |
# File 'lib/openai/models/evals/run_create_params.rb', line 277 optional :reasoning_effort, enum: -> { OpenAI::ReasoningEffort }, nil?: true |
#temperature ⇒ Float?
Sampling temperature. This is a query parameter used to select responses.
283 |
# File 'lib/openai/models/evals/run_create_params.rb', line 283 optional :temperature, Float, nil?: true |
#tools ⇒ ::Array[String]?
List of tool names. This is a query parameter used to select responses.
289 |
# File 'lib/openai/models/evals/run_create_params.rb', line 289 optional :tools, OpenAI::Internal::Type::ArrayOf[String], nil?: true |
#top_p ⇒ Float?
Nucleus sampling parameter. This is a query parameter used to select responses.
295 |
# File 'lib/openai/models/evals/run_create_params.rb', line 295 optional :top_p, Float, nil?: true |
#type ⇒ :responses
The type of run data source. Always responses.
231 |
# File 'lib/openai/models/evals/run_create_params.rb', line 231 required :type, const: :responses |
#users ⇒ ::Array[String]?
List of user identifiers. This is a query parameter used to select responses.
301 |
# File 'lib/openai/models/evals/run_create_params.rb', line 301 optional :users, OpenAI::Internal::Type::ArrayOf[String], nil?: true |
Instance Method Details
#to_hash ⇒ {
320 |
# File 'sig/openai/models/evals/run_create_params.rbs', line 320
def to_hash: -> {
|