Class: OpenAI::Models::Evals::RunCreateParams::DataSource::CreateEvalResponsesRunDataSource::Source::Responses

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/openai/models/evals/run_create_params.rb,
sig/openai/models/evals/run_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



198
# File 'sig/openai/models/evals/run_create_params.rbs', line 198

def initialize: (

Instance Attribute Details

#created_afterInteger?

Only include items created after this timestamp (inclusive). This is a query parameter used to select responses.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


205
# File 'lib/openai/models/evals/run_create_params.rb', line 205

optional :created_after, Integer, nil?: true

#created_beforeInteger?

Only include items created before this timestamp (inclusive). This is a query parameter used to select responses.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


212
# File 'lib/openai/models/evals/run_create_params.rb', line 212

optional :created_before, Integer, nil?: true

#instructions_searchString?

Optional string to search the 'instructions' field. This is a query parameter used to select responses.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


219
# File 'lib/openai/models/evals/run_create_params.rb', line 219

optional :instructions_search, String, nil?: true

#metadataObject?

Metadata filter for the responses. This is a query parameter used to select responses.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


226
# File 'lib/openai/models/evals/run_create_params.rb', line 226

optional :metadata, OpenAI::Internal::Type::Unknown, nil?: true

#modelString?

The name of the model to find responses for. This is a query parameter used to select responses.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


233
# File 'lib/openai/models/evals/run_create_params.rb', line 233

optional :model, String, nil?: true

#reasoning_effortSymbol, ...

Constrains effort on reasoning for reasoning models. Currently supported values are none, minimal, low, medium, high, and xhigh. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response.

  • gpt-5.1 defaults to none, which does not perform reasoning. The supported reasoning values for gpt-5.1 are none, low, medium, and high. Tool calls are supported for all reasoning values in gpt-5.1.
  • All models before gpt-5.1 default to medium reasoning effort, and do not support none.
  • The gpt-5-pro model defaults to (and only supports) high reasoning effort.
  • xhigh is supported for all models after gpt-5.1-codex-max.

Parameters:

  • value (OpenAI::Models::reasoning_effort, nil)

Returns:



251
# File 'lib/openai/models/evals/run_create_params.rb', line 251

optional :reasoning_effort, enum: -> { OpenAI::ReasoningEffort }, nil?: true

#temperatureFloat?

Sampling temperature. This is a query parameter used to select responses.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


257
# File 'lib/openai/models/evals/run_create_params.rb', line 257

optional :temperature, Float, nil?: true

#toolsArray<String>?

List of tool names. This is a query parameter used to select responses.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


263
# File 'lib/openai/models/evals/run_create_params.rb', line 263

optional :tools, OpenAI::Internal::Type::ArrayOf[String], nil?: true

#top_pFloat?

Nucleus sampling parameter. This is a query parameter used to select responses.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


269
# File 'lib/openai/models/evals/run_create_params.rb', line 269

optional :top_p, Float, nil?: true

#typeSymbol, :responses

The type of run data source. Always responses.

Parameters:

  • value (:responses)

Returns:

  • (Symbol, :responses)


198
# File 'lib/openai/models/evals/run_create_params.rb', line 198

required :type, const: :responses

#usersArray<String>?

List of user identifiers. This is a query parameter used to select responses.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


275
# File 'lib/openai/models/evals/run_create_params.rb', line 275

optional :users, OpenAI::Internal::Type::ArrayOf[String], nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


212
# File 'sig/openai/models/evals/run_create_params.rbs', line 212

def to_hash: -> {