Class: OpenAI::Models::Evals::RunCreateResponse::DataSource::Responses::Source::Responses
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Evals::RunCreateResponse::DataSource::Responses::Source::Responses
- Defined in:
- lib/openai/models/evals/run_create_response.rb,
sig/openai/models/evals/run_create_response.rbs
Instance Attribute Summary collapse
-
#created_after ⇒ Integer?
Only include items created after this timestamp (inclusive).
-
#created_before ⇒ Integer?
Only include items created before this timestamp (inclusive).
-
#instructions_search ⇒ String?
Optional string to search the 'instructions' field.
-
#metadata ⇒ Object?
Metadata filter for the responses.
-
#model ⇒ String?
The name of the model to find responses for.
-
#reasoning_effort ⇒ Symbol, ...
Constrains effort on reasoning for reasoning models.
-
#temperature ⇒ Float?
Sampling temperature.
-
#tools ⇒ Array<String>?
List of tool names.
-
#top_p ⇒ Float?
Nucleus sampling parameter.
-
#type ⇒ Symbol, :responses
The type of run data source.
-
#users ⇒ Array<String>?
List of user identifiers.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
240 |
# File 'sig/openai/models/evals/run_create_response.rbs', line 240
def initialize: (
|
Instance Attribute Details
#created_after ⇒ Integer?
Only include items created after this timestamp (inclusive). This is a query parameter used to select responses.
286 |
# File 'lib/openai/models/evals/run_create_response.rb', line 286 optional :created_after, Integer, nil?: true |
#created_before ⇒ Integer?
Only include items created before this timestamp (inclusive). This is a query parameter used to select responses.
293 |
# File 'lib/openai/models/evals/run_create_response.rb', line 293 optional :created_before, Integer, nil?: true |
#instructions_search ⇒ String?
Optional string to search the 'instructions' field. This is a query parameter used to select responses.
300 |
# File 'lib/openai/models/evals/run_create_response.rb', line 300 optional :instructions_search, String, nil?: true |
#metadata ⇒ Object?
Metadata filter for the responses. This is a query parameter used to select responses.
307 |
# File 'lib/openai/models/evals/run_create_response.rb', line 307 optional :metadata, OpenAI::Internal::Type::Unknown, nil?: true |
#model ⇒ String?
The name of the model to find responses for. This is a query parameter used to select responses.
314 |
# File 'lib/openai/models/evals/run_create_response.rb', line 314 optional :model, String, nil?: true |
#reasoning_effort ⇒ Symbol, ...
Constrains effort on reasoning for
reasoning models. Currently
supported values are none, minimal, low, medium, high, and xhigh.
Reducing reasoning effort can result in faster responses and fewer tokens used
on reasoning in a response.
gpt-5.1defaults tonone, which does not perform reasoning. The supported reasoning values forgpt-5.1arenone,low,medium, andhigh. Tool calls are supported for all reasoning values in gpt-5.1.- All models before
gpt-5.1default tomediumreasoning effort, and do not supportnone. - The
gpt-5-promodel defaults to (and only supports)highreasoning effort. xhighis supported for all models aftergpt-5.1-codex-max.
332 |
# File 'lib/openai/models/evals/run_create_response.rb', line 332 optional :reasoning_effort, enum: -> { OpenAI::ReasoningEffort }, nil?: true |
#temperature ⇒ Float?
Sampling temperature. This is a query parameter used to select responses.
338 |
# File 'lib/openai/models/evals/run_create_response.rb', line 338 optional :temperature, Float, nil?: true |
#tools ⇒ Array<String>?
List of tool names. This is a query parameter used to select responses.
344 |
# File 'lib/openai/models/evals/run_create_response.rb', line 344 optional :tools, OpenAI::Internal::Type::ArrayOf[String], nil?: true |
#top_p ⇒ Float?
Nucleus sampling parameter. This is a query parameter used to select responses.
350 |
# File 'lib/openai/models/evals/run_create_response.rb', line 350 optional :top_p, Float, nil?: true |
#type ⇒ Symbol, :responses
The type of run data source. Always responses.
279 |
# File 'lib/openai/models/evals/run_create_response.rb', line 279 required :type, const: :responses |
#users ⇒ Array<String>?
List of user identifiers. This is a query parameter used to select responses.
356 |
# File 'lib/openai/models/evals/run_create_response.rb', line 356 optional :users, OpenAI::Internal::Type::ArrayOf[String], nil?: true |
Instance Method Details
#to_hash ⇒ {
254 |
# File 'sig/openai/models/evals/run_create_response.rbs', line 254
def to_hash: -> {
|