Class: OpenAI::Models::FineTuning::FineTuningJobWandbIntegrationObject
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::FineTuning::FineTuningJobWandbIntegrationObject
- Defined in:
- lib/openai/models/fine_tuning/fine_tuning_job_wandb_integration_object.rb,
sig/openai/models/fine_tuning/fine_tuning_job_wandb_integration_object.rbs
Instance Attribute Summary collapse
-
#type ⇒ Symbol, :wandb
The type of the integration being enabled for the fine-tuning job.
-
#wandb ⇒ OpenAI::Models::FineTuning::FineTuningJobWandbIntegration
The settings for your integration with Weights and Biases.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
17 |
# File 'sig/openai/models/fine_tuning/fine_tuning_job_wandb_integration_object.rbs', line 17
def initialize: (
|
Instance Attribute Details
#type ⇒ Symbol, :wandb
The type of the integration being enabled for the fine-tuning job
11 |
# File 'lib/openai/models/fine_tuning/fine_tuning_job_wandb_integration_object.rb', line 11 required :type, const: :wandb |
#wandb ⇒ OpenAI::Models::FineTuning::FineTuningJobWandbIntegration
The settings for your integration with Weights and Biases. This payload specifies the project that metrics will be sent to. Optionally, you can set an explicit display name for your run, add tags to your run, and set a default entity (team, username, etc) to be associated with your run.
20 |
# File 'lib/openai/models/fine_tuning/fine_tuning_job_wandb_integration_object.rb', line 20 required :wandb, -> { OpenAI::FineTuning::FineTuningJobWandbIntegration } |
Instance Method Details
#to_hash ⇒ {
22 |
# File 'sig/openai/models/fine_tuning/fine_tuning_job_wandb_integration_object.rbs', line 22
def to_hash: -> {
|