Class: OpenAI::Models::FineTuning::JobCreateParams::Integration::Wandb

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/fine_tuning/job_create_params.rb,
sig/openai/models/fine_tuning/job_create_params.rbs

Overview

See Also:

  • OpenAI::Models::FineTuning::JobCreateParams::Integration#wandb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



195
# File 'sig/openai/models/fine_tuning/job_create_params.rbs', line 195

def initialize: (

Instance Attribute Details

#entityString?

The entity to use for the run. This allows you to set the team or username of the WandB user that you would like associated with the run. If not set, the default entity for the registered WandB API key is used.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


289
# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 289

optional :entity, String, nil?: true

#nameString?

A display name to set for the run. If not set, we will use the Job ID as the name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


296
# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 296

optional :name, String, nil?: true

#projectString

The name of the project that the new run will be created under.

Parameters:

  • value (String)

Returns:

  • (String)


281
# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 281

required :project, String

#tagsArray<String>?

A list of tags to be attached to the newly created run. These tags are passed through directly to WandB. Some default tags are generated by OpenAI: "openai/finetune", "openai/base-model", "openai/ftjob-abcdef".

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


304
# File 'lib/openai/models/fine_tuning/job_create_params.rb', line 304

optional :tags, OpenAI::Internal::Type::ArrayOf[String]

Instance Method Details

#to_hash{

Returns:

  • ({)


202
# File 'sig/openai/models/fine_tuning/job_create_params.rbs', line 202

def to_hash: -> {