Class: OpenAI::Models::Graders::ScoreModelGrader::SamplingParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Graders::ScoreModelGrader::SamplingParams
- Defined in:
- lib/openai/models/graders/score_model_grader.rb
Overview
Instance Attribute Summary collapse
-
#max_completions_tokens ⇒ Integer?
The maximum number of tokens the grader model may generate in its response.
-
#reasoning_effort ⇒ Symbol, ...
Constrains effort on reasoning for [reasoning models](platform.openai.com/docs/guides/reasoning).
-
#seed ⇒ Integer?
A seed value to initialize the randomness, during sampling.
-
#temperature ⇒ Float?
A higher temperature increases randomness in the outputs.
-
#top_p ⇒ Float?
An alternative to temperature for nucleus sampling; 1.0 includes all tokens.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#max_completions_tokens ⇒ Integer?
The maximum number of tokens the grader model may generate in its response.
220 |
# File 'lib/openai/models/graders/score_model_grader.rb', line 220 optional :max_completions_tokens, Integer, nil?: true |
#reasoning_effort ⇒ Symbol, ...
Constrains effort on reasoning for [reasoning models](platform.openai.com/docs/guides/reasoning). Currently supported values are ‘minimal`, `low`, `medium`, and `high`. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response.
Note: The ‘gpt-5-pro` model defaults to (and only supports) `high` reasoning effort.
233 |
# File 'lib/openai/models/graders/score_model_grader.rb', line 233 optional :reasoning_effort, enum: -> { OpenAI::ReasoningEffort }, nil?: true |
#seed ⇒ Integer?
A seed value to initialize the randomness, during sampling.
239 |
# File 'lib/openai/models/graders/score_model_grader.rb', line 239 optional :seed, Integer, nil?: true |
#temperature ⇒ Float?
A higher temperature increases randomness in the outputs.
245 |
# File 'lib/openai/models/graders/score_model_grader.rb', line 245 optional :temperature, Float, nil?: true |
#top_p ⇒ Float?
An alternative to temperature for nucleus sampling; 1.0 includes all tokens.
251 |
# File 'lib/openai/models/graders/score_model_grader.rb', line 251 optional :top_p, Float, nil?: true |