Class: OpenAI::Models::Graders::ScoreModelGrader::SamplingParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Graders::ScoreModelGrader::SamplingParams
- Defined in:
- lib/openai/models/graders/score_model_grader.rb,
sig/openai/models/graders/score_model_grader.rbs
Overview
Instance Attribute Summary collapse
-
#max_completions_tokens ⇒ Integer?
The maximum number of tokens the grader model may generate in its response.
-
#reasoning_effort ⇒ Symbol, ...
Constrains effort on reasoning for reasoning models.
-
#seed ⇒ Integer?
A seed value to initialize the randomness, during sampling.
-
#temperature ⇒ Float?
A higher temperature increases randomness in the outputs.
-
#top_p ⇒ Float?
An alternative to temperature for nucleus sampling; 1.0 includes all tokens.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
178 |
# File 'sig/openai/models/graders/score_model_grader.rbs', line 178
def initialize: (
|
Instance Attribute Details
#max_completions_tokens ⇒ Integer?
The maximum number of tokens the grader model may generate in its response.
223 |
# File 'lib/openai/models/graders/score_model_grader.rb', line 223 optional :max_completions_tokens, Integer, nil?: true |
#reasoning_effort ⇒ Symbol, ...
Constrains effort on reasoning for
reasoning models. Currently
supported values are none, minimal, low, medium, high, and xhigh.
Reducing reasoning effort can result in faster responses and fewer tokens used
on reasoning in a response.
gpt-5.1defaults tonone, which does not perform reasoning. The supported reasoning values forgpt-5.1arenone,low,medium, andhigh. Tool calls are supported for all reasoning values in gpt-5.1.- All models before
gpt-5.1default tomediumreasoning effort, and do not supportnone. - The
gpt-5-promodel defaults to (and only supports)highreasoning effort. xhighis supported for all models aftergpt-5.1-codex-max.
241 |
# File 'lib/openai/models/graders/score_model_grader.rb', line 241 optional :reasoning_effort, enum: -> { OpenAI::ReasoningEffort }, nil?: true |
#seed ⇒ Integer?
A seed value to initialize the randomness, during sampling.
247 |
# File 'lib/openai/models/graders/score_model_grader.rb', line 247 optional :seed, Integer, nil?: true |
#temperature ⇒ Float?
A higher temperature increases randomness in the outputs.
253 |
# File 'lib/openai/models/graders/score_model_grader.rb', line 253 optional :temperature, Float, nil?: true |
#top_p ⇒ Float?
An alternative to temperature for nucleus sampling; 1.0 includes all tokens.
259 |
# File 'lib/openai/models/graders/score_model_grader.rb', line 259 optional :top_p, Float, nil?: true |
Instance Method Details
#to_hash ⇒ {
186 |
# File 'sig/openai/models/graders/score_model_grader.rbs', line 186
def to_hash: -> {
|