Class: OpenAI::Models::Graders::ScoreModelGrader::SamplingParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/graders/score_model_grader.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from OpenAI::Internal::Type::BaseModel

Instance Attribute Details

#max_completions_tokensInteger?

The maximum number of tokens the grader model may generate in its response.

Returns:

  • (Integer, nil)


220
# File 'lib/openai/models/graders/score_model_grader.rb', line 220

optional :max_completions_tokens, Integer, nil?: true

#reasoning_effortSymbol, ...

Constrains effort on reasoning for [reasoning models](platform.openai.com/docs/guides/reasoning). Currently supported values are ‘none`, `minimal`, `low`, `medium`, `high`, and `xhigh`. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response.

  • ‘gpt-5.1` defaults to `none`, which does not perform reasoning. The supported reasoning values for `gpt-5.1` are `none`, `low`, `medium`, and `high`. Tool calls are supported for all reasoning values in gpt-5.1.

  • All models before ‘gpt-5.1` default to `medium` reasoning effort, and do not support `none`.

  • The ‘gpt-5-pro` model defaults to (and only supports) `high` reasoning effort.

  • ‘xhigh` is currently only supported for `gpt-5.1-codex-max`.

Returns:



238
# File 'lib/openai/models/graders/score_model_grader.rb', line 238

optional :reasoning_effort, enum: -> { OpenAI::ReasoningEffort }, nil?: true

#seedInteger?

A seed value to initialize the randomness, during sampling.

Returns:

  • (Integer, nil)


244
# File 'lib/openai/models/graders/score_model_grader.rb', line 244

optional :seed, Integer, nil?: true

#temperatureFloat?

A higher temperature increases randomness in the outputs.

Returns:

  • (Float, nil)


250
# File 'lib/openai/models/graders/score_model_grader.rb', line 250

optional :temperature, Float, nil?: true

#top_pFloat?

An alternative to temperature for nucleus sampling; 1.0 includes all tokens.

Returns:

  • (Float, nil)


256
# File 'lib/openai/models/graders/score_model_grader.rb', line 256

optional :top_p, Float, nil?: true