Class: OpenAI::Models::ImageEditParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::ImageEditParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/image_edit_params.rb,
sig/openai/models/image_edit_params.rbs
Overview
Defined Under Namespace
Modules: Background, Image, InputFidelity, Model, OutputFormat, Quality, ResponseFormat, Size
Instance Attribute Summary collapse
-
#background ⇒ Symbol, ...
Allows to set transparency for the background of the generated image(s).
-
#image ⇒ Pathname, ...
The image(s) to edit.
-
#input_fidelity ⇒ Symbol, ...
Control how much effort the model will exert to match the style and features, especially facial features, of input images.
-
#mask ⇒ Pathname, ...
An additional image whose fully transparent areas (e.g. where alpha is zero) indicate where
imageshould be edited. -
#model ⇒ String, ...
The model to use for image generation.
-
#n ⇒ Integer?
The number of images to generate.
-
#output_compression ⇒ Integer?
The compression level (0-100%) for the generated images.
-
#output_format ⇒ Symbol, ...
The format in which the generated images are returned.
-
#partial_images ⇒ Integer?
The number of partial images to generate.
-
#prompt ⇒ String
A text description of the desired image(s).
-
#quality ⇒ Symbol, ...
The quality of the image that will be generated for GPT image models.
-
#response_format ⇒ Symbol, ...
The format in which the generated images are returned.
-
#size ⇒ String, ...
The size of the generated images.
-
#user ⇒ String?
A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(image:, prompt:, background: nil, input_fidelity: nil, mask: nil, model: nil, n: nil, output_compression: nil, output_format: nil, partial_images: nil, quality: nil, response_format: nil, size: nil, user: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ImageEditParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(image:, prompt:, background: nil, input_fidelity: nil, mask: nil, model: nil, n: nil, output_compression: nil, output_format: nil, partial_images: nil, quality: nil, response_format: nil, size: nil, user: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::ImageEditParams for more details.
|
|
# File 'lib/openai/models/image_edit_params.rb', line 150
|
Instance Attribute Details
#background ⇒ Symbol, ...
Allows to set transparency for the background of the generated image(s). This
parameter is only supported for GPT image models that support transparent
backgrounds. Must be one of transparent, opaque, or auto (default value).
When auto is used, the model will automatically determine the best background
for the image.
gpt-image-2 and gpt-image-2-2026-04-21 do not support transparent
backgrounds. Requests with background set to transparent will return an
error for these models; use opaque or auto instead.
If transparent, the output format needs to support transparency, so it should
be set to either png (default value) or webp.
48 |
# File 'lib/openai/models/image_edit_params.rb', line 48 optional :background, enum: -> { OpenAI::ImageEditParams::Background }, nil?: true |
#image ⇒ Pathname, ...
The image(s) to edit. Must be a supported image file or an array of images.
For the GPT image models (gpt-image-1, gpt-image-1-mini, gpt-image-1.5,
gpt-image-2, gpt-image-2-2026-04-21, and chatgpt-image-latest), each image
should be a png, webp, or jpg file less than 50MB. You can provide up to
16 images.
For dall-e-2, you can only provide one image, and it should be a square png
file less than 4MB.
24 |
# File 'lib/openai/models/image_edit_params.rb', line 24 required :image, union: -> { OpenAI::ImageEditParams::Image } |
#input_fidelity ⇒ Symbol, ...
Control how much effort the model will exert to match the style and features,
especially facial features, of input images. This parameter is only supported
for gpt-image-1 and gpt-image-1.5 and later models, unsupported for
gpt-image-1-mini. Supports high and low. Defaults to low.
57 |
# File 'lib/openai/models/image_edit_params.rb', line 57 optional :input_fidelity, enum: -> { OpenAI::ImageEditParams::InputFidelity }, nil?: true |
#mask ⇒ Pathname, ...
An additional image whose fully transparent areas (e.g. where alpha is zero)
indicate where image should be edited. If there are multiple images provided,
the mask will be applied on the first image. Must be a valid PNG file, less than
4MB, and have the same dimensions as image.
66 |
# File 'lib/openai/models/image_edit_params.rb', line 66 optional :mask, OpenAI::Internal::Type::FileInput |
#model ⇒ String, ...
The model to use for image generation. One of dall-e-2 or a GPT image model
(gpt-image-1, gpt-image-1-mini, gpt-image-1.5, gpt-image-2,
gpt-image-2-2026-04-21, or chatgpt-image-latest). Defaults to
gpt-image-1.5.
75 |
# File 'lib/openai/models/image_edit_params.rb', line 75 optional :model, union: -> { OpenAI::ImageEditParams::Model }, nil?: true |
#n ⇒ Integer?
The number of images to generate. Must be between 1 and 10.
81 |
# File 'lib/openai/models/image_edit_params.rb', line 81 optional :n, Integer, nil?: true |
#output_compression ⇒ Integer?
The compression level (0-100%) for the generated images. This parameter is only
supported for the GPT image models with the webp or jpeg output formats, and
defaults to 100.
89 |
# File 'lib/openai/models/image_edit_params.rb', line 89 optional :output_compression, Integer, nil?: true |
#output_format ⇒ Symbol, ...
The format in which the generated images are returned. This parameter is only
supported for the GPT image models. Must be one of png, jpeg, or webp. The
default value is png.
97 |
# File 'lib/openai/models/image_edit_params.rb', line 97 optional :output_format, enum: -> { OpenAI::ImageEditParams::OutputFormat }, nil?: true |
#partial_images ⇒ Integer?
The number of partial images to generate. This parameter is used for streaming responses that return partial images. Value must be between 0 and 3. When set to 0, the response will be a single image sent in one streaming event.
Note that the final image may be sent before the full number of partial images are generated if the full image is generated more quickly.
108 |
# File 'lib/openai/models/image_edit_params.rb', line 108 optional :partial_images, Integer, nil?: true |
#prompt ⇒ String
A text description of the desired image(s). The maximum length is 1000
characters for dall-e-2, and 32000 characters for the GPT image models.
31 |
# File 'lib/openai/models/image_edit_params.rb', line 31 required :prompt, String |
#quality ⇒ Symbol, ...
The quality of the image that will be generated for GPT image models. Defaults
to auto.
115 |
# File 'lib/openai/models/image_edit_params.rb', line 115 optional :quality, enum: -> { OpenAI::ImageEditParams::Quality }, nil?: true |
#response_format ⇒ Symbol, ...
The format in which the generated images are returned. Must be one of url or
b64_json. URLs are only valid for 60 minutes after the image has been
generated. This parameter is only supported for dall-e-2 (default is url for
dall-e-2), as GPT image models always return base64-encoded images.
124 |
# File 'lib/openai/models/image_edit_params.rb', line 124 optional :response_format, enum: -> { OpenAI::ImageEditParams::ResponseFormat }, nil?: true |
#size ⇒ String, ...
The size of the generated images. For gpt-image-2 and
gpt-image-2-2026-04-21, arbitrary resolutions are supported as WIDTHxHEIGHT
strings, for example 1536x864. Width and height must both be divisible by 16
and the requested aspect ratio must be between 1:3 and 3:1. Resolutions above
2560x1440 are experimental, and the maximum supported resolution is
3840x2160. The requested size must also satisfy the model's current pixel and
edge limits. The standard sizes 1024x1024, 1536x1024, and 1024x1536 are
supported by the GPT image models; auto is supported for models that allow
automatic sizing. For dall-e-2, use one of 256x256, 512x512, or
1024x1024. For dall-e-3, use one of 1024x1024, 1792x1024, or
1024x1792.
140 |
# File 'lib/openai/models/image_edit_params.rb', line 140 optional :size, union: -> { OpenAI::ImageEditParams::Size }, nil?: true |
#user ⇒ String?
A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse. Learn more.
148 |
# File 'lib/openai/models/image_edit_params.rb', line 148 optional :user, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/image_edit_params.rb', line 226
|
.variants ⇒ Array(String, Symbol, OpenAI::Models::ImageModel)
|
|
# File 'lib/openai/models/image_edit_params.rb', line 256
|
Instance Method Details
#to_hash ⇒ {
76 |
# File 'sig/openai/models/image_edit_params.rbs', line 76
def to_hash: -> {
|