Class: OpenAI::Models::ImageEditParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/image_edit_params.rb

Overview

See Also:

Defined Under Namespace

Modules: Background, Image, InputFidelity, Model, OutputFormat, Quality, ResponseFormat, Size

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(image: , prompt: , background: nil, input_fidelity: nil, mask: nil, model: nil, n: nil, output_compression: nil, output_format: nil, partial_images: nil, quality: nil, response_format: nil, size: nil, user: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::ImageEditParams for more details.

Parameters:

  • image (Pathname, StringIO, IO, String, OpenAI::FilePart, Array<Pathname, StringIO, IO, String, OpenAI::FilePart>) (defaults to: )

    The image(s) to edit. Must be a supported image file or an array of images.

  • prompt (String) (defaults to: )

    A text description of the desired image(s). The maximum length is 1000 character

  • background (Symbol, OpenAI::Models::ImageEditParams::Background, nil) (defaults to: nil)

    Allows to set transparency for the background of the generated image(s).

  • input_fidelity (Symbol, OpenAI::Models::ImageEditParams::InputFidelity, nil) (defaults to: nil)

    Control how much effort the model will exert to match the style and features,

  • mask (Pathname, StringIO, IO, String, OpenAI::FilePart) (defaults to: nil)

    An additional image whose fully transparent areas (e.g. where alpha is zero) ind

  • model (String, Symbol, OpenAI::Models::ImageModel, nil) (defaults to: nil)

    The model to use for image generation. Only ‘dall-e-2` and `gpt-image-1` are sup

  • n (Integer, nil) (defaults to: nil)

    The number of images to generate. Must be between 1 and 10.

  • output_compression (Integer, nil) (defaults to: nil)

    The compression level (0-100%) for the generated images. This parameter

  • output_format (Symbol, OpenAI::Models::ImageEditParams::OutputFormat, nil) (defaults to: nil)

    The format in which the generated images are returned. This parameter is

  • partial_images (Integer, nil) (defaults to: nil)

    The number of partial images to generate. This parameter is used for

  • quality (Symbol, OpenAI::Models::ImageEditParams::Quality, nil) (defaults to: nil)

    The quality of the image that will be generated. ‘high`, `medium` and `low` are

  • response_format (Symbol, OpenAI::Models::ImageEditParams::ResponseFormat, nil) (defaults to: nil)

    The format in which the generated images are returned. Must be one of ‘url` or `

  • size (Symbol, OpenAI::Models::ImageEditParams::Size, nil) (defaults to: nil)

    The size of the generated images. Must be one of ‘1024x1024`, `1536x1024` (lands

  • user (String) (defaults to: nil)

    A unique identifier representing your end-user, which can help OpenAI to monitor

  • request_options (OpenAI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/openai/models/image_edit_params.rb', line 131

Instance Attribute Details

#backgroundSymbol, ...

Allows to set transparency for the background of the generated image(s). This parameter is only supported for ‘gpt-image-1`. Must be one of `transparent`, `opaque` or `auto` (default value). When `auto` is used, the model will automatically determine the best background for the image.

If ‘transparent`, the output format needs to support transparency, so it should be set to either `png` (default value) or `webp`.



41
# File 'lib/openai/models/image_edit_params.rb', line 41

optional :background, enum: -> { OpenAI::ImageEditParams::Background }, nil?: true

#imagePathname, ...

The image(s) to edit. Must be a supported image file or an array of images.

For ‘gpt-image-1`, each image should be a `png`, `webp`, or `jpg` file less than 50MB. You can provide up to 16 images.

For ‘dall-e-2`, you can only provide one image, and it should be a square `png` file less than 4MB.

Returns:



22
# File 'lib/openai/models/image_edit_params.rb', line 22

required :image, union: -> { OpenAI::ImageEditParams::Image }

#input_fidelitySymbol, ...

Control how much effort the model will exert to match the style and features, especially facial features, of input images. This parameter is only supported for ‘gpt-image-1`. Supports `high` and `low`. Defaults to `low`.



49
# File 'lib/openai/models/image_edit_params.rb', line 49

optional :input_fidelity, enum: -> { OpenAI::ImageEditParams::InputFidelity }, nil?: true

#maskPathname, ...

An additional image whose fully transparent areas (e.g. where alpha is zero) indicate where ‘image` should be edited. If there are multiple images provided, the mask will be applied on the first image. Must be a valid PNG file, less than 4MB, and have the same dimensions as `image`.

Returns:



58
# File 'lib/openai/models/image_edit_params.rb', line 58

optional :mask, OpenAI::Internal::Type::FileInput

#modelString, ...

The model to use for image generation. Only ‘dall-e-2` and `gpt-image-1` are supported. Defaults to `dall-e-2` unless a parameter specific to `gpt-image-1` is used.

Returns:



66
# File 'lib/openai/models/image_edit_params.rb', line 66

optional :model, union: -> { OpenAI::ImageEditParams::Model }, nil?: true

#nInteger?

The number of images to generate. Must be between 1 and 10.

Returns:

  • (Integer, nil)


72
# File 'lib/openai/models/image_edit_params.rb', line 72

optional :n, Integer, nil?: true

#output_compressionInteger?

The compression level (0-100%) for the generated images. This parameter is only supported for ‘gpt-image-1` with the `webp` or `jpeg` output formats, and defaults to 100.

Returns:

  • (Integer, nil)


80
# File 'lib/openai/models/image_edit_params.rb', line 80

optional :output_compression, Integer, nil?: true

#output_formatSymbol, ...

The format in which the generated images are returned. This parameter is only supported for ‘gpt-image-1`. Must be one of `png`, `jpeg`, or `webp`. The default value is `png`.



88
# File 'lib/openai/models/image_edit_params.rb', line 88

optional :output_format, enum: -> { OpenAI::ImageEditParams::OutputFormat }, nil?: true

#partial_imagesInteger?

The number of partial images to generate. This parameter is used for streaming responses that return partial images. Value must be between 0 and 3. When set to 0, the response will be a single image sent in one streaming event.

Returns:

  • (Integer, nil)


96
# File 'lib/openai/models/image_edit_params.rb', line 96

optional :partial_images, Integer, nil?: true

#promptString

A text description of the desired image(s). The maximum length is 1000 characters for ‘dall-e-2`, and 32000 characters for `gpt-image-1`.

Returns:

  • (String)


29
# File 'lib/openai/models/image_edit_params.rb', line 29

required :prompt, String

#qualitySymbol, ...

The quality of the image that will be generated. ‘high`, `medium` and `low` are only supported for `gpt-image-1`. `dall-e-2` only supports `standard` quality. Defaults to `auto`.



104
# File 'lib/openai/models/image_edit_params.rb', line 104

optional :quality, enum: -> { OpenAI::ImageEditParams::Quality }, nil?: true

#response_formatSymbol, ...

The format in which the generated images are returned. Must be one of ‘url` or `b64_json`. URLs are only valid for 60 minutes after the image has been generated. This parameter is only supported for `dall-e-2`, as `gpt-image-1` will always return base64-encoded images.



113
# File 'lib/openai/models/image_edit_params.rb', line 113

optional :response_format, enum: -> { OpenAI::ImageEditParams::ResponseFormat }, nil?: true

#sizeSymbol, ...

The size of the generated images. Must be one of ‘1024x1024`, `1536x1024` (landscape), `1024x1536` (portrait), or `auto` (default value) for `gpt-image-1`, and one of `256x256`, `512x512`, or `1024x1024` for `dall-e-2`.

Returns:



121
# File 'lib/openai/models/image_edit_params.rb', line 121

optional :size, enum: -> { OpenAI::ImageEditParams::Size }, nil?: true

#userString?

A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse. [Learn more](platform.openai.com/docs/guides/safety-best-practices#end-user-ids).

Returns:

  • (String, nil)


129
# File 'lib/openai/models/image_edit_params.rb', line 129

optional :user, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/image_edit_params.rb', line 200

.variantsArray(String, Symbol, OpenAI::Models::ImageModel)

Returns:



# File 'lib/openai/models/image_edit_params.rb', line 228