Module: OpenAI::Models::ImageEditParams::Background

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/image_edit_params.rb,
sig/openai/models/image_edit_params.rbs

Overview

Allows to set transparency for the background of the generated image(s). Must be one of transparent, opaque, or auto (default value). When auto is used, the model will automatically determine the best background for the image.

Transparent backgrounds are available for supported GPT Image models. For gpt-image-2 and gpt-image-2-2026-04-21, this support is in preview. When using transparent, set the output format to png or webp.

Constant Summary collapse

TRANSPARENT =

Returns:

  • (:transparent)
:transparent
OPAQUE =

Returns:

  • (:opaque)
:opaque
AUTO =

Returns:

  • (:auto)
:auto

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[OpenAI::Models::ImageEditParams::background]

Returns:

  • (::Array[OpenAI::Models::ImageEditParams::background])


114
# File 'sig/openai/models/image_edit_params.rbs', line 114

def self?.values: -> ::Array[OpenAI::Models::ImageEditParams::background]