Class: OpenAI::Models::ImageGenerateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::ImageGenerateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/image_generate_params.rb,
sig/openai/models/image_generate_params.rbs
Overview
Defined Under Namespace
Modules: Background, Model, Moderation, OutputFormat, Quality, ResponseFormat, Size, Style
Instance Attribute Summary collapse
-
#background ⇒ Symbol, ...
Allows to set transparency for the background of the generated image(s).
-
#model ⇒ String, ...
The model to use for image generation.
-
#moderation ⇒ Symbol, ...
Control the content-moderation level for images generated by the GPT image models.
-
#n ⇒ Integer?
The number of images to generate.
-
#output_compression ⇒ Integer?
The compression level (0-100%) for the generated images.
-
#output_format ⇒ Symbol, ...
The format in which the generated images are returned.
-
#partial_images ⇒ Integer?
The number of partial images to generate.
-
#prompt ⇒ String
A text description of the desired image(s).
-
#quality ⇒ Symbol, ...
The quality of the image that will be generated.
-
#response_format ⇒ Symbol, ...
The format in which generated images with
dall-e-2anddall-e-3are returned. -
#size ⇒ String, ...
The size of the generated images.
-
#style ⇒ Symbol, ...
The style of the generated images.
-
#user ⇒ String?
A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(prompt:, background: nil, model: nil, moderation: nil, n: nil, output_compression: nil, output_format: nil, partial_images: nil, quality: nil, response_format: nil, size: nil, style: nil, user: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ImageGenerateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(prompt:, background: nil, model: nil, moderation: nil, n: nil, output_compression: nil, output_format: nil, partial_images: nil, quality: nil, response_format: nil, size: nil, style: nil, user: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::ImageGenerateParams for more details.
|
|
# File 'lib/openai/models/image_generate_params.rb', line 141
|
Instance Attribute Details
#background ⇒ Symbol, ...
Allows to set transparency for the background of the generated image(s). This
parameter is only supported for GPT image models that support transparent
backgrounds. Must be one of transparent, opaque, or auto (default value).
When auto is used, the model will automatically determine the best background
for the image.
gpt-image-2 and gpt-image-2-2026-04-21 do not support transparent
backgrounds. Requests with background set to transparent will return an
error for these models; use opaque or auto instead.
If transparent, the output format needs to support transparency, so it should
be set to either png (default value) or webp.
35 |
# File 'lib/openai/models/image_generate_params.rb', line 35 optional :background, enum: -> { OpenAI::ImageGenerateParams::Background }, nil?: true |
#model ⇒ String, ...
The model to use for image generation. One of dall-e-2, dall-e-3, or a GPT
image model (gpt-image-1, gpt-image-1-mini, gpt-image-1.5, gpt-image-2,
or gpt-image-2-2026-04-21). Defaults to dall-e-2 unless a parameter specific
to the GPT image models is used.
44 |
# File 'lib/openai/models/image_generate_params.rb', line 44 optional :model, union: -> { OpenAI::ImageGenerateParams::Model }, nil?: true |
#moderation ⇒ Symbol, ...
Control the content-moderation level for images generated by the GPT image
models. Must be either low for less restrictive filtering or auto (default
value).
52 |
# File 'lib/openai/models/image_generate_params.rb', line 52 optional :moderation, enum: -> { OpenAI::ImageGenerateParams::Moderation }, nil?: true |
#n ⇒ Integer?
The number of images to generate. Must be between 1 and 10. For dall-e-3, only
n=1 is supported.
59 |
# File 'lib/openai/models/image_generate_params.rb', line 59 optional :n, Integer, nil?: true |
#output_compression ⇒ Integer?
The compression level (0-100%) for the generated images. This parameter is only
supported for the GPT image models with the webp or jpeg output formats, and
defaults to 100.
67 |
# File 'lib/openai/models/image_generate_params.rb', line 67 optional :output_compression, Integer, nil?: true |
#output_format ⇒ Symbol, ...
The format in which the generated images are returned. This parameter is only
supported for the GPT image models. Must be one of png, jpeg, or webp.
74 |
# File 'lib/openai/models/image_generate_params.rb', line 74 optional :output_format, enum: -> { OpenAI::ImageGenerateParams::OutputFormat }, nil?: true |
#partial_images ⇒ Integer?
The number of partial images to generate. This parameter is used for streaming responses that return partial images. Value must be between 0 and 3. When set to 0, the response will be a single image sent in one streaming event.
Note that the final image may be sent before the full number of partial images are generated if the full image is generated more quickly.
85 |
# File 'lib/openai/models/image_generate_params.rb', line 85 optional :partial_images, Integer, nil?: true |
#prompt ⇒ String
A text description of the desired image(s). The maximum length is 32000
characters for the GPT image models, 1000 characters for dall-e-2 and 4000
characters for dall-e-3.
18 |
# File 'lib/openai/models/image_generate_params.rb', line 18 required :prompt, String |
#quality ⇒ Symbol, ...
The quality of the image that will be generated.
auto(default value) will automatically select the best quality for the given model.high,mediumandloware supported for the GPT image models.hdandstandardare supported fordall-e-3.standardis the only option fordall-e-2.
97 |
# File 'lib/openai/models/image_generate_params.rb', line 97 optional :quality, enum: -> { OpenAI::ImageGenerateParams::Quality }, nil?: true |
#response_format ⇒ Symbol, ...
The format in which generated images with dall-e-2 and dall-e-3 are
returned. Must be one of url or b64_json. URLs are only valid for 60 minutes
after the image has been generated. This parameter isn't supported for the GPT
image models, which always return base64-encoded images.
106 |
# File 'lib/openai/models/image_generate_params.rb', line 106 optional :response_format, enum: -> { OpenAI::ImageGenerateParams::ResponseFormat }, nil?: true |
#size ⇒ String, ...
The size of the generated images. For gpt-image-2 and
gpt-image-2-2026-04-21, arbitrary resolutions are supported as WIDTHxHEIGHT
strings, for example 1536x864. Width and height must both be divisible by 16
and the requested aspect ratio must be between 1:3 and 3:1. Resolutions above
2560x1440 are experimental, and the maximum supported resolution is
3840x2160. The requested size must also satisfy the model's current pixel and
edge limits. The standard sizes 1024x1024, 1536x1024, and 1024x1536 are
supported by the GPT image models; auto is supported for models that allow
automatic sizing. For dall-e-2, use one of 256x256, 512x512, or
1024x1024. For dall-e-3, use one of 1024x1024, 1792x1024, or
1024x1792.
122 |
# File 'lib/openai/models/image_generate_params.rb', line 122 optional :size, union: -> { OpenAI::ImageGenerateParams::Size }, nil?: true |
#style ⇒ Symbol, ...
The style of the generated images. This parameter is only supported for
dall-e-3. Must be one of vivid or natural. Vivid causes the model to lean
towards generating hyper-real and dramatic images. Natural causes the model to
produce more natural, less hyper-real looking images.
131 |
# File 'lib/openai/models/image_generate_params.rb', line 131 optional :style, enum: -> { OpenAI::ImageGenerateParams::Style }, nil?: true |
#user ⇒ String?
A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse. Learn more.
139 |
# File 'lib/openai/models/image_generate_params.rb', line 139 optional :user, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/image_generate_params.rb', line 192
|
.variants ⇒ Array(String, Symbol, OpenAI::Models::ImageModel)
|
|
# File 'lib/openai/models/image_generate_params.rb', line 208
|
Instance Method Details
#to_hash ⇒ {
70 |
# File 'sig/openai/models/image_generate_params.rbs', line 70
def to_hash: -> {
|