Module: OpenAI::Models::ImageGenerateParams::Quality
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/image_generate_params.rb,
sig/openai/models/image_generate_params.rbs
Overview
The quality of the image that will be generated.
auto(default value) will automatically select the best quality for the given model.high,mediumandloware supported for the GPT image models.hdandstandardare supported fordall-e-3.standardis the only option fordall-e-2.
Constant Summary collapse
- STANDARD =
:standard- HD =
:hd- LOW =
:low- MEDIUM =
:medium- HIGH =
:high- AUTO =
:auto
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[OpenAI::Models::ImageGenerateParams::quality]
142 |
# File 'sig/openai/models/image_generate_params.rbs', line 142
def self?.values: -> ::Array[OpenAI::Models::ImageGenerateParams::quality]
|