Class: OpenAI::Models::ImagesResponse::Usage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::ImagesResponse::Usage
- Defined in:
- lib/openai/models/images_response.rb,
sig/openai/models/images_response.rbs
Overview
Defined Under Namespace
Classes: InputTokensDetails, OutputTokensDetails
Instance Attribute Summary collapse
-
#input_tokens ⇒ Integer
The number of tokens (images and text) in the input prompt.
-
#input_tokens_details ⇒ OpenAI::ImagesResponse::Usage::InputTokensDetails
The input tokens detailed information for the image generation.
-
#output_tokens ⇒ Integer
The number of output tokens generated by the model.
-
#output_tokens_details ⇒ OpenAI::ImagesResponse::Usage::OutputTokensDetails?
The output token details for the image generation.
-
#total_tokens ⇒ Integer
The total number of tokens (images and text) used for the image generation.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(image_tokens:, text_tokens:) ⇒ Object
|
|
# File 'lib/openai/models/images_response.rb', line 190
|
Instance Attribute Details
#input_tokens ⇒ Integer
The number of tokens (images and text) in the input prompt.
164 |
# File 'lib/openai/models/images_response.rb', line 164 required :input_tokens, Integer |
#input_tokens_details ⇒ OpenAI::ImagesResponse::Usage::InputTokensDetails
The input tokens detailed information for the image generation.
170 |
# File 'lib/openai/models/images_response.rb', line 170 required :input_tokens_details, -> { OpenAI::ImagesResponse::Usage::InputTokensDetails } |
#output_tokens ⇒ Integer
The number of output tokens generated by the model.
176 |
# File 'lib/openai/models/images_response.rb', line 176 required :output_tokens, Integer |
#output_tokens_details ⇒ OpenAI::ImagesResponse::Usage::OutputTokensDetails?
The output token details for the image generation.
188 |
# File 'lib/openai/models/images_response.rb', line 188 optional :output_tokens_details, -> { OpenAI::ImagesResponse::Usage::OutputTokensDetails } |
#total_tokens ⇒ Integer
The total number of tokens (images and text) used for the image generation.
182 |
# File 'lib/openai/models/images_response.rb', line 182 required :total_tokens, Integer |
Instance Method Details
#to_hash ⇒ {
205 |
# File 'sig/openai/models/images_response.rbs', line 205
def to_hash: -> {
|