Class: OpenAI::Models::Live::DataChannelConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::DataChannelConfig
- Defined in:
- lib/openai/models/live/data_channel_config.rb,
sig/openai/models/live/data_channel_config.rbs
Defined Under Namespace
Modules: AllowedClientEvents, AllowedServerEvents
Instance Attribute Summary collapse
-
#allowed_client_events ⇒ Symbol, ...
Client event types that the frontend data channel may send.
-
#allowed_server_events ⇒ Symbol, ...
Server events that may be sent to the frontend data channel.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(allowed_client_events: nil, allowed_server_events: nil) ⇒ Object
constructor
Control which Live events an untrusted WebRTC frontend can send and receive over its data channel.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allowed_client_events: nil, allowed_server_events: nil) ⇒ Object
Control which Live events an untrusted WebRTC frontend can send and receive over its data channel. These restrictions do not apply to trusted sideband connections.
|
|
# File 'lib/openai/models/live/data_channel_config.rb', line 24
|
Instance Attribute Details
#allowed_client_events ⇒ Symbol, ...
Client event types that the frontend data channel may send. Use 'all' to allow every client event; an empty array allows none. Omission preserves the existing allow-all behavior.
13 |
# File 'lib/openai/models/live/data_channel_config.rb', line 13 optional :allowed_client_events, union: -> { OpenAI::Live::DataChannelConfig::AllowedClientEvents } |
#allowed_server_events ⇒ Symbol, ...
Server events that may be sent to the frontend data channel. Use 'all' to allow every server event; an empty array allows none. Omission preserves the existing allow-all behavior. Responses events use an object with type 'response.event' and a response_event selector.
22 |
# File 'lib/openai/models/live/data_channel_config.rb', line 22 optional :allowed_server_events, union: -> { OpenAI::Live::DataChannelConfig::AllowedServerEvents } |
Instance Method Details
#to_hash ⇒ {
28 |
# File 'sig/openai/models/live/data_channel_config.rbs', line 28
def to_hash: -> {
|