Class: OpenAI::Models::Live::Error
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::Error
- Defined in:
- lib/openai/models/live/error.rb,
sig/openai/models/live/error.rbs
Instance Attribute Summary collapse
-
#client_event_id ⇒ String?
The event_id of the client command that caused the error, when supplied.
-
#code ⇒ String
A machine-readable code identifying the Live error, such as
unknown_parameter. -
#message ⇒ String
A human-readable explanation of the Live error.
-
#param ⇒ String?
The parameter that caused the error, when applicable, such as
session.voice. -
#type ⇒ String
The category of error, such as
invalid_request_errorfor an invalid Live client command.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(code:, message:, type:, client_event_id: nil, param: nil) ⇒ Object
constructor
Details of an error encountered by the Live session, including the affected parameter or client command when available.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code:, message:, type:, client_event_id: nil, param: nil) ⇒ Object
Details of an error encountered by the Live session, including the affected parameter or client command when available.
|
|
# File 'lib/openai/models/live/error.rb', line 38
|
Instance Attribute Details
#client_event_id ⇒ String?
The event_id of the client command that caused the error, when supplied.
30 |
# File 'lib/openai/models/live/error.rb', line 30 optional :client_event_id, String |
#code ⇒ String
A machine-readable code identifying the Live error, such as unknown_parameter.
11 |
# File 'lib/openai/models/live/error.rb', line 11 required :code, String |
#message ⇒ String
A human-readable explanation of the Live error.
17 |
# File 'lib/openai/models/live/error.rb', line 17 required :message, String |
#param ⇒ String?
The parameter that caused the error, when applicable, such as session.voice.
36 |
# File 'lib/openai/models/live/error.rb', line 36 optional :param, String |
#type ⇒ String
The category of error, such as invalid_request_error for an invalid Live
client command.
24 |
# File 'lib/openai/models/live/error.rb', line 24 required :type, String |
Instance Method Details
#to_hash ⇒ {
36 |
# File 'sig/openai/models/live/error.rbs', line 36
def to_hash: -> {
|