Class: OpenAI::Models::Live::InfoEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::InfoEvent
- Defined in:
- lib/openai/models/live/info_event.rb,
sig/openai/models/live/info_event.rbs
Instance Attribute Summary collapse
-
#client_event_id ⇒ String?
The event_id of the client command associated with this server event, when supplied.
-
#code ⇒ String
A machine-readable code for the notice, such as
data_channel_permissions. -
#event_id ⇒ String
The unique ID of the Live server event.
-
#message ⇒ String
A human-readable explanation of the Live session notice.
-
#type ⇒ Symbol, :info
The event type, always
info.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(code:, event_id:, message:, client_event_id: nil, type: :info) ⇒ Object
constructor
An informational notice about the Live session, such as the event permissions applied to a frontend data channel.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code:, event_id:, message:, client_event_id: nil, type: :info) ⇒ Object
An informational notice about the Live session, such as the event permissions applied to a frontend data channel.
|
|
# File 'lib/openai/models/live/info_event.rb', line 38
|
Instance Attribute Details
#client_event_id ⇒ String?
The event_id of the client command associated with this server event, when supplied.
36 |
# File 'lib/openai/models/live/info_event.rb', line 36 optional :client_event_id, String |
#code ⇒ String
A machine-readable code for the notice, such as data_channel_permissions.
11 |
# File 'lib/openai/models/live/info_event.rb', line 11 required :code, String |
#event_id ⇒ String
The unique ID of the Live server event.
17 |
# File 'lib/openai/models/live/info_event.rb', line 17 required :event_id, String |
#message ⇒ String
A human-readable explanation of the Live session notice.
23 |
# File 'lib/openai/models/live/info_event.rb', line 23 required :message, String |
#type ⇒ Symbol, :info
The event type, always info.
29 |
# File 'lib/openai/models/live/info_event.rb', line 29 required :type, const: :info |
Instance Method Details
#to_hash ⇒ {
34 |
# File 'sig/openai/models/live/info_event.rbs', line 34
def to_hash: -> {
|