Class: OpenAI::Models::Live::InputAudioMutedEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::InputAudioMutedEvent
- Defined in:
- lib/openai/models/live/input_audio_muted_event.rb,
sig/openai/models/live/input_audio_muted_event.rbs
Instance Attribute Summary collapse
-
#client_event_id ⇒ String?
The event_id of the client command associated with this server event, when supplied.
-
#event_id ⇒ String
The unique ID of the Live server event.
-
#type ⇒ Symbol, :"session.input_audio.muted"
The event type, always
session.input_audio.muted.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(event_id:, client_event_id: nil, type: :"session.input_audio.muted") ⇒ Object
constructor
Returned when a session.input_audio.mute command is accepted.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(event_id:, client_event_id: nil, type: :"session.input_audio.muted") ⇒ Object
Returned when a session.input_audio.mute command is accepted. Input audio is no longer sent to the model; sideband audio reflection continues.
|
|
# File 'lib/openai/models/live/input_audio_muted_event.rb', line 26
|
Instance Attribute Details
#client_event_id ⇒ String?
The event_id of the client command associated with this server event, when supplied.
24 |
# File 'lib/openai/models/live/input_audio_muted_event.rb', line 24 optional :client_event_id, String |
#event_id ⇒ String
The unique ID of the Live server event.
11 |
# File 'lib/openai/models/live/input_audio_muted_event.rb', line 11 required :event_id, String |
#type ⇒ Symbol, :"session.input_audio.muted"
The event type, always session.input_audio.muted.
17 |
# File 'lib/openai/models/live/input_audio_muted_event.rb', line 17 required :type, const: :"session.input_audio.muted" |
Instance Method Details
#to_hash ⇒ {
26 |
# File 'sig/openai/models/live/input_audio_muted_event.rbs', line 26
def to_hash: -> {
|