Class: OpenAI::Models::Live::ResponsesDelegationConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::ResponsesDelegationConfig
- Defined in:
- lib/openai/models/live/responses_delegation_config.rb,
sig/openai/models/live/responses_delegation_config.rbs
Defined Under Namespace
Modules: ServiceTier, Tool, ToolChoice Classes: Reasoning, Text
Instance Attribute Summary collapse
-
#instructions ⇒ String?
Instructions for the delegated Responses model, separate from Live instructions.
-
#max_output_tokens ⇒ Integer?
Maximum number of output tokens for each delegated response.
-
#model ⇒ String
The model used for server-owned Responses delegations.
-
#parallel_tool_calls ⇒ Boolean?
Whether the delegated Responses model may request multiple tool calls in a single response.
-
#reasoning ⇒ OpenAI::Models::Live::ResponsesDelegationConfig::Reasoning?
Reasoning settings passed to each delegated Responses request.
-
#service_tier ⇒ Symbol, ...
Service tier for delegated Responses requests.
-
#text ⇒ OpenAI::Models::Live::ResponsesDelegationConfig::Text?
Text generation settings passed to each delegated Responses request.
-
#tool_choice ⇒ Symbol, ...
Controls which tool the Responses backend uses when handling a task delegated by the Live model.
-
#tools ⇒ Array<OpenAI::Models::Live::FunctionTool, OpenAI::Models::Live::ResponsesDelegationConfig::Tool::WebSearch>?
Tools available to the Responses backend while it handles tasks delegated by the Live model.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Symbol, OpenAI::Models::Live::ResponsesDelegationConfig::ToolChoice::LiveToolChoiceEnum, OpenAI::Models::Live::ResponsesDelegationConfig::ToolChoice::LiveFunctionToolChoiceParam, OpenAI::Models::Live::ResponsesDelegationConfig::ToolChoice::LiveMCPToolChoiceParam)
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, server_label:, type: :mcp) ⇒ Object
|
|
# File 'lib/openai/models/live/responses_delegation_config.rb', line 69
|
Instance Attribute Details
#instructions ⇒ String?
Instructions for the delegated Responses model, separate from Live instructions. See backend prompting.
19 |
# File 'lib/openai/models/live/responses_delegation_config.rb', line 19 optional :instructions, String, nil?: true |
#max_output_tokens ⇒ Integer?
Maximum number of output tokens for each delegated response.
25 |
# File 'lib/openai/models/live/responses_delegation_config.rb', line 25 optional :max_output_tokens, Integer, nil?: true |
#model ⇒ String
The model used for server-owned Responses delegations.
11 |
# File 'lib/openai/models/live/responses_delegation_config.rb', line 11 required :model, String |
#parallel_tool_calls ⇒ Boolean?
Whether the delegated Responses model may request multiple tool calls in a single response.
32 |
# File 'lib/openai/models/live/responses_delegation_config.rb', line 32 optional :parallel_tool_calls, OpenAI::Internal::Type::Boolean, nil?: true |
#reasoning ⇒ OpenAI::Models::Live::ResponsesDelegationConfig::Reasoning?
Reasoning settings passed to each delegated Responses request.
38 |
# File 'lib/openai/models/live/responses_delegation_config.rb', line 38 optional :reasoning, -> { OpenAI::Live::ResponsesDelegationConfig::Reasoning }, nil?: true |
#service_tier ⇒ Symbol, ...
Service tier for delegated Responses requests.
44 |
# File 'lib/openai/models/live/responses_delegation_config.rb', line 44 optional :service_tier, enum: -> { OpenAI::Live::ResponsesDelegationConfig::ServiceTier }, nil?: true |
#text ⇒ OpenAI::Models::Live::ResponsesDelegationConfig::Text?
Text generation settings passed to each delegated Responses request.
50 |
# File 'lib/openai/models/live/responses_delegation_config.rb', line 50 optional :text, -> { OpenAI::Live::ResponsesDelegationConfig::Text }, nil?: true |
#tool_choice ⇒ Symbol, ...
Controls which tool the Responses backend uses when handling a task delegated by the Live model.
57 |
# File 'lib/openai/models/live/responses_delegation_config.rb', line 57 optional :tool_choice, union: -> { OpenAI::Live::ResponsesDelegationConfig::ToolChoice } |
#tools ⇒ Array<OpenAI::Models::Live::FunctionTool, OpenAI::Models::Live::ResponsesDelegationConfig::Tool::WebSearch>?
Tools available to the Responses backend while it handles tasks delegated by the Live model.
64 65 66 67 |
# File 'lib/openai/models/live/responses_delegation_config.rb', line 64 optional( :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Live::ResponsesDelegationConfig::Tool] } ) |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/live/responses_delegation_config.rb', line 173
|
.variants ⇒ Array(Symbol, OpenAI::Models::Live::ResponsesDelegationConfig::ToolChoice::LiveToolChoiceEnum, OpenAI::Models::Live::ResponsesDelegationConfig::ToolChoice::LiveFunctionToolChoiceParam, OpenAI::Models::Live::ResponsesDelegationConfig::ToolChoice::LiveMCPToolChoiceParam)
|
|
# File 'lib/openai/models/live/responses_delegation_config.rb', line 295
|
Instance Method Details
#to_hash ⇒ {
56 |
# File 'sig/openai/models/live/responses_delegation_config.rbs', line 56
def to_hash: -> {
|