Class: OpenAI::Models::Live::SessionStartedEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::SessionStartedEvent
- Defined in:
- lib/openai/models/live/session_started_event.rb,
sig/openai/models/live/session_started_event.rbs
Instance Attribute Summary collapse
-
#client_event_id ⇒ String?
The event_id of the client command associated with this server event, when supplied.
-
#event_id ⇒ String
The unique ID of the Live server event.
-
#session ⇒ OpenAI::Models::Live::SessionResource
The resolved Live session configuration and server-assigned session metadata.
-
#type ⇒ Symbol, :"session.started"
The event type, always
session.started.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(event_id:, session:, client_event_id: nil, type: :"session.started") ⇒ Object
constructor
Returned when a Live session has started.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(event_id:, session:, client_event_id: nil, type: :"session.started") ⇒ Object
Returned when a Live session has started. Contains the resolved session configuration, including server defaults.
|
|
# File 'lib/openai/models/live/session_started_event.rb', line 32
|
Instance Attribute Details
#client_event_id ⇒ String?
The event_id of the client command associated with this server event, when supplied.
30 |
# File 'lib/openai/models/live/session_started_event.rb', line 30 optional :client_event_id, String |
#event_id ⇒ String
The unique ID of the Live server event.
11 |
# File 'lib/openai/models/live/session_started_event.rb', line 11 required :event_id, String |
#session ⇒ OpenAI::Models::Live::SessionResource
The resolved Live session configuration and server-assigned session metadata.
17 |
# File 'lib/openai/models/live/session_started_event.rb', line 17 required :session, -> { OpenAI::Live::SessionResource } |
#type ⇒ Symbol, :"session.started"
The event type, always session.started.
23 |
# File 'lib/openai/models/live/session_started_event.rb', line 23 required :type, const: :"session.started" |
Instance Method Details
#to_hash ⇒ {
30 |
# File 'sig/openai/models/live/session_started_event.rbs', line 30
def to_hash: -> {
|