Class: OpenAI::Models::Live::SessionUpdateEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Live::SessionUpdateEvent
- Defined in:
- lib/openai/models/live/session_update_event.rb,
sig/openai/models/live/session_update_event.rbs
Instance Attribute Summary collapse
-
#event_id ⇒ String?
Optional client identifier for correlating this command with a server event's client_event_id or error.client_event_id.
-
#session ⇒ OpenAI::Models::Live::SessionUpdateConfig
Sparse delegation updates.
-
#type ⇒ Symbol, :"session.update"
The Live client event type.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(session:, event_id: nil, type: :"session.update") ⇒ Object
constructor
Update the delegation settings of an active Live session.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(session:, event_id: nil, type: :"session.update") ⇒ Object
Update the delegation settings of an active Live session. The server
acknowledges accepted changes with session.updated.
|
|
# File 'lib/openai/models/live/session_update_event.rb', line 28
|
Instance Attribute Details
#event_id ⇒ String?
Optional client identifier for correlating this command with a server event's client_event_id or error.client_event_id.
26 |
# File 'lib/openai/models/live/session_update_event.rb', line 26 optional :event_id, String, nil?: true |
#session ⇒ OpenAI::Models::Live::SessionUpdateConfig
Sparse delegation updates. Omitted settings retain their values. The delegation type cannot change, including resetting Responses delegation to null or client. Model, frontend instructions, audio, and startup input are immutable.
13 |
# File 'lib/openai/models/live/session_update_event.rb', line 13 required :session, -> { OpenAI::Live::SessionUpdateConfig } |
#type ⇒ Symbol, :"session.update"
The Live client event type. Always session.update.
19 |
# File 'lib/openai/models/live/session_update_event.rb', line 19 required :type, const: :"session.update" |
Instance Method Details
#to_hash ⇒ {
24 |
# File 'sig/openai/models/live/session_update_event.rbs', line 24
def to_hash: -> {
|