Class: OpenAI::Models::Realtime::AudioTranscription
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::AudioTranscription
- Defined in:
- lib/openai/models/realtime/audio_transcription.rb,
sig/openai/models/realtime/audio_transcription.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#delay ⇒ Symbol, ...
Controls how long the model waits before emitting transcription text.
-
#language ⇒ String?
The language of the input audio.
-
#model ⇒ String, ...
The model to use for transcription.
-
#prompt ⇒ String?
An optional text to guide the model's style or continue a previous audio segment.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(delay: nil, language: nil, model: nil, prompt: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see AudioTranscription for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(delay: nil, language: nil, model: nil, prompt: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Realtime::AudioTranscription for more details.
|
|
# File 'lib/openai/models/realtime/audio_transcription.rb', line 43
|
Instance Attribute Details
#delay ⇒ Symbol, ...
Controls how long the model waits before emitting transcription text. Higher
values can improve transcription accuracy at the cost of latency. Only supported
with gpt-realtime-whisper in GA Realtime sessions.
13 |
# File 'lib/openai/models/realtime/audio_transcription.rb', line 13 optional :delay, enum: -> { OpenAI::Realtime::AudioTranscription::Delay } |
#language ⇒ String?
The language of the input audio. Supplying the input language in
ISO-639-1 (e.g. en)
format will improve accuracy and latency.
21 |
# File 'lib/openai/models/realtime/audio_transcription.rb', line 21 optional :language, String |
#model ⇒ String, ...
The model to use for transcription. Current options are whisper-1,
gpt-4o-mini-transcribe, gpt-4o-mini-transcribe-2025-12-15,
gpt-4o-transcribe, gpt-4o-transcribe-diarize, and gpt-realtime-whisper.
Use gpt-4o-transcribe-diarize when you need diarization with speaker labels.
30 |
# File 'lib/openai/models/realtime/audio_transcription.rb', line 30 optional :model, union: -> { OpenAI::Realtime::AudioTranscription::Model } |
#prompt ⇒ String?
An optional text to guide the model's style or continue a previous audio
segment. For whisper-1, the
prompt is a list of keywords.
For gpt-4o-transcribe models (excluding gpt-4o-transcribe-diarize), the
prompt is a free text string, for example "expect words related to technology".
Prompt is not supported with gpt-realtime-whisper in GA Realtime sessions.
41 |
# File 'lib/openai/models/realtime/audio_transcription.rb', line 41 optional :prompt, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/realtime/audio_transcription.rb', line 69
|
Instance Method Details
#to_hash ⇒ {
40 |
# File 'sig/openai/models/realtime/audio_transcription.rbs', line 40
def to_hash: -> {
|