Module: OpenAI::Models::Realtime::AudioTranscription::Delay

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/realtime/audio_transcription.rb

Overview

Controls how long the model waits before emitting transcription text. Higher values can improve transcription accuracy at the cost of latency. Only supported with ‘gpt-realtime-whisper` in GA Realtime sessions.

See Also:

Constant Summary collapse

MINIMAL =
:minimal
LOW =
:low
MEDIUM =
:medium
HIGH =
:high
XHIGH =
:xhigh

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info