Class: OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter
- Defined in:
- lib/openai/models/realtime/client_secret_create_params.rb,
sig/openai/models/realtime/client_secret_create_params.rbs
Defined Under Namespace
Modules: Anchor
Instance Attribute Summary collapse
-
#anchor ⇒ OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter::anchor?
The anchor point for the client secret expiration, meaning that
secondswill be added to thecreated_attime of the client secret to produce an expiration timestamp. -
#seconds ⇒ Integer?
The number of seconds from the anchor point to the expiration.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(anchor: nil, seconds: nil) ⇒ Object
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/openai/models/realtime/client_secret_create_params.rb', line 40 class ExpiresAfter < OpenAI::Internal::Type::BaseModel # @!attribute anchor # The anchor point for the client secret expiration, meaning that `seconds` will # be added to the `created_at` time of the client secret to produce an expiration # timestamp. Only `created_at` is currently supported. # # @return [Symbol, OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter::Anchor, nil] optional :anchor, enum: -> { OpenAI::Realtime::ClientSecretCreateParams::ExpiresAfter::Anchor } # @!attribute seconds # The number of seconds from the anchor point to the expiration. Select a value # between `10` and `7200` (2 hours). This default to 600 seconds (10 minutes) if # not specified. # # @return [Integer, nil] optional :seconds, Integer # @!method initialize(anchor: nil, seconds: nil) # Configuration for the client secret expiration. Expiration refers to the time # after which a client secret will no longer be valid for creating sessions. The # session itself may continue after that time once started. A secret can be used # to create multiple sessions until it expires. # # @param anchor [Symbol, OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter::Anchor] # The anchor point for the client secret expiration, meaning that `seconds` will # be added to the `created_at` time of the client secret to produce an expiration # timestamp. Only `created_at` is currently supported. # # @param seconds [Integer] # The number of seconds from the anchor point to the expiration. Select a value # between `10` and `7200` (2 hours). This default to 600 seconds (10 minutes) if # not specified. # The anchor point for the client secret expiration, meaning that `seconds` will # be added to the `created_at` time of the client secret to produce an expiration # timestamp. Only `created_at` is currently supported. # # @see OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter#anchor module Anchor extend OpenAI::Internal::Type::Enum CREATED_AT = :created_at # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#anchor ⇒ OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter::anchor?
The anchor point for the client secret expiration, meaning that seconds will
be added to the created_at time of the client secret to produce an expiration
timestamp. Only created_at is currently supported.
47 |
# File 'lib/openai/models/realtime/client_secret_create_params.rb', line 47 optional :anchor, enum: -> { OpenAI::Realtime::ClientSecretCreateParams::ExpiresAfter::Anchor } |
#seconds ⇒ Integer?
The number of seconds from the anchor point to the expiration. Select a value
between 10 and 7200 (2 hours). This default to 600 seconds (10 minutes) if
not specified.
55 |
# File 'lib/openai/models/realtime/client_secret_create_params.rb', line 55 optional :seconds, Integer |
Instance Method Details
#to_hash ⇒ {
101 |
# File 'sig/openai/models/realtime/client_secret_create_params.rbs', line 101
def to_hash: -> {
|