Class: OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter
- Defined in:
- lib/openai/models/realtime/client_secret_create_params.rb
Defined Under Namespace
Modules: Anchor
Instance Attribute Summary collapse
-
#anchor ⇒ Symbol, ...
The anchor point for the ephemeral token expiration.
-
#seconds ⇒ Integer?
The number of seconds from the anchor point to the expiration.
Instance Method Summary collapse
-
#initialize(anchor: nil, seconds: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExpiresAfter for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(anchor: nil, seconds: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter for more details.
Configuration for the ephemeral token expiration.
34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/openai/models/realtime/client_secret_create_params.rb', line 34 class ExpiresAfter < OpenAI::Internal::Type::BaseModel # @!attribute anchor # The anchor point for the ephemeral token expiration. Only `created_at` is # currently supported. # # @return [Symbol, OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter::Anchor, nil] optional :anchor, enum: -> { OpenAI::Realtime::ClientSecretCreateParams::ExpiresAfter::Anchor } # @!attribute seconds # The number of seconds from the anchor point to the expiration. Select a value # between `10` and `7200`. # # @return [Integer, nil] optional :seconds, Integer # @!method initialize(anchor: nil, seconds: nil) # Some parameter documentations has been truncated, see # {OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter} for more # details. # # Configuration for the ephemeral token expiration. # # @param anchor [Symbol, OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter::Anchor] The anchor point for the ephemeral token expiration. Only `created_at` is curren # # @param seconds [Integer] The number of seconds from the anchor point to the expiration. Select a value be # The anchor point for the ephemeral token expiration. Only `created_at` is # currently supported. # # @see OpenAI::Models::Realtime::ClientSecretCreateParams::ExpiresAfter#anchor module Anchor extend OpenAI::Internal::Type::Enum CREATED_AT = :created_at # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#anchor ⇒ Symbol, ...
The anchor point for the ephemeral token expiration. Only ‘created_at` is currently supported.
40 |
# File 'lib/openai/models/realtime/client_secret_create_params.rb', line 40 optional :anchor, enum: -> { OpenAI::Realtime::ClientSecretCreateParams::ExpiresAfter::Anchor } |
#seconds ⇒ Integer?
The number of seconds from the anchor point to the expiration. Select a value between ‘10` and `7200`.
47 |
# File 'lib/openai/models/realtime/client_secret_create_params.rb', line 47 optional :seconds, Integer |