Class: OpenAI::Models::Realtime::ConversationItemInputAudioTranscriptionDeltaEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::ConversationItemInputAudioTranscriptionDeltaEvent
- Defined in:
- lib/openai/models/realtime/conversation_item_input_audio_transcription_delta_event.rb
Instance Attribute Summary collapse
-
#content_index ⇒ Integer?
The index of the content part in the item’s content array.
-
#delta ⇒ String?
The text delta.
-
#event_id ⇒ String
The unique ID of the server event.
-
#item_id ⇒ String
The ID of the item.
-
#logprobs ⇒ Array<OpenAI::Models::Realtime::LogProbProperties>?
The log probabilities of the transcription.
-
#type ⇒ Symbol, :"conversation.item.input_audio_transcription.delta"
The event type, must be ‘conversation.item.input_audio_transcription.delta`.
Instance Method Summary collapse
-
#initialize(event_id: , item_id: , content_index: nil, delta: nil, logprobs: nil, type: :"conversation.item.input_audio_transcription.delta") ⇒ Object
constructor
Returned when the text value of an input audio transcription content part is updated.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(event_id: , item_id: , content_index: nil, delta: nil, logprobs: nil, type: :"conversation.item.input_audio_transcription.delta") ⇒ Object
Returned when the text value of an input audio transcription content part is updated.
|
|
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_delta_event.rb', line 45
|
Instance Attribute Details
#content_index ⇒ Integer?
The index of the content part in the item’s content array.
29 |
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_delta_event.rb', line 29 optional :content_index, Integer |
#delta ⇒ String?
The text delta.
35 |
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_delta_event.rb', line 35 optional :delta, String |
#event_id ⇒ String
The unique ID of the server event.
11 |
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_delta_event.rb', line 11 required :event_id, String |
#item_id ⇒ String
The ID of the item.
17 |
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_delta_event.rb', line 17 required :item_id, String |
#logprobs ⇒ Array<OpenAI::Models::Realtime::LogProbProperties>?
The log probabilities of the transcription.
41 42 43 |
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_delta_event.rb', line 41 optional :logprobs, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Realtime::LogProbProperties] }, nil?: true |
#type ⇒ Symbol, :"conversation.item.input_audio_transcription.delta"
The event type, must be ‘conversation.item.input_audio_transcription.delta`.
23 |
# File 'lib/openai/models/realtime/conversation_item_input_audio_transcription_delta_event.rb', line 23 required :type, const: :"conversation.item.input_audio_transcription.delta" |