Class: OpenAI::Models::Realtime::InputAudioBufferAppendEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::InputAudioBufferAppendEvent
- Defined in:
- lib/openai/models/realtime/input_audio_buffer_append_event.rb
Instance Attribute Summary collapse
-
#audio ⇒ String
Base64-encoded audio bytes.
-
#event_id ⇒ String?
Optional client-generated ID used to identify this event.
-
#type ⇒ Symbol, :"input_audio_buffer.append"
The event type, must be ‘input_audio_buffer.append`.
Instance Method Summary collapse
-
#initialize(audio: , event_id: nil, type: :"input_audio_buffer.append") ⇒ Object
constructor
Some parameter documentations has been truncated, see InputAudioBufferAppendEvent for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(audio: , event_id: nil, type: :"input_audio_buffer.append") ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Realtime::InputAudioBufferAppendEvent for more details.
Send this event to append audio bytes to the input audio buffer. The audio buffer is temporary storage you can write to and later commit. In Server VAD mode, the audio buffer is used to detect speech and the server will decide when to commit. When Server VAD is disabled, you must commit the audio buffer manually.
The client may choose how much audio to place in each event up to a maximum of 15 MiB, for example streaming smaller chunks from the client may allow the VAD to be more responsive. Unlike made other client events, the server will not send a confirmation response to this event.
|
|
# File 'lib/openai/models/realtime/input_audio_buffer_append_event.rb', line 26
|
Instance Attribute Details
#audio ⇒ String
Base64-encoded audio bytes. This must be in the format specified by the ‘input_audio_format` field in the session configuration.
12 |
# File 'lib/openai/models/realtime/input_audio_buffer_append_event.rb', line 12 required :audio, String |
#event_id ⇒ String?
Optional client-generated ID used to identify this event.
24 |
# File 'lib/openai/models/realtime/input_audio_buffer_append_event.rb', line 24 optional :event_id, String |
#type ⇒ Symbol, :"input_audio_buffer.append"
The event type, must be ‘input_audio_buffer.append`.
18 |
# File 'lib/openai/models/realtime/input_audio_buffer_append_event.rb', line 18 required :type, const: :"input_audio_buffer.append" |