Class: OpenAI::Models::Realtime::InputAudioBufferSpeechStartedEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::InputAudioBufferSpeechStartedEvent
- Defined in:
- lib/openai/models/realtime/input_audio_buffer_speech_started_event.rb,
sig/openai/models/realtime/input_audio_buffer_speech_started_event.rbs
Instance Attribute Summary collapse
-
#audio_start_ms ⇒ Integer
Milliseconds from the start of all audio written to the buffer during the session when speech was first detected.
-
#event_id ⇒ String
The unique ID of the server event.
-
#item_id ⇒ String
The ID of the user message item that will be created when speech stops.
-
#type ⇒ :"input_audio_buffer.speech_started"
The event type, must be
input_audio_buffer.speech_started.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(audio_start_ms:, event_id:, item_id:, type: :"input_audio_buffer.speech_started") ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(audio_start_ms:, event_id:, item_id:, type: :"input_audio_buffer.speech_started") ⇒ Object
|
|
# File 'lib/openai/models/realtime/input_audio_buffer_speech_started_event.rb', line 34
|
Instance Attribute Details
#audio_start_ms ⇒ Integer
Milliseconds from the start of all audio written to the buffer during the
session when speech was first detected. This will correspond to the beginning of
audio sent to the model, and thus includes the prefix_padding_ms configured in
the Session.
14 |
# File 'lib/openai/models/realtime/input_audio_buffer_speech_started_event.rb', line 14 required :audio_start_ms, Integer |
#event_id ⇒ String
The unique ID of the server event.
20 |
# File 'lib/openai/models/realtime/input_audio_buffer_speech_started_event.rb', line 20 required :event_id, String |
#item_id ⇒ String
The ID of the user message item that will be created when speech stops.
26 |
# File 'lib/openai/models/realtime/input_audio_buffer_speech_started_event.rb', line 26 required :item_id, String |
#type ⇒ :"input_audio_buffer.speech_started"
The event type, must be input_audio_buffer.speech_started.
32 |
# File 'lib/openai/models/realtime/input_audio_buffer_speech_started_event.rb', line 32 required :type, const: :"input_audio_buffer.speech_started" |
Instance Method Details
#to_hash ⇒ {
46 |
# File 'sig/openai/models/realtime/input_audio_buffer_speech_started_event.rbs', line 46
def to_hash: -> {
|