Class: OpenAI::Models::Realtime::InputAudioBufferSpeechStoppedEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::InputAudioBufferSpeechStoppedEvent
- Defined in:
- lib/openai/models/realtime/input_audio_buffer_speech_stopped_event.rb
Instance Attribute Summary collapse
-
#audio_end_ms ⇒ Integer
Milliseconds since the session started when speech stopped.
-
#event_id ⇒ String
The unique ID of the server event.
-
#item_id ⇒ String
The ID of the user message item that will be created.
-
#type ⇒ Symbol, :"input_audio_buffer.speech_stopped"
The event type, must be
input_audio_buffer.speech_stopped.
Instance Method Summary collapse
-
#initialize(audio_end_ms:, event_id:, item_id:, type: :"input_audio_buffer.speech_stopped") ⇒ Object
constructor
Some parameter documentations has been truncated, see InputAudioBufferSpeechStoppedEvent for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(audio_end_ms:, event_id:, item_id:, type: :"input_audio_buffer.speech_stopped") ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Realtime::InputAudioBufferSpeechStoppedEvent for more details.
Returned in server_vad mode when the server detects the end of speech in the audio buffer. The server will also send an conversation.item.created event with the user message item that is created from the audio buffer.
|
|
# File 'lib/openai/models/realtime/input_audio_buffer_speech_stopped_event.rb', line 33
|
Instance Attribute Details
#audio_end_ms ⇒ Integer
Milliseconds since the session started when speech stopped. This will correspond to the end of audio sent to the model, and thus includes the min_silence_duration_ms configured in the Session.
13 |
# File 'lib/openai/models/realtime/input_audio_buffer_speech_stopped_event.rb', line 13 required :audio_end_ms, Integer |
#event_id ⇒ String
The unique ID of the server event.
19 |
# File 'lib/openai/models/realtime/input_audio_buffer_speech_stopped_event.rb', line 19 required :event_id, String |
#item_id ⇒ String
The ID of the user message item that will be created.
25 |
# File 'lib/openai/models/realtime/input_audio_buffer_speech_stopped_event.rb', line 25 required :item_id, String |
#type ⇒ Symbol, :"input_audio_buffer.speech_stopped"
The event type, must be input_audio_buffer.speech_stopped.
31 |
# File 'lib/openai/models/realtime/input_audio_buffer_speech_stopped_event.rb', line 31 required :type, const: :"input_audio_buffer.speech_stopped" |