Class: OpenAI::Models::Realtime::InputAudioBufferTimeoutTriggered
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::InputAudioBufferTimeoutTriggered
- Defined in:
- lib/openai/models/realtime/input_audio_buffer_timeout_triggered.rb,
sig/openai/models/realtime/input_audio_buffer_timeout_triggered.rbs
Instance Attribute Summary collapse
-
#audio_end_ms ⇒ Integer
Millisecond offset of audio written to the input audio buffer at the time the timeout was triggered.
-
#audio_start_ms ⇒ Integer
Millisecond offset of audio written to the input audio buffer that was after the playback time of the last model response.
-
#event_id ⇒ String
The unique ID of the server event.
-
#item_id ⇒ String
The ID of the item associated with this segment.
-
#type ⇒ :"input_audio_buffer.timeout_triggered"
The event type, must be
input_audio_buffer.timeout_triggered.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(audio_end_ms:, audio_start_ms:, event_id:, item_id:, type: :"input_audio_buffer.timeout_triggered") ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(audio_end_ms:, audio_start_ms:, event_id:, item_id:, type: :"input_audio_buffer.timeout_triggered") ⇒ Object
|
|
# File 'lib/openai/models/realtime/input_audio_buffer_timeout_triggered.rb', line 39
|
Instance Attribute Details
#audio_end_ms ⇒ Integer
Millisecond offset of audio written to the input audio buffer at the time the timeout was triggered.
12 |
# File 'lib/openai/models/realtime/input_audio_buffer_timeout_triggered.rb', line 12 required :audio_end_ms, Integer |
#audio_start_ms ⇒ Integer
Millisecond offset of audio written to the input audio buffer that was after the playback time of the last model response.
19 |
# File 'lib/openai/models/realtime/input_audio_buffer_timeout_triggered.rb', line 19 required :audio_start_ms, Integer |
#event_id ⇒ String
The unique ID of the server event.
25 |
# File 'lib/openai/models/realtime/input_audio_buffer_timeout_triggered.rb', line 25 required :event_id, String |
#item_id ⇒ String
The ID of the item associated with this segment.
31 |
# File 'lib/openai/models/realtime/input_audio_buffer_timeout_triggered.rb', line 31 required :item_id, String |
#type ⇒ :"input_audio_buffer.timeout_triggered"
The event type, must be input_audio_buffer.timeout_triggered.
37 |
# File 'lib/openai/models/realtime/input_audio_buffer_timeout_triggered.rb', line 37 required :type, const: :"input_audio_buffer.timeout_triggered" |
Instance Method Details
#to_hash ⇒ {
51 |
# File 'sig/openai/models/realtime/input_audio_buffer_timeout_triggered.rbs', line 51
def to_hash: -> {
|