Module: OpenAI::Models::Realtime::RealtimeAudioConfigOutput::Voice

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/realtime/realtime_audio_config_output.rb,
sig/openai/models/realtime/realtime_audio_config_output.rbs

Overview

The voice the model uses to respond. Supported built-in voices are alloy, ash, ballad, coral, echo, sage, shimmer, verse, marin, and cedar. You may also provide a custom voice object with an id, for example { "id": "voice_1234" }. Voice cannot be changed during the session once the model has responded with audio at least once. We recommend marin and cedar for best quality.

See Also:

  • OpenAI::Models::Realtime::RealtimeAudioConfigOutput#voice

Defined Under Namespace

Classes: ID

collapse

ALLOY =

Returns:

  • (:alloy)
:alloy
ASH =

Returns:

  • (:ash)
:ash
BALLAD =

Returns:

  • (:ballad)
:ballad
CORAL =

Returns:

  • (:coral)
:coral
ECHO =

Returns:

  • (:echo)
:echo
SAGE =

Returns:

  • (:sage)
:sage
SHIMMER =

Returns:

  • (:shimmer)
:shimmer
VERSE =

Returns:

  • (:verse)
:verse
MARIN =

Returns:

  • (:marin)
:marin
CEDAR =

Returns:

  • (:cedar)
:cedar

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.variantsArray(String, Symbol, OpenAI::Models::Realtime::RealtimeAudioConfigOutput::Voice::ID)



98
99
100
101
102
103
104
105
106
# File 'lib/openai/models/realtime/realtime_audio_config_output.rb', line 98

define_sorbet_constant!(:Variants) do
  T.type_alias do
    T.any(
      String,
      OpenAI::Realtime::RealtimeAudioConfigOutput::Voice::TaggedSymbol,
      OpenAI::Realtime::RealtimeAudioConfigOutput::Voice::ID
    )
  end
end

Instance Method Details

#initialize(id:) ⇒ Object

Custom voice reference.

Parameters:

  • id (String)

    The custom voice ID, e.g. voice_1234.



# File 'lib/openai/models/realtime/realtime_audio_config_output.rb', line 89

#self?.variants::Array[OpenAI::Models::Realtime::RealtimeAudioConfigOutput::voice]

Returns:

  • (::Array[OpenAI::Models::Realtime::RealtimeAudioConfigOutput::voice])


67
# File 'sig/openai/models/realtime/realtime_audio_config_output.rbs', line 67

def self?.variants: -> ::Array[OpenAI::Models::Realtime::RealtimeAudioConfigOutput::voice]