Module: OpenAI::Models::Realtime::RealtimeAudioConfigOutput::Voice
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/realtime/realtime_audio_config_output.rb
Overview
The voice the model uses to respond. Supported built-in voices are alloy, ash, ballad, coral, echo, sage, shimmer, verse, marin, and cedar. You may also provide a custom voice object with an id, for example ‘{ “id”: “voice_1234” }`. Voice cannot be changed during the session once the model has responded with audio at least once. We recommend marin and cedar for best quality.
Defined Under Namespace
Classes: ID
collapse
- ALLOY =
:alloy- ASH =
:ash- BALLAD =
:ballad- CORAL =
:coral- ECHO =
:echo- SAGE =
:sage- SHIMMER =
:shimmer- VERSE =
:verse- MARIN =
:marin- CEDAR =
:cedar
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
Custom voice reference.
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(String, Symbol, OpenAI::Models::Realtime::RealtimeAudioConfigOutput::Voice::ID)
98 99 100 101 102 103 104 105 106 |
# File 'lib/openai/models/realtime/realtime_audio_config_output.rb', line 98 define_sorbet_constant!(:Variants) do T.type_alias do T.any( String, OpenAI::Realtime::RealtimeAudioConfigOutput::Voice::TaggedSymbol, OpenAI::Realtime::RealtimeAudioConfigOutput::Voice::ID ) end end |
Instance Method Details
#initialize(id:) ⇒ Object
Custom voice reference.
|
|
# File 'lib/openai/models/realtime/realtime_audio_config_output.rb', line 89
|