Class: OpenAI::Models::Realtime::RealtimeAudioInputTurnDetection
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeAudioInputTurnDetection
- Defined in:
- lib/openai/models/realtime/realtime_audio_input_turn_detection.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#create_response ⇒ Boolean?
Whether or not to automatically generate a response when a VAD stop event occurs.
-
#eagerness ⇒ Symbol, ...
Used only for ‘semantic_vad` mode.
-
#idle_timeout_ms ⇒ Integer?
Optional idle timeout after which turn detection will auto-timeout when no additional audio is received.
-
#interrupt_response ⇒ Boolean?
Whether or not to automatically interrupt any ongoing response with output to the default conversation (i.e. ‘conversation` of `auto`) when a VAD start event occurs.
-
#prefix_padding_ms ⇒ Integer?
Used only for ‘server_vad` mode.
-
#silence_duration_ms ⇒ Integer?
Used only for ‘server_vad` mode.
-
#threshold ⇒ Float?
Used only for ‘server_vad` mode.
-
#type ⇒ Symbol, ...
Type of turn detection.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(create_response: nil, eagerness: nil, idle_timeout_ms: nil, interrupt_response: nil, prefix_padding_ms: nil, silence_duration_ms: nil, threshold: nil, type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RealtimeAudioInputTurnDetection for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(create_response: nil, eagerness: nil, idle_timeout_ms: nil, interrupt_response: nil, prefix_padding_ms: nil, silence_duration_ms: nil, threshold: nil, type: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeAudioInputTurnDetection for more details.
Configuration for turn detection, ether Server VAD or Semantic VAD. This can be set to ‘null` to turn off, in which case the client must manually trigger model response. Server VAD means that the model will detect the start and end of speech based on audio volume and respond at the end of user speech. Semantic VAD is more advanced and uses a turn detection model (in conjunction with VAD) to semantically estimate whether the user has finished speaking, then dynamically sets a timeout based on this probability. For example, if user audio trails off with “uhhm”, the model will score a low probability of turn end and wait longer for the user to continue speaking. This can be useful for more natural conversations, but may have a higher latency.
|
|
# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 67
|
Instance Attribute Details
#create_response ⇒ Boolean?
Whether or not to automatically generate a response when a VAD stop event occurs.
12 |
# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 12 optional :create_response, OpenAI::Internal::Type::Boolean |
#eagerness ⇒ Symbol, ...
Used only for ‘semantic_vad` mode. The eagerness of the model to respond. `low` will wait longer for the user to continue speaking, `high` will respond more quickly. `auto` is the default and is equivalent to `medium`. `low`, `medium`, and `high` have max timeouts of 8s, 4s, and 2s respectively.
21 |
# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 21 optional :eagerness, enum: -> { OpenAI::Realtime::RealtimeAudioInputTurnDetection::Eagerness } |
#idle_timeout_ms ⇒ Integer?
Optional idle timeout after which turn detection will auto-timeout when no additional audio is received.
28 |
# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 28 optional :idle_timeout_ms, Integer, nil?: true |
#interrupt_response ⇒ Boolean?
Whether or not to automatically interrupt any ongoing response with output to the default conversation (i.e. ‘conversation` of `auto`) when a VAD start event occurs.
36 |
# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 36 optional :interrupt_response, OpenAI::Internal::Type::Boolean |
#prefix_padding_ms ⇒ Integer?
Used only for ‘server_vad` mode. Amount of audio to include before the VAD detected speech (in milliseconds). Defaults to 300ms.
43 |
# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 43 optional :prefix_padding_ms, Integer |
#silence_duration_ms ⇒ Integer?
Used only for ‘server_vad` mode. Duration of silence to detect speech stop (in milliseconds). Defaults to 500ms. With shorter values the model will respond more quickly, but may jump in on short pauses from the user.
51 |
# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 51 optional :silence_duration_ms, Integer |
#threshold ⇒ Float?
Used only for ‘server_vad` mode. Activation threshold for VAD (0.0 to 1.0), this defaults to 0.5. A higher threshold will require louder audio to activate the model, and thus might perform better in noisy environments.
59 |
# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 59 optional :threshold, Float |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/realtime/realtime_audio_input_turn_detection.rb', line 112
|