Class: OpenAI::Models::Realtime::RealtimeConversationItemFunctionCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb

Defined Under Namespace

Modules: Object, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_id: , output: , id: nil, object: nil, status: nil, type: :function_call_output) ⇒ Object

A function call output item in a Realtime conversation.

Parameters:



# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 43

Instance Attribute Details

#call_idString

The ID of the function call this output is for.

Returns:

  • (String)


11
# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 11

required :call_id, String

#idString?

The unique ID of the item.

Returns:

  • (String, nil)


29
# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 29

optional :id, String

#objectSymbol, ...

Identifier for the API object being returned - always ‘realtime.item`.



35
# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 35

optional :object, enum: -> { OpenAI::Realtime::RealtimeConversationItemFunctionCallOutput::Object }

#outputString

The output of the function call.

Returns:

  • (String)


17
# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 17

required :output, String

#statusSymbol, ...

The status of the item. Has no effect on the conversation.



41
# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 41

optional :status, enum: -> { OpenAI::Realtime::RealtimeConversationItemFunctionCallOutput::Status }

#typeSymbol, :function_call_output

The type of the item. Always ‘function_call_output`.

Returns:

  • (Symbol, :function_call_output)


23
# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 23

required :type, const: :function_call_output

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/realtime/realtime_conversation_item_function_call_output.rb', line 66