Class: OpenAI::Models::Realtime::RealtimeResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_response.rb

Defined Under Namespace

Modules: MaxOutputTokens, Object, OutputModality, Status Classes: Audio

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, audio: nil, conversation_id: nil, max_output_tokens: nil, metadata: nil, object: nil, output: nil, output_modalities: nil, status: nil, status_details: nil, usage: nil) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeResponse for more details.

The response resource.

Parameters:

  • (defaults to: nil)

    The unique ID of the response, will look like resp_1234.

  • (defaults to: nil)

    Configuration for audio output.

  • (defaults to: nil)

    Which conversation the response is added to, determined by the conversation

  • (defaults to: nil)

    Maximum number of output tokens for a single assistant response,

  • (defaults to: nil)

    Set of 16 key-value pairs that can be attached to an object. This can be

  • (defaults to: nil)

    The object type, must be realtime.response.

  • (defaults to: nil)

    The list of output items generated by the response.

  • (defaults to: nil)

    The set of modalities the model used to respond, currently the only possible val

  • (defaults to: nil)

    The final status of the response (completed, cancelled, failed, or

  • (defaults to: nil)

    Additional details about the status.

  • (defaults to: nil)

    Usage statistics for the Response, this will correspond to billing. A



# File 'lib/openai/models/realtime/realtime_response.rb', line 92


Instance Attribute Details

#audioOpenAI::Models::Realtime::RealtimeResponse::Audio?

Configuration for audio output.

Returns:



17
# File 'lib/openai/models/realtime/realtime_response.rb', line 17

optional :audio, -> { OpenAI::Realtime::RealtimeResponse::Audio }

#conversation_idString?

Which conversation the response is added to, determined by the conversation field in the response.create event. If auto, the response will be added to the default conversation and the value of conversation_id will be an id like conv_1234. If none, the response will not be added to any conversation and the value of conversation_id will be null. If responses are being triggered automatically by VAD the response will be added to the default conversation

Returns:



28
# File 'lib/openai/models/realtime/realtime_response.rb', line 28

optional :conversation_id, String

#idString?

The unique ID of the response, will look like resp_1234.

Returns:



11
# File 'lib/openai/models/realtime/realtime_response.rb', line 11

optional :id, String

#max_output_tokensInteger, ...

Maximum number of output tokens for a single assistant response, inclusive of tool calls, that was used in this response.

Returns:



35
# File 'lib/openai/models/realtime/realtime_response.rb', line 35

optional :max_output_tokens, union: -> { OpenAI::Realtime::RealtimeResponse::MaxOutputTokens }

#metadataHash{Symbol=>String}?

Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

Returns:



46
# File 'lib/openai/models/realtime/realtime_response.rb', line 46

optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true

#objectSymbol, ...

The object type, must be realtime.response.

Returns:



52
# File 'lib/openai/models/realtime/realtime_response.rb', line 52

optional :object, enum: -> { OpenAI::Realtime::RealtimeResponse::Object }

#outputArray<OpenAI::Models::Realtime::RealtimeConversationItemSystemMessage, OpenAI::Models::Realtime::RealtimeConversationItemUserMessage, OpenAI::Models::Realtime::RealtimeConversationItemAssistantMessage, OpenAI::Models::Realtime::RealtimeConversationItemFunctionCall, OpenAI::Models::Realtime::RealtimeConversationItemFunctionCallOutput, OpenAI::Models::Realtime::RealtimeMcpApprovalResponse, OpenAI::Models::Realtime::RealtimeMcpListTools, OpenAI::Models::Realtime::RealtimeMcpToolCall, OpenAI::Models::Realtime::RealtimeMcpApprovalRequest>?

The list of output items generated by the response.

Returns:



58
# File 'lib/openai/models/realtime/realtime_response.rb', line 58

optional :output, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Realtime::ConversationItem] }

#output_modalitiesArray<Symbol, OpenAI::Models::Realtime::RealtimeResponse::OutputModality>?

The set of modalities the model used to respond, currently the only possible values are ‘["audio"]`, `["text"]`. Audio output always include a text transcript. Setting the output to mode text will disable audio output from the model.

Returns:



67
68
# File 'lib/openai/models/realtime/realtime_response.rb', line 67

optional :output_modalities,
-> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Realtime::RealtimeResponse::OutputModality] }

#statusSymbol, ...

The final status of the response (completed, cancelled, failed, or incomplete, in_progress).

Returns:



75
# File 'lib/openai/models/realtime/realtime_response.rb', line 75

optional :status, enum: -> { OpenAI::Realtime::RealtimeResponse::Status }

#status_detailsOpenAI::Models::Realtime::RealtimeResponseStatus?

Additional details about the status.

Returns:



81
# File 'lib/openai/models/realtime/realtime_response.rb', line 81

optional :status_details, -> { OpenAI::Realtime::RealtimeResponseStatus }

#usageOpenAI::Models::Realtime::RealtimeResponseUsage?

Usage statistics for the Response, this will correspond to billing. A Realtime API session will maintain a conversation context and append new Items to the Conversation, thus output from previous turns (text and audio tokens) will become the input for later turns.

Returns:



90
# File 'lib/openai/models/realtime/realtime_response.rb', line 90

optional :usage, -> { OpenAI::Realtime::RealtimeResponseUsage }

Class Method Details

.valuesArray<Symbol>

Returns:



# File 'lib/openai/models/realtime/realtime_response.rb', line 236


.variantsArray(Integer, Symbol, :inf)

Returns:



# File 'lib/openai/models/realtime/realtime_response.rb', line 224