Class: OpenAI::Models::Realtime::RealtimeResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeResponse
- Defined in:
- lib/openai/models/realtime/realtime_response.rb
Defined Under Namespace
Modules: MaxOutputTokens, Object, OutputModality, Status Classes: Audio
Instance Attribute Summary collapse
-
#audio ⇒ OpenAI::Models::Realtime::RealtimeResponse::Audio?
Configuration for audio output.
-
#conversation_id ⇒ String?
Which conversation the response is added to, determined by the
conversationfield in theresponse.createevent. -
#id ⇒ String?
The unique ID of the response, will look like
resp_1234. -
#max_output_tokens ⇒ Integer, ...
Maximum number of output tokens for a single assistant response, inclusive of tool calls, that was used in this response.
-
#metadata ⇒ Hash{Symbol=>String}?
Set of 16 key-value pairs that can be attached to an object.
-
#object ⇒ Symbol, ...
The object type, must be
realtime.response. -
#output ⇒ Array<OpenAI::Models::Realtime::RealtimeConversationItemSystemMessage, OpenAI::Models::Realtime::RealtimeConversationItemUserMessage, OpenAI::Models::Realtime::RealtimeConversationItemAssistantMessage, OpenAI::Models::Realtime::RealtimeConversationItemFunctionCall, OpenAI::Models::Realtime::RealtimeConversationItemFunctionCallOutput, OpenAI::Models::Realtime::RealtimeMcpApprovalResponse, OpenAI::Models::Realtime::RealtimeMcpListTools, OpenAI::Models::Realtime::RealtimeMcpToolCall, OpenAI::Models::Realtime::RealtimeMcpApprovalRequest>?
The list of output items generated by the response.
-
#output_modalities ⇒ Array<Symbol, OpenAI::Models::Realtime::RealtimeResponse::OutputModality>?
The set of modalities the model used to respond, currently the only possible values are ‘["audio"]`, `["text"]`.
-
#status ⇒ Symbol, ...
The final status of the response (
completed,cancelled,failed, orincomplete,in_progress). -
#status_details ⇒ OpenAI::Models::Realtime::RealtimeResponseStatus?
Additional details about the status.
-
#usage ⇒ OpenAI::Models::Realtime::RealtimeResponseUsage?
Usage statistics for the Response, this will correspond to billing.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, audio: nil, conversation_id: nil, max_output_tokens: nil, metadata: nil, object: nil, output: nil, output_modalities: nil, status: nil, status_details: nil, usage: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RealtimeResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, audio: nil, conversation_id: nil, max_output_tokens: nil, metadata: nil, object: nil, output: nil, output_modalities: nil, status: nil, status_details: nil, usage: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeResponse for more details.
The response resource.
|
|
# File 'lib/openai/models/realtime/realtime_response.rb', line 92
|
Instance Attribute Details
#audio ⇒ OpenAI::Models::Realtime::RealtimeResponse::Audio?
Configuration for audio output.
17 |
# File 'lib/openai/models/realtime/realtime_response.rb', line 17 optional :audio, -> { OpenAI::Realtime::RealtimeResponse::Audio } |
#conversation_id ⇒ String?
Which conversation the response is added to, determined by the conversation field in the response.create event. If auto, the response will be added to the default conversation and the value of conversation_id will be an id like conv_1234. If none, the response will not be added to any conversation and the value of conversation_id will be null. If responses are being triggered automatically by VAD the response will be added to the default conversation
28 |
# File 'lib/openai/models/realtime/realtime_response.rb', line 28 optional :conversation_id, String |
#id ⇒ String?
The unique ID of the response, will look like resp_1234.
11 |
# File 'lib/openai/models/realtime/realtime_response.rb', line 11 optional :id, String |
#max_output_tokens ⇒ Integer, ...
Maximum number of output tokens for a single assistant response, inclusive of tool calls, that was used in this response.
35 |
# File 'lib/openai/models/realtime/realtime_response.rb', line 35 optional :max_output_tokens, union: -> { OpenAI::Realtime::RealtimeResponse::MaxOutputTokens } |
#metadata ⇒ Hash{Symbol=>String}?
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
46 |
# File 'lib/openai/models/realtime/realtime_response.rb', line 46 optional :metadata, OpenAI::Internal::Type::HashOf[String], nil?: true |
#object ⇒ Symbol, ...
The object type, must be realtime.response.
52 |
# File 'lib/openai/models/realtime/realtime_response.rb', line 52 optional :object, enum: -> { OpenAI::Realtime::RealtimeResponse::Object } |
#output ⇒ Array<OpenAI::Models::Realtime::RealtimeConversationItemSystemMessage, OpenAI::Models::Realtime::RealtimeConversationItemUserMessage, OpenAI::Models::Realtime::RealtimeConversationItemAssistantMessage, OpenAI::Models::Realtime::RealtimeConversationItemFunctionCall, OpenAI::Models::Realtime::RealtimeConversationItemFunctionCallOutput, OpenAI::Models::Realtime::RealtimeMcpApprovalResponse, OpenAI::Models::Realtime::RealtimeMcpListTools, OpenAI::Models::Realtime::RealtimeMcpToolCall, OpenAI::Models::Realtime::RealtimeMcpApprovalRequest>?
The list of output items generated by the response.
58 |
# File 'lib/openai/models/realtime/realtime_response.rb', line 58 optional :output, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Realtime::ConversationItem] } |
#output_modalities ⇒ Array<Symbol, OpenAI::Models::Realtime::RealtimeResponse::OutputModality>?
The set of modalities the model used to respond, currently the only possible values are ‘["audio"]`, `["text"]`. Audio output always include a text transcript. Setting the output to mode text will disable audio output from the model.
67 68 |
# File 'lib/openai/models/realtime/realtime_response.rb', line 67 optional :output_modalities, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Realtime::RealtimeResponse::OutputModality] } |
#status ⇒ Symbol, ...
The final status of the response (completed, cancelled, failed, or incomplete, in_progress).
75 |
# File 'lib/openai/models/realtime/realtime_response.rb', line 75 optional :status, enum: -> { OpenAI::Realtime::RealtimeResponse::Status } |
#status_details ⇒ OpenAI::Models::Realtime::RealtimeResponseStatus?
Additional details about the status.
81 |
# File 'lib/openai/models/realtime/realtime_response.rb', line 81 optional :status_details, -> { OpenAI::Realtime::RealtimeResponseStatus } |
#usage ⇒ OpenAI::Models::Realtime::RealtimeResponseUsage?
Usage statistics for the Response, this will correspond to billing. A Realtime API session will maintain a conversation context and append new Items to the Conversation, thus output from previous turns (text and audio tokens) will become the input for later turns.
90 |
# File 'lib/openai/models/realtime/realtime_response.rb', line 90 optional :usage, -> { OpenAI::Realtime::RealtimeResponseUsage } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/realtime/realtime_response.rb', line 236
|
.variants ⇒ Array(Integer, Symbol, :inf)
|
|
# File 'lib/openai/models/realtime/realtime_response.rb', line 224
|