Class: OpenAI::Models::Realtime::RealtimeResponse::Audio::Output
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeResponse::Audio::Output
- Defined in:
- lib/openai/models/realtime/realtime_response.rb
Overview
Defined Under Namespace
Modules: Voice
Instance Attribute Summary collapse
-
#format_ ⇒ OpenAI::Models::Realtime::RealtimeAudioFormats::AudioPCM, ...
The format of the output audio.
-
#voice ⇒ String, ...
The voice the model uses to respond.
Instance Method Summary collapse
-
#initialize(format_: nil, voice: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Output for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(format_: nil, voice: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeResponse::Audio::Output for more details.
|
|
# File 'lib/openai/models/realtime/realtime_response.rb', line 149
|
Instance Attribute Details
#format_ ⇒ OpenAI::Models::Realtime::RealtimeAudioFormats::AudioPCM, ...
The format of the output audio.
138 |
# File 'lib/openai/models/realtime/realtime_response.rb', line 138 optional :format_, union: -> { OpenAI::Realtime::RealtimeAudioFormats }, api_name: :format |
#voice ⇒ String, ...
The voice the model uses to respond. Voice cannot be changed during the session once the model has responded with audio at least once. Current voice options are alloy, ash, ballad, coral, echo, sage, shimmer, verse, marin, and cedar. We recommend marin and cedar for best quality.
147 |
# File 'lib/openai/models/realtime/realtime_response.rb', line 147 optional :voice, union: -> { OpenAI::Realtime::RealtimeResponse::Audio::Output::Voice } |