Class: OpenAI::Models::Realtime::RealtimeResponseCreateMcpTool

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_response_create_mcp_tool.rb

Defined Under Namespace

Modules: AllowedTools, ConnectorID, RequireApproval

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(server_label:, allowed_tools: nil, authorization: nil, connector_id: nil, defer_loading: nil, headers: nil, require_approval: nil, server_description: nil, server_url: nil, type: :mcp) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeResponseCreateMcpTool for more details.

Give the model access to additional tools via remote Model Context Protocol (MCP) servers. [Learn more about MCP](platform.openai.com/docs/guides/tools-remote-mcp).

Parameters:



# File 'lib/openai/models/realtime/realtime_response_create_mcp_tool.rb', line 89

Instance Attribute Details

#allowed_toolsArray<String>, ...

List of allowed tool names or a filter object.



23
24
25
# File 'lib/openai/models/realtime/realtime_response_create_mcp_tool.rb', line 23

optional :allowed_tools,
union: -> { OpenAI::Realtime::RealtimeResponseCreateMcpTool::AllowedTools },
nil?: true

#authorizationString?

An OAuth access token that can be used with a remote MCP server, either with a custom MCP server URL or a service connector. Your application must handle the OAuth authorization flow and provide the token here.

Returns:

  • (String, nil)


33
# File 'lib/openai/models/realtime/realtime_response_create_mcp_tool.rb', line 33

optional :authorization, String

#connector_idSymbol, ...

Identifier for service connectors, like those available in ChatGPT. One of server_url or connector_id must be provided. Learn more about service connectors [here](platform.openai.com/docs/guides/tools-remote-mcp#connectors).

Currently supported connector_id values are:

  • Dropbox: connector_dropbox

  • Gmail: connector_gmail

  • Google Calendar: connector_googlecalendar

  • Google Drive: connector_googledrive

  • Microsoft Teams: connector_microsoftteams

  • Outlook Calendar: connector_outlookcalendar

  • Outlook Email: connector_outlookemail

  • SharePoint: connector_sharepoint



53
# File 'lib/openai/models/realtime/realtime_response_create_mcp_tool.rb', line 53

optional :connector_id, enum: -> { OpenAI::Realtime::RealtimeResponseCreateMcpTool::ConnectorID }

#defer_loadingBoolean?

Whether this MCP tool is deferred and discovered via tool search.

Returns:



59
# File 'lib/openai/models/realtime/realtime_response_create_mcp_tool.rb', line 59

optional :defer_loading, OpenAI::Internal::Type::Boolean

#headersHash{Symbol=>String}?

Optional HTTP headers to send to the MCP server. Use for authentication or other purposes.

Returns:

  • (Hash{Symbol=>String}, nil)


66
# File 'lib/openai/models/realtime/realtime_response_create_mcp_tool.rb', line 66

optional :headers, OpenAI::Internal::Type::HashOf[String], nil?: true

#require_approvalOpenAI::Models::Realtime::RealtimeResponseCreateMcpTool::RequireApproval::McpToolApprovalFilter, ...

Specify which of the MCP server’s tools require approval.



72
73
74
# File 'lib/openai/models/realtime/realtime_response_create_mcp_tool.rb', line 72

optional :require_approval,
union: -> { OpenAI::Realtime::RealtimeResponseCreateMcpTool::RequireApproval },
nil?: true

#server_descriptionString?

Optional description of the MCP server, used to provide more context.

Returns:

  • (String, nil)


80
# File 'lib/openai/models/realtime/realtime_response_create_mcp_tool.rb', line 80

optional :server_description, String

#server_labelString

A label for this MCP server, used to identify it in tool calls.

Returns:

  • (String)


11
# File 'lib/openai/models/realtime/realtime_response_create_mcp_tool.rb', line 11

required :server_label, String

#server_urlString?

The URL for the MCP server. One of server_url or connector_id must be provided.

Returns:

  • (String, nil)


87
# File 'lib/openai/models/realtime/realtime_response_create_mcp_tool.rb', line 87

optional :server_url, String

#typeSymbol, :mcp

The type of the MCP tool. Always mcp.

Returns:

  • (Symbol, :mcp)


17
# File 'lib/openai/models/realtime/realtime_response_create_mcp_tool.rb', line 17

required :type, const: :mcp

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/realtime/realtime_response_create_mcp_tool.rb', line 193