Class: OpenAI::Models::Realtime::RealtimeSession::InputAudioTranscription
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeSession::InputAudioTranscription
- Defined in:
- lib/openai/models/realtime/realtime_session.rb
Overview
Instance Attribute Summary collapse
-
#language ⇒ String?
The language of the input audio.
-
#model ⇒ String?
The model to use for transcription, current options are ‘gpt-4o-transcribe`, `gpt-4o-mini-transcribe`, and `whisper-1`.
-
#prompt ⇒ String?
An optional text to guide the model’s style or continue a previous audio segment.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#language ⇒ String?
The language of the input audio. Supplying the input language in [ISO-639-1](en.wikipedia.org/wiki/List_of_ISO_639-1_codes) (e.g. ‘en`) format will improve accuracy and latency.
301 |
# File 'lib/openai/models/realtime/realtime_session.rb', line 301 optional :language, String |
#model ⇒ String?
The model to use for transcription, current options are ‘gpt-4o-transcribe`, `gpt-4o-mini-transcribe`, and `whisper-1`.
308 |
# File 'lib/openai/models/realtime/realtime_session.rb', line 308 optional :model, String |
#prompt ⇒ String?
An optional text to guide the model’s style or continue a previous audio segment. For ‘whisper-1`, the [prompt is a list of keywords](platform.openai.com/docs/guides/speech-to-text#prompting). For `gpt-4o-transcribe` models, the prompt is a free text string, for example “expect words related to technology”.
318 |
# File 'lib/openai/models/realtime/realtime_session.rb', line 318 optional :prompt, String |