Module: OpenAI::Models::Realtime::RealtimeSession::Voice
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/realtime/realtime_session.rb,
sig/openai/models/realtime/realtime_session.rbs
Overview
The voice the model uses to respond. Voice cannot be changed during the session
once the model has responded with audio at least once. Current voice options are
alloy, ash, ballad, coral, echo, sage, shimmer, and verse.
collapse
- ALLOY =
:alloy- ASH =
:ash- BALLAD =
:ballad- CORAL =
:coral- ECHO =
:echo- SAGE =
:sage- SHIMMER =
:shimmer- VERSE =
:verse- MARIN =
:marin- CEDAR =
:cedar
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(String, Symbol)
693 694 695 |
# File 'lib/openai/models/realtime/realtime_session.rb', line 693 define_sorbet_constant!(:Variants) do T.type_alias { T.any(String, OpenAI::Realtime::RealtimeSession::Voice::TaggedSymbol) } end |
Instance Method Details
#self?.variants ⇒ ::Array[OpenAI::Models::Realtime::RealtimeSession::voice]
462 |
# File 'sig/openai/models/realtime/realtime_session.rbs', line 462
def self?.variants: -> ::Array[OpenAI::Models::Realtime::RealtimeSession::voice]
|