Class: OpenAI::Models::Realtime::RealtimeSessionCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeSessionCreateResponse
- Defined in:
- lib/openai/models/realtime/realtime_session_create_response.rb
Defined Under Namespace
Modules: Include, MaxOutputTokens, Model, OutputModality, Tool, ToolChoice, Tracing, Type Classes: Audio
Instance Attribute Summary collapse
-
#audio ⇒ OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio?
Configuration for input and output audio.
-
#client_secret ⇒ OpenAI::Models::Realtime::RealtimeSessionClientSecret?
Ephemeral key returned by the API.
-
#include ⇒ Array<Symbol, OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Include>?
Additional fields to include in server outputs.
-
#instructions ⇒ String?
The default system instructions (i.e. system message) prepended to model calls.
-
#max_output_tokens ⇒ Integer, ...
Maximum number of output tokens for a single assistant response, inclusive of tool calls.
-
#model ⇒ String, ...
The Realtime model used for this session.
-
#output_modalities ⇒ Array<Symbol, OpenAI::Models::Realtime::RealtimeSessionCreateResponse::OutputModality>?
The set of modalities the model can respond with.
-
#prompt ⇒ OpenAI::Models::Responses::ResponsePrompt?
Reference to a prompt template and its variables.
-
#tool_choice ⇒ Symbol, ...
How the model chooses tools.
-
#tools ⇒ Array<OpenAI::Models::Realtime::Models, OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Tool::McpTool>?
Tools available to the model.
-
#tracing ⇒ Symbol, ...
Realtime API can write session traces to the [Traces Dashboard](/logs?api=traces).
-
#truncation ⇒ Symbol, ...
Controls how the realtime conversation is truncated prior to model inference.
-
#type ⇒ Symbol, ...
The type of session to create.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(Symbol, :auto, OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Tracing::TracingConfiguration)
Instance Method Summary collapse
-
#initialize(group_id: nil, metadata: nil, workflow_name: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Tracing::TracingConfiguration for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(group_id: nil, metadata: nil, workflow_name: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Tracing::TracingConfiguration for more details.
Granular configuration for tracing.
|
|
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 115
|
Instance Attribute Details
#audio ⇒ OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio?
Configuration for input and output audio.
11 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 11 optional :audio, -> { OpenAI::Realtime::RealtimeSessionCreateResponse::Audio } |
#client_secret ⇒ OpenAI::Models::Realtime::RealtimeSessionClientSecret?
Ephemeral key returned by the API.
17 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 17 optional :client_secret, -> { OpenAI::Realtime::RealtimeSessionClientSecret } |
#include ⇒ Array<Symbol, OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Include>?
Additional fields to include in server outputs.
‘item.input_audio_transcription.logprobs`: Include logprobs for input audio transcription.
26 27 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 26 optional :include, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Realtime::RealtimeSessionCreateResponse::Include] } |
#instructions ⇒ String?
The default system instructions (i.e. system message) prepended to model calls. This field allows the client to guide the model on desired responses. The model can be instructed on response content and format, (e.g. “be extremely succinct”, “act friendly”, “here are examples of good responses”) and on audio behavior (e.g. “talk quickly”, “inject emotion into your voice”, “laugh frequently”). The instructions are not guaranteed to be followed by the model, but they provide guidance to the model on the desired behavior.
Note that the server sets default instructions which will be used if this field is not set and are visible in the ‘session.created` event at the start of the session.
43 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 43 optional :instructions, String |
#max_output_tokens ⇒ Integer, ...
Maximum number of output tokens for a single assistant response, inclusive of tool calls. Provide an integer between 1 and 4096 to limit output tokens, or ‘inf` for the maximum available tokens for a given model. Defaults to `inf`.
51 52 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 51 optional :max_output_tokens, union: -> { OpenAI::Realtime::RealtimeSessionCreateResponse::MaxOutputTokens } |
#model ⇒ String, ...
The Realtime model used for this session.
58 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 58 optional :model, union: -> { OpenAI::Realtime::RealtimeSessionCreateResponse::Model } |
#output_modalities ⇒ Array<Symbol, OpenAI::Models::Realtime::RealtimeSessionCreateResponse::OutputModality>?
The set of modalities the model can respond with. It defaults to ‘[“audio”]`, indicating that the model will respond with audio plus a transcript. `[“text”]` can be used to make the model respond with text only. It is not possible to request both `text` and `audio` at the same time.
67 68 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 67 optional :output_modalities, -> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Realtime::RealtimeSessionCreateResponse::OutputModality] } |
#prompt ⇒ OpenAI::Models::Responses::ResponsePrompt?
Reference to a prompt template and its variables. [Learn more](platform.openai.com/docs/guides/text?api-mode=responses#reusable-prompts).
75 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 75 optional :prompt, -> { OpenAI::Responses::ResponsePrompt }, nil?: true |
#tool_choice ⇒ Symbol, ...
How the model chooses tools. Provide one of the string modes or force a specific function/MCP tool.
82 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 82 optional :tool_choice, union: -> { OpenAI::Realtime::RealtimeSessionCreateResponse::ToolChoice } |
#tools ⇒ Array<OpenAI::Models::Realtime::Models, OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Tool::McpTool>?
Tools available to the model.
88 89 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 88 optional :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Realtime::RealtimeSessionCreateResponse::Tool] } |
#tracing ⇒ Symbol, ...
Realtime API can write session traces to the [Traces Dashboard](/logs?api=traces). Set to null to disable tracing. Once tracing is enabled for a session, the configuration cannot be modified.
‘auto` will create a trace for the session with default values for the workflow name, group id, and metadata.
100 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 100 optional :tracing, union: -> { OpenAI::Realtime::RealtimeSessionCreateResponse::Tracing }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 481
|
.variants ⇒ Array(Symbol, :auto, OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Tracing::TracingConfiguration)
|
|
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 497
|