Class: OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio::Input
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio::Input
- Defined in:
- lib/openai/models/realtime/realtime_session_create_response.rb
Overview
Defined Under Namespace
Modules: TurnDetection Classes: NoiseReduction
Instance Attribute Summary collapse
-
#format_ ⇒ OpenAI::Models::Realtime::RealtimeAudioFormats::AudioPCM, ...
The format of the input audio.
-
#noise_reduction ⇒ OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio::Input::NoiseReduction?
Configuration for input audio noise reduction.
- #transcription ⇒ OpenAI::Models::Realtime::AudioTranscription?
-
#turn_detection ⇒ OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio::Input::TurnDetection::ServerVad, ...
Configuration for turn detection, ether Server VAD or Semantic VAD.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see NoiseReduction for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type: nil) ⇒ Object
Some parameter documentations has been truncated, see NoiseReduction for more details.
Configuration for input audio noise reduction. This can be set to ‘null` to turn off. Noise reduction filters audio added to the input audio buffer before it is sent to VAD and the model. Filtering the audio can improve VAD and turn detection accuracy (reducing false positives) and model performance by improving perception of the input audio.
|
|
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 255
|
Instance Attribute Details
#format_ ⇒ OpenAI::Models::Realtime::RealtimeAudioFormats::AudioPCM, ...
The format of the input audio.
212 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 212 optional :format_, union: -> { OpenAI::Realtime::RealtimeAudioFormats }, api_name: :format |
#noise_reduction ⇒ OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio::Input::NoiseReduction?
Configuration for input audio noise reduction. This can be set to ‘null` to turn off. Noise reduction filters audio added to the input audio buffer before it is sent to VAD and the model. Filtering the audio can improve VAD and turn detection accuracy (reducing false positives) and model performance by improving perception of the input audio.
222 223 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 222 optional :noise_reduction, -> { OpenAI::Realtime::RealtimeSessionCreateResponse::Audio::Input::NoiseReduction } |
#transcription ⇒ OpenAI::Models::Realtime::AudioTranscription?
228 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 228 optional :transcription, -> { OpenAI::Realtime::AudioTranscription } |
#turn_detection ⇒ OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio::Input::TurnDetection::ServerVad, ...
Configuration for turn detection, ether Server VAD or Semantic VAD. This can be set to ‘null` to turn off, in which case the client must manually trigger model response.
Server VAD means that the model will detect the start and end of speech based on audio volume and respond at the end of user speech.
Semantic VAD is more advanced and uses a turn detection model (in conjunction with VAD) to semantically estimate whether the user has finished speaking, then dynamically sets a timeout based on this probability. For example, if user audio trails off with “uhhm”, the model will score a low probability of turn end and wait longer for the user to continue speaking. This can be useful for more natural conversations, but may have a higher latency.
For ‘gpt-realtime-whisper` transcription sessions, turn detection must be set to `null`; VAD is not supported.
249 250 251 252 253 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 249 optional :turn_detection, union: -> { OpenAI::Realtime::RealtimeSessionCreateResponse::Audio::Input::TurnDetection }, nil?: true |