Class: OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio::Input::TurnDetection::SemanticVad
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio::Input::TurnDetection::SemanticVad
- Defined in:
- lib/openai/models/realtime/realtime_session_create_response.rb,
sig/openai/models/realtime/realtime_session_create_response.rbs
Defined Under Namespace
Modules: Eagerness
Instance Attribute Summary collapse
-
#create_response ⇒ Boolean?
Whether or not to automatically generate a response when a VAD stop event occurs.
-
#eagerness ⇒ Symbol, ...
Used only for
semantic_vadmode. -
#interrupt_response ⇒ Boolean?
Whether or not to automatically interrupt any ongoing response with output to the default conversation (i.e.
conversationofauto) when a VAD start event occurs. -
#type ⇒ Symbol, :semantic_vad
Type of turn detection,
semantic_vadto turn on Semantic VAD.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(create_response: nil, eagerness: nil, interrupt_response: nil, type: :semantic_vad) ⇒ Object
constructor
Server-side semantic turn detection which uses a model to determine when the user has finished speaking.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(create_response: nil, eagerness: nil, interrupt_response: nil, type: :semantic_vad) ⇒ Object
Server-side semantic turn detection which uses a model to determine when the user has finished speaking.
|
|
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 571
|
Instance Attribute Details
#create_response ⇒ Boolean?
Whether or not to automatically generate a response when a VAD stop event occurs.
547 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 547 optional :create_response, OpenAI::Internal::Type::Boolean |
#eagerness ⇒ Symbol, ...
Used only for semantic_vad mode. The eagerness of the model to respond. low
will wait longer for the user to continue speaking, high will respond more
quickly. auto is the default and is equivalent to medium. low, medium,
and high have max timeouts of 8s, 4s, and 2s respectively.
556 557 558 559 560 561 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 556 optional( :eagerness, enum: -> { OpenAI::Realtime::RealtimeSessionCreateResponse::Audio::Input::TurnDetection::SemanticVad::Eagerness } ) |
#interrupt_response ⇒ Boolean?
Whether or not to automatically interrupt any ongoing response with output to
the default conversation (i.e. conversation of auto) when a VAD start event
occurs.
569 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 569 optional :interrupt_response, OpenAI::Internal::Type::Boolean |
#type ⇒ Symbol, :semantic_vad
Type of turn detection, semantic_vad to turn on Semantic VAD.
540 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 540 required :type, const: :semantic_vad |
Instance Method Details
#to_hash ⇒ {
324 |
# File 'sig/openai/models/realtime/realtime_session_create_response.rbs', line 324
def to_hash: -> {
|