Module: OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio::Output::Voice
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/openai/models/realtime/realtime_session_create_response.rb,
sig/openai/models/realtime/realtime_session_create_response.rbs
Overview
The voice the model uses to respond. Voice cannot be changed during the session
once the model has responded with audio at least once. Current voice options are
alloy, ash, ballad, coral, echo, sage, shimmer, verse, marin,
and cedar. We recommend marin and cedar for best quality.
collapse
- ALLOY =
:alloy- ASH =
:ash- BALLAD =
:ballad- CORAL =
:coral- ECHO =
:echo- SAGE =
:sage- SHIMMER =
:shimmer- VERSE =
:verse- MARIN =
:marin- CEDAR =
:cedar
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(String, Symbol)
562 563 564 |
# File 'lib/openai/models/realtime/realtime_session_create_response.rb', line 562 define_sorbet_constant!(:Variants) do T.type_alias { T.any(String, OpenAI::Realtime::RealtimeSessionCreateResponse::Audio::Output::Voice::TaggedSymbol) } end |
Instance Method Details
#self?.variants ⇒ ::Array[OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio::Output::voice]
401 |
# File 'sig/openai/models/realtime/realtime_session_create_response.rbs', line 401
def self?.variants: -> ::Array[OpenAI::Models::Realtime::RealtimeSessionCreateResponse::Audio::Output::voice]
|