Class: OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio::Input

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_transcription_session_create_response.rb,
sig/openai/models/realtime/realtime_transcription_session_create_response.rbs

Overview

See Also:

  • OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio#input

Defined Under Namespace

Classes: NoiseReduction

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(format_: nil, noise_reduction: nil, transcription: nil, turn_detection: nil) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio::Input for more details.

Parameters:



# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 119

Instance Attribute Details

#format_OpenAI::Models::Realtime::RealtimeAudioFormats::AudioPCM, ...

The PCM audio format. Only a 24kHz sample rate is supported.



88
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 88

optional :format_, union: -> { OpenAI::Realtime::RealtimeAudioFormats }, api_name: :format

#noise_reductionOpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio::Input::NoiseReduction?

Configuration for input audio noise reduction.



94
95
96
97
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 94

optional(
  :noise_reduction,
  -> { OpenAI::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio::Input::NoiseReduction }
)

#transcriptionOpenAI::Models::Realtime::AudioTranscription?



102
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 102

optional :transcription, -> { OpenAI::Realtime::AudioTranscription }

#turn_detectionOpenAI::Models::Realtime::RealtimeTranscriptionSessionTurnDetection?

Configuration for turn detection. Can be set to null to turn off. Server VAD means that the model will detect the start and end of speech based on audio volume and respond at the end of user speech. For gpt-realtime-whisper, this must be null; VAD is not supported.

Parameters:

  • value (OpenAI::Realtime::RealtimeTranscriptionSessionTurnDetection, nil)

Returns:



111
112
113
114
115
116
117
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 111

optional(
  :turn_detection,
  -> {
    OpenAI::Realtime::RealtimeTranscriptionSessionTurnDetection
  },
  nil?: true
)

Instance Method Details

#to_hash{

Returns:

  • ({)


113
# File 'sig/openai/models/realtime/realtime_transcription_session_create_response.rbs', line 113

def to_hash: -> {