Class: OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio::Input
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio::Input
- Defined in:
- lib/openai/models/realtime/realtime_transcription_session_create_response.rb
Overview
Defined Under Namespace
Classes: NoiseReduction
Instance Attribute Summary collapse
-
#format_ ⇒ OpenAI::Models::Realtime::RealtimeAudioFormats::AudioPCM, ...
The PCM audio format.
-
#noise_reduction ⇒ OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio::Input::NoiseReduction?
Configuration for input audio noise reduction.
-
#transcription ⇒ OpenAI::Models::Realtime::AudioTranscription?
Configuration of the transcription model.
-
#turn_detection ⇒ OpenAI::Models::Realtime::RealtimeTranscriptionSessionTurnDetection?
Configuration for turn detection.
Instance Method Summary collapse
-
#initialize(format_: nil, noise_reduction: nil, transcription: nil, turn_detection: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Input for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(format_: nil, noise_reduction: nil, transcription: nil, turn_detection: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio::Input for more details.
|
|
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 107
|
Instance Attribute Details
#format_ ⇒ OpenAI::Models::Realtime::RealtimeAudioFormats::AudioPCM, ...
The PCM audio format. Only a 24kHz sample rate is supported.
84 |
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 84 optional :format_, union: -> { OpenAI::Realtime::RealtimeAudioFormats }, api_name: :format |
#noise_reduction ⇒ OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio::Input::NoiseReduction?
Configuration for input audio noise reduction.
90 91 |
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 90 optional :noise_reduction, -> { OpenAI::Realtime::RealtimeTranscriptionSessionCreateResponse::Audio::Input::NoiseReduction } |
#transcription ⇒ OpenAI::Models::Realtime::AudioTranscription?
Configuration of the transcription model.
97 |
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 97 optional :transcription, -> { OpenAI::Realtime::AudioTranscription } |
#turn_detection ⇒ OpenAI::Models::Realtime::RealtimeTranscriptionSessionTurnDetection?
Configuration for turn detection. Can be set to null to turn off. Server VAD means that the model will detect the start and end of speech based on audio volume and respond at the end of user speech.
105 |
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 105 optional :turn_detection, -> { OpenAI::Realtime::RealtimeTranscriptionSessionTurnDetection } |