Module: OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse::Modality
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/realtime/realtime_transcription_session_create_response.rb
Constant Summary collapse
- TEXT =
:text- AUDIO =
:audio
Instance Method Summary collapse
-
#initialize(client_secret: , input_audio_format: nil, input_audio_transcription: nil, modalities: nil, turn_detection: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse for more details.
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#initialize(client_secret: , input_audio_format: nil, input_audio_transcription: nil, modalities: nil, turn_detection: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateResponse for more details.
A new Realtime transcription session configuration.
When a session is created on the server via REST API, the session object also contains an ephemeral key. Default TTL for keys is 10 minutes. This property is not present when a session is updated via the WebSocket API.
64 65 66 67 68 69 70 71 72 |
# File 'lib/openai/models/realtime/realtime_transcription_session_create_response.rb', line 64 module Modality extend OpenAI::Internal::Type::Enum TEXT = :text AUDIO = :audio # @!method self.values # @return [Array<Symbol>] end |