Class: OpenAI::Models::Realtime::RealtimeTranslationClientSecretCreateRequest::ExpiresAfter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/realtime_translation_client_secret_create_request.rb

Overview

See Also:

Defined Under Namespace

Modules: Anchor

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(anchor: nil, seconds: nil) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Realtime::RealtimeTranslationClientSecretCreateRequest::ExpiresAfter for more details.

Configuration for the client secret expiration. Expiration refers to the time after which a client secret will no longer be valid for creating sessions. The session itself may continue after that time once started. A secret can be used to create multiple sessions until it expires.

Parameters:



# File 'lib/openai/models/realtime/realtime_translation_client_secret_create_request.rb', line 54

Instance Attribute Details

#anchorSymbol, ...

The anchor point for the client secret expiration, meaning that ‘seconds` will be added to the `created_at` time of the client secret to produce an expiration timestamp. Only `created_at` is currently supported.



43
44
# File 'lib/openai/models/realtime/realtime_translation_client_secret_create_request.rb', line 43

optional :anchor,
enum: -> { OpenAI::Realtime::RealtimeTranslationClientSecretCreateRequest::ExpiresAfter::Anchor }

#secondsInteger?

The number of seconds from the anchor point to the expiration. Select a value between ‘10` and `7200` (2 hours). This default to 600 seconds (10 minutes) if not specified.

Returns:

  • (Integer, nil)


52
# File 'lib/openai/models/realtime/realtime_translation_client_secret_create_request.rb', line 52

optional :seconds, Integer