Class: OpenAI::Models::Realtime::RealtimeTranslationClientSecretCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Realtime::RealtimeTranslationClientSecretCreateResponse
- Defined in:
- lib/openai/models/realtime/realtime_translation_client_secret_create_response.rb,
sig/openai/models/realtime/realtime_translation_client_secret_create_response.rbs
Instance Attribute Summary collapse
-
#expires_at ⇒ Integer
Expiration timestamp for the client secret, in seconds since epoch.
-
#session ⇒ OpenAI::Realtime::RealtimeTranslationSession
A Realtime translation session.
-
#value ⇒ String
The generated client secret value.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(expires_at:, session:, value:) ⇒ Object
|
|
# File 'lib/openai/models/realtime/realtime_translation_client_secret_create_response.rb', line 26
|
Instance Attribute Details
#expires_at ⇒ Integer
Expiration timestamp for the client secret, in seconds since epoch.
11 |
# File 'lib/openai/models/realtime/realtime_translation_client_secret_create_response.rb', line 11 required :expires_at, Integer |
#session ⇒ OpenAI::Realtime::RealtimeTranslationSession
A Realtime translation session. Translation sessions continuously translate input audio into the configured output language.
18 |
# File 'lib/openai/models/realtime/realtime_translation_client_secret_create_response.rb', line 18 required :session, -> { OpenAI::Realtime::RealtimeTranslationSession } |
#value ⇒ String
The generated client secret value.
24 |
# File 'lib/openai/models/realtime/realtime_translation_client_secret_create_response.rb', line 24 required :value, String |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/openai/models/realtime/realtime_translation_client_secret_create_response.rbs', line 35
def to_hash: -> {
|