Class: OpenAI::Models::Realtime::SessionUpdateEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/realtime/session_update_event.rb

Defined Under Namespace

Modules: Session

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(session:, event_id: nil, type: :"session.update") ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Realtime::SessionUpdateEvent for more details.

Send this event to update the session’s configuration. The client may send this event at any time to update any field except for voice and model. voice can be updated only if there have been no other audio outputs yet.

When the server receives a session.update, it will respond with a session.updated event showing the full, effective configuration. Only the fields that are present in the session.update are updated. To clear a field like instructions, pass an empty string. To clear a field like tools, pass an empty array. To clear a field like turn_detection, pass null.

Parameters:

  • Update the Realtime session. Choose either a realtime

  • (defaults to: nil)

    Optional client-generated ID used to identify this event. This is an arbitrary s

  • (defaults to: :"session.update")

    The event type, must be session.update.



# File 'lib/openai/models/realtime/session_update_event.rb', line 29


Instance Attribute Details

#event_idString?

Optional client-generated ID used to identify this event. This is an arbitrary string that a client may assign. It will be passed back if there is an error with the event, but the corresponding session.updated event will not include it.

Returns:



27
# File 'lib/openai/models/realtime/session_update_event.rb', line 27

optional :event_id, String

#sessionOpenAI::Models::Realtime::RealtimeSessionCreateRequest, OpenAI::Models::Realtime::RealtimeTranscriptionSessionCreateRequest

Update the Realtime session. Choose either a realtime session or a transcription session.

Returns:



12
# File 'lib/openai/models/realtime/session_update_event.rb', line 12

required :session, union: -> { OpenAI::Realtime::SessionUpdateEvent::Session }

#typeSymbol, :"session.update"

The event type, must be session.update.

Returns:



18
# File 'lib/openai/models/realtime/session_update_event.rb', line 18

required :type, const: :"session.update"