Class: OpenAI::Models::Reasoning
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Reasoning
- Defined in:
- lib/openai/models/reasoning.rb
Defined Under Namespace
Modules: GenerateSummary, Summary
Instance Attribute Summary collapse
-
#effort ⇒ Symbol, ...
Constrains effort on reasoning for [reasoning models](platform.openai.com/docs/guides/reasoning).
- #generate_summary ⇒ Symbol, ... deprecated Deprecated.
-
#summary ⇒ Symbol, ...
A summary of the reasoning performed by the model.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(effort: nil, generate_summary: nil, summary: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Reasoning for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(effort: nil, generate_summary: nil, summary: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Reasoning for more details.
**gpt-5 and o-series models only**
Configuration options for [reasoning models](platform.openai.com/docs/guides/reasoning).
|
|
# File 'lib/openai/models/reasoning.rb', line 47
|
Instance Attribute Details
#effort ⇒ Symbol, ...
Constrains effort on reasoning for [reasoning models](platform.openai.com/docs/guides/reasoning). Currently supported values are none, minimal, low, medium, high, and xhigh. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response.
-
gpt-5.1defaults tonone, which does not perform reasoning. The supported reasoning values forgpt-5.1arenone,low,medium, andhigh. Tool calls are supported for all reasoning values in gpt-5.1. -
All models before
gpt-5.1default tomediumreasoning effort, and do not supportnone. -
The
gpt-5-promodel defaults to (and only supports)highreasoning effort. -
xhighis supported for all models aftergpt-5.1-codex-max.
22 |
# File 'lib/openai/models/reasoning.rb', line 22 optional :effort, enum: -> { OpenAI::ReasoningEffort }, nil?: true |
#generate_summary ⇒ Symbol, ...
Deprecated: use summary instead.
A summary of the reasoning performed by the model. This can be useful for debugging and understanding the model’s reasoning process. One of auto, concise, or detailed.
34 |
# File 'lib/openai/models/reasoning.rb', line 34 optional :generate_summary, enum: -> { OpenAI::Reasoning::GenerateSummary }, nil?: true |
#summary ⇒ Symbol, ...
A summary of the reasoning performed by the model. This can be useful for debugging and understanding the model’s reasoning process. One of auto, concise, or detailed.
concise is supported for computer-use-preview models and all reasoning models after gpt-5.
45 |
# File 'lib/openai/models/reasoning.rb', line 45 optional :summary, enum: -> { OpenAI::Reasoning::Summary }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/reasoning.rb', line 78
|