Module: OpenAI::Models::Reasoning::Summary
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/reasoning.rb
Overview
A summary of the reasoning performed by the model. This can be useful for debugging and understanding the model’s reasoning process. One of auto, concise, or detailed.
concise is supported for computer-use-preview models and all reasoning models after gpt-5.
Constant Summary collapse
- AUTO =
:auto- CONCISE =
:concise- DETAILED =
:detailed
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/reasoning.rb', line 97
|