Module: OpenAI::Models::ReasoningEffort

Extended by:
Internal::Type::Enum
Defined in:
lib/openai/models/reasoning_effort.rb,
sig/openai/models/reasoning_effort.rbs

Overview

Constrains effort on reasoning for reasoning models. Currently supported values are none, minimal, low, medium, high, xhigh, and max. Reducing reasoning effort can result in faster responses and fewer tokens used on reasoning in a response. Not all reasoning models support every value. See the reasoning guide for model-specific support.

Constant Summary collapse

NONE =

Returns:

  • (:none)
:none
MINIMAL =

Returns:

  • (:minimal)
:minimal
LOW =

Returns:

  • (:low)
:low
MEDIUM =

Returns:

  • (:medium)
:medium
HIGH =

Returns:

  • (:high)
:high
XHIGH =

Returns:

  • (:xhigh)
:xhigh
MAX =

Returns:

  • (:max)
:max

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/reasoning_effort.rb', line 22

Instance Method Details

#self?.values::Array[OpenAI::Models::reasoning_effort]

Returns:

  • (::Array[OpenAI::Models::reasoning_effort])


17
# File 'sig/openai/models/reasoning_effort.rbs', line 17

def self?.values: -> ::Array[OpenAI::Models::reasoning_effort]