Module: OpenAI::Models::ReasoningEffort
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/reasoning_effort.rb,
sig/openai/models/reasoning_effort.rbs
Overview
Constrains effort on reasoning for
reasoning models. Currently
supported values are none, minimal, low, medium, high, and xhigh.
Reducing reasoning effort can result in faster responses and fewer tokens used
on reasoning in a response.
gpt-5.1defaults tonone, which does not perform reasoning. The supported reasoning values forgpt-5.1arenone,low,medium, andhigh. Tool calls are supported for all reasoning values in gpt-5.1.- All models before
gpt-5.1default tomediumreasoning effort, and do not supportnone. - The
gpt-5-promodel defaults to (and only supports)highreasoning effort. xhighis supported for all models aftergpt-5.1-codex-max.
Constant Summary collapse
- NONE =
:none- MINIMAL =
:minimal- LOW =
:low- MEDIUM =
:medium- HIGH =
:high- XHIGH =
:xhigh
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/reasoning_effort.rb', line 28
|
Instance Method Details
#self?.values ⇒ ::Array[OpenAI::Models::reasoning_effort]
15 |
# File 'sig/openai/models/reasoning_effort.rbs', line 15
def self?.values: -> ::Array[OpenAI::Models::reasoning_effort]
|