Class: OpenAI::Models::Responses::ContainerAuto
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ContainerAuto
- Defined in:
- lib/openai/models/responses/container_auto.rb
Defined Under Namespace
Modules: MemoryLimit, NetworkPolicy, Skill
Instance Attribute Summary collapse
-
#file_ids ⇒ Array<String>?
An optional list of uploaded files to make available to your code.
-
#memory_limit ⇒ Symbol, ...
The memory limit for the container.
-
#network_policy ⇒ OpenAI::Models::Responses::ContainerNetworkPolicyDisabled, ...
Network access policy for the container.
-
#skills ⇒ Array<OpenAI::Models::Responses::SkillReference, OpenAI::Models::Responses::InlineSkill>?
An optional list of skills referenced by id or inline data.
-
#type ⇒ Symbol, :container_auto
Automatically creates a container for this request.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(OpenAI::Models::Responses::ContainerNetworkPolicyDisabled, OpenAI::Models::Responses::ContainerNetworkPolicyAllowlist)
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(file_ids: nil, memory_limit: nil, network_policy: nil, skills: nil, type: :container_auto) ⇒ Object
|
|
# File 'lib/openai/models/responses/container_auto.rb', line 37
|
Instance Attribute Details
#file_ids ⇒ Array<String>?
An optional list of uploaded files to make available to your code.
17 |
# File 'lib/openai/models/responses/container_auto.rb', line 17 optional :file_ids, OpenAI::Internal::Type::ArrayOf[String] |
#memory_limit ⇒ Symbol, ...
The memory limit for the container.
23 |
# File 'lib/openai/models/responses/container_auto.rb', line 23 optional :memory_limit, enum: -> { OpenAI::Responses::ContainerAuto::MemoryLimit }, nil?: true |
#network_policy ⇒ OpenAI::Models::Responses::ContainerNetworkPolicyDisabled, ...
Network access policy for the container.
29 |
# File 'lib/openai/models/responses/container_auto.rb', line 29 optional :network_policy, union: -> { OpenAI::Responses::ContainerAuto::NetworkPolicy } |
#skills ⇒ Array<OpenAI::Models::Responses::SkillReference, OpenAI::Models::Responses::InlineSkill>?
An optional list of skills referenced by id or inline data.
35 |
# File 'lib/openai/models/responses/container_auto.rb', line 35 optional :skills, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Responses::ContainerAuto::Skill] } |
#type ⇒ Symbol, :container_auto
Automatically creates a container for this request
11 |
# File 'lib/openai/models/responses/container_auto.rb', line 11 required :type, const: :container_auto |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/container_auto.rb', line 59
|
.variants ⇒ Array(OpenAI::Models::Responses::ContainerNetworkPolicyDisabled, OpenAI::Models::Responses::ContainerNetworkPolicyAllowlist)
|
|
# File 'lib/openai/models/responses/container_auto.rb', line 75
|