Class: OpenAI::Models::Responses::ContainerNetworkPolicyAllowlist

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/container_network_policy_allowlist.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allowed_domains:, domain_secrets: nil, type: :allowlist) ⇒ Object

Parameters:

  • allowed_domains (Array<String>)

    A list of allowed domains when type is allowlist.

  • domain_secrets (Array<OpenAI::Models::Responses::ContainerNetworkPolicyDomainSecret>) (defaults to: nil)

    Optional domain-scoped secrets for allowlisted domains.

  • type (Symbol, :allowlist) (defaults to: :allowlist)

    Allow outbound network access only to specified domains. Always allowlist.



# File 'lib/openai/models/responses/container_network_policy_allowlist.rb', line 26

Instance Attribute Details

#allowed_domainsArray<String>

A list of allowed domains when type is allowlist.

Returns:

  • (Array<String>)


11
# File 'lib/openai/models/responses/container_network_policy_allowlist.rb', line 11

required :allowed_domains, OpenAI::Internal::Type::ArrayOf[String]

#domain_secretsArray<OpenAI::Models::Responses::ContainerNetworkPolicyDomainSecret>?

Optional domain-scoped secrets for allowlisted domains.



23
24
# File 'lib/openai/models/responses/container_network_policy_allowlist.rb', line 23

optional :domain_secrets,
-> { OpenAI::Internal::Type::ArrayOf[OpenAI::Responses::ContainerNetworkPolicyDomainSecret] }

#typeSymbol, :allowlist

Allow outbound network access only to specified domains. Always allowlist.

Returns:

  • (Symbol, :allowlist)


17
# File 'lib/openai/models/responses/container_network_policy_allowlist.rb', line 17

required :type, const: :allowlist