Module: OpenAI::Models::Responses::CustomTool::AllowedCaller
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/openai/models/responses/custom_tool.rb,
sig/openai/models/responses/custom_tool.rbs
Constant Summary collapse
- DIRECT =
:direct- PROGRAMMATIC =
:programmatic
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(name:, allowed_callers: nil, defer_loading: nil, description: nil, format_: nil, type: :custom) ⇒ Object
A custom tool that processes input using a specified format.
- #self?.values ⇒ ::Array[OpenAI::Models::Responses::CustomTool::allowed_caller]
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/custom_tool.rb', line 67
|
Instance Method Details
#initialize(name:, allowed_callers: nil, defer_loading: nil, description: nil, format_: nil, type: :custom) ⇒ Object
A custom tool that processes input using a specified format. Learn more about custom tools
61 62 63 64 65 66 67 68 69 |
# File 'lib/openai/models/responses/custom_tool.rb', line 61 module AllowedCaller extend OpenAI::Internal::Type::Enum DIRECT = :direct PROGRAMMATIC = :programmatic # @!method self.values # @return [Array<Symbol>] end |
#self?.values ⇒ ::Array[OpenAI::Models::Responses::CustomTool::allowed_caller]
61 |
# File 'sig/openai/models/responses/custom_tool.rbs', line 61
def self?.values: -> ::Array[OpenAI::Models::Responses::CustomTool::allowed_caller]
|