Class: OpenAI::Models::Responses::Response::Moderation::Output::ModerationResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::Response::Moderation::Output::ModerationResult
- Defined in:
- lib/openai/models/responses/response.rb
Defined Under Namespace
Modules: CategoryAppliedInputType
Instance Attribute Summary collapse
-
#categories ⇒ Hash{Symbol=>Boolean}
A dictionary of moderation categories to booleans, True if the input is flagged under this category.
-
#category_applied_input_types ⇒ Hash{Symbol=>Array<Symbol, OpenAI::Models::Responses::Response::Moderation::Output::ModerationResult::CategoryAppliedInputType>}
Which modalities of input are reflected by the score for each category.
-
#category_scores ⇒ Hash{Symbol=>Float}
A dictionary of moderation categories to scores.
-
#flagged ⇒ Boolean
A boolean indicating whether the content was flagged by any category.
-
#model ⇒ String
The moderation model that produced this result.
-
#type ⇒ Symbol, :moderation_result
The object type, which was always ‘moderation_result` for successful moderation results.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#categories ⇒ Hash{Symbol=>Boolean}
A dictionary of moderation categories to booleans, True if the input is flagged under this category.
|
|
# File 'lib/openai/models/responses/response.rb', line 690
|
#category_applied_input_types ⇒ Hash{Symbol=>Array<Symbol, OpenAI::Models::Responses::Response::Moderation::Output::ModerationResult::CategoryAppliedInputType>}
Which modalities of input are reflected by the score for each category.
696 697 698 699 700 701 |
# File 'lib/openai/models/responses/response.rb', line 696 required :category_applied_input_types, -> do OpenAI::Internal::Type::HashOf[ OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Responses::Response::Moderation::Output::ModerationResult::CategoryAppliedInputType] ] end |
#category_scores ⇒ Hash{Symbol=>Float}
A dictionary of moderation categories to scores.
|
|
# File 'lib/openai/models/responses/response.rb', line 707
|
#flagged ⇒ Boolean
A boolean indicating whether the content was flagged by any category.
713 |
# File 'lib/openai/models/responses/response.rb', line 713 required :flagged, OpenAI::Internal::Type::Boolean |
#model ⇒ String
The moderation model that produced this result.
719 |
# File 'lib/openai/models/responses/response.rb', line 719 required :model, String |
#type ⇒ Symbol, :moderation_result
The object type, which was always ‘moderation_result` for successful moderation results.
726 |
# File 'lib/openai/models/responses/response.rb', line 726 required :type, const: :moderation_result |