Class: OpenAI::Models::Responses::ResponseApplyPatchToolCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseApplyPatchToolCall
- Defined in:
- lib/openai/models/responses/response_apply_patch_tool_call.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
-
#created_by ⇒ String?
The ID of the entity that created this tool call.
-
#id ⇒ String
The unique ID of the apply patch tool call.
-
#operation ⇒ OpenAI::Models::Responses::ResponseApplyPatchToolCall::Operation::CreateFile, ...
One of the create_file, delete_file, or update_file operations applied via apply_patch.
-
#status ⇒ Symbol, OpenAI::Models::Responses::ResponseApplyPatchToolCall::Status
The status of the apply patch tool call.
-
#type ⇒ Symbol, :apply_patch_call
The type of the item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: , call_id: , status: , created_by: nil, operation: nil, type: :apply_patch_call) ⇒ Object
constructor
Some parameter documentations has been truncated, see ResponseApplyPatchToolCall for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , call_id: , status: , created_by: nil, operation: nil, type: :apply_patch_call) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseApplyPatchToolCall for more details.
A tool call that applies file diffs by creating, deleting, or updating files.
|
|
# File 'lib/openai/models/responses/response_apply_patch_tool_call.rb', line 45
|
Instance Attribute Details
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
18 |
# File 'lib/openai/models/responses/response_apply_patch_tool_call.rb', line 18 required :call_id, String |
#created_by ⇒ String?
The ID of the entity that created this tool call.
36 |
# File 'lib/openai/models/responses/response_apply_patch_tool_call.rb', line 36 optional :created_by, String |
#id ⇒ String
The unique ID of the apply patch tool call. Populated when this item is returned via API.
12 |
# File 'lib/openai/models/responses/response_apply_patch_tool_call.rb', line 12 required :id, String |
#operation ⇒ OpenAI::Models::Responses::ResponseApplyPatchToolCall::Operation::CreateFile, ...
One of the create_file, delete_file, or update_file operations applied via apply_patch.
43 |
# File 'lib/openai/models/responses/response_apply_patch_tool_call.rb', line 43 optional :operation, union: -> { OpenAI::Responses::ResponseApplyPatchToolCall::Operation } |
#status ⇒ Symbol, OpenAI::Models::Responses::ResponseApplyPatchToolCall::Status
The status of the apply patch tool call. One of ‘in_progress` or `completed`.
24 |
# File 'lib/openai/models/responses/response_apply_patch_tool_call.rb', line 24 required :status, enum: -> { OpenAI::Responses::ResponseApplyPatchToolCall::Status } |
#type ⇒ Symbol, :apply_patch_call
The type of the item. Always ‘apply_patch_call`.
30 |
# File 'lib/openai/models/responses/response_apply_patch_tool_call.rb', line 30 required :type, const: :apply_patch_call |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/response_apply_patch_tool_call.rb', line 72
|