Class: OpenAI::Models::Responses::ResponseApplyPatchToolCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseApplyPatchToolCallOutput
- Defined in:
- lib/openai/models/responses/response_apply_patch_tool_call_output.rb,
sig/openai/models/responses/response_apply_patch_tool_call_output.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Responses::ResponseApplyPatchToolCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
-
#created_by ⇒ String?
The ID of the entity that created this tool call output.
-
#id ⇒ String
The unique ID of the apply patch tool call output.
-
#output ⇒ String?
Optional textual output returned by the apply patch tool.
-
#status ⇒ Symbol, OpenAI::Models::Responses::ResponseApplyPatchToolCallOutput::Status
The status of the apply patch tool call output.
-
#type ⇒ Symbol, :apply_patch_call_output
The type of the item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, call_id:, status:, caller_: nil, created_by: nil, output: nil, type: :apply_patch_call_output) ⇒ Object
constructor
Some parameter documentations has been truncated, see ResponseApplyPatchToolCallOutput for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, call_id:, status:, caller_: nil, created_by: nil, output: nil, type: :apply_patch_call_output) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseApplyPatchToolCallOutput for more details.
The output emitted by an apply patch tool call.
|
|
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 53
|
Instance Attribute Details
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
18 |
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 18 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Responses::ResponseApplyPatchToolCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
36 37 38 39 |
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 36 optional :caller_, union: -> { OpenAI::Responses::ResponseApplyPatchToolCallOutput::Caller }, api_name: :caller, nil?: true |
#created_by ⇒ String?
The ID of the entity that created this tool call output.
45 |
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 45 optional :created_by, String |
#id ⇒ String
The unique ID of the apply patch tool call output. Populated when this item is returned via API.
12 |
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 12 required :id, String |
#output ⇒ String?
Optional textual output returned by the apply patch tool.
51 |
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 51 optional :output, String, nil?: true |
#status ⇒ Symbol, OpenAI::Models::Responses::ResponseApplyPatchToolCallOutput::Status
The status of the apply patch tool call output. One of completed or failed.
24 |
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 24 required :status, enum: -> { OpenAI::Responses::ResponseApplyPatchToolCallOutput::Status } |
#type ⇒ Symbol, :apply_patch_call_output
The type of the item. Always apply_patch_call_output.
30 |
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 30 required :type, const: :apply_patch_call_output |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/response_apply_patch_tool_call_output.rb', line 82
|
Instance Method Details
#to_hash ⇒ {
42 |
# File 'sig/openai/models/responses/response_apply_patch_tool_call_output.rbs', line 42
def to_hash: -> {
|