Class: OpenAI::Models::Responses::ResponseComputerToolCall::Action::Keypress
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseComputerToolCall::Action::Keypress
- Defined in:
- lib/openai/models/responses/response_computer_tool_call.rb,
sig/openai/models/responses/response_computer_tool_call.rbs
Instance Attribute Summary collapse
-
#keys ⇒ Array<String>
The combination of keys the model is requesting to be pressed.
-
#type ⇒ Symbol, :keypress
Specifies the event type.
Instance Method Summary collapse
-
#initialize ⇒ Keypress
constructor
A new instance of Keypress.
- #to_hash ⇒ { keys: ::Array[String], type: :keypress }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Keypress
Returns a new instance of Keypress.
242 |
# File 'sig/openai/models/responses/response_computer_tool_call.rbs', line 242
def initialize: (keys: ::Array[String], ?type: :keypress) -> void
|
Instance Attribute Details
#keys ⇒ Array<String>
The combination of keys the model is requesting to be pressed. This is an array of strings, each representing a key.
344 |
# File 'lib/openai/models/responses/response_computer_tool_call.rb', line 344 required :keys, OpenAI::Internal::Type::ArrayOf[String] |
#type ⇒ Symbol, :keypress
Specifies the event type. For a keypress action, this property is always set to
keypress.
351 |
# File 'lib/openai/models/responses/response_computer_tool_call.rb', line 351 required :type, const: :keypress |
Instance Method Details
#to_hash ⇒ { keys: ::Array[String], type: :keypress }
244 |
# File 'sig/openai/models/responses/response_computer_tool_call.rbs', line 244
def to_hash: -> { keys: ::Array[String], type: :keypress }
|