Class: OpenAI::Models::Responses::ResponseCreateParams::PromptCacheOptions
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseCreateParams::PromptCacheOptions
- Defined in:
- lib/openai/models/responses/response_create_params.rb,
sig/openai/models/responses/response_create_params.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#comparison_response_id ⇒ String?
The ID of a response to compare when diagnosing prompt cache reuse.
-
#mode ⇒ OpenAI::Models::Responses::ResponseCreateParams::PromptCacheOptions::mode?
Controls whether OpenAI automatically creates an implicit cache breakpoint.
-
#prewarm ⇒ Boolean?
Prepares the prompt cache without generating output.
-
#ttl ⇒ OpenAI::Models::Responses::ResponseCreateParams::PromptCacheOptions::ttl?
The minimum lifetime applied to every implicit and explicit cache breakpoint written by the request.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(comparison_response_id: nil, mode: nil, prewarm: nil, ttl: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(comparison_response_id: nil, mode: nil, prewarm: nil, ttl: nil) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_create_params.rb', line 835
|
Instance Attribute Details
#comparison_response_id ⇒ String?
The ID of a response to compare when diagnosing prompt cache reuse. Supplying this field requests prompt cache diagnostics when the feature is enabled.
807 |
# File 'lib/openai/models/responses/response_create_params.rb', line 807 optional :comparison_response_id, String, nil?: true |
#mode ⇒ OpenAI::Models::Responses::ResponseCreateParams::PromptCacheOptions::mode?
Controls whether OpenAI automatically creates an implicit cache breakpoint.
Defaults to implicit. With implicit, OpenAI creates one implicit breakpoint
and writes up to the latest three explicit breakpoints in the request. With
explicit, OpenAI does not create an implicit breakpoint and writes up to the
latest four explicit breakpoints. If there are no explicit breakpoints, the
request does not use prompt caching.
818 |
# File 'lib/openai/models/responses/response_create_params.rb', line 818 optional :mode, enum: -> { OpenAI::Responses::ResponseCreateParams::PromptCacheOptions::Mode } |
#prewarm ⇒ Boolean?
Prepares the prompt cache without generating output. Defaults to false. When
set to true, overrides the generate field to false.
825 |
# File 'lib/openai/models/responses/response_create_params.rb', line 825 optional :prewarm, OpenAI::Internal::Type::Boolean |
#ttl ⇒ OpenAI::Models::Responses::ResponseCreateParams::PromptCacheOptions::ttl?
The minimum lifetime applied to every implicit and explicit cache breakpoint
written by the request. Defaults to 30m, which is currently the only supported
value. The backend may retain cache entries for longer.
833 |
# File 'lib/openai/models/responses/response_create_params.rb', line 833 optional :ttl, enum: -> { OpenAI::Responses::ResponseCreateParams::PromptCacheOptions::Ttl } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/response_create_params.rb', line 881
|
Instance Method Details
#to_hash ⇒ {
877 |
# File 'sig/openai/models/responses/response_create_params.rbs', line 877
def to_hash: -> {
|