Class: OpenAI::Models::Responses::ResponseCreateParams::StreamOptions
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseCreateParams::StreamOptions
- Defined in:
- lib/openai/models/responses/response_create_params.rb,
sig/openai/models/responses/response_create_params.rbs
Instance Attribute Summary collapse
-
#include_obfuscation ⇒ Boolean?
When true, stream obfuscation will be enabled.
Instance Method Summary collapse
-
#initialize ⇒ StreamOptions
constructor
A new instance of StreamOptions.
- #to_hash ⇒ { include_obfuscation: bool }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ StreamOptions
Returns a new instance of StreamOptions.
413 |
# File 'sig/openai/models/responses/response_create_params.rbs', line 413
def initialize: (?include_obfuscation: bool) -> void
|
Instance Attribute Details
#include_obfuscation ⇒ Boolean?
When true, stream obfuscation will be enabled. Stream obfuscation adds random
characters to an obfuscation field on streaming delta events to normalize
payload sizes as a mitigation to certain side-channel attacks. These obfuscation
fields are included by default, but add a small amount of overhead to the data
stream. You can set include_obfuscation to false to optimize for bandwidth if
you trust the network links between your application and the OpenAI API.
729 |
# File 'lib/openai/models/responses/response_create_params.rb', line 729 optional :include_obfuscation, OpenAI::Internal::Type::Boolean |
Instance Method Details
#to_hash ⇒ { include_obfuscation: bool }
415 |
# File 'sig/openai/models/responses/response_create_params.rbs', line 415
def to_hash: -> { include_obfuscation: bool }
|