Class: OpenAI::Models::Responses::ResponseCustomToolCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_custom_tool_call_output.rb,
sig/openai/models/responses/response_custom_tool_call_output.rbs

Direct Known Subclasses

ResponseCustomToolCallOutputItem

Defined Under Namespace

Modules: Caller, Output

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_id:, output:, id: nil, caller_: nil, type: :custom_tool_call_output) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseCustomToolCallOutput for more details.

The output of a custom tool call from your code, being sent back to the model.

Parameters:



# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 41

Instance Attribute Details

#call_idString

The call ID, used to map this custom tool call output to a custom tool call.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 11

required :call_id, String

#caller_OpenAI::Models::Responses::ResponseCustomToolCallOutput::Caller::Direct, ...

The execution context that produced this tool call.

Parameters:

  • value (OpenAI::Models::Responses::ResponseCustomToolCallOutput::caller_, nil)

Returns:



36
37
38
39
# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 36

optional :caller_,
union: -> { OpenAI::Responses::ResponseCustomToolCallOutput::Caller },
api_name: :caller,
nil?: true

#idString?

The unique ID of the custom tool call output in the OpenAI platform.

Parameters:

  • (String)

Returns:

  • (String, nil)


30
# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 30

optional :id, String

#outputString, Array<OpenAI::Models::Responses::ResponseInputText, OpenAI::Models::Responses::ResponseInputImage, OpenAI::Models::Responses::ResponseInputFile>

The output from the custom tool call generated by your code. Can be a string or an list of output content.

Parameters:

  • value (OpenAI::Models::Responses::ResponseCustomToolCallOutput::output)

Returns:



18
# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 18

required :output, union: -> { OpenAI::Responses::ResponseCustomToolCallOutput::Output }

#typeSymbol, :custom_tool_call_output

The type of the custom tool call output. Always custom_tool_call_output.

Parameters:

  • value (:custom_tool_call_output)

Returns:

  • (Symbol, :custom_tool_call_output)


24
# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 24

required :type, const: :custom_tool_call_output

Instance Method Details

#to_hash{

Returns:

  • ({)


34
# File 'sig/openai/models/responses/response_custom_tool_call_output.rbs', line 34

def to_hash: -> {