Class: OpenAI::Models::Responses::ResponseCustomToolCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_custom_tool_call_output.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_id: , output: , id: nil, type: :custom_tool_call_output) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseCustomToolCallOutput for more details.

The output of a custom tool call from your code, being sent back to the model.

Parameters:

  • call_id (String) (defaults to: )

    The call ID, used to map this custom tool call output to a custom tool call.

  • output (String) (defaults to: )

    The output from the custom tool call generated by your code.

  • id (String) (defaults to: nil)

    The unique ID of the custom tool call output in the OpenAI platform.

  • type (Symbol, :custom_tool_call_output) (defaults to: :custom_tool_call_output)

    The type of the custom tool call output. Always ‘custom_tool_call_output`.



# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 31

Instance Attribute Details

#call_idString

The call ID, used to map this custom tool call output to a custom tool call.

Returns:

  • (String)


11
# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 11

required :call_id, String

#idString?

The unique ID of the custom tool call output in the OpenAI platform.

Returns:

  • (String, nil)


29
# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 29

optional :id, String

#outputString

The output from the custom tool call generated by your code.

Returns:

  • (String)


17
# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 17

required :output, String

#typeSymbol, :custom_tool_call_output

The type of the custom tool call output. Always ‘custom_tool_call_output`.

Returns:

  • (Symbol, :custom_tool_call_output)


23
# File 'lib/openai/models/responses/response_custom_tool_call_output.rb', line 23

required :type, const: :custom_tool_call_output