Class: OpenAI::Models::Responses::ResponseFunctionShellToolCall::Action
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseFunctionShellToolCall::Action
- Defined in:
- lib/openai/models/responses/response_function_shell_tool_call.rb,
sig/openai/models/responses/response_function_shell_tool_call.rbs
Overview
Instance Attribute Summary collapse
- #commands ⇒ Array<String>
-
#max_output_length ⇒ Integer?
Optional maximum number of characters to return from each command.
-
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the commands.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
71 |
# File 'sig/openai/models/responses/response_function_shell_tool_call.rbs', line 71
def initialize: (
|
Instance Attribute Details
#commands ⇒ Array<String>
89 |
# File 'lib/openai/models/responses/response_function_shell_tool_call.rb', line 89 required :commands, OpenAI::Internal::Type::ArrayOf[String] |
#max_output_length ⇒ Integer?
Optional maximum number of characters to return from each command.
95 |
# File 'lib/openai/models/responses/response_function_shell_tool_call.rb', line 95 required :max_output_length, Integer, nil?: true |
#timeout_ms ⇒ Integer?
Optional timeout in milliseconds for the commands.
101 |
# File 'lib/openai/models/responses/response_function_shell_tool_call.rb', line 101 required :timeout_ms, Integer, nil?: true |
Instance Method Details
#to_hash ⇒ {
77 |
# File 'sig/openai/models/responses/response_function_shell_tool_call.rbs', line 77
def to_hash: -> {
|