Class: OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_function_shell_tool_call_output.rb

Defined Under Namespace

Modules: Status Classes: Output

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(exit_code:, type: :exit) ⇒ Object

Indicates that the shell commands finished and returned an exit code.

Parameters:

  • exit_code (Integer)

    Exit code from the shell process.

  • type (Symbol, :exit) (defaults to: :exit)

    The outcome type. Always exit.



# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 156


Instance Attribute Details

#call_idString

The unique ID of the shell tool call generated by the model.

Returns:

  • (String)


18
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 18

required :call_id, String

#created_byString?

The identifier of the actor that created the item.

Returns:

  • (String, nil)


51
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 51

optional :created_by, String

#idString

The unique ID of the shell call output. Populated when this item is returned via API.

Returns:

  • (String)


12
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 12

required :id, String

#max_output_lengthInteger?

The maximum length of the shell command output. This is generated by the model and should be passed back with the raw output.

Returns:

  • (Integer, nil)


25
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 25

required :max_output_length, Integer, nil?: true

#outputArray<OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Output>

An array of shell call output contents



31
32
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 31

required :output,
-> { OpenAI::Internal::Type::ArrayOf[OpenAI::Responses::ResponseFunctionShellToolCallOutput::Output] }

#statusSymbol, OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Status

The status of the shell call output. One of in_progress, completed, or incomplete.



39
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 39

required :status, enum: -> { OpenAI::Responses::ResponseFunctionShellToolCallOutput::Status }

#typeSymbol, :shell_call_output

The type of the shell call output. Always shell_call_output.

Returns:

  • (Symbol, :shell_call_output)


45
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 45

required :type, const: :shell_call_output

Class Method Details

.variantsArray(OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Output::Outcome::Timeout, OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Output::Outcome::Exit)



# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 164