Class: OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput
- Defined in:
- lib/openai/models/responses/response_function_shell_tool_call_output.rb
Defined Under Namespace
Modules: Status Classes: Output
Instance Attribute Summary collapse
-
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
-
#created_by ⇒ String?
The identifier of the actor that created the item.
-
#id ⇒ String
The unique ID of the shell call output.
-
#max_output_length ⇒ Integer?
The maximum length of the shell command output.
-
#output ⇒ Array<OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Output>
An array of shell call output contents.
-
#status ⇒ Symbol, OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Status
The status of the shell call output.
-
#type ⇒ Symbol, :shell_call_output
The type of the shell call output.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(exit_code:, type: :exit) ⇒ Object
constructor
Indicates that the shell commands finished and returned an exit code.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(exit_code:, type: :exit) ⇒ Object
Indicates that the shell commands finished and returned an exit code.
|
|
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 156
|
Instance Attribute Details
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
18 |
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 18 required :call_id, String |
#created_by ⇒ String?
The identifier of the actor that created the item.
51 |
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 51 optional :created_by, String |
#id ⇒ String
The unique ID of the shell call output. Populated when this item is returned via API.
12 |
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 12 required :id, String |
#max_output_length ⇒ Integer?
The maximum length of the shell command output. This is generated by the model and should be passed back with the raw output.
25 |
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 25 required :max_output_length, Integer, nil?: true |
#output ⇒ Array<OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Output>
An array of shell call output contents
31 32 |
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 31 required :output, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Responses::ResponseFunctionShellToolCallOutput::Output] } |
#status ⇒ Symbol, OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Status
The status of the shell call output. One of in_progress, completed, or incomplete.
39 |
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 39 required :status, enum: -> { OpenAI::Responses::ResponseFunctionShellToolCallOutput::Status } |
#type ⇒ Symbol, :shell_call_output
The type of the shell call output. Always shell_call_output.
45 |
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 45 required :type, const: :shell_call_output |
Class Method Details
.variants ⇒ Array(OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Output::Outcome::Timeout, OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Output::Outcome::Exit)
|
|
# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 164
|