Module: OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Output::Outcome

Extended by:
Internal::Type::Union
Defined in:
lib/openai/models/responses/response_function_shell_tool_call_output.rb,
sig/openai/models/responses/response_function_shell_tool_call_output.rbs

Overview

Represents either an exit outcome (with an exit code) or a timeout outcome for a shell call output chunk.

See Also:

  • OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Output#outcome

Defined Under Namespace

Classes: Exit, Timeout

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(type: :timeout) ⇒ Object

Indicates that the shell call exceeded its configured time limit.

Parameters:

  • type (Symbol, :timeout) (defaults to: :timeout)

    The outcome type. Always timeout.



# File 'lib/openai/models/responses/response_function_shell_tool_call_output.rb', line 148

#self?.variants::Array[OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Output::outcome]

Returns:

  • (::Array[OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Output::outcome])


119
# File 'sig/openai/models/responses/response_function_shell_tool_call_output.rbs', line 119

def self?.variants: -> ::Array[OpenAI::Models::Responses::ResponseFunctionShellToolCallOutput::Output::outcome]