Class: OpenAI::Models::Responses::ResponseFunctionToolCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseFunctionToolCall
- Defined in:
- lib/openai/models/responses/response_function_tool_call.rb,
sig/openai/models/responses/response_function_tool_call.rbs
Direct Known Subclasses
Defined Under Namespace
Instance Attribute Summary collapse
-
#arguments ⇒ String
A JSON string of the arguments to pass to the function.
-
#call_id ⇒ String
The unique ID of the function tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Responses::ResponseFunctionToolCall::Caller::Direct, ...
The execution context that produced this tool call.
-
#id ⇒ String?
The unique ID of the function tool call.
-
#name ⇒ String
The name of the function to run.
-
#namespace ⇒ String?
The namespace of the function to run.
-
#status ⇒ Symbol, ...
The status of the item.
-
#type ⇒ Symbol, :function_call
The type of the function tool call.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caller_id:, type: :program) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_function_tool_call.rb', line 67
|
Instance Attribute Details
#arguments ⇒ String
A JSON string of the arguments to pass to the function.
11 |
# File 'lib/openai/models/responses/response_function_tool_call.rb', line 11 required :arguments, String |
#call_id ⇒ String
The unique ID of the function tool call generated by the model.
25 |
# File 'lib/openai/models/responses/response_function_tool_call.rb', line 25 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Responses::ResponseFunctionToolCall::Caller::Direct, ...
The execution context that produced this tool call.
49 50 51 52 |
# File 'lib/openai/models/responses/response_function_tool_call.rb', line 49 optional :caller_, union: -> { OpenAI::Responses::ResponseFunctionToolCall::Caller }, api_name: :caller, nil?: true |
#id ⇒ String?
The unique ID of the function tool call.
43 |
# File 'lib/openai/models/responses/response_function_tool_call.rb', line 43 optional :id, String |
#name ⇒ String
The name of the function to run.
31 |
# File 'lib/openai/models/responses/response_function_tool_call.rb', line 31 required :name, String |
#namespace ⇒ String?
The namespace of the function to run.
58 |
# File 'lib/openai/models/responses/response_function_tool_call.rb', line 58 optional :namespace, String |
#status ⇒ Symbol, ...
The status of the item. One of in_progress, completed, or incomplete.
Populated when items are returned via API.
65 |
# File 'lib/openai/models/responses/response_function_tool_call.rb', line 65 optional :status, enum: -> { OpenAI::Responses::ResponseFunctionToolCall::Status } |
#type ⇒ Symbol, :function_call
The type of the function tool call. Always function_call.
37 |
# File 'lib/openai/models/responses/response_function_tool_call.rb', line 37 required :type, const: :function_call |
Class Method Details
.variants ⇒ Array(OpenAI::Models::Responses::ResponseFunctionToolCall::Caller::Direct, OpenAI::Models::Responses::ResponseFunctionToolCall::Caller::Program)
|
|
# File 'lib/openai/models/responses/response_function_tool_call.rb', line 131
|
Instance Method Details
#to_hash ⇒ {
52 |
# File 'sig/openai/models/responses/response_function_tool_call.rbs', line 52
def to_hash: -> {
|