Class: OpenAI::Models::Responses::ResponseFunctionToolCallItem
- Inherits:
-
ResponseFunctionToolCall
- Object
- Internal::Type::BaseModel
- ResponseFunctionToolCall
- OpenAI::Models::Responses::ResponseFunctionToolCallItem
- Defined in:
- lib/openai/models/responses/response_function_tool_call_item.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#created_by ⇒ String?
The identifier of the actor that created the item.
-
#id ⇒ String
The unique ID of the function tool call.
-
#status ⇒ Symbol, OpenAI::Models::Responses::ResponseFunctionToolCallItem::Status
The status of the item.
Attributes inherited from ResponseFunctionToolCall
#arguments, #call_id, #name, #namespace, #type
Instance Method Summary collapse
-
#initialize(id:, status:, created_by: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ResponseFunctionToolCallItem for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, status:, created_by: nil) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseFunctionToolCallItem for more details.
A tool call to run a function. See the [function calling guide](platform.openai.com/docs/guides/function-calling) for more information.
|
|
# File 'lib/openai/models/responses/response_function_tool_call_item.rb', line 26
|
Instance Attribute Details
#created_by ⇒ String?
The identifier of the actor that created the item.
24 |
# File 'lib/openai/models/responses/response_function_tool_call_item.rb', line 24 optional :created_by, String |
#id ⇒ String
The unique ID of the function tool call.
11 |
# File 'lib/openai/models/responses/response_function_tool_call_item.rb', line 11 required :id, String |
#status ⇒ Symbol, OpenAI::Models::Responses::ResponseFunctionToolCallItem::Status
The status of the item. One of in_progress, completed, or incomplete. Populated when items are returned via API.
18 |
# File 'lib/openai/models/responses/response_function_tool_call_item.rb', line 18 required :status, enum: -> { OpenAI::Responses::ResponseFunctionToolCallItem::Status } |