Class: OpenAI::Models::Responses::ResponseInputFile

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_file.rb,
sig/openai/models/responses/response_input_file.rbs

Defined Under Namespace

Modules: Detail

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(detail: nil, file_data: nil, file_id: nil, file_url: nil, filename: nil, type: :input_file) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseInputFile for more details.

A file input to the model.

Parameters:

  • detail (Symbol, OpenAI::Models::Responses::ResponseInputFile::Detail) (defaults to: nil)

    The detail level of the file to be sent to the model. Use low for the default

  • file_data (String) (defaults to: nil)

    The content of the file to be sent to the model.

  • file_id (String, nil) (defaults to: nil)

    The ID of the file to be sent to the model.

  • file_url (String) (defaults to: nil)

    The URL of the file to be sent to the model.

  • filename (String) (defaults to: nil)

    The name of the file to be sent to the model.

  • type (Symbol, :input_file) (defaults to: :input_file)

    The type of the input item. Always input_file.



# File 'lib/openai/models/responses/response_input_file.rb', line 45

Instance Attribute Details

#detailSymbol, ...

The detail level of the file to be sent to the model. Use low for the default rendering behavior, or high to render the file at higher quality. Defaults to low.



19
# File 'lib/openai/models/responses/response_input_file.rb', line 19

optional :detail, enum: -> { OpenAI::Responses::ResponseInputFile::Detail }

#file_dataString?

The content of the file to be sent to the model.

Parameters:

  • (String)

Returns:

  • (String, nil)


25
# File 'lib/openai/models/responses/response_input_file.rb', line 25

optional :file_data, String

#file_idString?

The ID of the file to be sent to the model.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


31
# File 'lib/openai/models/responses/response_input_file.rb', line 31

optional :file_id, String, nil?: true

#file_urlString?

The URL of the file to be sent to the model.

Parameters:

  • (String)

Returns:

  • (String, nil)


37
# File 'lib/openai/models/responses/response_input_file.rb', line 37

optional :file_url, String

#filenameString?

The name of the file to be sent to the model.

Parameters:

  • (String)

Returns:

  • (String, nil)


43
# File 'lib/openai/models/responses/response_input_file.rb', line 43

optional :filename, String

#typeSymbol, :input_file

The type of the input item. Always input_file.

Parameters:

  • value (:input_file)

Returns:

  • (Symbol, :input_file)


11
# File 'lib/openai/models/responses/response_input_file.rb', line 11

required :type, const: :input_file

Instance Method Details

#to_hash{

Returns:

  • ({)


46
# File 'sig/openai/models/responses/response_input_file.rbs', line 46

def to_hash: -> {