Class: OpenAI::Models::Responses::ResponseInputFileContent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputFileContent
- Defined in:
- lib/openai/models/responses/response_input_file_content.rb,
sig/openai/models/responses/response_input_file_content.rbs
Defined Under Namespace
Modules: Detail
Instance Attribute Summary collapse
-
#detail ⇒ Symbol, ...
The detail level of the file to be sent to the model.
-
#file_data ⇒ String?
The base64-encoded data of the file to be sent to the model.
-
#file_id ⇒ String?
The ID of the file to be sent to the model.
-
#file_url ⇒ String?
The URL of the file to be sent to the model.
-
#filename ⇒ String?
The name of the file to be sent to the model.
-
#type ⇒ Symbol, :input_file
The type of the input item.
Instance Method Summary collapse
-
#initialize(detail: nil, file_data: nil, file_id: nil, file_url: nil, filename: nil, type: :input_file) ⇒ Object
constructor
Some parameter documentations has been truncated, see ResponseInputFileContent for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(detail: nil, file_data: nil, file_id: nil, file_url: nil, filename: nil, type: :input_file) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseInputFileContent for more details.
A file input to the model.
|
|
# File 'lib/openai/models/responses/response_input_file_content.rb', line 45
|
Instance Attribute Details
#detail ⇒ Symbol, ...
The detail level of the file to be sent to the model. Use low for the default
rendering behavior, or high to render the file at higher quality. Defaults to
low.
19 |
# File 'lib/openai/models/responses/response_input_file_content.rb', line 19 optional :detail, enum: -> { OpenAI::Responses::ResponseInputFileContent::Detail } |
#file_data ⇒ String?
The base64-encoded data of the file to be sent to the model.
25 |
# File 'lib/openai/models/responses/response_input_file_content.rb', line 25 optional :file_data, String, nil?: true |
#file_id ⇒ String?
The ID of the file to be sent to the model.
31 |
# File 'lib/openai/models/responses/response_input_file_content.rb', line 31 optional :file_id, String, nil?: true |
#file_url ⇒ String?
The URL of the file to be sent to the model.
37 |
# File 'lib/openai/models/responses/response_input_file_content.rb', line 37 optional :file_url, String, nil?: true |
#filename ⇒ String?
The name of the file to be sent to the model.
43 |
# File 'lib/openai/models/responses/response_input_file_content.rb', line 43 optional :filename, String, nil?: true |
#type ⇒ Symbol, :input_file
The type of the input item. Always input_file.
11 |
# File 'lib/openai/models/responses/response_input_file_content.rb', line 11 required :type, const: :input_file |
Instance Method Details
#to_hash ⇒ {
40 |
# File 'sig/openai/models/responses/response_input_file_content.rbs', line 40
def to_hash: -> {
|