Class: OpenAI::Models::Responses::ResponseInputItem::AdditionalTools
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputItem::AdditionalTools
- Defined in:
- lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs
Instance Attribute Summary collapse
-
#id ⇒ String?
The unique ID of this additional tools item.
-
#role ⇒ :developer
The role that provided the additional tools.
-
#tools ⇒ ::Array[OpenAI::Models::Responses::tool]
A list of additional tools made available at this item.
-
#type ⇒ :additional_tools
The item type.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
499 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 499
def initialize: (
|
Instance Attribute Details
#id ⇒ String?
The unique ID of this additional tools item.
617 |
# File 'lib/openai/models/responses/response_input_item.rb', line 617 optional :id, String, nil?: true |
#role ⇒ :developer
The role that provided the additional tools. Only developer is supported.
599 |
# File 'lib/openai/models/responses/response_input_item.rb', line 599 required :role, const: :developer |
#tools ⇒ ::Array[OpenAI::Models::Responses::tool]
A list of additional tools made available at this item.
605 |
# File 'lib/openai/models/responses/response_input_item.rb', line 605 required :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Responses::Tool] } |
#type ⇒ :additional_tools
The item type. Always additional_tools.
611 |
# File 'lib/openai/models/responses/response_input_item.rb', line 611 required :type, const: :additional_tools |
Instance Method Details
#to_hash ⇒ {
506 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 506
def to_hash: -> {
|