Class: OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs

Defined Under Namespace

Modules: Caller, Operation, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(diff:, path:, type: :update_file) ⇒ Object

Instruction for updating an existing file via the apply_patch tool.

Parameters:

  • diff (String)

    Unified diff content to apply to the existing file.

  • path (String)

    Path of the file to update relative to the workspace root.

  • type (Symbol, :update_file) (defaults to: :update_file)

    The operation type. Always update_file.



# File 'lib/openai/models/responses/response_input_item.rb', line 1162

Instance Attribute Details

#call_idString

The unique ID of the apply patch tool call generated by the model.

Parameters:

  • value (String)

Returns:

  • (String)


1125
# File 'lib/openai/models/responses/response_input_item.rb', line 1125

required :call_id, String

#caller_OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Caller::Direct, ...

The execution context that produced this tool call.

Parameters:

  • value (OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::caller_, nil)

Returns:



1157
1158
1159
1160
# File 'lib/openai/models/responses/response_input_item.rb', line 1157

optional :caller_,
union: -> { OpenAI::Responses::ResponseInputItem::ApplyPatchCall::Caller },
api_name: :caller,
nil?: true

#idString?

The unique ID of the apply patch tool call. Populated when this item is returned via API.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1151
# File 'lib/openai/models/responses/response_input_item.rb', line 1151

optional :id, String, nil?: true

#operationOpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Operation::CreateFile, ...

The specific create, delete, or update instruction for the apply_patch tool call.



1132
# File 'lib/openai/models/responses/response_input_item.rb', line 1132

required :operation, union: -> { OpenAI::Responses::ResponseInputItem::ApplyPatchCall::Operation }

#statusSymbol, OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Status

The status of the apply patch tool call. One of in_progress or completed.

Parameters:

  • value (OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::status)

Returns:



1138
# File 'lib/openai/models/responses/response_input_item.rb', line 1138

required :status, enum: -> { OpenAI::Responses::ResponseInputItem::ApplyPatchCall::Status }

#typeSymbol, :apply_patch_call

The type of the item. Always apply_patch_call.

Parameters:

  • value (:apply_patch_call)

Returns:

  • (Symbol, :apply_patch_call)


1144
# File 'lib/openai/models/responses/response_input_item.rb', line 1144

required :type, const: :apply_patch_call

Instance Method Details

#to_hash{

Returns:

  • ({)


816
# File 'sig/openai/models/responses/response_input_item.rbs', line 816

def to_hash: -> {