Class: OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall
- Defined in:
- lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs
Defined Under Namespace
Modules: Caller, Operation, Status
Instance Attribute Summary collapse
-
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Caller::Direct, ...
The execution context that produced this tool call.
-
#id ⇒ String?
The unique ID of the apply patch tool call.
-
#operation ⇒ OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Operation::CreateFile, ...
The specific create, delete, or update instruction for the apply_patch tool call.
-
#status ⇒ Symbol, OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Status
The status of the apply patch tool call.
-
#type ⇒ Symbol, :apply_patch_call
The type of the item.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Operation::CreateFile, OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Operation::DeleteFile, OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Operation::UpdateFile)
Instance Method Summary collapse
-
#initialize(diff:, path:, type: :update_file) ⇒ Object
constructor
Instruction for updating an existing file via the apply_patch tool.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(diff:, path:, type: :update_file) ⇒ Object
Instruction for updating an existing file via the apply_patch tool.
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 1162
|
Instance Attribute Details
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
1125 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1125 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Caller::Direct, ...
The execution context that produced this tool call.
1157 1158 1159 1160 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1157 optional :caller_, union: -> { OpenAI::Responses::ResponseInputItem::ApplyPatchCall::Caller }, api_name: :caller, nil?: true |
#id ⇒ String?
The unique ID of the apply patch tool call. Populated when this item is returned via API.
1151 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1151 optional :id, String, nil?: true |
#operation ⇒ OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Operation::CreateFile, ...
The specific create, delete, or update instruction for the apply_patch tool call.
1132 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1132 required :operation, union: -> { OpenAI::Responses::ResponseInputItem::ApplyPatchCall::Operation } |
#status ⇒ Symbol, OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Status
The status of the apply patch tool call. One of in_progress or completed.
1138 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1138 required :status, enum: -> { OpenAI::Responses::ResponseInputItem::ApplyPatchCall::Status } |
#type ⇒ Symbol, :apply_patch_call
The type of the item. Always apply_patch_call.
1144 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1144 required :type, const: :apply_patch_call |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 1291
|
.variants ⇒ Array(OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Operation::CreateFile, OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Operation::DeleteFile, OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCall::Operation::UpdateFile)
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 1278
|
Instance Method Details
#to_hash ⇒ {
816 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 816
def to_hash: -> {
|