Class: OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs

Defined Under Namespace

Modules: Caller, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_id:, status:, id: nil, caller_: nil, output: nil, type: :apply_patch_call_output) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput for more details.

The streamed output emitted by an apply patch tool call.

Parameters:



# File 'lib/openai/models/responses/response_input_item.rb', line 1384

Instance Attribute Details

#call_idString

The unique ID of the apply patch tool call generated by the model.

Parameters:

  • value (String)

Returns:

  • (String)


1347
# File 'lib/openai/models/responses/response_input_item.rb', line 1347

required :call_id, String

#caller_OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput::Caller::Direct, ...

The execution context that produced this tool call.

Parameters:

  • value (OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput::caller_, nil)

Returns:



1372
1373
1374
1375
# File 'lib/openai/models/responses/response_input_item.rb', line 1372

optional :caller_,
union: -> { OpenAI::Responses::ResponseInputItem::ApplyPatchCallOutput::Caller },
api_name: :caller,
nil?: true

#idString?

The unique ID of the apply patch tool call output. Populated when this item is returned via API.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1366
# File 'lib/openai/models/responses/response_input_item.rb', line 1366

optional :id, String, nil?: true

#outputString?

Optional human-readable log text from the apply patch tool (e.g., patch results or errors).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1382
# File 'lib/openai/models/responses/response_input_item.rb', line 1382

optional :output, String, nil?: true

#statusSymbol, OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput::Status

The status of the apply patch tool call output. One of completed or failed.

Parameters:

  • value (OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput::status)

Returns:



1353
# File 'lib/openai/models/responses/response_input_item.rb', line 1353

required :status, enum: -> { OpenAI::Responses::ResponseInputItem::ApplyPatchCallOutput::Status }

#typeSymbol, :apply_patch_call_output

The type of the item. Always apply_patch_call_output.

Parameters:

  • value (:apply_patch_call_output)

Returns:

  • (Symbol, :apply_patch_call_output)


1359
# File 'lib/openai/models/responses/response_input_item.rb', line 1359

required :type, const: :apply_patch_call_output

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/responses/response_input_item.rb', line 1412

Instance Method Details

#to_hash{

Returns:

  • ({)


962
# File 'sig/openai/models/responses/response_input_item.rbs', line 962

def to_hash: -> {