Class: OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput
- Defined in:
- lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput::caller_?
The execution context that produced this tool call.
-
#id ⇒ String?
The unique ID of the apply patch tool call output.
-
#output ⇒ String?
Optional human-readable log text from the apply patch tool (e.g., patch results or errors).
-
#status ⇒ OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput::status
The status of the apply patch tool call output.
-
#type ⇒ :apply_patch_call_output
The type of the item.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(call_id:, status:, id: nil, caller_: nil, output: nil, type: :apply_patch_call_output) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_id:, status:, id: nil, caller_: nil, output: nil, type: :apply_patch_call_output) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 1679
|
Instance Attribute Details
#call_id ⇒ String
The unique ID of the apply patch tool call generated by the model.
1640 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1640 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput::caller_?
The execution context that produced this tool call.
1665 1666 1667 1668 1669 1670 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1665 optional( :caller_, union: -> { OpenAI::Responses::ResponseInputItem::ApplyPatchCallOutput::Caller }, api_name: :caller, nil?: true ) |
#id ⇒ String?
The unique ID of the apply patch tool call output. Populated when this item is returned via API.
1659 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1659 optional :id, String, nil?: true |
#output ⇒ String?
Optional human-readable log text from the apply patch tool (e.g., patch results or errors).
1677 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1677 optional :output, String, nil?: true |
#status ⇒ OpenAI::Models::Responses::ResponseInputItem::ApplyPatchCallOutput::status
The status of the apply patch tool call output. One of completed or failed.
1646 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1646 required :status, enum: -> { OpenAI::Responses::ResponseInputItem::ApplyPatchCallOutput::Status } |
#type ⇒ :apply_patch_call_output
The type of the item. Always apply_patch_call_output.
1652 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1652 required :type, const: :apply_patch_call_output |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 1711
|
Instance Method Details
#to_hash ⇒ {
1427 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 1427
def to_hash: -> {
|