Class: OpenAI::Models::Responses::ResponseInputItem::ComputerCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs

Defined Under Namespace

Modules: Status Classes: AcknowledgedSafetyCheck

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, code: nil, message: nil) ⇒ Object

A pending safety check for the computer call.

Parameters:

  • id (String)

    The ID of the pending safety check.

  • code (String, nil) (defaults to: nil)

    The type of the pending safety check.

  • message (String, nil) (defaults to: nil)

    Details about the pending safety check.



# File 'lib/openai/models/responses/response_input_item.rb', line 288

Instance Attribute Details

#acknowledged_safety_checksArray<OpenAI::Models::Responses::ResponseInputItem::ComputerCallOutput::AcknowledgedSafetyCheck>?

The safety checks reported by the API that have been acknowledged by the developer.

Parameters:

  • value (::Array[OpenAI::Responses::ResponseInputItem::ComputerCallOutput::AcknowledgedSafetyCheck], nil)

Returns:



235
236
237
238
239
# File 'lib/openai/models/responses/response_input_item.rb', line 235

optional :acknowledged_safety_checks,
-> {
  OpenAI::Internal::Type::ArrayOf[OpenAI::Responses::ResponseInputItem::ComputerCallOutput::AcknowledgedSafetyCheck]
},
nil?: true

#call_idString

The ID of the computer tool call that produced the output.

Parameters:

  • value (String)

Returns:

  • (String)


210
# File 'lib/openai/models/responses/response_input_item.rb', line 210

required :call_id, String

#idString?

The ID of the computer tool call output.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


228
# File 'lib/openai/models/responses/response_input_item.rb', line 228

optional :id, String, nil?: true

#outputOpenAI::Models::Responses::ResponseComputerToolCallOutputScreenshot

A computer screenshot image used with the computer use tool.

Parameters:

  • value (OpenAI::Responses::ResponseComputerToolCallOutputScreenshot)

Returns:



216
# File 'lib/openai/models/responses/response_input_item.rb', line 216

required :output, -> { OpenAI::Responses::ResponseComputerToolCallOutputScreenshot }

#statusSymbol, ...

The status of the message input. One of in_progress, completed, or incomplete. Populated when input items are returned via API.

Parameters:

  • value (OpenAI::Models::Responses::ResponseInputItem::ComputerCallOutput::status, nil)

Returns:



246
247
248
# File 'lib/openai/models/responses/response_input_item.rb', line 246

optional :status,
enum: -> { OpenAI::Responses::ResponseInputItem::ComputerCallOutput::Status },
nil?: true

#typeSymbol, :computer_call_output

The type of the computer tool call output. Always computer_call_output.

Parameters:

  • value (:computer_call_output)

Returns:

  • (Symbol, :computer_call_output)


222
# File 'lib/openai/models/responses/response_input_item.rb', line 222

required :type, const: :computer_call_output

Instance Method Details

#to_hash{

Returns:

  • ({)


147
# File 'sig/openai/models/responses/response_input_item.rbs', line 147

def to_hash: -> {