Class: OpenAI::Models::Responses::ResponseInputItem::FunctionCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs

Defined Under Namespace

Modules: Caller, Output, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(caller_id:, type: :program) ⇒ Object

Parameters:

  • caller_id (String)

    The call ID of the program item that produced this tool call.

  • type (Symbol, :program) (defaults to: :program)

    The caller type. Always program.



# File 'lib/openai/models/responses/response_input_item.rb', line 358

Instance Attribute Details

#call_idString

The unique ID of the function tool call generated by the model.

Parameters:

  • value (String)

Returns:

  • (String)


319
# File 'lib/openai/models/responses/response_input_item.rb', line 319

required :call_id, String

#caller_OpenAI::Models::Responses::ResponseInputItem::FunctionCallOutput::Caller::Direct, ...

The execution context that produced this tool call.

Parameters:

  • value (OpenAI::Models::Responses::ResponseInputItem::FunctionCallOutput::caller_, nil)

Returns:



344
345
346
347
# File 'lib/openai/models/responses/response_input_item.rb', line 344

optional :caller_,
union: -> { OpenAI::Responses::ResponseInputItem::FunctionCallOutput::Caller },
api_name: :caller,
nil?: true

#idString?

The unique ID of the function tool call output. Populated when this item is returned via API.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


338
# File 'lib/openai/models/responses/response_input_item.rb', line 338

optional :id, String, nil?: true

#outputString, Array<OpenAI::Models::Responses::ResponseInputTextContent, OpenAI::Models::Responses::ResponseInputImageContent, OpenAI::Models::Responses::ResponseInputFileContent>

Text, image, or file output of the function tool call.

Parameters:

  • value (OpenAI::Models::Responses::ResponseInputItem::FunctionCallOutput::output)

Returns:



325
# File 'lib/openai/models/responses/response_input_item.rb', line 325

required :output, union: -> { OpenAI::Responses::ResponseInputItem::FunctionCallOutput::Output }

#statusSymbol, ...

The status of the item. One of in_progress, completed, or incomplete. Populated when items are returned via API.

Parameters:

  • value (OpenAI::Models::Responses::ResponseInputItem::FunctionCallOutput::status, nil)

Returns:



354
355
356
# File 'lib/openai/models/responses/response_input_item.rb', line 354

optional :status,
enum: -> { OpenAI::Responses::ResponseInputItem::FunctionCallOutput::Status },
nil?: true

#typeSymbol, :function_call_output

The type of the function tool call output. Always function_call_output.

Parameters:

  • value (:function_call_output)

Returns:

  • (Symbol, :function_call_output)


331
# File 'lib/openai/models/responses/response_input_item.rb', line 331

required :type, const: :function_call_output

Instance Method Details

#to_hash{

Returns:

  • ({)


220
# File 'sig/openai/models/responses/response_input_item.rbs', line 220

def to_hash: -> {