Class: OpenAI::Models::Responses::ResponseInputItem::LocalShellCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputItem::LocalShellCallOutput
- Defined in:
- lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#id ⇒ String
The unique ID of the local shell tool call generated by the model.
-
#output ⇒ String
A JSON string of the output of the local shell tool call.
-
#status ⇒ Symbol, ...
The status of the item.
-
#type ⇒ Symbol, :local_shell_call_output
The type of the local shell tool call output.
Instance Method Summary collapse
-
#initialize(id:, output:, status: nil, type: :local_shell_call_output) ⇒ Object
constructor
Some parameter documentations has been truncated, see LocalShellCallOutput for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, output:, status: nil, type: :local_shell_call_output) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseInputItem::LocalShellCallOutput for more details.
The output of a local shell tool call.
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 771
|
Instance Attribute Details
#id ⇒ String
The unique ID of the local shell tool call generated by the model.
749 |
# File 'lib/openai/models/responses/response_input_item.rb', line 749 required :id, String |
#output ⇒ String
A JSON string of the output of the local shell tool call.
755 |
# File 'lib/openai/models/responses/response_input_item.rb', line 755 required :output, String |
#status ⇒ Symbol, ...
The status of the item. One of in_progress, completed, or incomplete.
767 768 769 |
# File 'lib/openai/models/responses/response_input_item.rb', line 767 optional :status, enum: -> { OpenAI::Responses::ResponseInputItem::LocalShellCallOutput::Status }, nil?: true |
#type ⇒ Symbol, :local_shell_call_output
The type of the local shell tool call output. Always local_shell_call_output.
761 |
# File 'lib/openai/models/responses/response_input_item.rb', line 761 required :type, const: :local_shell_call_output |
Instance Method Details
#to_hash ⇒ {
545 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 545
def to_hash: -> {
|