Class: OpenAI::Models::Responses::ResponseInputItem::McpCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputItem::McpCall
- Defined in:
- lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#approval_request_id ⇒ String?
Unique identifier for the MCP tool call approval request.
-
#arguments ⇒ String
A JSON string of the arguments passed to the tool.
-
#error ⇒ OpenAI::Models::Responses::McpToolCallError::McpProtocolError, ...
The error from the tool call, if any.
-
#id ⇒ String
The unique ID of the tool call.
-
#name ⇒ String
The name of the tool that was run.
-
#output ⇒ String?
The output from the tool call.
-
#server_label ⇒ String
The label of the MCP server running the tool.
-
#status ⇒ Symbol, ...
The status of the tool call.
-
#type ⇒ Symbol, :mcp_call
The type of the item.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(id:, arguments:, name:, server_label:, approval_request_id: nil, error: nil, output: nil, status: nil, type: :mcp_call) ⇒ Object
constructor
Some parameter documentations has been truncated, see McpCall for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, arguments:, name:, server_label:, approval_request_id: nil, error: nil, output: nil, status: nil, type: :mcp_call) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseInputItem::McpCall for more details.
An invocation of a tool on an MCP server.
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 1755
|
Instance Attribute Details
#approval_request_id ⇒ String?
Unique identifier for the MCP tool call approval request. Include this value in
a subsequent mcp_approval_response input to approve or reject the
corresponding tool call.
1734 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1734 optional :approval_request_id, String, nil?: true |
#arguments ⇒ String
A JSON string of the arguments passed to the tool.
1708 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1708 required :arguments, String |
#error ⇒ OpenAI::Models::Responses::McpToolCallError::McpProtocolError, ...
The error from the tool call, if any.
1740 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1740 optional :error, union: -> { OpenAI::Responses::McpToolCallError }, nil?: true |
#id ⇒ String
The unique ID of the tool call.
1702 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1702 required :id, String |
#name ⇒ String
The name of the tool that was run.
1714 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1714 required :name, String |
#output ⇒ String?
The output from the tool call.
1746 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1746 optional :output, String, nil?: true |
#server_label ⇒ String
The label of the MCP server running the tool.
1720 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1720 required :server_label, String |
#status ⇒ Symbol, ...
The status of the tool call. One of in_progress, completed, incomplete,
calling, or failed.
1753 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1753 optional :status, enum: -> { OpenAI::Responses::ResponseInputItem::McpCall::Status } |
#type ⇒ Symbol, :mcp_call
The type of the item. Always mcp_call.
1726 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1726 required :type, const: :mcp_call |
Instance Method Details
#to_hash ⇒ {
1216 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 1216
def to_hash: -> {
|