Class: OpenAI::Models::Responses::ResponseInputItem::ShellCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputItem::ShellCall
- Defined in:
- lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs
Defined Under Namespace
Modules: Caller, Environment, Status Classes: Action
Instance Attribute Summary collapse
-
#action ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCall::Action
The shell commands and limits that describe how to run the tool call.
-
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCall::Caller::Direct, ...
The execution context that produced this tool call.
-
#environment ⇒ OpenAI::Models::Responses::LocalEnvironment, ...
The environment to execute the shell commands in.
-
#id ⇒ String?
The unique ID of the shell tool call.
-
#status ⇒ Symbol, ...
The status of the shell call.
-
#type ⇒ Symbol, :shell_call
The type of the item.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caller_id:, type: :program) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 867
|
Instance Attribute Details
#action ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCall::Action
The shell commands and limits that describe how to run the tool call.
822 |
# File 'lib/openai/models/responses/response_input_item.rb', line 822 required :action, -> { OpenAI::Responses::ResponseInputItem::ShellCall::Action } |
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
828 |
# File 'lib/openai/models/responses/response_input_item.rb', line 828 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCall::Caller::Direct, ...
The execution context that produced this tool call.
847 848 849 850 |
# File 'lib/openai/models/responses/response_input_item.rb', line 847 optional :caller_, union: -> { OpenAI::Responses::ResponseInputItem::ShellCall::Caller }, api_name: :caller, nil?: true |
#environment ⇒ OpenAI::Models::Responses::LocalEnvironment, ...
The environment to execute the shell commands in.
856 857 858 |
# File 'lib/openai/models/responses/response_input_item.rb', line 856 optional :environment, union: -> { OpenAI::Responses::ResponseInputItem::ShellCall::Environment }, nil?: true |
#id ⇒ String?
The unique ID of the shell tool call. Populated when this item is returned via API.
841 |
# File 'lib/openai/models/responses/response_input_item.rb', line 841 optional :id, String, nil?: true |
#status ⇒ Symbol, ...
The status of the shell call. One of in_progress, completed, or
incomplete.
865 |
# File 'lib/openai/models/responses/response_input_item.rb', line 865 optional :status, enum: -> { OpenAI::Responses::ResponseInputItem::ShellCall::Status }, nil?: true |
#type ⇒ Symbol, :shell_call
The type of the item. Always shell_call.
834 |
# File 'lib/openai/models/responses/response_input_item.rb', line 834 required :type, const: :shell_call |
Class Method Details
.variants ⇒ Array(OpenAI::Models::Responses::LocalEnvironment, OpenAI::Models::Responses::ContainerReference)
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 964
|
Instance Method Details
#to_hash ⇒ {
611 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 611
def to_hash: -> {
|