Class: OpenAI::Models::Responses::ResponseInputItem::ShellCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs

Defined Under Namespace

Modules: Caller, Environment, Status Classes: Action

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(caller_id:, type: :program) ⇒ Object

Parameters:

  • caller_id (String)

    The call ID of the program item that produced this tool call.

  • type (Symbol, :program) (defaults to: :program)

    The caller type. Always program.



# File 'lib/openai/models/responses/response_input_item.rb', line 851

Instance Attribute Details

#actionOpenAI::Models::Responses::ResponseInputItem::ShellCall::Action

The shell commands and limits that describe how to run the tool call.

Parameters:

  • value (OpenAI::Responses::ResponseInputItem::ShellCall::Action)

Returns:



806
# File 'lib/openai/models/responses/response_input_item.rb', line 806

required :action, -> { OpenAI::Responses::ResponseInputItem::ShellCall::Action }

#call_idString

The unique ID of the shell tool call generated by the model.

Parameters:

  • value (String)

Returns:

  • (String)


812
# File 'lib/openai/models/responses/response_input_item.rb', line 812

required :call_id, String

#caller_OpenAI::Models::Responses::ResponseInputItem::ShellCall::Caller::Direct, ...

The execution context that produced this tool call.

Parameters:

  • value (OpenAI::Models::Responses::ResponseInputItem::ShellCall::caller_, nil)

Returns:



831
832
833
834
# File 'lib/openai/models/responses/response_input_item.rb', line 831

optional :caller_,
union: -> { OpenAI::Responses::ResponseInputItem::ShellCall::Caller },
api_name: :caller,
nil?: true

#environmentOpenAI::Models::Responses::LocalEnvironment, ...

The environment to execute the shell commands in.

Parameters:

  • value (OpenAI::Models::Responses::ResponseInputItem::ShellCall::environment, nil)

Returns:



840
841
842
# File 'lib/openai/models/responses/response_input_item.rb', line 840

optional :environment,
union: -> { OpenAI::Responses::ResponseInputItem::ShellCall::Environment },
nil?: true

#idString?

The unique ID of the shell tool call. Populated when this item is returned via API.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


825
# File 'lib/openai/models/responses/response_input_item.rb', line 825

optional :id, String, nil?: true

#statusSymbol, ...

The status of the shell call. One of in_progress, completed, or incomplete.

Parameters:

  • value (OpenAI::Models::Responses::ResponseInputItem::ShellCall::status, nil)

Returns:



849
# File 'lib/openai/models/responses/response_input_item.rb', line 849

optional :status, enum: -> { OpenAI::Responses::ResponseInputItem::ShellCall::Status }, nil?: true

#typeSymbol, :shell_call

The type of the item. Always shell_call.

Parameters:

  • value (:shell_call)

Returns:

  • (Symbol, :shell_call)


818
# File 'lib/openai/models/responses/response_input_item.rb', line 818

required :type, const: :shell_call

Class Method Details

Instance Method Details

#to_hash{

Returns:

  • ({)


601
# File 'sig/openai/models/responses/response_input_item.rbs', line 601

def to_hash: -> {