Class: OpenAI::Models::Responses::ResponseInputItem::ShellCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputItem::ShellCall
- Defined in:
- lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs
Defined Under Namespace
Modules: Caller, Environment, Status Classes: Action
Instance Attribute Summary collapse
-
#action ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCall::Action
The shell commands and limits that describe how to run the tool call.
-
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCall::Caller::Direct, ...
The execution context that produced this tool call.
-
#environment ⇒ OpenAI::Models::Responses::LocalEnvironment, ...
The environment to execute the shell commands in.
-
#id ⇒ String?
The unique ID of the shell tool call.
-
#status ⇒ Symbol, ...
The status of the shell call.
-
#type ⇒ Symbol, :shell_call
The type of the item.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caller_id:, type: :program) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 851
|
Instance Attribute Details
#action ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCall::Action
The shell commands and limits that describe how to run the tool call.
806 |
# File 'lib/openai/models/responses/response_input_item.rb', line 806 required :action, -> { OpenAI::Responses::ResponseInputItem::ShellCall::Action } |
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
812 |
# File 'lib/openai/models/responses/response_input_item.rb', line 812 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCall::Caller::Direct, ...
The execution context that produced this tool call.
831 832 833 834 |
# File 'lib/openai/models/responses/response_input_item.rb', line 831 optional :caller_, union: -> { OpenAI::Responses::ResponseInputItem::ShellCall::Caller }, api_name: :caller, nil?: true |
#environment ⇒ OpenAI::Models::Responses::LocalEnvironment, ...
The environment to execute the shell commands in.
840 841 842 |
# File 'lib/openai/models/responses/response_input_item.rb', line 840 optional :environment, union: -> { OpenAI::Responses::ResponseInputItem::ShellCall::Environment }, nil?: true |
#id ⇒ String?
The unique ID of the shell tool call. Populated when this item is returned via API.
825 |
# File 'lib/openai/models/responses/response_input_item.rb', line 825 optional :id, String, nil?: true |
#status ⇒ Symbol, ...
The status of the shell call. One of in_progress, completed, or
incomplete.
849 |
# File 'lib/openai/models/responses/response_input_item.rb', line 849 optional :status, enum: -> { OpenAI::Responses::ResponseInputItem::ShellCall::Status }, nil?: true |
#type ⇒ Symbol, :shell_call
The type of the item. Always shell_call.
818 |
# File 'lib/openai/models/responses/response_input_item.rb', line 818 required :type, const: :shell_call |
Class Method Details
.variants ⇒ Array(OpenAI::Models::Responses::LocalEnvironment, OpenAI::Models::Responses::ContainerReference)
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 948
|
Instance Method Details
#to_hash ⇒ {
601 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 601
def to_hash: -> {
|