Class: OpenAI::Models::Responses::ResponseInputItem::ShellCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputItem::ShellCall
- Defined in:
- lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs
Defined Under Namespace
Modules: Caller, Environment, Status Classes: Action
Instance Attribute Summary collapse
-
#action ⇒ OpenAI::Responses::ResponseInputItem::ShellCall::Action
The shell commands and limits that describe how to run the tool call.
-
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCall::caller_?
The execution context that produced this tool call.
-
#environment ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCall::environment?
The environment to execute the shell commands in.
-
#id ⇒ String?
The unique ID of the shell tool call.
-
#status ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCall::status?
The status of the shell call.
-
#type ⇒ :shell_call
The type of the item.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caller_id:, type: :program) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 1102
|
Instance Attribute Details
#action ⇒ OpenAI::Responses::ResponseInputItem::ShellCall::Action
The shell commands and limits that describe how to run the tool call.
1053 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1053 required :action, -> { OpenAI::Responses::ResponseInputItem::ShellCall::Action } |
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
1059 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1059 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCall::caller_?
The execution context that produced this tool call.
1078 1079 1080 1081 1082 1083 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1078 optional( :caller_, union: -> { OpenAI::Responses::ResponseInputItem::ShellCall::Caller }, api_name: :caller, nil?: true ) |
#environment ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCall::environment?
The environment to execute the shell commands in.
1089 1090 1091 1092 1093 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1089 optional( :environment, union: -> { OpenAI::Responses::ResponseInputItem::ShellCall::Environment }, nil?: true ) |
#id ⇒ String?
The unique ID of the shell tool call. Populated when this item is returned via API.
1072 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1072 optional :id, String, nil?: true |
#status ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCall::status?
The status of the shell call. One of in_progress, completed, or
incomplete.
1100 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1100 optional :status, enum: -> { OpenAI::Responses::ResponseInputItem::ShellCall::Status }, nil?: true |
#type ⇒ :shell_call
The type of the item. Always shell_call.
1065 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1065 required :type, const: :shell_call |
Class Method Details
.variants ⇒ Array(OpenAI::Models::Responses::LocalEnvironment, OpenAI::Models::Responses::ContainerReference)
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 1208
|
Instance Method Details
#to_hash ⇒ {
925 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 925
def to_hash: -> {
|