Class: OpenAI::Models::Responses::ResponseInputItem::ShellCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb

Defined Under Namespace

Modules: Environment, Status Classes: Action

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(commands:, max_output_length: nil, timeout_ms: nil) ⇒ Object

Some parameter documentations has been truncated, see Action for more details.

The shell commands and limits that describe how to run the tool call.

Parameters:

  • commands (Array<String>)

    Ordered shell commands for the execution environment to run.

  • max_output_length (Integer, nil) (defaults to: nil)

    Maximum number of UTF-8 characters to capture from combined stdout and stderr ou

  • timeout_ms (Integer, nil) (defaults to: nil)

    Maximum wall-clock time in milliseconds to allow the shell commands to run.



# File 'lib/openai/models/responses/response_input_item.rb', line 741

Instance Attribute Details

#actionOpenAI::Models::Responses::ResponseInputItem::ShellCall::Action

The shell commands and limits that describe how to run the tool call.



705
# File 'lib/openai/models/responses/response_input_item.rb', line 705

required :action, -> { OpenAI::Responses::ResponseInputItem::ShellCall::Action }

#call_idString

The unique ID of the shell tool call generated by the model.

Returns:

  • (String)


711
# File 'lib/openai/models/responses/response_input_item.rb', line 711

required :call_id, String

#environmentOpenAI::Models::Responses::LocalEnvironment, ...

The environment to execute the shell commands in.



730
731
732
# File 'lib/openai/models/responses/response_input_item.rb', line 730

optional :environment,
union: -> { OpenAI::Responses::ResponseInputItem::ShellCall::Environment },
nil?: true

#idString?

The unique ID of the shell tool call. Populated when this item is returned via API.

Returns:

  • (String, nil)


724
# File 'lib/openai/models/responses/response_input_item.rb', line 724

optional :id, String, nil?: true

#statusSymbol, ...

The status of the shell call. One of in_progress, completed, or incomplete.



739
# File 'lib/openai/models/responses/response_input_item.rb', line 739

optional :status, enum: -> { OpenAI::Responses::ResponseInputItem::ShellCall::Status }, nil?: true

#typeSymbol, :shell_call

The type of the item. Always shell_call.

Returns:

  • (Symbol, :shell_call)


717
# File 'lib/openai/models/responses/response_input_item.rb', line 717

required :type, const: :shell_call

Class Method Details

.variantsArray(OpenAI::Models::Responses::LocalEnvironment, OpenAI::Models::Responses::ContainerReference)



# File 'lib/openai/models/responses/response_input_item.rb', line 806