Class: OpenAI::Models::Responses::ResponseInputItem::ShellCall::Action
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputItem::ShellCall::Action
- Defined in:
- lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs
Overview
Instance Attribute Summary collapse
-
#commands ⇒ Array<String>
Ordered shell commands for the execution environment to run.
-
#max_output_length ⇒ Integer?
Maximum number of UTF-8 characters to capture from combined stdout and stderr output.
-
#timeout_ms ⇒ Integer?
Maximum wall-clock time in milliseconds to allow the shell commands to run.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
625 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 625
def initialize: (
|
Instance Attribute Details
#commands ⇒ Array<String>
Ordered shell commands for the execution environment to run.
877 |
# File 'lib/openai/models/responses/response_input_item.rb', line 877 required :commands, OpenAI::Internal::Type::ArrayOf[String] |
#max_output_length ⇒ Integer?
Maximum number of UTF-8 characters to capture from combined stdout and stderr output.
884 |
# File 'lib/openai/models/responses/response_input_item.rb', line 884 optional :max_output_length, Integer, nil?: true |
#timeout_ms ⇒ Integer?
Maximum wall-clock time in milliseconds to allow the shell commands to run.
890 |
# File 'lib/openai/models/responses/response_input_item.rb', line 890 optional :timeout_ms, Integer, nil?: true |
Instance Method Details
#to_hash ⇒ {
631 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 631
def to_hash: -> {
|