Class: OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs

Defined Under Namespace

Modules: Caller, Status

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(caller_id:, type: :program) ⇒ Object

Parameters:

  • caller_id (String)

    The call ID of the program item that produced this tool call.

  • type (Symbol, :program) (defaults to: :program)

    The caller type. Always program.



# File 'lib/openai/models/responses/response_input_item.rb', line 1078

Instance Attribute Details

#call_idString

The unique ID of the shell tool call generated by the model.

Parameters:

  • value (String)

Returns:

  • (String)


1023
# File 'lib/openai/models/responses/response_input_item.rb', line 1023

required :call_id, String

#caller_OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::Caller::Direct, ...

The execution context that produced this tool call.

Parameters:

  • value (OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::caller_, nil)

Returns:



1052
1053
1054
1055
1056
1057
# File 'lib/openai/models/responses/response_input_item.rb', line 1052

optional(
  :caller_,
  union: -> { OpenAI::Responses::ResponseInputItem::ShellCallOutput::Caller },
  api_name: :caller,
  nil?: true
)

#idString?

The unique ID of the shell tool call output. Populated when this item is returned via API.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1046
# File 'lib/openai/models/responses/response_input_item.rb', line 1046

optional :id, String, nil?: true

#max_output_lengthInteger?

The maximum number of UTF-8 characters captured for this shell call's combined output.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


1064
# File 'lib/openai/models/responses/response_input_item.rb', line 1064

optional :max_output_length, Integer, nil?: true

#outputArray<OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent>

Captured chunks of stdout and stderr output, along with their associated outcomes.

Parameters:

  • value (::Array[OpenAI::Responses::ResponseFunctionShellCallOutputContent])

Returns:



1030
1031
1032
1033
# File 'lib/openai/models/responses/response_input_item.rb', line 1030

required(
  :output,
  -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Responses::ResponseFunctionShellCallOutputContent] }
)

#statusSymbol, ...

The status of the shell call output.

Parameters:

  • value (OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::status, nil)

Returns:



1070
1071
1072
1073
1074
1075
1076
# File 'lib/openai/models/responses/response_input_item.rb', line 1070

optional(
  :status,
  enum: -> {
    OpenAI::Responses::ResponseInputItem::ShellCallOutput::Status
  },
  nil?: true
)

#typeSymbol, :shell_call_output

The type of the item. Always shell_call_output.

Parameters:

  • value (:shell_call_output)

Returns:

  • (Symbol, :shell_call_output)


1039
# File 'lib/openai/models/responses/response_input_item.rb', line 1039

required :type, const: :shell_call_output

Instance Method Details

#to_hash{

Returns:

  • ({)


739
# File 'sig/openai/models/responses/response_input_item.rbs', line 739

def to_hash: -> {