Class: OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs

Defined Under Namespace

Modules: Caller, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(caller_id:, type: :program) ⇒ Object

Parameters:

  • caller_id (String)

    The call ID of the program item that produced this tool call.

  • type (Symbol, :program) (defaults to: :program)

    The caller type. Always program.



# File 'lib/openai/models/responses/response_input_item.rb', line 1038

Instance Attribute Details

#call_idString

The unique ID of the shell tool call generated by the model.

Parameters:

  • value (String)

Returns:

  • (String)


989
# File 'lib/openai/models/responses/response_input_item.rb', line 989

required :call_id, String

#caller_OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::Caller::Direct, ...

The execution context that produced this tool call.

Parameters:

  • value (OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::caller_, nil)

Returns:



1016
1017
1018
1019
# File 'lib/openai/models/responses/response_input_item.rb', line 1016

optional :caller_,
union: -> { OpenAI::Responses::ResponseInputItem::ShellCallOutput::Caller },
api_name: :caller,
nil?: true

#idString?

The unique ID of the shell tool call output. Populated when this item is returned via API.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1010
# File 'lib/openai/models/responses/response_input_item.rb', line 1010

optional :id, String, nil?: true

#max_output_lengthInteger?

The maximum number of UTF-8 characters captured for this shell call's combined output.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


1026
# File 'lib/openai/models/responses/response_input_item.rb', line 1026

optional :max_output_length, Integer, nil?: true

#outputArray<OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent>

Captured chunks of stdout and stderr output, along with their associated outcomes.

Parameters:

  • value (::Array[OpenAI::Responses::ResponseFunctionShellCallOutputContent])

Returns:



996
997
# File 'lib/openai/models/responses/response_input_item.rb', line 996

required :output,
-> { OpenAI::Internal::Type::ArrayOf[OpenAI::Responses::ResponseFunctionShellCallOutputContent] }

#statusSymbol, ...

The status of the shell call output.

Parameters:

  • value (OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::status, nil)

Returns:



1032
1033
1034
1035
1036
# File 'lib/openai/models/responses/response_input_item.rb', line 1032

optional :status,
enum: -> {
  OpenAI::Responses::ResponseInputItem::ShellCallOutput::Status
},
nil?: true

#typeSymbol, :shell_call_output

The type of the item. Always shell_call_output.

Parameters:

  • value (:shell_call_output)

Returns:

  • (Symbol, :shell_call_output)


1003
# File 'lib/openai/models/responses/response_input_item.rb', line 1003

required :type, const: :shell_call_output

Instance Method Details

#to_hash{

Returns:

  • ({)


729
# File 'sig/openai/models/responses/response_input_item.rbs', line 729

def to_hash: -> {