Class: OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput
- Defined in:
- lib/openai/models/responses/response_input_item.rb,
sig/openai/models/responses/response_input_item.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
-
#id ⇒ String?
The unique ID of the shell tool call output.
-
#max_output_length ⇒ Integer?
The maximum number of UTF-8 characters captured for this shell call's combined output.
-
#output ⇒ Array<OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent>
Captured chunks of stdout and stderr output, along with their associated outcomes.
-
#status ⇒ Symbol, ...
The status of the shell call output.
-
#type ⇒ Symbol, :shell_call_output
The type of the item.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caller_id:, type: :program) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 1038
|
Instance Attribute Details
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
989 |
# File 'lib/openai/models/responses/response_input_item.rb', line 989 required :call_id, String |
#caller_ ⇒ OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
1016 1017 1018 1019 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1016 optional :caller_, union: -> { OpenAI::Responses::ResponseInputItem::ShellCallOutput::Caller }, api_name: :caller, nil?: true |
#id ⇒ String?
The unique ID of the shell tool call output. Populated when this item is returned via API.
1010 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1010 optional :id, String, nil?: true |
#max_output_length ⇒ Integer?
The maximum number of UTF-8 characters captured for this shell call's combined output.
1026 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1026 optional :max_output_length, Integer, nil?: true |
#output ⇒ Array<OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent>
Captured chunks of stdout and stderr output, along with their associated outcomes.
996 997 |
# File 'lib/openai/models/responses/response_input_item.rb', line 996 required :output, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Responses::ResponseFunctionShellCallOutputContent] } |
#status ⇒ Symbol, ...
The status of the shell call output.
1032 1033 1034 1035 1036 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1032 optional :status, enum: -> { OpenAI::Responses::ResponseInputItem::ShellCallOutput::Status }, nil?: true |
#type ⇒ Symbol, :shell_call_output
The type of the item. Always shell_call_output.
1003 |
# File 'lib/openai/models/responses/response_input_item.rb', line 1003 required :type, const: :shell_call_output |
Class Method Details
.variants ⇒ Array(OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::Caller::Direct, OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::Caller::Program)
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 1101
|
Instance Method Details
#to_hash ⇒ {
729 |
# File 'sig/openai/models/responses/response_input_item.rbs', line 729
def to_hash: -> {
|