Class: OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput
- Defined in:
- lib/openai/models/responses/response_input_item.rb
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
-
#id ⇒ String?
The unique ID of the shell tool call output.
-
#max_output_length ⇒ Integer?
The maximum number of UTF-8 characters captured for this shell call’s combined output.
-
#output ⇒ Array<OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent>
Captured chunks of stdout and stderr output, along with their associated outcomes.
-
#status ⇒ Symbol, ...
The status of the shell call output.
-
#type ⇒ Symbol, :shell_call_output
The type of the item.
Instance Method Summary collapse
-
#initialize(call_id:, output:, id: nil, max_output_length: nil, status: nil, type: :shell_call_output) ⇒ Object
constructor
Some parameter documentations has been truncated, see ShellCallOutput for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(call_id:, output:, id: nil, max_output_length: nil, status: nil, type: :shell_call_output) ⇒ Object
Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput for more details.
The streamed output items emitted by a shell tool call.
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 785
|
Instance Attribute Details
#call_id ⇒ String
The unique ID of the shell tool call generated by the model.
745 |
# File 'lib/openai/models/responses/response_input_item.rb', line 745 required :call_id, String |
#id ⇒ String?
The unique ID of the shell tool call output. Populated when this item is returned via API.
766 |
# File 'lib/openai/models/responses/response_input_item.rb', line 766 optional :id, String, nil?: true |
#max_output_length ⇒ Integer?
The maximum number of UTF-8 characters captured for this shell call’s combined output.
773 |
# File 'lib/openai/models/responses/response_input_item.rb', line 773 optional :max_output_length, Integer, nil?: true |
#output ⇒ Array<OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent>
Captured chunks of stdout and stderr output, along with their associated outcomes.
752 753 |
# File 'lib/openai/models/responses/response_input_item.rb', line 752 required :output, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Responses::ResponseFunctionShellCallOutputContent] } |
#status ⇒ Symbol, ...
The status of the shell call output.
779 780 781 782 783 |
# File 'lib/openai/models/responses/response_input_item.rb', line 779 optional :status, enum: -> { OpenAI::Responses::ResponseInputItem::ShellCallOutput::Status }, nil?: true |
#type ⇒ Symbol, :shell_call_output
The type of the item. Always ‘shell_call_output`.
759 |
# File 'lib/openai/models/responses/response_input_item.rb', line 759 required :type, const: :shell_call_output |