Class: OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(call_id:, output:, id: nil, max_output_length: nil, status: nil, type: :shell_call_output) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput for more details.

The streamed output items emitted by a shell tool call.

Parameters:

  • call_id (String)

    The unique ID of the shell tool call generated by the model.

  • output (Array<OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent>)

    Captured chunks of stdout and stderr output, along with their associated outcome

  • id (String, nil) (defaults to: nil)

    The unique ID of the shell tool call output. Populated when this item is returne

  • max_output_length (Integer, nil) (defaults to: nil)

    The maximum number of UTF-8 characters captured for this shell call’s combined o

  • status (Symbol, OpenAI::Models::Responses::ResponseInputItem::ShellCallOutput::Status, nil) (defaults to: nil)

    The status of the shell call output.

  • type (Symbol, :shell_call_output) (defaults to: :shell_call_output)

    The type of the item. Always shell_call_output.



# File 'lib/openai/models/responses/response_input_item.rb', line 871

Instance Attribute Details

#call_idString

The unique ID of the shell tool call generated by the model.

Returns:

  • (String)


831
# File 'lib/openai/models/responses/response_input_item.rb', line 831

required :call_id, String

#idString?

The unique ID of the shell tool call output. Populated when this item is returned via API.

Returns:

  • (String, nil)


852
# File 'lib/openai/models/responses/response_input_item.rb', line 852

optional :id, String, nil?: true

#max_output_lengthInteger?

The maximum number of UTF-8 characters captured for this shell call’s combined output.

Returns:

  • (Integer, nil)


859
# File 'lib/openai/models/responses/response_input_item.rb', line 859

optional :max_output_length, Integer, nil?: true

#outputArray<OpenAI::Models::Responses::ResponseFunctionShellCallOutputContent>

Captured chunks of stdout and stderr output, along with their associated outcomes.



838
839
# File 'lib/openai/models/responses/response_input_item.rb', line 838

required :output,
-> { OpenAI::Internal::Type::ArrayOf[OpenAI::Responses::ResponseFunctionShellCallOutputContent] }

#statusSymbol, ...

The status of the shell call output.



865
866
867
868
869
# File 'lib/openai/models/responses/response_input_item.rb', line 865

optional :status,
enum: -> {
  OpenAI::Responses::ResponseInputItem::ShellCallOutput::Status
},
nil?: true

#typeSymbol, :shell_call_output

The type of the item. Always shell_call_output.

Returns:

  • (Symbol, :shell_call_output)


845
# File 'lib/openai/models/responses/response_input_item.rb', line 845

required :type, const: :shell_call_output