Class: OpenAI::Models::Responses::ResponseInputItem::ToolSearchCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_input_item.rb

Defined Under Namespace

Modules: Execution, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(arguments:, id: nil, call_id: nil, execution: nil, status: nil, type: :tool_search_call) ⇒ Object

Parameters:

  • arguments (Object)

    The arguments supplied to the tool search call.

  • id (String, nil) (defaults to: nil)

    The unique ID of this tool search call.

  • call_id (String, nil) (defaults to: nil)

    The unique ID of the tool search call generated by the model.

  • execution (Symbol, OpenAI::Models::Responses::ResponseInputItem::ToolSearchCall::Execution) (defaults to: nil)

    Whether tool search was executed by the server or by the client.

  • status (Symbol, OpenAI::Models::Responses::ResponseInputItem::ToolSearchCall::Status, nil) (defaults to: nil)

    The status of the tool search call.

  • type (Symbol, :tool_search_call) (defaults to: :tool_search_call)

    The item type. Always tool_search_call.



# File 'lib/openai/models/responses/response_input_item.rb', line 430

Instance Attribute Details

#argumentsObject

The arguments supplied to the tool search call.

Returns:

  • (Object)


394
# File 'lib/openai/models/responses/response_input_item.rb', line 394

required :arguments, OpenAI::Internal::Type::Unknown

#call_idString?

The unique ID of the tool search call generated by the model.

Returns:

  • (String, nil)


412
# File 'lib/openai/models/responses/response_input_item.rb', line 412

optional :call_id, String, nil?: true

#executionSymbol, ...

Whether tool search was executed by the server or by the client.



418
# File 'lib/openai/models/responses/response_input_item.rb', line 418

optional :execution, enum: -> { OpenAI::Responses::ResponseInputItem::ToolSearchCall::Execution }

#idString?

The unique ID of this tool search call.

Returns:

  • (String, nil)


406
# File 'lib/openai/models/responses/response_input_item.rb', line 406

optional :id, String, nil?: true

#statusSymbol, ...

The status of the tool search call.



424
425
426
427
428
# File 'lib/openai/models/responses/response_input_item.rb', line 424

optional :status,
enum: -> {
  OpenAI::Responses::ResponseInputItem::ToolSearchCall::Status
},
nil?: true

#typeSymbol, :tool_search_call

The item type. Always tool_search_call.

Returns:

  • (Symbol, :tool_search_call)


400
# File 'lib/openai/models/responses/response_input_item.rb', line 400

required :type, const: :tool_search_call

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/responses/response_input_item.rb', line 452