Class: OpenAI::Models::Responses::ResponseInputItem::ToolSearchCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseInputItem::ToolSearchCall
- Defined in:
- lib/openai/models/responses/response_input_item.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#arguments ⇒ Object
The arguments supplied to the tool search call.
-
#call_id ⇒ String?
The unique ID of the tool search call generated by the model.
-
#execution ⇒ Symbol, ...
Whether tool search was executed by the server or by the client.
-
#id ⇒ String?
The unique ID of this tool search call.
-
#status ⇒ Symbol, ...
The status of the tool search call.
-
#type ⇒ Symbol, :tool_search_call
The item type.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(arguments:, id: nil, call_id: nil, execution: nil, status: nil, type: :tool_search_call) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 430
|
Instance Attribute Details
#arguments ⇒ Object
The arguments supplied to the tool search call.
394 |
# File 'lib/openai/models/responses/response_input_item.rb', line 394 required :arguments, OpenAI::Internal::Type::Unknown |
#call_id ⇒ String?
The unique ID of the tool search call generated by the model.
412 |
# File 'lib/openai/models/responses/response_input_item.rb', line 412 optional :call_id, String, nil?: true |
#execution ⇒ Symbol, ...
Whether tool search was executed by the server or by the client.
418 |
# File 'lib/openai/models/responses/response_input_item.rb', line 418 optional :execution, enum: -> { OpenAI::Responses::ResponseInputItem::ToolSearchCall::Execution } |
#id ⇒ String?
The unique ID of this tool search call.
406 |
# File 'lib/openai/models/responses/response_input_item.rb', line 406 optional :id, String, nil?: true |
#status ⇒ Symbol, ...
The status of the tool search call.
424 425 426 427 428 |
# File 'lib/openai/models/responses/response_input_item.rb', line 424 optional :status, enum: -> { OpenAI::Responses::ResponseInputItem::ToolSearchCall::Status }, nil?: true |
#type ⇒ Symbol, :tool_search_call
The item type. Always tool_search_call.
400 |
# File 'lib/openai/models/responses/response_input_item.rb', line 400 required :type, const: :tool_search_call |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/response_input_item.rb', line 452
|