Class: OpenAI::Models::Responses::ResponseOutputItem::AdditionalTools
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseOutputItem::AdditionalTools
- Defined in:
- lib/openai/models/responses/response_output_item.rb,
sig/openai/models/responses/response_output_item.rbs
Defined Under Namespace
Modules: Role
Instance Attribute Summary collapse
-
#id ⇒ String
The unique ID of the additional tools item.
-
#role ⇒ OpenAI::Models::Responses::ResponseOutputItem::AdditionalTools::role
The role that provided the additional tools.
-
#tools ⇒ ::Array[OpenAI::Models::Responses::tool]
The additional tool definitions made available at this item.
-
#type ⇒ :additional_tools
The type of the item.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, role:, tools:, type: :additional_tools) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_output_item.rb', line 230
|
Instance Attribute Details
#id ⇒ String
The unique ID of the additional tools item.
210 |
# File 'lib/openai/models/responses/response_output_item.rb', line 210 required :id, String |
#role ⇒ OpenAI::Models::Responses::ResponseOutputItem::AdditionalTools::role
The role that provided the additional tools.
216 |
# File 'lib/openai/models/responses/response_output_item.rb', line 216 required :role, enum: -> { OpenAI::Responses::ResponseOutputItem::AdditionalTools::Role } |
#tools ⇒ ::Array[OpenAI::Models::Responses::tool]
The additional tool definitions made available at this item.
222 |
# File 'lib/openai/models/responses/response_output_item.rb', line 222 required :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Responses::Tool] } |
#type ⇒ :additional_tools
The type of the item. Always additional_tools.
228 |
# File 'lib/openai/models/responses/response_output_item.rb', line 228 required :type, const: :additional_tools |
Instance Method Details
#to_hash ⇒ {
188 |
# File 'sig/openai/models/responses/response_output_item.rbs', line 188 def to_hash: -> { |