Class: OpenAI::Models::Responses::ResponseOutputItem::McpCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseOutputItem::McpCall
- Defined in:
- lib/openai/models/responses/response_output_item.rb,
sig/openai/models/responses/response_output_item.rbs
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#approval_request_id ⇒ String?
Unique identifier for the MCP tool call approval request.
-
#arguments ⇒ String
A JSON string of the arguments passed to the tool.
-
#error ⇒ OpenAI::Models::Responses::mcp_tool_call_error?
The error from the tool call, if any.
-
#id ⇒ String
The unique ID of the tool call.
-
#name ⇒ String
The name of the tool that was run.
-
#output ⇒ String?
The output from the tool call.
-
#server_label ⇒ String
The label of the MCP server running the tool.
-
#status ⇒ OpenAI::Models::Responses::ResponseOutputItem::McpCall::status?
The status of the tool call.
-
#type ⇒ :mcp_call
The type of the item.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(id:, arguments:, name:, server_label:, approval_request_id: nil, error: nil, output: nil, status: nil, type: :mcp_call) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, arguments:, name:, server_label:, approval_request_id: nil, error: nil, output: nil, status: nil, type: :mcp_call) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_output_item.rb', line 736
|
Instance Attribute Details
#approval_request_id ⇒ String?
Unique identifier for the MCP tool call approval request. Include this value in
a subsequent mcp_approval_response input to approve or reject the
corresponding tool call.
715 |
# File 'lib/openai/models/responses/response_output_item.rb', line 715 optional :approval_request_id, String, nil?: true |
#arguments ⇒ String
A JSON string of the arguments passed to the tool.
689 |
# File 'lib/openai/models/responses/response_output_item.rb', line 689 required :arguments, String |
#error ⇒ OpenAI::Models::Responses::mcp_tool_call_error?
The error from the tool call, if any.
721 |
# File 'lib/openai/models/responses/response_output_item.rb', line 721 optional :error, union: -> { OpenAI::Responses::McpToolCallError }, nil?: true |
#id ⇒ String
The unique ID of the tool call.
683 |
# File 'lib/openai/models/responses/response_output_item.rb', line 683 required :id, String |
#name ⇒ String
The name of the tool that was run.
695 |
# File 'lib/openai/models/responses/response_output_item.rb', line 695 required :name, String |
#output ⇒ String?
The output from the tool call.
727 |
# File 'lib/openai/models/responses/response_output_item.rb', line 727 optional :output, String, nil?: true |
#server_label ⇒ String
The label of the MCP server running the tool.
701 |
# File 'lib/openai/models/responses/response_output_item.rb', line 701 required :server_label, String |
#status ⇒ OpenAI::Models::Responses::ResponseOutputItem::McpCall::status?
The status of the tool call. One of in_progress, completed, incomplete,
calling, or failed.
734 |
# File 'lib/openai/models/responses/response_output_item.rb', line 734 optional :status, enum: -> { OpenAI::Responses::ResponseOutputItem::McpCall::Status } |
#type ⇒ :mcp_call
The type of the item. Always mcp_call.
707 |
# File 'lib/openai/models/responses/response_output_item.rb', line 707 required :type, const: :mcp_call |
Instance Method Details
#to_hash ⇒ {
654 |
# File 'sig/openai/models/responses/response_output_item.rbs', line 654
def to_hash: -> {
|