Class: OpenAI::Models::Responses::ResponseOutputItem::McpCall

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_output_item.rb

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, arguments:, name:, server_label:, approval_request_id: nil, error: nil, output: nil, status: nil, type: :mcp_call) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Responses::ResponseOutputItem::McpCall for more details.

An invocation of a tool on an MCP server.

Parameters:

  • The unique ID of the tool call.

  • A JSON string of the arguments passed to the tool.

  • The name of the tool that was run.

  • The label of the MCP server running the tool.

  • (defaults to: nil)

    Unique identifier for the MCP tool call approval request.

  • (defaults to: nil)

    The error from the tool call, if any.

  • (defaults to: nil)

    The output from the tool call.

  • (defaults to: nil)

    The status of the tool call. One of in_progress, completed, incomplete, ‘c

  • (defaults to: :mcp_call)

    The type of the item. Always mcp_call.



# File 'lib/openai/models/responses/response_output_item.rb', line 308


Instance Attribute Details

#approval_request_idString?

Unique identifier for the MCP tool call approval request. Include this value in a subsequent mcp_approval_response input to approve or reject the corresponding tool call.

Returns:



287
# File 'lib/openai/models/responses/response_output_item.rb', line 287

optional :approval_request_id, String, nil?: true

#argumentsString

A JSON string of the arguments passed to the tool.

Returns:



261
# File 'lib/openai/models/responses/response_output_item.rb', line 261

required :arguments, String

#errorString?

The error from the tool call, if any.

Returns:



293
# File 'lib/openai/models/responses/response_output_item.rb', line 293

optional :error, String, nil?: true

#idString

The unique ID of the tool call.

Returns:



255
# File 'lib/openai/models/responses/response_output_item.rb', line 255

required :id, String

#nameString

The name of the tool that was run.

Returns:



267
# File 'lib/openai/models/responses/response_output_item.rb', line 267

required :name, String

#outputString?

The output from the tool call.

Returns:



299
# File 'lib/openai/models/responses/response_output_item.rb', line 299

optional :output, String, nil?: true

#server_labelString

The label of the MCP server running the tool.

Returns:



273
# File 'lib/openai/models/responses/response_output_item.rb', line 273

required :server_label, String

#statusSymbol, ...

The status of the tool call. One of in_progress, completed, incomplete, calling, or failed.

Returns:



306
# File 'lib/openai/models/responses/response_output_item.rb', line 306

optional :status, enum: -> { OpenAI::Responses::ResponseOutputItem::McpCall::Status }

#typeSymbol, :mcp_call

The type of the item. Always mcp_call.

Returns:



279
# File 'lib/openai/models/responses/response_output_item.rb', line 279

required :type, const: :mcp_call