Class: OpenAI::Models::Responses::ResponseOutputText::Annotation::ContainerFileCitation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/response_output_text.rb,
sig/openai/models/responses/response_output_text.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



140
# File 'sig/openai/models/responses/response_output_text.rbs', line 140

def initialize: (

Instance Attribute Details

#container_idString

The ID of the container file.

Parameters:

  • value (String)

Returns:

  • (String)


156
# File 'lib/openai/models/responses/response_output_text.rb', line 156

required :container_id, String

#end_indexInteger

The index of the last character of the container file citation in the message.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


162
# File 'lib/openai/models/responses/response_output_text.rb', line 162

required :end_index, Integer

#file_idString

The ID of the file.

Parameters:

  • value (String)

Returns:

  • (String)


168
# File 'lib/openai/models/responses/response_output_text.rb', line 168

required :file_id, String

#filenameString

The filename of the container file cited.

Parameters:

  • value (String)

Returns:

  • (String)


174
# File 'lib/openai/models/responses/response_output_text.rb', line 174

required :filename, String

#start_indexInteger

The index of the first character of the container file citation in the message.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


180
# File 'lib/openai/models/responses/response_output_text.rb', line 180

required :start_index, Integer

#typeSymbol, :container_file_citation

The type of the container file citation. Always container_file_citation.

Parameters:

  • value (:container_file_citation)

Returns:

  • (Symbol, :container_file_citation)


186
# File 'lib/openai/models/responses/response_output_text.rb', line 186

required :type, const: :container_file_citation

Instance Method Details

#to_hash{

Returns:

  • ({)


149
# File 'sig/openai/models/responses/response_output_text.rbs', line 149

def to_hash: -> {