Class: OpenAI::Models::Responses::ResponseOutputText::Annotation::FilePath
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseOutputText::Annotation::FilePath
- Defined in:
- lib/openai/models/responses/response_output_text.rb,
sig/openai/models/responses/response_output_text.rbs
Instance Attribute Summary collapse
-
#file_id ⇒ String
The ID of the file.
-
#index ⇒ Integer
The index of the file in the list of files.
-
#type ⇒ Symbol, :file_path
The type of the file path.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
168 |
# File 'sig/openai/models/responses/response_output_text.rbs', line 168
def initialize: (
|
Instance Attribute Details
#file_id ⇒ String
The ID of the file.
209 |
# File 'lib/openai/models/responses/response_output_text.rb', line 209 required :file_id, String |
#index ⇒ Integer
The index of the file in the list of files.
215 |
# File 'lib/openai/models/responses/response_output_text.rb', line 215 required :index, Integer |
#type ⇒ Symbol, :file_path
The type of the file path. Always file_path.
221 |
# File 'lib/openai/models/responses/response_output_text.rb', line 221 required :type, const: :file_path |
Instance Method Details
#to_hash ⇒ {
174 |
# File 'sig/openai/models/responses/response_output_text.rbs', line 174
def to_hash: -> {
|