Class: OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent
- Defined in:
- lib/openai/models/responses/response_output_text_annotation_added_event.rb,
sig/openai/models/responses/response_output_text_annotation_added_event.rbs
Direct Known Subclasses
OpenAI::Models::Responses::ResponsesServerEvent::ResponseOutputTextAnnotationWsAdded
Defined Under Namespace
Modules: Annotation
Instance Attribute Summary collapse
-
#annotation ⇒ OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent::Annotation::FileCitation, ...
An annotation that applies to a span of output text.
-
#annotation_index ⇒ Integer
The index of the annotation within the content part.
-
#content_index ⇒ Integer
The index of the content part within the output item.
-
#item_id ⇒ String
The unique identifier of the item to which the annotation is being added.
-
#output_index ⇒ Integer
The index of the output item in the response's output array.
-
#sequence_number ⇒ Integer
The sequence number of this event.
-
#type ⇒ Symbol, :"response.output_text.annotation.added"
The type of the event.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
-
#initialize(annotation:, annotation_index:, content_index:, item_id:, output_index:, sequence_number:, type: :"response.output_text.annotation.added") ⇒ Object
constructor
Emitted when an annotation is added to output text content.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(annotation:, annotation_index:, content_index:, item_id:, output_index:, sequence_number:, type: :"response.output_text.annotation.added") ⇒ Object
Emitted when an annotation is added to output text content.
|
|
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 51
|
Instance Attribute Details
#annotation ⇒ OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent::Annotation::FileCitation, ...
An annotation that applies to a span of output text.
11 12 13 |
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 11 required :annotation, union: -> { OpenAI::Responses::ResponseOutputTextAnnotationAddedEvent::Annotation }, nil?: true |
#annotation_index ⇒ Integer
The index of the annotation within the content part.
19 |
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 19 required :annotation_index, Integer |
#content_index ⇒ Integer
The index of the content part within the output item.
25 |
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 25 required :content_index, Integer |
#item_id ⇒ String
The unique identifier of the item to which the annotation is being added.
31 |
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 31 required :item_id, String |
#output_index ⇒ Integer
The index of the output item in the response's output array.
37 |
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 37 required :output_index, Integer |
#sequence_number ⇒ Integer
The sequence number of this event.
43 |
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 43 required :sequence_number, Integer |
#type ⇒ Symbol, :"response.output_text.annotation.added"
The type of the event. Always 'response.output_text.annotation.added'.
49 |
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 49 required :type, const: :"response.output_text.annotation.added" |
Instance Method Details
#to_hash ⇒ {
40 |
# File 'sig/openai/models/responses/response_output_text_annotation_added_event.rbs', line 40
def to_hash: -> {
|