Class: OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent::Annotation::URLCitation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseOutputTextAnnotationAddedEvent::Annotation::URLCitation
- Defined in:
- lib/openai/models/responses/response_output_text_annotation_added_event.rb,
sig/openai/models/responses/response_output_text_annotation_added_event.rbs
Instance Attribute Summary collapse
-
#end_index ⇒ Integer
The index of the last character of the URL citation in the message.
-
#start_index ⇒ Integer
The index of the first character of the URL citation in the message.
-
#title ⇒ String
The title of the web resource.
-
#type ⇒ Symbol, :url_citation
The type of the URL citation.
-
#url ⇒ String
The URL of the web resource.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
111 |
# File 'sig/openai/models/responses/response_output_text_annotation_added_event.rbs', line 111
def initialize: (
|
Instance Attribute Details
#end_index ⇒ Integer
The index of the last character of the URL citation in the message.
133 |
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 133 required :end_index, Integer |
#start_index ⇒ Integer
The index of the first character of the URL citation in the message.
139 |
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 139 required :start_index, Integer |
#title ⇒ String
The title of the web resource.
145 |
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 145 required :title, String |
#type ⇒ Symbol, :url_citation
The type of the URL citation. Always url_citation.
151 |
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 151 required :type, const: :url_citation |
#url ⇒ String
The URL of the web resource.
157 |
# File 'lib/openai/models/responses/response_output_text_annotation_added_event.rb', line 157 required :url, String |
Instance Method Details
#to_hash ⇒ {
119 |
# File 'sig/openai/models/responses/response_output_text_annotation_added_event.rbs', line 119
def to_hash: -> {
|