Class: OpenAI::Models::Responses::ResponseShellCallOutputContentDoneEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseShellCallOutputContentDoneEvent
- Defined in:
- lib/openai/models/responses/response_shell_call_output_content_done_event.rb,
sig/openai/models/responses/response_shell_call_output_content_done_event.rbs
Direct Known Subclasses
OpenAI::Models::Responses::ResponsesServerEvent::ResponseShellCallOutputContentWsDone
Defined Under Namespace
Classes: Output
Instance Attribute Summary collapse
-
#command_index ⇒ Integer
The index of the shell command that produced output.
-
#item_id ⇒ String
The ID of the output item that was updated.
-
#output ⇒ Array<OpenAI::Models::Responses::ResponseShellCallOutputContentDoneEvent::Output>
The output contents emitted for the shell command.
-
#output_index ⇒ Integer
The index of the output item that was updated.
-
#sequence_number ⇒ Integer
The sequence number of the event that was emitted.
-
#type ⇒ Symbol, :"response.shell_call_output_content.done"
The type of the event, always
response.shell_call_output_content.done.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
27 |
# File 'sig/openai/models/responses/response_shell_call_output_content_done_event.rbs', line 27
def initialize: (
|
Instance Attribute Details
#command_index ⇒ Integer
The index of the shell command that produced output.
11 |
# File 'lib/openai/models/responses/response_shell_call_output_content_done_event.rb', line 11 required :command_index, Integer |
#item_id ⇒ String
The ID of the output item that was updated.
17 |
# File 'lib/openai/models/responses/response_shell_call_output_content_done_event.rb', line 17 required :item_id, String |
#output ⇒ Array<OpenAI::Models::Responses::ResponseShellCallOutputContentDoneEvent::Output>
The output contents emitted for the shell command.
23 24 25 26 |
# File 'lib/openai/models/responses/response_shell_call_output_content_done_event.rb', line 23 required( :output, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Responses::ResponseShellCallOutputContentDoneEvent::Output] } ) |
#output_index ⇒ Integer
The index of the output item that was updated.
32 |
# File 'lib/openai/models/responses/response_shell_call_output_content_done_event.rb', line 32 required :output_index, Integer |
#sequence_number ⇒ Integer
The sequence number of the event that was emitted.
38 |
# File 'lib/openai/models/responses/response_shell_call_output_content_done_event.rb', line 38 required :sequence_number, Integer |
#type ⇒ Symbol, :"response.shell_call_output_content.done"
The type of the event, always response.shell_call_output_content.done.
44 |
# File 'lib/openai/models/responses/response_shell_call_output_content_done_event.rb', line 44 required :type, const: :"response.shell_call_output_content.done" |
Instance Method Details
#to_hash ⇒ {
36 |
# File 'sig/openai/models/responses/response_shell_call_output_content_done_event.rbs', line 36
def to_hash: -> {
|