Class: OpenAI::Models::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput
- Defined in:
- lib/openai/models/responses/response_steer_input.rb,
sig/openai/models/responses/response_steer_input.rbs
Defined Under Namespace
Modules: Caller, Output, Status
Instance Attribute Summary collapse
-
#call_id ⇒ String?
The unique ID of the function tool call generated by the model.
-
#caller_ ⇒ OpenAI::Models::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
-
#id ⇒ String?
The unique ID of the function tool call output.
-
#name ⇒ String?
The name of the tool that produced the output.
-
#namespace ⇒ String?
The namespace of the tool that produced the output.
-
#output ⇒ String, Array<OpenAI::Models::Responses::ResponseInputTextContent, OpenAI::Models::Responses::ResponseInputImageContent, OpenAI::Models::Responses::ResponseInputFileContent>
Text, image, or file output of the function tool call.
-
#status ⇒ Symbol, ...
The status of the item.
-
#type ⇒ Symbol, :function_call_output
The type of the function tool call output.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(caller_id:, type: :program) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_steer_input.rb', line 182
|
Instance Attribute Details
#call_id ⇒ String?
The unique ID of the function tool call generated by the model.
142 |
# File 'lib/openai/models/responses/response_steer_input.rb', line 142 optional :call_id, String, nil?: true |
#caller_ ⇒ OpenAI::Models::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Caller::Direct, ...
The execution context that produced this tool call.
148 149 150 151 152 153 154 155 |
# File 'lib/openai/models/responses/response_steer_input.rb', line 148 optional( :caller_, union: -> { OpenAI::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Caller }, api_name: :caller, nil?: true ) |
#id ⇒ String?
The unique ID of the function tool call output. Populated when this item is returned via API.
136 |
# File 'lib/openai/models/responses/response_steer_input.rb', line 136 optional :id, String, nil?: true |
#name ⇒ String?
The name of the tool that produced the output.
161 |
# File 'lib/openai/models/responses/response_steer_input.rb', line 161 optional :name, String, nil?: true |
#namespace ⇒ String?
The namespace of the tool that produced the output.
167 |
# File 'lib/openai/models/responses/response_steer_input.rb', line 167 optional :namespace, String, nil?: true |
#output ⇒ String, Array<OpenAI::Models::Responses::ResponseInputTextContent, OpenAI::Models::Responses::ResponseInputImageContent, OpenAI::Models::Responses::ResponseInputFileContent>
Text, image, or file output of the function tool call.
118 119 120 121 122 123 |
# File 'lib/openai/models/responses/response_steer_input.rb', line 118 required( :output, union: -> { OpenAI::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Output } ) |
#status ⇒ Symbol, ...
The status of the item. One of in_progress, completed, or incomplete.
Populated when items are returned via API.
174 175 176 177 178 179 180 |
# File 'lib/openai/models/responses/response_steer_input.rb', line 174 optional( :status, enum: -> { OpenAI::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Status }, nil?: true ) |
#type ⇒ Symbol, :function_call_output
The type of the function tool call output. Always function_call_output.
129 |
# File 'lib/openai/models/responses/response_steer_input.rb', line 129 required :type, const: :function_call_output |
Class Method Details
.variants ⇒ Array(OpenAI::Models::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Caller::Direct, OpenAI::Models::Responses::ResponseSteerInput::ResponseSteerInputItemList::FunctionCallOutput::Caller::Program)
|
|
# File 'lib/openai/models/responses/response_steer_input.rb', line 223
|
Instance Method Details
#to_hash ⇒ {
107 |
# File 'sig/openai/models/responses/response_steer_input.rbs', line 107
def to_hash: -> {
|