Class: OpenAI::Models::Responses::ResponseToolSearchCall
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseToolSearchCall
- Defined in:
- lib/openai/models/responses/response_tool_search_call.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#arguments ⇒ Object
Arguments used for the tool search call.
-
#call_id ⇒ String?
The unique ID of the tool search call generated by the model.
-
#created_by ⇒ String?
The identifier of the actor that created the item.
-
#execution ⇒ Symbol, OpenAI::Models::Responses::ResponseToolSearchCall::Execution
Whether tool search was executed by the server or by the client.
-
#id ⇒ String
The unique ID of the tool search call item.
-
#status ⇒ Symbol, OpenAI::Models::Responses::ResponseToolSearchCall::Status
The status of the tool search call item that was recorded.
-
#type ⇒ Symbol, :tool_search_call
The type of the item.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, arguments:, call_id:, execution:, status:, created_by: nil, type: :tool_search_call) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 49
|
Instance Attribute Details
#arguments ⇒ Object
Arguments used for the tool search call.
17 |
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 17 required :arguments, OpenAI::Internal::Type::Unknown |
#call_id ⇒ String?
The unique ID of the tool search call generated by the model.
23 |
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 23 required :call_id, String, nil?: true |
#created_by ⇒ String?
The identifier of the actor that created the item.
47 |
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 47 optional :created_by, String |
#execution ⇒ Symbol, OpenAI::Models::Responses::ResponseToolSearchCall::Execution
Whether tool search was executed by the server or by the client.
29 |
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 29 required :execution, enum: -> { OpenAI::Responses::ResponseToolSearchCall::Execution } |
#id ⇒ String
The unique ID of the tool search call item.
11 |
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 11 required :id, String |
#status ⇒ Symbol, OpenAI::Models::Responses::ResponseToolSearchCall::Status
The status of the tool search call item that was recorded.
35 |
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 35 required :status, enum: -> { OpenAI::Responses::ResponseToolSearchCall::Status } |
#type ⇒ Symbol, :tool_search_call
The type of the item. Always tool_search_call.
41 |
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 41 required :type, const: :tool_search_call |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/response_tool_search_call.rb', line 73
|