Class: OpenAI::Models::Responses::ResponseToolSearchOutputItemParam
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponseToolSearchOutputItemParam
- Defined in:
- lib/openai/models/responses/response_tool_search_output_item_param.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#call_id ⇒ String?
The unique ID of the tool search call generated by the model.
-
#execution ⇒ Symbol, ...
Whether tool search was executed by the server or by the client.
-
#id ⇒ String?
The unique ID of this tool search output.
-
#status ⇒ Symbol, ...
The status of the tool search output.
-
#tools ⇒ Array<OpenAI::Models::Responses::FunctionTool, OpenAI::Models::Responses::FileSearchTool, OpenAI::Models::Responses::ComputerTool, OpenAI::Models::Responses::ComputerUsePreviewTool, OpenAI::Models::Responses::Tool::Mcp, OpenAI::Models::Responses::Tool::CodeInterpreter, OpenAI::Models::Responses::Tool::ImageGeneration, OpenAI::Models::Responses::Tool::LocalShell, OpenAI::Models::Responses::FunctionShellTool, OpenAI::Models::Responses::CustomTool, OpenAI::Models::Responses::NamespaceTool, OpenAI::Models::Responses::ToolSearchTool, OpenAI::Models::Responses::ApplyPatchTool, OpenAI::Models::Responses::WebSearchTool, OpenAI::Models::Responses::WebSearchPreviewTool>
The loaded tool definitions returned by the tool search output.
-
#type ⇒ Symbol, :tool_search_output
The item type.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(tools:, id: nil, call_id: nil, execution: nil, status: nil, type: :tool_search_output) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tools:, id: nil, call_id: nil, execution: nil, status: nil, type: :tool_search_output) ⇒ Object
|
|
# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 47
|
Instance Attribute Details
#call_id ⇒ String?
The unique ID of the tool search call generated by the model.
29 |
# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 29 optional :call_id, String, nil?: true |
#execution ⇒ Symbol, ...
Whether tool search was executed by the server or by the client.
35 |
# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 35 optional :execution, enum: -> { OpenAI::Responses::ResponseToolSearchOutputItemParam::Execution } |
#id ⇒ String?
The unique ID of this tool search output.
23 |
# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 23 optional :id, String, nil?: true |
#status ⇒ Symbol, ...
The status of the tool search output.
41 42 43 44 45 |
# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 41 optional :status, enum: -> { OpenAI::Responses::ResponseToolSearchOutputItemParam::Status }, nil?: true |
#tools ⇒ Array<OpenAI::Models::Responses::FunctionTool, OpenAI::Models::Responses::FileSearchTool, OpenAI::Models::Responses::ComputerTool, OpenAI::Models::Responses::ComputerUsePreviewTool, OpenAI::Models::Responses::Tool::Mcp, OpenAI::Models::Responses::Tool::CodeInterpreter, OpenAI::Models::Responses::Tool::ImageGeneration, OpenAI::Models::Responses::Tool::LocalShell, OpenAI::Models::Responses::FunctionShellTool, OpenAI::Models::Responses::CustomTool, OpenAI::Models::Responses::NamespaceTool, OpenAI::Models::Responses::ToolSearchTool, OpenAI::Models::Responses::ApplyPatchTool, OpenAI::Models::Responses::WebSearchTool, OpenAI::Models::Responses::WebSearchPreviewTool>
The loaded tool definitions returned by the tool search output.
11 |
# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 11 required :tools, -> { OpenAI::Internal::Type::ArrayOf[union: OpenAI::Responses::Tool] } |
#type ⇒ Symbol, :tool_search_output
The item type. Always tool_search_output.
17 |
# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 17 required :type, const: :tool_search_output |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/response_tool_search_output_item_param.rb', line 69
|