Class: OpenAI::Models::Responses::ResponsesClientEvent::ResponseCreate::AccessPrograms
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponsesClientEvent::ResponseCreate::AccessPrograms
- Defined in:
- lib/openai/models/responses/responses_client_event.rb,
sig/openai/models/responses/responses_client_event.rbs
Overview
Defined Under Namespace
Modules: Cyber
Instance Attribute Summary collapse
-
#cyber ⇒ OpenAI::Models::Responses::ResponsesClientEvent::ResponseCreate::AccessPrograms::cyber?
The Cyber access program to use for this request.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(cyber: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cyber: nil) ⇒ Object
|
|
# File 'lib/openai/models/responses/responses_client_event.rb', line 763
|
Instance Attribute Details
#cyber ⇒ OpenAI::Models::Responses::ResponsesClientEvent::ResponseCreate::AccessPrograms::cyber?
The Cyber access program to use for this request. Supported values are
standard, daybreak_blue, and daybreak_red. If omitted, the API resolves
the program from the model's Cyber tier and your organization and project
access, subject to model-specific eligibility restrictions. By default, models
without a Cyber tier use Standard. Blue-tier models use Daybreak Blue when
authorized; otherwise they fall back to Standard unless the model requires
Daybreak access. Red-tier models use Daybreak Red and require authorization.
Requests that require unavailable Daybreak access return 403. An implicit
Standard fallback is represented by null in the response's access_programs
field, rather than an explicit Standard selection.
758 759 760 761 |
# File 'lib/openai/models/responses/responses_client_event.rb', line 758 optional( :cyber, enum: -> { OpenAI::Responses::ResponsesClientEvent::ResponseCreate::AccessPrograms::Cyber } ) |
Instance Method Details
#to_hash ⇒ {
763 |
# File 'sig/openai/models/responses/responses_client_event.rbs', line 763 def to_hash: -> { |