Class: OpenAI::Models::Responses::ResponsesServerEvent::ResponseWsError::Error
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ResponsesServerEvent::ResponseWsError::Error
- Defined in:
- lib/openai/models/responses/responses_server_event.rb,
sig/openai/models/responses/responses_server_event.rbs
Overview
Defined Under Namespace
Classes: Misalignment
Instance Attribute Summary collapse
-
#code ⇒ String?
The error code that was emitted, if any.
-
#headers ⇒ ::Hash[Symbol, String]?
The response headers that were emitted with the error, if any.
-
#message ⇒ String
The human-readable error message that was emitted.
- #misalignment ⇒ OpenAI::Models::Responses::ResponsesServerEvent::ResponseWsError::Error::Misalignment?
-
#param ⇒ String?
The parameter name that was associated with the error, if any.
-
#type ⇒ String
The error type that was emitted.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(code:, message:, param:, type:, headers: nil, misalignment: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(code:, message:, param:, type:, headers: nil, misalignment: nil) ⇒ Object
|
|
# File 'lib/openai/models/responses/responses_server_event.rb', line 2224
|
Instance Attribute Details
#code ⇒ String?
The error code that was emitted, if any.
2190 |
# File 'lib/openai/models/responses/responses_server_event.rb', line 2190 required :code, String, nil?: true |
#headers ⇒ ::Hash[Symbol, String]?
The response headers that were emitted with the error, if any.
2214 |
# File 'lib/openai/models/responses/responses_server_event.rb', line 2214 optional :headers, OpenAI::Internal::Type::HashOf[String] |
#message ⇒ String
The human-readable error message that was emitted.
2196 |
# File 'lib/openai/models/responses/responses_server_event.rb', line 2196 required :message, String |
#misalignment ⇒ OpenAI::Models::Responses::ResponsesServerEvent::ResponseWsError::Error::Misalignment?
2219 2220 2221 2222 |
# File 'lib/openai/models/responses/responses_server_event.rb', line 2219 optional( :misalignment, -> { OpenAI::Responses::ResponsesServerEvent::ResponseWsError::Error::Misalignment } ) |
#param ⇒ String?
The parameter name that was associated with the error, if any.
2202 |
# File 'lib/openai/models/responses/responses_server_event.rb', line 2202 required :param, String, nil?: true |
#type ⇒ String
The error type that was emitted.
2208 |
# File 'lib/openai/models/responses/responses_server_event.rb', line 2208 required :type, String |
Instance Method Details
#to_hash ⇒ {
3064 |
# File 'sig/openai/models/responses/responses_server_event.rbs', line 3064 def to_hash: -> { |