Class: OpenAI::Models::Responses::Tool::CodeInterpreter::Container::CodeInterpreterToolAuto

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/tool.rb,
sig/openai/models/responses/tool.rbs

Defined Under Namespace

Modules: MemoryLimit, NetworkPolicy

Instance Attribute Summary collapse

Attributes inherited from Internal::Type::BaseModel

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, coerce_with_error, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(file_ids: nil, memory_limit: nil, network_policy: nil, type: :auto) ⇒ Object

Configuration for a code interpreter container. Optionally specify the IDs of the files to run the code on.

Parameters:



# File 'lib/openai/models/responses/tool.rb', line 488

Instance Attribute Details

#file_idsArray<String>?

An optional list of uploaded files to make available to your code.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


463
# File 'lib/openai/models/responses/tool.rb', line 463

optional :file_ids, OpenAI::Internal::Type::ArrayOf[String]

#memory_limitSymbol, ...

The memory limit for the code interpreter container.

Parameters:

  • value (OpenAI::Models::Responses::Tool::CodeInterpreter::Container::CodeInterpreterToolAuto::memory_limit, nil)

Returns:



469
470
471
472
473
474
475
# File 'lib/openai/models/responses/tool.rb', line 469

optional(
  :memory_limit,
  enum: -> {
    OpenAI::Responses::Tool::CodeInterpreter::Container::CodeInterpreterToolAuto::MemoryLimit
  },
  nil?: true
)

#network_policyOpenAI::Models::Responses::ContainerNetworkPolicyDisabled, ...

Network access policy for the container.



481
482
483
484
485
486
# File 'lib/openai/models/responses/tool.rb', line 481

optional(
  :network_policy,
  union: -> {
    OpenAI::Responses::Tool::CodeInterpreter::Container::CodeInterpreterToolAuto::NetworkPolicy
  }
)

#typeSymbol, :auto

Always auto.

Parameters:

  • value (:auto)

Returns:

  • (Symbol, :auto)


457
# File 'lib/openai/models/responses/tool.rb', line 457

required :type, const: :auto

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/responses/tool.rb', line 511

Instance Method Details

#to_hash{

Returns:

  • ({)


331
# File 'sig/openai/models/responses/tool.rbs', line 331

def to_hash: -> {