Class: OpenAI::Models::Responses::Tool::CodeInterpreter::Container::CodeInterpreterToolAuto
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::Tool::CodeInterpreter::Container::CodeInterpreterToolAuto
- Defined in:
- lib/openai/models/responses/tool.rb,
sig/openai/models/responses/tool.rbs
Defined Under Namespace
Modules: MemoryLimit, NetworkPolicy
Instance Attribute Summary collapse
-
#file_ids ⇒ ::Array[String]?
An optional list of uploaded files to make available to your code.
-
#memory_limit ⇒ OpenAI::Models::Responses::Tool::CodeInterpreter::Container::CodeInterpreterToolAuto::memory_limit?
The memory limit for the code interpreter container.
-
#network_policy ⇒ OpenAI::Models::Responses::Tool::CodeInterpreter::Container::CodeInterpreterToolAuto::network_policy?
Network access policy for the container.
-
#type ⇒ :auto
Always
auto.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(file_ids: nil, memory_limit: nil, network_policy: nil, type: :auto) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(file_ids: nil, memory_limit: nil, network_policy: nil, type: :auto) ⇒ Object
|
|
# File 'lib/openai/models/responses/tool.rb', line 534
|
Instance Attribute Details
#file_ids ⇒ ::Array[String]?
An optional list of uploaded files to make available to your code.
509 |
# File 'lib/openai/models/responses/tool.rb', line 509 optional :file_ids, OpenAI::Internal::Type::ArrayOf[String] |
#memory_limit ⇒ OpenAI::Models::Responses::Tool::CodeInterpreter::Container::CodeInterpreterToolAuto::memory_limit?
The memory limit for the code interpreter container.
515 516 517 518 519 520 521 |
# File 'lib/openai/models/responses/tool.rb', line 515 optional( :memory_limit, enum: -> { OpenAI::Responses::Tool::CodeInterpreter::Container::CodeInterpreterToolAuto::MemoryLimit }, nil?: true ) |
#network_policy ⇒ OpenAI::Models::Responses::Tool::CodeInterpreter::Container::CodeInterpreterToolAuto::network_policy?
Network access policy for the container.
527 528 529 530 531 532 |
# File 'lib/openai/models/responses/tool.rb', line 527 optional( :network_policy, union: -> { OpenAI::Responses::Tool::CodeInterpreter::Container::CodeInterpreterToolAuto::NetworkPolicy } ) |
#type ⇒ :auto
Always auto.
503 |
# File 'lib/openai/models/responses/tool.rb', line 503 required :type, const: :auto |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/openai/models/responses/tool.rb', line 561
|
Instance Method Details
#to_hash ⇒ {
533 |
# File 'sig/openai/models/responses/tool.rbs', line 533
def to_hash: -> {
|