Class: OpenAI::Models::Responses::Tool::ImageGeneration

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/tool.rb

Defined Under Namespace

Modules: Action, Background, InputFidelity, Model, Moderation, OutputFormat, Quality, Size Classes: InputImageMask

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(file_id: nil, image_url: nil) ⇒ Object

Some parameter documentations has been truncated, see InputImageMask for more details.

Optional mask for inpainting. Contains image_url (string, optional) and file_id (string, optional).

Parameters:

  • file_id (String) (defaults to: nil)

    File ID for the mask image.

  • image_url (String) (defaults to: nil)

    Base64-encoded mask image.



# File 'lib/openai/models/responses/tool.rb', line 570


Instance Attribute Details

#actionSymbol, ...

Whether to generate a new image or edit an existing image. Default: auto.



495
# File 'lib/openai/models/responses/tool.rb', line 495

optional :action, enum: -> { OpenAI::Responses::Tool::ImageGeneration::Action }

#backgroundSymbol, ...

Background type for the generated image. One of transparent, opaque, or auto. Default: auto.



502
# File 'lib/openai/models/responses/tool.rb', line 502

optional :background, enum: -> { OpenAI::Responses::Tool::ImageGeneration::Background }

#input_fidelitySymbol, ...

Control how much effort the model will exert to match the style and features, especially facial features, of input images. This parameter is only supported for gpt-image-1 and gpt-image-1.5 and later models, unsupported for gpt-image-1-mini. Supports high and low. Defaults to low.



511
512
513
514
515
# File 'lib/openai/models/responses/tool.rb', line 511

optional :input_fidelity,
enum: -> {
  OpenAI::Responses::Tool::ImageGeneration::InputFidelity
},
nil?: true

#input_image_maskOpenAI::Models::Responses::Tool::ImageGeneration::InputImageMask?

Optional mask for inpainting. Contains image_url (string, optional) and file_id (string, optional).



522
# File 'lib/openai/models/responses/tool.rb', line 522

optional :input_image_mask, -> { OpenAI::Responses::Tool::ImageGeneration::InputImageMask }

#modelString, ...

The image generation model to use. Default: gpt-image-1.



528
# File 'lib/openai/models/responses/tool.rb', line 528

optional :model, union: -> { OpenAI::Responses::Tool::ImageGeneration::Model }

#moderationSymbol, ...

Moderation level for the generated image. Default: auto.



534
# File 'lib/openai/models/responses/tool.rb', line 534

optional :moderation, enum: -> { OpenAI::Responses::Tool::ImageGeneration::Moderation }

#output_compressionInteger?

Compression level for the output image. Default: 100.

Returns:

  • (Integer, nil)


540
# File 'lib/openai/models/responses/tool.rb', line 540

optional :output_compression, Integer

#output_formatSymbol, ...

The output format of the generated image. One of png, webp, or jpeg. Default: png.



547
# File 'lib/openai/models/responses/tool.rb', line 547

optional :output_format, enum: -> { OpenAI::Responses::Tool::ImageGeneration::OutputFormat }

#partial_imagesInteger?

Number of partial images to generate in streaming mode, from 0 (default value) to 3.

Returns:

  • (Integer, nil)


554
# File 'lib/openai/models/responses/tool.rb', line 554

optional :partial_images, Integer

#qualitySymbol, ...

The quality of the generated image. One of low, medium, high, or auto. Default: auto.



561
# File 'lib/openai/models/responses/tool.rb', line 561

optional :quality, enum: -> { OpenAI::Responses::Tool::ImageGeneration::Quality }

#sizeSymbol, ...

The size of the generated image. One of 1024x1024, 1024x1536, 1536x1024, or auto. Default: auto.



568
# File 'lib/openai/models/responses/tool.rb', line 568

optional :size, enum: -> { OpenAI::Responses::Tool::ImageGeneration::Size }

#typeSymbol, :image_generation

The type of the image generation tool. Always image_generation.

Returns:

  • (Symbol, :image_generation)


489
# File 'lib/openai/models/responses/tool.rb', line 489

required :type, const: :image_generation

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/openai/models/responses/tool.rb', line 610