Class: OpenAI::Models::Responses::ToolSearchTool
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Responses::ToolSearchTool
- Defined in:
- lib/openai/models/responses/tool_search_tool.rb
Defined Under Namespace
Modules: Execution
Instance Attribute Summary collapse
-
#description ⇒ String?
Description shown to the model for a client-executed tool search tool.
-
#execution ⇒ Symbol, ...
Whether tool search is executed by the server or by the client.
-
#parameters ⇒ Object?
Parameter schema for a client-executed tool search tool.
-
#type ⇒ Symbol, :tool_search
The type of the tool.
Instance Method Summary collapse
-
#initialize(description: nil, execution: nil, parameters: nil, type: :tool_search) ⇒ Object
constructor
Hosted or BYOT tool search configuration for deferred tools.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(description: nil, execution: nil, parameters: nil, type: :tool_search) ⇒ Object
Hosted or BYOT tool search configuration for deferred tools.
|
|
# File 'lib/openai/models/responses/tool_search_tool.rb', line 31
|
Instance Attribute Details
#description ⇒ String?
Description shown to the model for a client-executed tool search tool.
17 |
# File 'lib/openai/models/responses/tool_search_tool.rb', line 17 optional :description, String, nil?: true |
#execution ⇒ Symbol, ...
Whether tool search is executed by the server or by the client.
23 |
# File 'lib/openai/models/responses/tool_search_tool.rb', line 23 optional :execution, enum: -> { OpenAI::Responses::ToolSearchTool::Execution } |
#parameters ⇒ Object?
Parameter schema for a client-executed tool search tool.
29 |
# File 'lib/openai/models/responses/tool_search_tool.rb', line 29 optional :parameters, OpenAI::Internal::Type::Unknown, nil?: true |
#type ⇒ Symbol, :tool_search
The type of the tool. Always tool_search.
11 |
# File 'lib/openai/models/responses/tool_search_tool.rb', line 11 required :type, const: :tool_search |