Class: OpenAI::Models::Responses::WebSearchPreviewTool

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/openai/models/responses/web_search_preview_tool.rb

Defined Under Namespace

Modules: SearchContentType, SearchContextSize, Type Classes: UserLocation

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type:, search_content_types: nil, search_context_size: nil, user_location: nil) ⇒ Object

Some parameter documentations has been truncated, see OpenAI::Models::Responses::WebSearchPreviewTool for more details.

This tool searches the web for relevant results to use in a response. Learn more about the [web search tool](platform.openai.com/docs/guides/tools-web-search).

Parameters:

  • The type of the web search tool. One of web_search_preview or ‘web_search_prev

  • (defaults to: nil)
  • (defaults to: nil)

    High level guidance for the amount of context window space to use for the search

  • (defaults to: nil)

    The user’s location.



# File 'lib/openai/models/responses/web_search_preview_tool.rb', line 33


Instance Attribute Details

#search_content_typesArray<Symbol, OpenAI::Models::Responses::WebSearchPreviewTool::SearchContentType>?

Returns:



17
18
# File 'lib/openai/models/responses/web_search_preview_tool.rb', line 17

optional :search_content_types,
-> { OpenAI::Internal::Type::ArrayOf[enum: OpenAI::Responses::WebSearchPreviewTool::SearchContentType] }

#search_context_sizeSymbol, ...

High level guidance for the amount of context window space to use for the search. One of low, medium, or high. medium is the default.

Returns:



25
# File 'lib/openai/models/responses/web_search_preview_tool.rb', line 25

optional :search_context_size, enum: -> { OpenAI::Responses::WebSearchPreviewTool::SearchContextSize }

#typeSymbol, OpenAI::Models::Responses::WebSearchPreviewTool::Type

The type of the web search tool. One of web_search_preview or web_search_preview_2025_03_11.

Returns:



12
# File 'lib/openai/models/responses/web_search_preview_tool.rb', line 12

required :type, enum: -> { OpenAI::Responses::WebSearchPreviewTool::Type }

#user_locationOpenAI::Models::Responses::WebSearchPreviewTool::UserLocation?

The user’s location.

Returns:



31
# File 'lib/openai/models/responses/web_search_preview_tool.rb', line 31

optional :user_location, -> { OpenAI::Responses::WebSearchPreviewTool::UserLocation }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:



# File 'lib/openai/models/responses/web_search_preview_tool.rb', line 59