Class: OpenAI::Models::UploadCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/openai/models/upload_create_params.rb,
sig/openai/models/upload_create_params.rbs

Overview

See Also:

  • OpenAI::Resources::Uploads#create

Defined Under Namespace

Classes: ExpiresAfter

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



31
# File 'sig/openai/models/upload_create_params.rbs', line 31

def initialize: (

Instance Attribute Details

#bytesInteger

The number of bytes in the file you are uploading.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


14
# File 'lib/openai/models/upload_create_params.rb', line 14

required :bytes, Integer

#expires_afterOpenAI::Models::UploadCreateParams::ExpiresAfter?

The expiration policy for a file. By default, files with purpose=batch expire after 30 days and all other files are persisted until they are manually deleted.



45
# File 'lib/openai/models/upload_create_params.rb', line 45

optional :expires_after, -> { OpenAI::UploadCreateParams::ExpiresAfter }

#filenameString

The name of the file to upload.

Parameters:

  • value (String)

Returns:

  • (String)


20
# File 'lib/openai/models/upload_create_params.rb', line 20

required :filename, String

#mime_typeString

The MIME type of the file.

This must fall within the supported MIME types for your file purpose. See the supported MIME types for assistants and vision.

Parameters:

  • value (String)

Returns:

  • (String)


29
# File 'lib/openai/models/upload_create_params.rb', line 29

required :mime_type, String

#purposeSymbol, OpenAI::Models::FilePurpose

The intended purpose of the uploaded file.

See the documentation on File purposes.

Parameters:

  • value (OpenAI::Models::file_purpose)

Returns:



38
# File 'lib/openai/models/upload_create_params.rb', line 38

required :purpose, enum: -> { OpenAI::FilePurpose }

Instance Method Details

#to_hash{

Returns:

  • ({)


40
# File 'sig/openai/models/upload_create_params.rbs', line 40

def to_hash: -> {