Class: OpenAI::Models::Uploads::UploadPart
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Uploads::UploadPart
- Defined in:
- lib/openai/models/uploads/upload_part.rb,
sig/openai/models/uploads/upload_part.rbs
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ Integer
The Unix timestamp (in seconds) for when the Part was created.
-
#id ⇒ String
The upload Part unique identifier, which can be referenced in API endpoints.
-
#object ⇒ Symbol, :"upload.part"
The object type, which is always
upload.part. -
#upload_id ⇒ String
The ID of the Upload object that this Part was added to.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
23 |
# File 'sig/openai/models/uploads/upload_part.rbs', line 23
def initialize: (
|
Instance Attribute Details
#created_at ⇒ Integer
The Unix timestamp (in seconds) for when the Part was created.
18 |
# File 'lib/openai/models/uploads/upload_part.rb', line 18 required :created_at, Integer |
#id ⇒ String
The upload Part unique identifier, which can be referenced in API endpoints.
12 |
# File 'lib/openai/models/uploads/upload_part.rb', line 12 required :id, String |
#object ⇒ Symbol, :"upload.part"
The object type, which is always upload.part.
24 |
# File 'lib/openai/models/uploads/upload_part.rb', line 24 required :object, const: :"upload.part" |
#upload_id ⇒ String
The ID of the Upload object that this Part was added to.
30 |
# File 'lib/openai/models/uploads/upload_part.rb', line 30 required :upload_id, String |
Instance Method Details
#to_hash ⇒ {
30 |
# File 'sig/openai/models/uploads/upload_part.rbs', line 30
def to_hash: -> {
|