Class: OpenAI::Models::VectorStoreSearchResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::VectorStoreSearchResponse
- Defined in:
- lib/openai/models/vector_store_search_response.rb,
sig/openai/models/vector_store_search_response.rbs
Overview
Defined Under Namespace
Modules: Attribute Classes: Content
Instance Attribute Summary collapse
-
#attributes ⇒ Hash{Symbol=>String, Float, Boolean}?
Set of 16 key-value pairs that can be attached to an object.
-
#content ⇒ Array<OpenAI::Models::VectorStoreSearchResponse::Content>
Content chunks from the file.
-
#file_id ⇒ String
The ID of the vector store file.
-
#filename ⇒ String
The name of the vector store file.
-
#score ⇒ Float
The similarity score for the result.
Attributes inherited from Internal::Type::BaseModel
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
23 |
# File 'sig/openai/models/vector_store_search_response.rbs', line 23
def initialize: (
|
Instance Attribute Details
#attributes ⇒ Hash{Symbol=>String, Float, Boolean}?
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard. Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters, booleans, or numbers.
15 16 17 18 19 |
# File 'lib/openai/models/vector_store_search_response.rb', line 15 required :attributes, -> { OpenAI::Internal::Type::HashOf[union: OpenAI::Models::VectorStoreSearchResponse::Attribute] }, nil?: true |
#content ⇒ Array<OpenAI::Models::VectorStoreSearchResponse::Content>
Content chunks from the file.
25 26 |
# File 'lib/openai/models/vector_store_search_response.rb', line 25 required :content, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Models::VectorStoreSearchResponse::Content] } |
#file_id ⇒ String
The ID of the vector store file.
32 |
# File 'lib/openai/models/vector_store_search_response.rb', line 32 required :file_id, String |
#filename ⇒ String
The name of the vector store file.
38 |
# File 'lib/openai/models/vector_store_search_response.rb', line 38 required :filename, String |
#score ⇒ Float
The similarity score for the result.
44 |
# File 'lib/openai/models/vector_store_search_response.rb', line 44 required :score, Float |
Class Method Details
.variants ⇒ Array(String, Float, Boolean)
|
|
# File 'lib/openai/models/vector_store_search_response.rb', line 69
|
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/openai/models/vector_store_search_response.rbs', line 31
def to_hash: -> {
|