Class: OpenAI::Models::VectorStores::FileBatchCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::VectorStores::FileBatchCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/openai/models/vector_stores/file_batch_create_params.rb
Overview
Defined Under Namespace
Modules: Attribute Classes: File
Instance Attribute Summary collapse
-
#attributes ⇒ Hash{Symbol=>String, Float, Boolean}?
Set of 16 key-value pairs that can be attached to an object.
-
#chunking_strategy ⇒ OpenAI::Models::AutoFileChunkingStrategyParam, ...
The chunking strategy used to chunk the file(s).
-
#file_ids ⇒ Array<String>?
A list of [File](platform.openai.com/docs/api-reference/files) IDs that the vector store should use.
-
#files ⇒ Array<OpenAI::Models::VectorStores::FileBatchCreateParams::File>?
A list of objects that each include a
file_idplus optionalattributesorchunking_strategy. - #vector_store_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from OpenAI::Internal::Type::BaseModel
Instance Attribute Details
#attributes ⇒ Hash{Symbol=>String, Float, Boolean}?
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard. Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters, booleans, or numbers.
24 25 26 27 28 |
# File 'lib/openai/models/vector_stores/file_batch_create_params.rb', line 24 optional :attributes, -> { OpenAI::Internal::Type::HashOf[union: OpenAI::VectorStores::FileBatchCreateParams::Attribute] }, nil?: true |
#chunking_strategy ⇒ OpenAI::Models::AutoFileChunkingStrategyParam, ...
The chunking strategy used to chunk the file(s). If not set, will use the auto strategy. Only applicable if file_ids is non-empty.
35 |
# File 'lib/openai/models/vector_stores/file_batch_create_params.rb', line 35 optional :chunking_strategy, union: -> { OpenAI::FileChunkingStrategyParam } |
#file_ids ⇒ Array<String>?
A list of [File](platform.openai.com/docs/api-reference/files) IDs that the vector store should use. Useful for tools like file_search that can access files. If attributes or chunking_strategy are provided, they will be applied to all files in the batch. The maximum batch size is 2000 files. Mutually exclusive with files.
45 |
# File 'lib/openai/models/vector_stores/file_batch_create_params.rb', line 45 optional :file_ids, OpenAI::Internal::Type::ArrayOf[String] |
#files ⇒ Array<OpenAI::Models::VectorStores::FileBatchCreateParams::File>?
A list of objects that each include a file_id plus optional attributes or chunking_strategy. Use this when you need to override metadata for specific files. The global attributes or chunking_strategy will be ignored and must be specified for each file. The maximum batch size is 2000 files. Mutually exclusive with file_ids.
55 |
# File 'lib/openai/models/vector_stores/file_batch_create_params.rb', line 55 optional :files, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::VectorStores::FileBatchCreateParams::File] } |
#vector_store_id ⇒ String
14 |
# File 'lib/openai/models/vector_stores/file_batch_create_params.rb', line 14 required :vector_store_id, String |
Class Method Details
.variants ⇒ Array(String, Float, Boolean)
|
|
# File 'lib/openai/models/vector_stores/file_batch_create_params.rb', line 82
|