Class: OpenAI::Models::VectorStores::FileBatchCreateParams::File
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::VectorStores::FileBatchCreateParams::File
- Defined in:
- lib/openai/models/vector_stores/file_batch_create_params.rb,
sig/openai/models/vector_stores/file_batch_create_params.rbs
Defined Under Namespace
Modules: Attribute
Instance Attribute Summary collapse
-
#attributes ⇒ Hash{Symbol=>String, Float, Boolean}?
Set of 16 key-value pairs that can be attached to an object.
-
#chunking_strategy ⇒ OpenAI::Models::AutoFileChunkingStrategyParam, ...
The chunking strategy used to chunk the file(s).
-
#file_id ⇒ String
A File ID that the vector store should use.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
82 |
# File 'sig/openai/models/vector_stores/file_batch_create_params.rbs', line 82
def initialize: (
|
Instance Attribute Details
#attributes ⇒ Hash{Symbol=>String, Float, Boolean}?
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard. Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters, booleans, or numbers.
107 108 109 110 111 |
# File 'lib/openai/models/vector_stores/file_batch_create_params.rb', line 107 optional :attributes, -> { OpenAI::Internal::Type::HashOf[union: OpenAI::VectorStores::FileBatchCreateParams::File::Attribute] }, nil?: true |
#chunking_strategy ⇒ OpenAI::Models::AutoFileChunkingStrategyParam, ...
The chunking strategy used to chunk the file(s). If not set, will use the auto
strategy. Only applicable if file_ids is non-empty.
118 |
# File 'lib/openai/models/vector_stores/file_batch_create_params.rb', line 118 optional :chunking_strategy, union: -> { OpenAI::FileChunkingStrategyParam } |
#file_id ⇒ String
A File ID that the
vector store should use. Useful for tools like file_search that can access
files. For multi-file ingestion, we recommend
file_batches
to minimize per-vector-store write requests.
97 |
# File 'lib/openai/models/vector_stores/file_batch_create_params.rb', line 97 required :file_id, String |
Instance Method Details
#to_hash ⇒ {
88 |
# File 'sig/openai/models/vector_stores/file_batch_create_params.rbs', line 88
def to_hash: -> {
|