Class: OpenAI::Models::VectorStores::VectorStoreFileBatch::FileCounts
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::VectorStores::VectorStoreFileBatch::FileCounts
- Defined in:
- lib/openai/models/vector_stores/vector_store_file_batch.rb,
sig/openai/models/vector_stores/vector_store_file_batch.rbs
Overview
Instance Attribute Summary collapse
-
#cancelled ⇒ Integer
The number of files that where cancelled.
-
#completed ⇒ Integer
The number of files that have been processed.
-
#failed ⇒ Integer
The number of files that have failed to process.
-
#in_progress ⇒ Integer
The number of files that are currently being processed.
-
#total ⇒ Integer
The total number of files.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
67 |
# File 'sig/openai/models/vector_stores/vector_store_file_batch.rbs', line 67
def initialize: (
|
Instance Attribute Details
#cancelled ⇒ Integer
The number of files that where cancelled.
72 |
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 72 required :cancelled, Integer |
#completed ⇒ Integer
The number of files that have been processed.
78 |
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 78 required :completed, Integer |
#failed ⇒ Integer
The number of files that have failed to process.
84 |
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 84 required :failed, Integer |
#in_progress ⇒ Integer
The number of files that are currently being processed.
90 |
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 90 required :in_progress, Integer |
#total ⇒ Integer
The total number of files.
96 |
# File 'lib/openai/models/vector_stores/vector_store_file_batch.rb', line 96 required :total, Integer |
Instance Method Details
#to_hash ⇒ {
75 |
# File 'sig/openai/models/vector_stores/vector_store_file_batch.rbs', line 75
def to_hash: -> {
|