Class: OpenAI::Models::Webhooks::LiveTransportIncomingWebhookEvent::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Webhooks::LiveTransportIncomingWebhookEvent::Data
- Defined in:
- lib/openai/models/webhooks/live_transport_incoming_webhook_event.rb,
sig/openai/models/webhooks/live_transport_incoming_webhook_event.rbs
Overview
Defined Under Namespace
Classes: SipHeader
Instance Attribute Summary collapse
-
#session_id ⇒ String
The
live_...ID of the pending SIP session. -
#sip_headers ⇒ Array<OpenAI::Models::Webhooks::LiveTransportIncomingWebhookEvent::Data::SipHeader>
Headers from the SIP INVITE, excluding SIP authorization headers.
-
#type ⇒ Symbol, :sip
The incoming transport type.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
58 |
# File 'sig/openai/models/webhooks/live_transport_incoming_webhook_event.rbs', line 58
def initialize: (
|
Instance Attribute Details
#session_id ⇒ String
The live_... ID of the pending SIP session. Forward this value unchanged when
accepting or rejecting the call through the Live API.
64 |
# File 'lib/openai/models/webhooks/live_transport_incoming_webhook_event.rb', line 64 required :session_id, String |
#sip_headers ⇒ Array<OpenAI::Models::Webhooks::LiveTransportIncomingWebhookEvent::Data::SipHeader>
Headers from the SIP INVITE, excluding SIP authorization headers. Retained names, values, repeated entries, and order are preserved. Treat these values as untrusted call metadata.
72 73 74 75 76 77 |
# File 'lib/openai/models/webhooks/live_transport_incoming_webhook_event.rb', line 72 required( :sip_headers, -> { OpenAI::Internal::Type::ArrayOf[OpenAI::Webhooks::LiveTransportIncomingWebhookEvent::Data::SipHeader] } ) |
#type ⇒ Symbol, :sip
The incoming transport type. Always sip.
83 |
# File 'lib/openai/models/webhooks/live_transport_incoming_webhook_event.rb', line 83 required :type, const: :sip |
Instance Method Details
#to_hash ⇒ {
64 |
# File 'sig/openai/models/webhooks/live_transport_incoming_webhook_event.rbs', line 64
def to_hash: -> {
|