Class: OpenAI::Models::Webhooks::SafetyWarningIssuedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- OpenAI::Models::Webhooks::SafetyWarningIssuedWebhookEvent
- Defined in:
- lib/openai/models/webhooks/safety_warning_issued_webhook_event.rb,
sig/openai/models/webhooks/safety_warning_issued_webhook_event.rbs
Defined Under Namespace
Classes: Data
Instance Attribute Summary collapse
-
#created_at ⇒ Integer
The Unix timestamp in seconds when the event was created.
- #data ⇒ OpenAI::Models::Webhooks::SafetyWarningIssuedWebhookEvent::Data
-
#id ⇒ String
The unique ID of the webhook event.
-
#object ⇒ :event
Always
event. -
#type ⇒ :"safety.warning_issued"
Always
safety.warning_issued.
Attributes inherited from Internal::Type::BaseModel
Instance Method Summary collapse
- #initialize(id:, created_at:, data:, object: :event, type: :"safety.warning_issued") ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], #_request_id, #_set_last_response, coerce, #deconstruct_keys, #deep_to_h, dump, #encode_with, fields, hash, #hash, inherited, #inspect, inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, coerce_with_error, dump, #dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, data:, object: :event, type: :"safety.warning_issued") ⇒ Object
|
|
# File 'lib/openai/models/webhooks/safety_warning_issued_webhook_event.rb', line 36
|
Instance Attribute Details
#created_at ⇒ Integer
The Unix timestamp in seconds when the event was created.
17 |
# File 'lib/openai/models/webhooks/safety_warning_issued_webhook_event.rb', line 17 required :created_at, Integer |
#data ⇒ OpenAI::Models::Webhooks::SafetyWarningIssuedWebhookEvent::Data
22 |
# File 'lib/openai/models/webhooks/safety_warning_issued_webhook_event.rb', line 22 required :data, -> { OpenAI::Webhooks::SafetyWarningIssuedWebhookEvent::Data } |
#id ⇒ String
The unique ID of the webhook event.
11 |
# File 'lib/openai/models/webhooks/safety_warning_issued_webhook_event.rb', line 11 required :id, String |
#object ⇒ :event
Always event.
28 |
# File 'lib/openai/models/webhooks/safety_warning_issued_webhook_event.rb', line 28 required :object, const: :event |
#type ⇒ :"safety.warning_issued"
Always safety.warning_issued.
34 |
# File 'lib/openai/models/webhooks/safety_warning_issued_webhook_event.rb', line 34 required :type, const: :"safety.warning_issued" |
Instance Method Details
#to_hash ⇒ {
44 |
# File 'sig/openai/models/webhooks/safety_warning_issued_webhook_event.rbs', line 44
def to_hash: -> {
|