Class: OpenAI::Resources::Admin::Organization::AuditLogs
- Inherits:
-
Object
- Object
- OpenAI::Resources::Admin::Organization::AuditLogs
- Defined in:
- lib/openai/resources/admin/organization/audit_logs.rb
Overview
List user actions and configuration changes within this organization.
Instance Method Summary collapse
-
#initialize(client:) ⇒ AuditLogs
constructor
private
A new instance of AuditLogs.
-
#list(actor_emails: nil, actor_ids: nil, after: nil, before: nil, effective_at: nil, event_types: nil, limit: nil, project_ids: nil, resource_ids: nil, request_options: {}) ⇒ OpenAI::Internal::ConversationCursorPage<OpenAI::Models::Admin::Organization::AuditLogListResponse>
Some parameter documentations has been truncated, see Models::Admin::Organization::AuditLogListParams for more details.
Constructor Details
#initialize(client:) ⇒ AuditLogs
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of AuditLogs.
56 57 58 |
# File 'lib/openai/resources/admin/organization/audit_logs.rb', line 56 def initialize(client:) @client = client end |
Instance Method Details
#list(actor_emails: nil, actor_ids: nil, after: nil, before: nil, effective_at: nil, event_types: nil, limit: nil, project_ids: nil, resource_ids: nil, request_options: {}) ⇒ OpenAI::Internal::ConversationCursorPage<OpenAI::Models::Admin::Organization::AuditLogListResponse>
Some parameter documentations has been truncated, see Models::Admin::Organization::AuditLogListParams for more details.
List user actions and configuration changes within this organization.
39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/openai/resources/admin/organization/audit_logs.rb', line 39 def list(params = {}) parsed, = OpenAI::Admin::Organization::AuditLogListParams.dump_request(params) query = OpenAI::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "organization/audit_logs", query: query, page: OpenAI::Internal::ConversationCursorPage, model: OpenAI::Models::Admin::Organization::AuditLogListResponse, security: {admin_api_key_auth: true}, options: ) end |