Class: OpenAI::Resources::Admin::Organization::Users::Roles

Inherits:
Object
  • Object
show all
Defined in:
lib/openai/resources/admin/organization/users/roles.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Roles

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Roles.

Parameters:



99
100
101
# File 'lib/openai/resources/admin/organization/users/roles.rb', line 99

def initialize(client:)
  @client = client
end

Instance Method Details

#create(user_id, role_id:, request_options: {}) ⇒ OpenAI::Models::Admin::Organization::Users::RoleCreateResponse

Assigns an organization role to a user within the organization.

Parameters:

  • user_id (String)

    The ID of the user that should receive the organization role.

  • role_id (String)

    Identifier of the role to assign.

  • request_options (OpenAI::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



22
23
24
25
26
27
28
29
30
31
32
# File 'lib/openai/resources/admin/organization/users/roles.rb', line 22

def create(user_id, params)
  parsed, options = OpenAI::Admin::Organization::Users::RoleCreateParams.dump_request(params)
  @client.request(
    method: :post,
    path: ["organization/users/%1$s/roles", user_id],
    body: parsed,
    model: OpenAI::Models::Admin::Organization::Users::RoleCreateResponse,
    security: {admin_api_key_auth: true},
    options: options
  )
end

#delete(role_id, user_id:, request_options: {}) ⇒ OpenAI::Models::Admin::Organization::Users::RoleDeleteResponse

Unassigns an organization role from a user within the organization.

Parameters:

  • role_id (String)

    The ID of the organization role to remove from the user.

  • user_id (String)

    The ID of the user to modify.

  • request_options (OpenAI::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/openai/resources/admin/organization/users/roles.rb', line 81

def delete(role_id, params)
  parsed, options = OpenAI::Admin::Organization::Users::RoleDeleteParams.dump_request(params)
  user_id =
    parsed.delete(:user_id) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :delete,
    path: ["organization/users/%1$s/roles/%2$s", user_id, role_id],
    model: OpenAI::Models::Admin::Organization::Users::RoleDeleteResponse,
    security: {admin_api_key_auth: true},
    options: options
  )
end

#list(user_id, after: nil, limit: nil, order: nil, request_options: {}) ⇒ OpenAI::Internal::NextCursorPage<OpenAI::Models::Admin::Organization::Users::RoleListResponse>

Some parameter documentations has been truncated, see Models::Admin::Organization::Users::RoleListParams for more details.

Lists the organization roles assigned to a user within the organization.

Parameters:

  • user_id (String)

    The ID of the user to inspect.

  • after (String)

    Cursor for pagination. Provide the value from the previous response’s ‘next` fie

  • limit (Integer)

    A limit on the number of organization role assignments to return.

  • order (Symbol, OpenAI::Models::Admin::Organization::Users::RoleListParams::Order)

    Sort order for the returned organization roles.

  • request_options (OpenAI::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/openai/resources/admin/organization/users/roles.rb', line 54

def list(user_id, params = {})
  parsed, options = OpenAI::Admin::Organization::Users::RoleListParams.dump_request(params)
  query = OpenAI::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: ["organization/users/%1$s/roles", user_id],
    query: query,
    page: OpenAI::Internal::NextCursorPage,
    model: OpenAI::Models::Admin::Organization::Users::RoleListResponse,
    security: {admin_api_key_auth: true},
    options: options
  )
end